package com.bsadutil;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import junit.framework.Assert;

import java.io.FileInputStream;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.List;
import java.util.ArrayList;

import com.bsadutil.core.Date;
import com.bsadutil.dict.Bs;
import com.bsadutil.dict.Ad;


class Pair<A, B> {
    public A a;
    public B b;
    public Pair(A a, B b) {
        this.a = a;
        this.b = b;
    }
}

/**
 * Unit test for simple App.
 */
public class AppTest extends TestCase {
    private Bs bs = new Bs();
    private Ad ad = new Ad();
    List<Pair<String, String>> datePairs = new ArrayList<Pair<String, String>>();

    public void testToString1() {
        Date<Bs> np = new Date<Bs>("2012-02-12", bs);
        assertEquals(np.toString(), "2012-02-12");
    };

    public void testToString2() {
        Date<Bs> np = new Date<Bs>(2019, 11, 2, bs);
        assertEquals(np.toString(), "2019-11-02");
    };

    public void testHigherMonthValue() {
        try {
            Date<Bs> np1 = new Date<Bs>("2012-13-12", bs);
            fail("Month value is out of range");
        } catch (Exception e) {
        }
    }

    public void testLowerMonthValue() {
        try {
            Date<Bs> np1 = new Date<Bs>(2012, 0, 12, bs);
            fail("Month value is out of range");
        } catch (Exception e) {
        }
    }

    public void testLowerDayValue() {
        try {
            Date<Bs> np1 = new Date<Bs>(2012, 0, -12, bs);
            fail("Day value is out of range");
        } catch (Exception e) {
        }
    }

    public void testBadFormat() {
        try {
            Date<Bs> np1 = new Date<Bs>("2012-12", bs);
            fail("Supplied date is not properly formatted");
        } catch (Exception e) {
        }
    }

    public void testAddYearOverflow1() {
        Date<Bs> np = new Date<Bs>("2073-12-31", bs);
        assertEquals(np.addYears(5).toString(), "2078-12-30");
    }

    public void testAddYearOverflow2() {
        Date<Bs> np = new Date<Bs>("2073-12-31", bs);
        assertEquals(np.addYears(5).toString(), "2078-12-30");
    }

    public void testAddYearNoOverflow1() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addYears(5).toString(), "2078-11-10");
    }

    public void testAddYearNoOverflow2() {
        Date<Bs> np = new Date<Bs>("2073-11-30", bs);
        assertEquals(np.addYears(1).toString(), "2074-11-30");
    }

    public void testAddYearNoOverflow3() {
        Date<Bs> np = new Date<Bs>("2062-11-29", bs);
        assertEquals(np.addYears(1).toString(), "2063-11-29");
    }

    public void testAddMonthNoOverflow1() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addMonths(1).toString(), "2073-12-10");
    }

    public void testAddMonthNoOverflow5() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addMonths(2).toString(), "2074-01-10");
    }

    public void testAddMonthNoOverflow2() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addMonths(3).toString(), "2074-02-10");
    }

    public void testAddMonthNoOverflow3() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addMonths(13).toString(), "2074-12-10");
    }

    public void testAddMonthNoOverflow4() {
        Date<Bs> np = new Date<Bs>("2058-05-31", bs);
        assertEquals(np.addMonths(12).toString(), "2059-05-31");
    }

    public void testAddMonthOverflow1() {
        Date<Bs> np = new Date<Bs>("2058-05-31", bs);
        assertEquals(np.addMonths(16).toString(), "2059-09-30");
    }

    public void testAddMonthOverflow2() {
        Date<Bs> np = new Date<Bs>("2056-09-30", bs);
        assertEquals(np.addMonths(24).toString(), "2058-09-29");
    }

    public void testAddMonthOverflow3() {
        Date<Bs> np = new Date<Bs>("2073-11-10", bs);
        assertEquals(np.addMonths(14).toString(), "2075-01-10");
    }

    public void testAddMonthOverflow4() {
        Date<Bs> np = new Date<Bs>("2073-11-30", bs);
        assertEquals(np.addMonths(2).toString(), "2074-01-30");
    }

    public void testAddMonthOverflow5() {
        Date<Bs> np = new Date<Bs>("2074-01-31", bs);
        assertEquals(np.addMonths(7).toString(), "2074-08-29");
    }

    public void testAddMonthOverflow6() {
        Date<Bs> np = new Date<Bs>("2074-04-32", bs);
        assertEquals(np.addMonths(4).toString(), "2074-08-29");
    }

    public void appendConversionValues1() {
        // Read date pairs
        datePairs.add(new Pair<String, String>("2063-12-16", "2007-03-30"));
        datePairs.add(new Pair<String, String>("2063-12-17", "2007-03-31"));
        datePairs.add(new Pair<String, String>("2063-12-18", "2007-04-01"));
        datePairs.add(new Pair<String, String>("2063-12-19", "2007-04-02"));
        datePairs.add(new Pair<String, String>("2063-12-20", "2007-04-03"));
        datePairs.add(new Pair<String, String>("2063-12-21", "2007-04-04"));
        datePairs.add(new Pair<String, String>("2063-12-22", "2007-04-05"));
        datePairs.add(new Pair<String, String>("2063-12-23", "2007-04-06"));
        datePairs.add(new Pair<String, String>("2063-12-24", "2007-04-07"));
        datePairs.add(new Pair<String, String>("2063-12-25", "2007-04-08"));
        datePairs.add(new Pair<String, String>("2063-12-26", "2007-04-09"));
        datePairs.add(new Pair<String, String>("2063-12-27", "2007-04-10"));
        datePairs.add(new Pair<String, String>("2063-12-28", "2007-04-11"));
        datePairs.add(new Pair<String, String>("2063-12-29", "2007-04-12"));
        datePairs.add(new Pair<String, String>("2063-12-30", "2007-04-13"));
        datePairs.add(new Pair<String, String>("2064-01-01", "2007-04-14"));
        datePairs.add(new Pair<String, String>("2064-01-02", "2007-04-15"));
        datePairs.add(new Pair<String, String>("2064-01-03", "2007-04-16"));
        datePairs.add(new Pair<String, String>("2064-01-04", "2007-04-17"));
        datePairs.add(new Pair<String, String>("2064-01-05", "2007-04-18"));
        datePairs.add(new Pair<String, String>("2064-01-06", "2007-04-19"));
        datePairs.add(new Pair<String, String>("2064-01-07", "2007-04-20"));
        datePairs.add(new Pair<String, String>("2064-01-08", "2007-04-21"));
        datePairs.add(new Pair<String, String>("2064-01-09", "2007-04-22"));
        datePairs.add(new Pair<String, String>("2064-01-10", "2007-04-23"));
        datePairs.add(new Pair<String, String>("2064-01-11", "2007-04-24"));
        datePairs.add(new Pair<String, String>("2064-01-12", "2007-04-25"));
        datePairs.add(new Pair<String, String>("2064-01-13", "2007-04-26"));
        datePairs.add(new Pair<String, String>("2064-01-14", "2007-04-27"));
        datePairs.add(new Pair<String, String>("2064-01-15", "2007-04-28"));
        datePairs.add(new Pair<String, String>("2064-01-16", "2007-04-29"));
        datePairs.add(new Pair<String, String>("2064-01-17", "2007-04-30"));
        datePairs.add(new Pair<String, String>("2064-01-18", "2007-05-01"));
        datePairs.add(new Pair<String, String>("2064-01-19", "2007-05-02"));
        datePairs.add(new Pair<String, String>("2064-01-20", "2007-05-03"));
        datePairs.add(new Pair<String, String>("2064-01-21", "2007-05-04"));
        datePairs.add(new Pair<String, String>("2064-01-22", "2007-05-05"));
        datePairs.add(new Pair<String, String>("2064-01-23", "2007-05-06"));
        datePairs.add(new Pair<String, String>("2064-01-24", "2007-05-07"));
        datePairs.add(new Pair<String, String>("2064-01-25", "2007-05-08"));
        datePairs.add(new Pair<String, String>("2064-01-26", "2007-05-09"));
        datePairs.add(new Pair<String, String>("2064-01-27", "2007-05-10"));
        datePairs.add(new Pair<String, String>("2064-01-28", "2007-05-11"));
        datePairs.add(new Pair<String, String>("2064-01-29", "2007-05-12"));
        datePairs.add(new Pair<String, String>("2064-01-30", "2007-05-13"));
        datePairs.add(new Pair<String, String>("2064-01-31", "2007-05-14"));
        datePairs.add(new Pair<String, String>("2064-02-01", "2007-05-15"));
        datePairs.add(new Pair<String, String>("2064-02-02", "2007-05-16"));
        datePairs.add(new Pair<String, String>("2064-02-03", "2007-05-17"));
        datePairs.add(new Pair<String, String>("2064-02-04", "2007-05-18"));
        datePairs.add(new Pair<String, String>("2064-02-05", "2007-05-19"));
        datePairs.add(new Pair<String, String>("2064-02-06", "2007-05-20"));
        datePairs.add(new Pair<String, String>("2064-02-07", "2007-05-21"));
        datePairs.add(new Pair<String, String>("2064-02-08", "2007-05-22"));
        datePairs.add(new Pair<String, String>("2064-02-09", "2007-05-23"));
        datePairs.add(new Pair<String, String>("2064-02-10", "2007-05-24"));
        datePairs.add(new Pair<String, String>("2064-02-11", "2007-05-25"));
        datePairs.add(new Pair<String, String>("2064-02-12", "2007-05-26"));
        datePairs.add(new Pair<String, String>("2064-02-13", "2007-05-27"));
        datePairs.add(new Pair<String, String>("2064-02-14", "2007-05-28"));
        datePairs.add(new Pair<String, String>("2064-02-15", "2007-05-29"));
        datePairs.add(new Pair<String, String>("2064-02-16", "2007-05-30"));
        datePairs.add(new Pair<String, String>("2064-02-17", "2007-05-31"));
        datePairs.add(new Pair<String, String>("2064-02-18", "2007-06-01"));
        datePairs.add(new Pair<String, String>("2064-02-19", "2007-06-02"));
        datePairs.add(new Pair<String, String>("2064-02-20", "2007-06-03"));
        datePairs.add(new Pair<String, String>("2064-02-21", "2007-06-04"));
        datePairs.add(new Pair<String, String>("2064-02-22", "2007-06-05"));
        datePairs.add(new Pair<String, String>("2064-02-23", "2007-06-06"));
        datePairs.add(new Pair<String, String>("2064-02-24", "2007-06-07"));
        datePairs.add(new Pair<String, String>("2064-02-25", "2007-06-08"));
        datePairs.add(new Pair<String, String>("2064-02-26", "2007-06-09"));
        datePairs.add(new Pair<String, String>("2064-02-27", "2007-06-10"));
        datePairs.add(new Pair<String, String>("2064-02-28", "2007-06-11"));
        datePairs.add(new Pair<String, String>("2064-02-29", "2007-06-12"));
        datePairs.add(new Pair<String, String>("2064-02-30", "2007-06-13"));
        datePairs.add(new Pair<String, String>("2064-02-31", "2007-06-14"));
        datePairs.add(new Pair<String, String>("2064-03-01", "2007-06-15"));
        datePairs.add(new Pair<String, String>("2064-03-02", "2007-06-16"));
        datePairs.add(new Pair<String, String>("2064-03-03", "2007-06-17"));
        datePairs.add(new Pair<String, String>("2064-03-04", "2007-06-18"));
        datePairs.add(new Pair<String, String>("2064-03-05", "2007-06-19"));
        datePairs.add(new Pair<String, String>("2064-03-06", "2007-06-20"));
        datePairs.add(new Pair<String, String>("2064-03-07", "2007-06-21"));
        datePairs.add(new Pair<String, String>("2064-03-08", "2007-06-22"));
        datePairs.add(new Pair<String, String>("2064-03-09", "2007-06-23"));
        datePairs.add(new Pair<String, String>("2064-03-10", "2007-06-24"));
        datePairs.add(new Pair<String, String>("2064-03-11", "2007-06-25"));
        datePairs.add(new Pair<String, String>("2064-03-12", "2007-06-26"));
        datePairs.add(new Pair<String, String>("2064-03-13", "2007-06-27"));
        datePairs.add(new Pair<String, String>("2064-03-14", "2007-06-28"));
        datePairs.add(new Pair<String, String>("2064-03-15", "2007-06-29"));
        datePairs.add(new Pair<String, String>("2064-03-16", "2007-06-30"));
        datePairs.add(new Pair<String, String>("2064-03-17", "2007-07-01"));
        datePairs.add(new Pair<String, String>("2064-03-18", "2007-07-02"));
        datePairs.add(new Pair<String, String>("2064-03-19", "2007-07-03"));
        datePairs.add(new Pair<String, String>("2064-03-20", "2007-07-04"));
        datePairs.add(new Pair<String, String>("2064-03-21", "2007-07-05"));
        datePairs.add(new Pair<String, String>("2064-03-22", "2007-07-06"));
        datePairs.add(new Pair<String, String>("2064-03-23", "2007-07-07"));
        datePairs.add(new Pair<String, String>("2064-03-24", "2007-07-08"));
        datePairs.add(new Pair<String, String>("2064-03-25", "2007-07-09"));
        datePairs.add(new Pair<String, String>("2064-03-26", "2007-07-10"));
        datePairs.add(new Pair<String, String>("2064-03-27", "2007-07-11"));
        datePairs.add(new Pair<String, String>("2064-03-28", "2007-07-12"));
        datePairs.add(new Pair<String, String>("2064-03-29", "2007-07-13"));
        datePairs.add(new Pair<String, String>("2064-03-30", "2007-07-14"));
        datePairs.add(new Pair<String, String>("2064-03-31", "2007-07-15"));
        datePairs.add(new Pair<String, String>("2064-03-32", "2007-07-16"));
        datePairs.add(new Pair<String, String>("2064-04-01", "2007-07-17"));
        datePairs.add(new Pair<String, String>("2064-04-02", "2007-07-18"));
        datePairs.add(new Pair<String, String>("2064-04-03", "2007-07-19"));
        datePairs.add(new Pair<String, String>("2064-04-04", "2007-07-20"));
        datePairs.add(new Pair<String, String>("2064-04-05", "2007-07-21"));
        datePairs.add(new Pair<String, String>("2064-04-06", "2007-07-22"));
        datePairs.add(new Pair<String, String>("2064-04-07", "2007-07-23"));
        datePairs.add(new Pair<String, String>("2064-04-08", "2007-07-24"));
        datePairs.add(new Pair<String, String>("2064-04-09", "2007-07-25"));
        datePairs.add(new Pair<String, String>("2064-04-10", "2007-07-26"));
        datePairs.add(new Pair<String, String>("2064-04-11", "2007-07-27"));
        datePairs.add(new Pair<String, String>("2064-04-12", "2007-07-28"));
        datePairs.add(new Pair<String, String>("2064-04-13", "2007-07-29"));
        datePairs.add(new Pair<String, String>("2064-04-14", "2007-07-30"));
        datePairs.add(new Pair<String, String>("2064-04-15", "2007-07-31"));
        datePairs.add(new Pair<String, String>("2064-04-16", "2007-08-01"));
        datePairs.add(new Pair<String, String>("2064-04-17", "2007-08-02"));
        datePairs.add(new Pair<String, String>("2064-04-18", "2007-08-03"));
        datePairs.add(new Pair<String, String>("2064-04-19", "2007-08-04"));
        datePairs.add(new Pair<String, String>("2064-04-20", "2007-08-05"));
        datePairs.add(new Pair<String, String>("2064-04-21", "2007-08-06"));
        datePairs.add(new Pair<String, String>("2064-04-22", "2007-08-07"));
        datePairs.add(new Pair<String, String>("2064-04-23", "2007-08-08"));
        datePairs.add(new Pair<String, String>("2064-04-24", "2007-08-09"));
        datePairs.add(new Pair<String, String>("2064-04-25", "2007-08-10"));
        datePairs.add(new Pair<String, String>("2064-04-26", "2007-08-11"));
        datePairs.add(new Pair<String, String>("2064-04-27", "2007-08-12"));
        datePairs.add(new Pair<String, String>("2064-04-28", "2007-08-13"));
        datePairs.add(new Pair<String, String>("2064-04-29", "2007-08-14"));
        datePairs.add(new Pair<String, String>("2064-04-30", "2007-08-15"));
        datePairs.add(new Pair<String, String>("2064-04-31", "2007-08-16"));
        datePairs.add(new Pair<String, String>("2064-04-32", "2007-08-17"));
        datePairs.add(new Pair<String, String>("2064-05-01", "2007-08-18"));
        datePairs.add(new Pair<String, String>("2064-05-02", "2007-08-19"));
        datePairs.add(new Pair<String, String>("2064-05-03", "2007-08-20"));
        datePairs.add(new Pair<String, String>("2064-05-04", "2007-08-21"));
        datePairs.add(new Pair<String, String>("2064-05-05", "2007-08-22"));
        datePairs.add(new Pair<String, String>("2064-05-06", "2007-08-23"));
        datePairs.add(new Pair<String, String>("2064-05-07", "2007-08-24"));
        datePairs.add(new Pair<String, String>("2064-05-08", "2007-08-25"));
        datePairs.add(new Pair<String, String>("2064-05-09", "2007-08-26"));
        datePairs.add(new Pair<String, String>("2064-05-10", "2007-08-27"));
        datePairs.add(new Pair<String, String>("2064-05-11", "2007-08-28"));
        datePairs.add(new Pair<String, String>("2064-05-12", "2007-08-29"));
        datePairs.add(new Pair<String, String>("2064-05-13", "2007-08-30"));
        datePairs.add(new Pair<String, String>("2064-05-14", "2007-08-31"));
        datePairs.add(new Pair<String, String>("2064-05-15", "2007-09-01"));
        datePairs.add(new Pair<String, String>("2064-05-16", "2007-09-02"));
        datePairs.add(new Pair<String, String>("2064-05-17", "2007-09-03"));
        datePairs.add(new Pair<String, String>("2064-05-18", "2007-09-04"));
        datePairs.add(new Pair<String, String>("2064-05-19", "2007-09-05"));
        datePairs.add(new Pair<String, String>("2064-05-20", "2007-09-06"));
        datePairs.add(new Pair<String, String>("2064-05-21", "2007-09-07"));
        datePairs.add(new Pair<String, String>("2064-05-22", "2007-09-08"));
        datePairs.add(new Pair<String, String>("2064-05-23", "2007-09-09"));
        datePairs.add(new Pair<String, String>("2064-05-24", "2007-09-10"));
        datePairs.add(new Pair<String, String>("2064-05-25", "2007-09-11"));
        datePairs.add(new Pair<String, String>("2064-05-26", "2007-09-12"));
        datePairs.add(new Pair<String, String>("2064-05-27", "2007-09-13"));
        datePairs.add(new Pair<String, String>("2064-05-28", "2007-09-14"));
        datePairs.add(new Pair<String, String>("2064-05-29", "2007-09-15"));
        datePairs.add(new Pair<String, String>("2064-05-30", "2007-09-16"));
        datePairs.add(new Pair<String, String>("2064-05-31", "2007-09-17"));
        datePairs.add(new Pair<String, String>("2064-06-01", "2007-09-18"));
        datePairs.add(new Pair<String, String>("2064-06-02", "2007-09-19"));
        datePairs.add(new Pair<String, String>("2064-06-03", "2007-09-20"));
        datePairs.add(new Pair<String, String>("2064-06-04", "2007-09-21"));
        datePairs.add(new Pair<String, String>("2064-06-05", "2007-09-22"));
        datePairs.add(new Pair<String, String>("2064-06-06", "2007-09-23"));
        datePairs.add(new Pair<String, String>("2064-06-07", "2007-09-24"));
        datePairs.add(new Pair<String, String>("2064-06-08", "2007-09-25"));
        datePairs.add(new Pair<String, String>("2064-06-09", "2007-09-26"));
        datePairs.add(new Pair<String, String>("2064-06-10", "2007-09-27"));
        datePairs.add(new Pair<String, String>("2064-06-11", "2007-09-28"));
        datePairs.add(new Pair<String, String>("2064-06-12", "2007-09-29"));
        datePairs.add(new Pair<String, String>("2064-06-13", "2007-09-30"));
        datePairs.add(new Pair<String, String>("2064-06-14", "2007-10-01"));
        datePairs.add(new Pair<String, String>("2064-06-15", "2007-10-02"));
        datePairs.add(new Pair<String, String>("2064-06-16", "2007-10-03"));
        datePairs.add(new Pair<String, String>("2064-06-17", "2007-10-04"));
        datePairs.add(new Pair<String, String>("2064-06-18", "2007-10-05"));
        datePairs.add(new Pair<String, String>("2064-06-19", "2007-10-06"));
        datePairs.add(new Pair<String, String>("2064-06-20", "2007-10-07"));
        datePairs.add(new Pair<String, String>("2064-06-21", "2007-10-08"));
        datePairs.add(new Pair<String, String>("2064-06-22", "2007-10-09"));
        datePairs.add(new Pair<String, String>("2064-06-23", "2007-10-10"));
        datePairs.add(new Pair<String, String>("2064-06-24", "2007-10-11"));
        datePairs.add(new Pair<String, String>("2064-06-25", "2007-10-12"));
        datePairs.add(new Pair<String, String>("2064-06-26", "2007-10-13"));
        datePairs.add(new Pair<String, String>("2064-06-27", "2007-10-14"));
        datePairs.add(new Pair<String, String>("2064-06-28", "2007-10-15"));
        datePairs.add(new Pair<String, String>("2064-06-29", "2007-10-16"));
        datePairs.add(new Pair<String, String>("2064-06-30", "2007-10-17"));
        datePairs.add(new Pair<String, String>("2064-07-01", "2007-10-18"));
        datePairs.add(new Pair<String, String>("2064-07-02", "2007-10-19"));
        datePairs.add(new Pair<String, String>("2064-07-03", "2007-10-20"));
        datePairs.add(new Pair<String, String>("2064-07-04", "2007-10-21"));
        datePairs.add(new Pair<String, String>("2064-07-05", "2007-10-22"));
        datePairs.add(new Pair<String, String>("2064-07-06", "2007-10-23"));
        datePairs.add(new Pair<String, String>("2064-07-07", "2007-10-24"));
        datePairs.add(new Pair<String, String>("2064-07-08", "2007-10-25"));
        datePairs.add(new Pair<String, String>("2064-07-09", "2007-10-26"));
        datePairs.add(new Pair<String, String>("2064-07-10", "2007-10-27"));
        datePairs.add(new Pair<String, String>("2064-07-11", "2007-10-28"));
        datePairs.add(new Pair<String, String>("2064-07-12", "2007-10-29"));
        datePairs.add(new Pair<String, String>("2064-07-13", "2007-10-30"));
        datePairs.add(new Pair<String, String>("2064-07-14", "2007-10-31"));
        datePairs.add(new Pair<String, String>("2064-07-15", "2007-11-01"));
        datePairs.add(new Pair<String, String>("2064-07-16", "2007-11-02"));
        datePairs.add(new Pair<String, String>("2064-07-17", "2007-11-03"));
        datePairs.add(new Pair<String, String>("2064-07-18", "2007-11-04"));
        datePairs.add(new Pair<String, String>("2064-07-19", "2007-11-05"));
        datePairs.add(new Pair<String, String>("2064-07-20", "2007-11-06"));
        datePairs.add(new Pair<String, String>("2064-07-21", "2007-11-07"));
        datePairs.add(new Pair<String, String>("2064-07-22", "2007-11-08"));
        datePairs.add(new Pair<String, String>("2064-07-23", "2007-11-09"));
        datePairs.add(new Pair<String, String>("2064-07-24", "2007-11-10"));
        datePairs.add(new Pair<String, String>("2064-07-25", "2007-11-11"));
        datePairs.add(new Pair<String, String>("2064-07-26", "2007-11-12"));
        datePairs.add(new Pair<String, String>("2064-07-27", "2007-11-13"));
        datePairs.add(new Pair<String, String>("2064-07-28", "2007-11-14"));
        datePairs.add(new Pair<String, String>("2064-07-29", "2007-11-15"));
        datePairs.add(new Pair<String, String>("2064-07-30", "2007-11-16"));
        datePairs.add(new Pair<String, String>("2064-08-01", "2007-11-17"));
        datePairs.add(new Pair<String, String>("2064-08-02", "2007-11-18"));
        datePairs.add(new Pair<String, String>("2064-08-03", "2007-11-19"));
        datePairs.add(new Pair<String, String>("2064-08-04", "2007-11-20"));
        datePairs.add(new Pair<String, String>("2064-08-05", "2007-11-21"));
        datePairs.add(new Pair<String, String>("2064-08-06", "2007-11-22"));
        datePairs.add(new Pair<String, String>("2064-08-07", "2007-11-23"));
        datePairs.add(new Pair<String, String>("2064-08-08", "2007-11-24"));
        datePairs.add(new Pair<String, String>("2064-08-09", "2007-11-25"));
        datePairs.add(new Pair<String, String>("2064-08-10", "2007-11-26"));
        datePairs.add(new Pair<String, String>("2064-08-11", "2007-11-27"));
        datePairs.add(new Pair<String, String>("2064-08-12", "2007-11-28"));
        datePairs.add(new Pair<String, String>("2064-08-13", "2007-11-29"));
        datePairs.add(new Pair<String, String>("2064-08-14", "2007-11-30"));
        datePairs.add(new Pair<String, String>("2064-08-15", "2007-12-01"));
        datePairs.add(new Pair<String, String>("2064-08-16", "2007-12-02"));
        datePairs.add(new Pair<String, String>("2064-08-17", "2007-12-03"));
        datePairs.add(new Pair<String, String>("2064-08-18", "2007-12-04"));
        datePairs.add(new Pair<String, String>("2064-08-19", "2007-12-05"));
        datePairs.add(new Pair<String, String>("2064-08-20", "2007-12-06"));
        datePairs.add(new Pair<String, String>("2064-08-21", "2007-12-07"));
        datePairs.add(new Pair<String, String>("2064-08-22", "2007-12-08"));
        datePairs.add(new Pair<String, String>("2064-08-23", "2007-12-09"));
        datePairs.add(new Pair<String, String>("2064-08-24", "2007-12-10"));
        datePairs.add(new Pair<String, String>("2064-08-25", "2007-12-11"));
        datePairs.add(new Pair<String, String>("2064-08-26", "2007-12-12"));
        datePairs.add(new Pair<String, String>("2064-08-27", "2007-12-13"));
        datePairs.add(new Pair<String, String>("2064-08-28", "2007-12-14"));
        datePairs.add(new Pair<String, String>("2064-08-29", "2007-12-15"));
        datePairs.add(new Pair<String, String>("2064-09-01", "2007-12-16"));
        datePairs.add(new Pair<String, String>("2064-09-02", "2007-12-17"));
        datePairs.add(new Pair<String, String>("2064-09-03", "2007-12-18"));
        datePairs.add(new Pair<String, String>("2064-09-04", "2007-12-19"));
        datePairs.add(new Pair<String, String>("2064-09-05", "2007-12-20"));
        datePairs.add(new Pair<String, String>("2064-09-06", "2007-12-21"));
        datePairs.add(new Pair<String, String>("2064-09-07", "2007-12-22"));
        datePairs.add(new Pair<String, String>("2064-09-08", "2007-12-23"));
        datePairs.add(new Pair<String, String>("2064-09-09", "2007-12-24"));
        datePairs.add(new Pair<String, String>("2064-09-10", "2007-12-25"));
        datePairs.add(new Pair<String, String>("2064-09-11", "2007-12-26"));
        datePairs.add(new Pair<String, String>("2064-09-12", "2007-12-27"));
        datePairs.add(new Pair<String, String>("2064-09-13", "2007-12-28"));
        datePairs.add(new Pair<String, String>("2064-09-14", "2007-12-29"));
        datePairs.add(new Pair<String, String>("2064-09-15", "2007-12-30"));
        datePairs.add(new Pair<String, String>("2064-09-16", "2007-12-31"));
        datePairs.add(new Pair<String, String>("2064-09-17", "2008-01-01"));
        datePairs.add(new Pair<String, String>("2064-09-18", "2008-01-02"));
        datePairs.add(new Pair<String, String>("2064-09-19", "2008-01-03"));
        datePairs.add(new Pair<String, String>("2064-09-20", "2008-01-04"));
        datePairs.add(new Pair<String, String>("2064-09-21", "2008-01-05"));
        datePairs.add(new Pair<String, String>("2064-09-22", "2008-01-06"));
        datePairs.add(new Pair<String, String>("2064-09-23", "2008-01-07"));
        datePairs.add(new Pair<String, String>("2064-09-24", "2008-01-08"));
        datePairs.add(new Pair<String, String>("2064-09-25", "2008-01-09"));
        datePairs.add(new Pair<String, String>("2064-09-26", "2008-01-10"));
        datePairs.add(new Pair<String, String>("2064-09-27", "2008-01-11"));
        datePairs.add(new Pair<String, String>("2064-09-28", "2008-01-12"));
        datePairs.add(new Pair<String, String>("2064-09-29", "2008-01-13"));
        datePairs.add(new Pair<String, String>("2064-09-30", "2008-01-14"));
        datePairs.add(new Pair<String, String>("2064-10-01", "2008-01-15"));
        datePairs.add(new Pair<String, String>("2064-10-02", "2008-01-16"));
        datePairs.add(new Pair<String, String>("2064-10-03", "2008-01-17"));
        datePairs.add(new Pair<String, String>("2064-10-04", "2008-01-18"));
        datePairs.add(new Pair<String, String>("2064-10-05", "2008-01-19"));
        datePairs.add(new Pair<String, String>("2064-10-06", "2008-01-20"));
        datePairs.add(new Pair<String, String>("2064-10-07", "2008-01-21"));
        datePairs.add(new Pair<String, String>("2064-10-08", "2008-01-22"));
        datePairs.add(new Pair<String, String>("2064-10-09", "2008-01-23"));
        datePairs.add(new Pair<String, String>("2064-10-10", "2008-01-24"));
        datePairs.add(new Pair<String, String>("2064-10-11", "2008-01-25"));
        datePairs.add(new Pair<String, String>("2064-10-12", "2008-01-26"));
        datePairs.add(new Pair<String, String>("2064-10-13", "2008-01-27"));
        datePairs.add(new Pair<String, String>("2064-10-14", "2008-01-28"));
        datePairs.add(new Pair<String, String>("2064-10-15", "2008-01-29"));
        datePairs.add(new Pair<String, String>("2064-10-16", "2008-01-30"));
        datePairs.add(new Pair<String, String>("2064-10-17", "2008-01-31"));
        datePairs.add(new Pair<String, String>("2064-10-18", "2008-02-01"));
        datePairs.add(new Pair<String, String>("2064-10-19", "2008-02-02"));
        datePairs.add(new Pair<String, String>("2064-10-20", "2008-02-03"));
        datePairs.add(new Pair<String, String>("2064-10-21", "2008-02-04"));
        datePairs.add(new Pair<String, String>("2064-10-22", "2008-02-05"));
        datePairs.add(new Pair<String, String>("2064-10-23", "2008-02-06"));
        datePairs.add(new Pair<String, String>("2064-10-24", "2008-02-07"));
        datePairs.add(new Pair<String, String>("2064-10-25", "2008-02-08"));
        datePairs.add(new Pair<String, String>("2064-10-26", "2008-02-09"));
        datePairs.add(new Pair<String, String>("2064-10-27", "2008-02-10"));
        datePairs.add(new Pair<String, String>("2064-10-28", "2008-02-11"));
        datePairs.add(new Pair<String, String>("2064-10-29", "2008-02-12"));
        datePairs.add(new Pair<String, String>("2064-11-01", "2008-02-13"));
        datePairs.add(new Pair<String, String>("2064-11-02", "2008-02-14"));
        datePairs.add(new Pair<String, String>("2064-11-03", "2008-02-15"));
        datePairs.add(new Pair<String, String>("2064-11-04", "2008-02-16"));
        datePairs.add(new Pair<String, String>("2064-11-05", "2008-02-17"));
        datePairs.add(new Pair<String, String>("2064-11-06", "2008-02-18"));
        datePairs.add(new Pair<String, String>("2064-11-07", "2008-02-19"));
        datePairs.add(new Pair<String, String>("2064-11-08", "2008-02-20"));
        datePairs.add(new Pair<String, String>("2064-11-09", "2008-02-21"));
        datePairs.add(new Pair<String, String>("2064-11-10", "2008-02-22"));
        datePairs.add(new Pair<String, String>("2064-11-11", "2008-02-23"));
        datePairs.add(new Pair<String, String>("2064-11-12", "2008-02-24"));
        datePairs.add(new Pair<String, String>("2064-11-13", "2008-02-25"));
        datePairs.add(new Pair<String, String>("2064-11-14", "2008-02-26"));
        datePairs.add(new Pair<String, String>("2064-11-15", "2008-02-27"));
        datePairs.add(new Pair<String, String>("2064-11-16", "2008-02-28"));
        datePairs.add(new Pair<String, String>("2064-11-17", "2008-02-29"));
        datePairs.add(new Pair<String, String>("2064-11-18", "2008-03-01"));
        datePairs.add(new Pair<String, String>("2064-11-19", "2008-03-02"));
        datePairs.add(new Pair<String, String>("2064-11-20", "2008-03-03"));
        datePairs.add(new Pair<String, String>("2064-11-21", "2008-03-04"));
        datePairs.add(new Pair<String, String>("2064-11-22", "2008-03-05"));
        datePairs.add(new Pair<String, String>("2064-11-23", "2008-03-06"));
        datePairs.add(new Pair<String, String>("2064-11-24", "2008-03-07"));
        datePairs.add(new Pair<String, String>("2064-11-25", "2008-03-08"));
        datePairs.add(new Pair<String, String>("2064-11-26", "2008-03-09"));
        datePairs.add(new Pair<String, String>("2064-11-27", "2008-03-10"));
        datePairs.add(new Pair<String, String>("2064-11-28", "2008-03-11"));
        datePairs.add(new Pair<String, String>("2064-11-29", "2008-03-12"));
        datePairs.add(new Pair<String, String>("2064-11-30", "2008-03-13"));
        datePairs.add(new Pair<String, String>("2064-12-01", "2008-03-14"));
        datePairs.add(new Pair<String, String>("2064-12-02", "2008-03-15"));
        datePairs.add(new Pair<String, String>("2064-12-03", "2008-03-16"));
        datePairs.add(new Pair<String, String>("2064-12-04", "2008-03-17"));
        datePairs.add(new Pair<String, String>("2064-12-05", "2008-03-18"));
        datePairs.add(new Pair<String, String>("2064-12-06", "2008-03-19"));
        datePairs.add(new Pair<String, String>("2064-12-07", "2008-03-20"));
        datePairs.add(new Pair<String, String>("2064-12-08", "2008-03-21"));
        datePairs.add(new Pair<String, String>("2064-12-09", "2008-03-22"));
        datePairs.add(new Pair<String, String>("2064-12-10", "2008-03-23"));
        datePairs.add(new Pair<String, String>("2064-12-11", "2008-03-24"));
        datePairs.add(new Pair<String, String>("2064-12-12", "2008-03-25"));
        datePairs.add(new Pair<String, String>("2064-12-13", "2008-03-26"));
        datePairs.add(new Pair<String, String>("2064-12-14", "2008-03-27"));
        datePairs.add(new Pair<String, String>("2064-12-15", "2008-03-28"));
        datePairs.add(new Pair<String, String>("2064-12-16", "2008-03-29"));
        datePairs.add(new Pair<String, String>("2064-12-17", "2008-03-30"));
        datePairs.add(new Pair<String, String>("2064-12-18", "2008-03-31"));
        datePairs.add(new Pair<String, String>("2064-12-19", "2008-04-01"));
        datePairs.add(new Pair<String, String>("2064-12-20", "2008-04-02"));
        datePairs.add(new Pair<String, String>("2064-12-21", "2008-04-03"));
        datePairs.add(new Pair<String, String>("2064-12-22", "2008-04-04"));
        datePairs.add(new Pair<String, String>("2064-12-23", "2008-04-05"));
        datePairs.add(new Pair<String, String>("2064-12-24", "2008-04-06"));
        datePairs.add(new Pair<String, String>("2064-12-25", "2008-04-07"));
        datePairs.add(new Pair<String, String>("2064-12-26", "2008-04-08"));
        datePairs.add(new Pair<String, String>("2064-12-27", "2008-04-09"));
        datePairs.add(new Pair<String, String>("2064-12-28", "2008-04-10"));
        datePairs.add(new Pair<String, String>("2064-12-29", "2008-04-11"));
        datePairs.add(new Pair<String, String>("2064-12-30", "2008-04-12"));
        datePairs.add(new Pair<String, String>("2065-01-01", "2008-04-13"));
        datePairs.add(new Pair<String, String>("2065-01-02", "2008-04-14"));
        datePairs.add(new Pair<String, String>("2065-01-03", "2008-04-15"));
        datePairs.add(new Pair<String, String>("2065-01-04", "2008-04-16"));
        datePairs.add(new Pair<String, String>("2065-01-05", "2008-04-17"));
        datePairs.add(new Pair<String, String>("2065-01-06", "2008-04-18"));
        datePairs.add(new Pair<String, String>("2065-01-07", "2008-04-19"));
        datePairs.add(new Pair<String, String>("2065-01-08", "2008-04-20"));
        datePairs.add(new Pair<String, String>("2065-01-09", "2008-04-21"));
        datePairs.add(new Pair<String, String>("2065-01-10", "2008-04-22"));
        datePairs.add(new Pair<String, String>("2065-01-11", "2008-04-23"));
        datePairs.add(new Pair<String, String>("2065-01-12", "2008-04-24"));
        datePairs.add(new Pair<String, String>("2065-01-13", "2008-04-25"));
        datePairs.add(new Pair<String, String>("2065-01-14", "2008-04-26"));
        datePairs.add(new Pair<String, String>("2065-01-15", "2008-04-27"));
        datePairs.add(new Pair<String, String>("2065-01-16", "2008-04-28"));
        datePairs.add(new Pair<String, String>("2065-01-17", "2008-04-29"));
        datePairs.add(new Pair<String, String>("2065-01-18", "2008-04-30"));
        datePairs.add(new Pair<String, String>("2065-01-19", "2008-05-01"));
        datePairs.add(new Pair<String, String>("2065-01-20", "2008-05-02"));
        datePairs.add(new Pair<String, String>("2065-01-21", "2008-05-03"));
        datePairs.add(new Pair<String, String>("2065-01-22", "2008-05-04"));
        datePairs.add(new Pair<String, String>("2065-01-23", "2008-05-05"));
        datePairs.add(new Pair<String, String>("2065-01-24", "2008-05-06"));
        datePairs.add(new Pair<String, String>("2065-01-25", "2008-05-07"));
        datePairs.add(new Pair<String, String>("2065-01-26", "2008-05-08"));
        datePairs.add(new Pair<String, String>("2065-01-27", "2008-05-09"));
        datePairs.add(new Pair<String, String>("2065-01-28", "2008-05-10"));
        datePairs.add(new Pair<String, String>("2065-01-29", "2008-05-11"));
        datePairs.add(new Pair<String, String>("2065-01-30", "2008-05-12"));
        datePairs.add(new Pair<String, String>("2065-01-31", "2008-05-13"));
        datePairs.add(new Pair<String, String>("2065-02-01", "2008-05-14"));
        datePairs.add(new Pair<String, String>("2065-02-02", "2008-05-15"));
        datePairs.add(new Pair<String, String>("2065-02-03", "2008-05-16"));
        datePairs.add(new Pair<String, String>("2065-02-04", "2008-05-17"));
        datePairs.add(new Pair<String, String>("2065-02-05", "2008-05-18"));
        datePairs.add(new Pair<String, String>("2065-02-06", "2008-05-19"));
        datePairs.add(new Pair<String, String>("2065-02-07", "2008-05-20"));
        datePairs.add(new Pair<String, String>("2065-02-08", "2008-05-21"));
        datePairs.add(new Pair<String, String>("2065-02-09", "2008-05-22"));
        datePairs.add(new Pair<String, String>("2065-02-10", "2008-05-23"));
        datePairs.add(new Pair<String, String>("2065-02-11", "2008-05-24"));
        datePairs.add(new Pair<String, String>("2065-02-12", "2008-05-25"));
        datePairs.add(new Pair<String, String>("2065-02-13", "2008-05-26"));
        datePairs.add(new Pair<String, String>("2065-02-14", "2008-05-27"));
        datePairs.add(new Pair<String, String>("2065-02-15", "2008-05-28"));
        datePairs.add(new Pair<String, String>("2065-02-16", "2008-05-29"));
        datePairs.add(new Pair<String, String>("2065-02-17", "2008-05-30"));
        datePairs.add(new Pair<String, String>("2065-02-18", "2008-05-31"));
        datePairs.add(new Pair<String, String>("2065-02-19", "2008-06-01"));
        datePairs.add(new Pair<String, String>("2065-02-20", "2008-06-02"));
        datePairs.add(new Pair<String, String>("2065-02-21", "2008-06-03"));
        datePairs.add(new Pair<String, String>("2065-02-22", "2008-06-04"));
        datePairs.add(new Pair<String, String>("2065-02-23", "2008-06-05"));
        datePairs.add(new Pair<String, String>("2065-02-24", "2008-06-06"));
        datePairs.add(new Pair<String, String>("2065-02-25", "2008-06-07"));
        datePairs.add(new Pair<String, String>("2065-02-26", "2008-06-08"));
        datePairs.add(new Pair<String, String>("2065-02-27", "2008-06-09"));
        datePairs.add(new Pair<String, String>("2065-02-28", "2008-06-10"));
        datePairs.add(new Pair<String, String>("2065-02-29", "2008-06-11"));
        datePairs.add(new Pair<String, String>("2065-02-30", "2008-06-12"));
        datePairs.add(new Pair<String, String>("2065-02-31", "2008-06-13"));
        datePairs.add(new Pair<String, String>("2065-02-32", "2008-06-14"));
        datePairs.add(new Pair<String, String>("2065-03-01", "2008-06-15"));
        datePairs.add(new Pair<String, String>("2065-03-02", "2008-06-16"));
        datePairs.add(new Pair<String, String>("2065-03-03", "2008-06-17"));
        datePairs.add(new Pair<String, String>("2065-03-04", "2008-06-18"));
        datePairs.add(new Pair<String, String>("2065-03-05", "2008-06-19"));
        datePairs.add(new Pair<String, String>("2065-03-06", "2008-06-20"));
        datePairs.add(new Pair<String, String>("2065-03-07", "2008-06-21"));
        datePairs.add(new Pair<String, String>("2065-03-08", "2008-06-22"));
        datePairs.add(new Pair<String, String>("2065-03-09", "2008-06-23"));
        datePairs.add(new Pair<String, String>("2065-03-10", "2008-06-24"));
        datePairs.add(new Pair<String, String>("2065-03-11", "2008-06-25"));
        datePairs.add(new Pair<String, String>("2065-03-12", "2008-06-26"));
        datePairs.add(new Pair<String, String>("2065-03-13", "2008-06-27"));
        datePairs.add(new Pair<String, String>("2065-03-14", "2008-06-28"));
        datePairs.add(new Pair<String, String>("2065-03-15", "2008-06-29"));
        datePairs.add(new Pair<String, String>("2065-03-16", "2008-06-30"));
        datePairs.add(new Pair<String, String>("2065-03-17", "2008-07-01"));
        datePairs.add(new Pair<String, String>("2065-03-18", "2008-07-02"));
        datePairs.add(new Pair<String, String>("2065-03-19", "2008-07-03"));
        datePairs.add(new Pair<String, String>("2065-03-20", "2008-07-04"));
        datePairs.add(new Pair<String, String>("2065-03-21", "2008-07-05"));
        datePairs.add(new Pair<String, String>("2065-03-22", "2008-07-06"));
        datePairs.add(new Pair<String, String>("2065-03-23", "2008-07-07"));
        datePairs.add(new Pair<String, String>("2065-03-24", "2008-07-08"));
        datePairs.add(new Pair<String, String>("2065-03-25", "2008-07-09"));
        datePairs.add(new Pair<String, String>("2065-03-26", "2008-07-10"));
        datePairs.add(new Pair<String, String>("2065-03-27", "2008-07-11"));
        datePairs.add(new Pair<String, String>("2065-03-28", "2008-07-12"));
        datePairs.add(new Pair<String, String>("2065-03-29", "2008-07-13"));
        datePairs.add(new Pair<String, String>("2065-03-30", "2008-07-14"));
        datePairs.add(new Pair<String, String>("2065-03-31", "2008-07-15"));
        datePairs.add(new Pair<String, String>("2065-04-01", "2008-07-16"));
        datePairs.add(new Pair<String, String>("2065-04-02", "2008-07-17"));
        datePairs.add(new Pair<String, String>("2065-04-03", "2008-07-18"));
        datePairs.add(new Pair<String, String>("2065-04-04", "2008-07-19"));
        datePairs.add(new Pair<String, String>("2065-04-05", "2008-07-20"));
        datePairs.add(new Pair<String, String>("2065-04-06", "2008-07-21"));
        datePairs.add(new Pair<String, String>("2065-04-07", "2008-07-22"));
        datePairs.add(new Pair<String, String>("2065-04-08", "2008-07-23"));
        datePairs.add(new Pair<String, String>("2065-04-09", "2008-07-24"));
        datePairs.add(new Pair<String, String>("2065-04-10", "2008-07-25"));
        datePairs.add(new Pair<String, String>("2065-04-11", "2008-07-26"));
        datePairs.add(new Pair<String, String>("2065-04-12", "2008-07-27"));
        datePairs.add(new Pair<String, String>("2065-04-13", "2008-07-28"));
        datePairs.add(new Pair<String, String>("2065-04-14", "2008-07-29"));
        datePairs.add(new Pair<String, String>("2065-04-15", "2008-07-30"));
        datePairs.add(new Pair<String, String>("2065-04-16", "2008-07-31"));
        datePairs.add(new Pair<String, String>("2065-04-17", "2008-08-01"));
        datePairs.add(new Pair<String, String>("2065-04-18", "2008-08-02"));
        datePairs.add(new Pair<String, String>("2065-04-19", "2008-08-03"));
        datePairs.add(new Pair<String, String>("2065-04-20", "2008-08-04"));
        datePairs.add(new Pair<String, String>("2065-04-21", "2008-08-05"));
        datePairs.add(new Pair<String, String>("2065-04-22", "2008-08-06"));
        datePairs.add(new Pair<String, String>("2065-04-23", "2008-08-07"));
        datePairs.add(new Pair<String, String>("2065-04-24", "2008-08-08"));
        datePairs.add(new Pair<String, String>("2065-04-25", "2008-08-09"));
        datePairs.add(new Pair<String, String>("2065-04-26", "2008-08-10"));
        datePairs.add(new Pair<String, String>("2065-04-27", "2008-08-11"));
        datePairs.add(new Pair<String, String>("2065-04-28", "2008-08-12"));
        datePairs.add(new Pair<String, String>("2065-04-29", "2008-08-13"));
        datePairs.add(new Pair<String, String>("2065-04-30", "2008-08-14"));
        datePairs.add(new Pair<String, String>("2065-04-31", "2008-08-15"));
        datePairs.add(new Pair<String, String>("2065-04-32", "2008-08-16"));
        datePairs.add(new Pair<String, String>("2065-05-01", "2008-08-17"));
        datePairs.add(new Pair<String, String>("2065-05-02", "2008-08-18"));
        datePairs.add(new Pair<String, String>("2065-05-03", "2008-08-19"));
        datePairs.add(new Pair<String, String>("2065-05-04", "2008-08-20"));
        datePairs.add(new Pair<String, String>("2065-05-05", "2008-08-21"));
        datePairs.add(new Pair<String, String>("2065-05-06", "2008-08-22"));
        datePairs.add(new Pair<String, String>("2065-05-07", "2008-08-23"));
        datePairs.add(new Pair<String, String>("2065-05-08", "2008-08-24"));
        datePairs.add(new Pair<String, String>("2065-05-09", "2008-08-25"));
        datePairs.add(new Pair<String, String>("2065-05-10", "2008-08-26"));
        datePairs.add(new Pair<String, String>("2065-05-11", "2008-08-27"));
        datePairs.add(new Pair<String, String>("2065-05-12", "2008-08-28"));
        datePairs.add(new Pair<String, String>("2065-05-13", "2008-08-29"));
        datePairs.add(new Pair<String, String>("2065-05-14", "2008-08-30"));
        datePairs.add(new Pair<String, String>("2065-05-15", "2008-08-31"));
        datePairs.add(new Pair<String, String>("2065-05-16", "2008-09-01"));
        datePairs.add(new Pair<String, String>("2065-05-17", "2008-09-02"));
        datePairs.add(new Pair<String, String>("2065-05-18", "2008-09-03"));
        datePairs.add(new Pair<String, String>("2065-05-19", "2008-09-04"));
        datePairs.add(new Pair<String, String>("2065-05-20", "2008-09-05"));
        datePairs.add(new Pair<String, String>("2065-05-21", "2008-09-06"));
        datePairs.add(new Pair<String, String>("2065-05-22", "2008-09-07"));
        datePairs.add(new Pair<String, String>("2065-05-23", "2008-09-08"));
        datePairs.add(new Pair<String, String>("2065-05-24", "2008-09-09"));
        datePairs.add(new Pair<String, String>("2065-05-25", "2008-09-10"));
        datePairs.add(new Pair<String, String>("2065-05-26", "2008-09-11"));
        datePairs.add(new Pair<String, String>("2065-05-27", "2008-09-12"));
        datePairs.add(new Pair<String, String>("2065-05-28", "2008-09-13"));
        datePairs.add(new Pair<String, String>("2065-05-29", "2008-09-14"));
        datePairs.add(new Pair<String, String>("2065-05-30", "2008-09-15"));
        datePairs.add(new Pair<String, String>("2065-05-31", "2008-09-16"));
        datePairs.add(new Pair<String, String>("2065-06-01", "2008-09-17"));
        datePairs.add(new Pair<String, String>("2065-06-02", "2008-09-18"));
        datePairs.add(new Pair<String, String>("2065-06-03", "2008-09-19"));
        datePairs.add(new Pair<String, String>("2065-06-04", "2008-09-20"));
        datePairs.add(new Pair<String, String>("2065-06-05", "2008-09-21"));
        datePairs.add(new Pair<String, String>("2065-06-06", "2008-09-22"));
        datePairs.add(new Pair<String, String>("2065-06-07", "2008-09-23"));
        datePairs.add(new Pair<String, String>("2065-06-08", "2008-09-24"));
        datePairs.add(new Pair<String, String>("2065-06-09", "2008-09-25"));
        datePairs.add(new Pair<String, String>("2065-06-10", "2008-09-26"));
        datePairs.add(new Pair<String, String>("2065-06-11", "2008-09-27"));
        datePairs.add(new Pair<String, String>("2065-06-12", "2008-09-28"));
        datePairs.add(new Pair<String, String>("2065-06-13", "2008-09-29"));
        datePairs.add(new Pair<String, String>("2065-06-14", "2008-09-30"));
        datePairs.add(new Pair<String, String>("2065-06-15", "2008-10-01"));
        datePairs.add(new Pair<String, String>("2065-06-16", "2008-10-02"));
        datePairs.add(new Pair<String, String>("2065-06-17", "2008-10-03"));
        datePairs.add(new Pair<String, String>("2065-06-18", "2008-10-04"));
        datePairs.add(new Pair<String, String>("2065-06-19", "2008-10-05"));
        datePairs.add(new Pair<String, String>("2065-06-20", "2008-10-06"));
        datePairs.add(new Pair<String, String>("2065-06-21", "2008-10-07"));
        datePairs.add(new Pair<String, String>("2065-06-22", "2008-10-08"));
        datePairs.add(new Pair<String, String>("2065-06-23", "2008-10-09"));
        datePairs.add(new Pair<String, String>("2065-06-24", "2008-10-10"));
        datePairs.add(new Pair<String, String>("2065-06-25", "2008-10-11"));
        datePairs.add(new Pair<String, String>("2065-06-26", "2008-10-12"));
        datePairs.add(new Pair<String, String>("2065-06-27", "2008-10-13"));
        datePairs.add(new Pair<String, String>("2065-06-28", "2008-10-14"));
        datePairs.add(new Pair<String, String>("2065-06-29", "2008-10-15"));
        datePairs.add(new Pair<String, String>("2065-06-30", "2008-10-16"));
        datePairs.add(new Pair<String, String>("2065-07-01", "2008-10-17"));
        datePairs.add(new Pair<String, String>("2065-07-02", "2008-10-18"));
        datePairs.add(new Pair<String, String>("2065-07-03", "2008-10-19"));
        datePairs.add(new Pair<String, String>("2065-07-04", "2008-10-20"));
        datePairs.add(new Pair<String, String>("2065-07-05", "2008-10-21"));
        datePairs.add(new Pair<String, String>("2065-07-06", "2008-10-22"));
        datePairs.add(new Pair<String, String>("2065-07-07", "2008-10-23"));
        datePairs.add(new Pair<String, String>("2065-07-08", "2008-10-24"));
        datePairs.add(new Pair<String, String>("2065-07-09", "2008-10-25"));
        datePairs.add(new Pair<String, String>("2065-07-10", "2008-10-26"));
        datePairs.add(new Pair<String, String>("2065-07-11", "2008-10-27"));
        datePairs.add(new Pair<String, String>("2065-07-12", "2008-10-28"));
        datePairs.add(new Pair<String, String>("2065-07-13", "2008-10-29"));
        datePairs.add(new Pair<String, String>("2065-07-14", "2008-10-30"));
        datePairs.add(new Pair<String, String>("2065-07-15", "2008-10-31"));
        datePairs.add(new Pair<String, String>("2065-07-16", "2008-11-01"));
        datePairs.add(new Pair<String, String>("2065-07-17", "2008-11-02"));
        datePairs.add(new Pair<String, String>("2065-07-18", "2008-11-03"));
        datePairs.add(new Pair<String, String>("2065-07-19", "2008-11-04"));
        datePairs.add(new Pair<String, String>("2065-07-20", "2008-11-05"));
        datePairs.add(new Pair<String, String>("2065-07-21", "2008-11-06"));
        datePairs.add(new Pair<String, String>("2065-07-22", "2008-11-07"));
        datePairs.add(new Pair<String, String>("2065-07-23", "2008-11-08"));
        datePairs.add(new Pair<String, String>("2065-07-24", "2008-11-09"));
        datePairs.add(new Pair<String, String>("2065-07-25", "2008-11-10"));
        datePairs.add(new Pair<String, String>("2065-07-26", "2008-11-11"));
        datePairs.add(new Pair<String, String>("2065-07-27", "2008-11-12"));
        datePairs.add(new Pair<String, String>("2065-07-28", "2008-11-13"));
        datePairs.add(new Pair<String, String>("2065-07-29", "2008-11-14"));
        datePairs.add(new Pair<String, String>("2065-07-30", "2008-11-15"));
        datePairs.add(new Pair<String, String>("2065-08-01", "2008-11-16"));
        datePairs.add(new Pair<String, String>("2065-08-02", "2008-11-17"));
        datePairs.add(new Pair<String, String>("2065-08-03", "2008-11-18"));
        datePairs.add(new Pair<String, String>("2065-08-04", "2008-11-19"));
        datePairs.add(new Pair<String, String>("2065-08-05", "2008-11-20"));
        datePairs.add(new Pair<String, String>("2065-08-06", "2008-11-21"));
        datePairs.add(new Pair<String, String>("2065-08-07", "2008-11-22"));
        datePairs.add(new Pair<String, String>("2065-08-08", "2008-11-23"));
        datePairs.add(new Pair<String, String>("2065-08-09", "2008-11-24"));
        datePairs.add(new Pair<String, String>("2065-08-10", "2008-11-25"));
        datePairs.add(new Pair<String, String>("2065-08-11", "2008-11-26"));
        datePairs.add(new Pair<String, String>("2065-08-12", "2008-11-27"));
        datePairs.add(new Pair<String, String>("2065-08-13", "2008-11-28"));
        datePairs.add(new Pair<String, String>("2065-08-14", "2008-11-29"));
        datePairs.add(new Pair<String, String>("2065-08-15", "2008-11-30"));
        datePairs.add(new Pair<String, String>("2065-08-16", "2008-12-01"));
        datePairs.add(new Pair<String, String>("2065-08-17", "2008-12-02"));
        datePairs.add(new Pair<String, String>("2065-08-18", "2008-12-03"));
        datePairs.add(new Pair<String, String>("2065-08-19", "2008-12-04"));
        datePairs.add(new Pair<String, String>("2065-08-20", "2008-12-05"));
        datePairs.add(new Pair<String, String>("2065-08-21", "2008-12-06"));
        datePairs.add(new Pair<String, String>("2065-08-22", "2008-12-07"));
        datePairs.add(new Pair<String, String>("2065-08-23", "2008-12-08"));
        datePairs.add(new Pair<String, String>("2065-08-24", "2008-12-09"));
        datePairs.add(new Pair<String, String>("2065-08-25", "2008-12-10"));
        datePairs.add(new Pair<String, String>("2065-08-26", "2008-12-11"));
        datePairs.add(new Pair<String, String>("2065-08-27", "2008-12-12"));
        datePairs.add(new Pair<String, String>("2065-08-28", "2008-12-13"));
        datePairs.add(new Pair<String, String>("2065-08-29", "2008-12-14"));
        datePairs.add(new Pair<String, String>("2065-08-30", "2008-12-15"));
        datePairs.add(new Pair<String, String>("2065-09-01", "2008-12-16"));
        datePairs.add(new Pair<String, String>("2065-09-02", "2008-12-17"));
        datePairs.add(new Pair<String, String>("2065-09-03", "2008-12-18"));
        datePairs.add(new Pair<String, String>("2065-09-04", "2008-12-19"));
        datePairs.add(new Pair<String, String>("2065-09-05", "2008-12-20"));
        datePairs.add(new Pair<String, String>("2065-09-06", "2008-12-21"));
        datePairs.add(new Pair<String, String>("2065-09-07", "2008-12-22"));
        datePairs.add(new Pair<String, String>("2065-09-08", "2008-12-23"));
        datePairs.add(new Pair<String, String>("2065-09-09", "2008-12-24"));
        datePairs.add(new Pair<String, String>("2065-09-10", "2008-12-25"));
        datePairs.add(new Pair<String, String>("2065-09-11", "2008-12-26"));
        datePairs.add(new Pair<String, String>("2065-09-12", "2008-12-27"));
        datePairs.add(new Pair<String, String>("2065-09-13", "2008-12-28"));
        datePairs.add(new Pair<String, String>("2065-09-14", "2008-12-29"));
        datePairs.add(new Pair<String, String>("2065-09-15", "2008-12-30"));
        datePairs.add(new Pair<String, String>("2065-09-16", "2008-12-31"));
        datePairs.add(new Pair<String, String>("2065-09-17", "2009-01-01"));
        datePairs.add(new Pair<String, String>("2065-09-18", "2009-01-02"));
        datePairs.add(new Pair<String, String>("2065-09-19", "2009-01-03"));
        datePairs.add(new Pair<String, String>("2065-09-20", "2009-01-04"));
        datePairs.add(new Pair<String, String>("2065-09-21", "2009-01-05"));
        datePairs.add(new Pair<String, String>("2065-09-22", "2009-01-06"));
        datePairs.add(new Pair<String, String>("2065-09-23", "2009-01-07"));
        datePairs.add(new Pair<String, String>("2065-09-24", "2009-01-08"));
        datePairs.add(new Pair<String, String>("2065-09-25", "2009-01-09"));
        datePairs.add(new Pair<String, String>("2065-09-26", "2009-01-10"));
        datePairs.add(new Pair<String, String>("2065-09-27", "2009-01-11"));
        datePairs.add(new Pair<String, String>("2065-09-28", "2009-01-12"));
        datePairs.add(new Pair<String, String>("2065-09-29", "2009-01-13"));
        datePairs.add(new Pair<String, String>("2065-10-01", "2009-01-14"));
        datePairs.add(new Pair<String, String>("2065-10-02", "2009-01-15"));
        datePairs.add(new Pair<String, String>("2065-10-03", "2009-01-16"));
        datePairs.add(new Pair<String, String>("2065-10-04", "2009-01-17"));
        datePairs.add(new Pair<String, String>("2065-10-05", "2009-01-18"));
        datePairs.add(new Pair<String, String>("2065-10-06", "2009-01-19"));
        datePairs.add(new Pair<String, String>("2065-10-07", "2009-01-20"));
        datePairs.add(new Pair<String, String>("2065-10-08", "2009-01-21"));
        datePairs.add(new Pair<String, String>("2065-10-09", "2009-01-22"));
        datePairs.add(new Pair<String, String>("2065-10-10", "2009-01-23"));
        datePairs.add(new Pair<String, String>("2065-10-11", "2009-01-24"));
        datePairs.add(new Pair<String, String>("2065-10-12", "2009-01-25"));
        datePairs.add(new Pair<String, String>("2065-10-13", "2009-01-26"));
        datePairs.add(new Pair<String, String>("2065-10-14", "2009-01-27"));
        datePairs.add(new Pair<String, String>("2065-10-15", "2009-01-28"));
        datePairs.add(new Pair<String, String>("2065-10-16", "2009-01-29"));
        datePairs.add(new Pair<String, String>("2065-10-17", "2009-01-30"));
        datePairs.add(new Pair<String, String>("2065-10-18", "2009-01-31"));
        datePairs.add(new Pair<String, String>("2065-10-19", "2009-02-01"));
        datePairs.add(new Pair<String, String>("2065-10-20", "2009-02-02"));
        datePairs.add(new Pair<String, String>("2065-10-21", "2009-02-03"));
        datePairs.add(new Pair<String, String>("2065-10-22", "2009-02-04"));
        datePairs.add(new Pair<String, String>("2065-10-23", "2009-02-05"));
        datePairs.add(new Pair<String, String>("2065-10-24", "2009-02-06"));
        datePairs.add(new Pair<String, String>("2065-10-25", "2009-02-07"));
        datePairs.add(new Pair<String, String>("2065-10-26", "2009-02-08"));
        datePairs.add(new Pair<String, String>("2065-10-27", "2009-02-09"));
        datePairs.add(new Pair<String, String>("2065-10-28", "2009-02-10"));
        datePairs.add(new Pair<String, String>("2065-10-29", "2009-02-11"));
        datePairs.add(new Pair<String, String>("2065-11-01", "2009-02-12"));
        datePairs.add(new Pair<String, String>("2065-11-02", "2009-02-13"));
        datePairs.add(new Pair<String, String>("2065-11-03", "2009-02-14"));
        datePairs.add(new Pair<String, String>("2065-11-04", "2009-02-15"));
        datePairs.add(new Pair<String, String>("2065-11-05", "2009-02-16"));
        datePairs.add(new Pair<String, String>("2065-11-06", "2009-02-17"));
        datePairs.add(new Pair<String, String>("2065-11-07", "2009-02-18"));
        datePairs.add(new Pair<String, String>("2065-11-08", "2009-02-19"));
        datePairs.add(new Pair<String, String>("2065-11-09", "2009-02-20"));
        datePairs.add(new Pair<String, String>("2065-11-10", "2009-02-21"));
        datePairs.add(new Pair<String, String>("2065-11-11", "2009-02-22"));
        datePairs.add(new Pair<String, String>("2065-11-12", "2009-02-23"));
        datePairs.add(new Pair<String, String>("2065-11-13", "2009-02-24"));
        datePairs.add(new Pair<String, String>("2065-11-14", "2009-02-25"));
        datePairs.add(new Pair<String, String>("2065-11-15", "2009-02-26"));
        datePairs.add(new Pair<String, String>("2065-11-16", "2009-02-27"));
        datePairs.add(new Pair<String, String>("2065-11-17", "2009-02-28"));
        datePairs.add(new Pair<String, String>("2065-11-18", "2009-03-01"));
        datePairs.add(new Pair<String, String>("2065-11-19", "2009-03-02"));
        datePairs.add(new Pair<String, String>("2065-11-20", "2009-03-03"));
        datePairs.add(new Pair<String, String>("2065-11-21", "2009-03-04"));
        datePairs.add(new Pair<String, String>("2065-11-22", "2009-03-05"));
        datePairs.add(new Pair<String, String>("2065-11-23", "2009-03-06"));
        datePairs.add(new Pair<String, String>("2065-11-24", "2009-03-07"));
        datePairs.add(new Pair<String, String>("2065-11-25", "2009-03-08"));
        datePairs.add(new Pair<String, String>("2065-11-26", "2009-03-09"));
        datePairs.add(new Pair<String, String>("2065-11-27", "2009-03-10"));
        datePairs.add(new Pair<String, String>("2065-11-28", "2009-03-11"));
        datePairs.add(new Pair<String, String>("2065-11-29", "2009-03-12"));
        datePairs.add(new Pair<String, String>("2065-11-30", "2009-03-13"));
        datePairs.add(new Pair<String, String>("2065-12-01", "2009-03-14"));
        datePairs.add(new Pair<String, String>("2065-12-02", "2009-03-15"));
        datePairs.add(new Pair<String, String>("2065-12-03", "2009-03-16"));
        datePairs.add(new Pair<String, String>("2065-12-04", "2009-03-17"));
        datePairs.add(new Pair<String, String>("2065-12-05", "2009-03-18"));
        datePairs.add(new Pair<String, String>("2065-12-06", "2009-03-19"));
        datePairs.add(new Pair<String, String>("2065-12-07", "2009-03-20"));
        datePairs.add(new Pair<String, String>("2065-12-08", "2009-03-21"));
        datePairs.add(new Pair<String, String>("2065-12-09", "2009-03-22"));
        datePairs.add(new Pair<String, String>("2065-12-10", "2009-03-23"));
        datePairs.add(new Pair<String, String>("2065-12-11", "2009-03-24"));
        datePairs.add(new Pair<String, String>("2065-12-12", "2009-03-25"));
        datePairs.add(new Pair<String, String>("2065-12-13", "2009-03-26"));
        datePairs.add(new Pair<String, String>("2065-12-14", "2009-03-27"));
        datePairs.add(new Pair<String, String>("2065-12-15", "2009-03-28"));
        datePairs.add(new Pair<String, String>("2065-12-16", "2009-03-29"));
        datePairs.add(new Pair<String, String>("2065-12-17", "2009-03-30"));
        datePairs.add(new Pair<String, String>("2065-12-18", "2009-03-31"));
        datePairs.add(new Pair<String, String>("2065-12-19", "2009-04-01"));
        datePairs.add(new Pair<String, String>("2065-12-20", "2009-04-02"));
        datePairs.add(new Pair<String, String>("2065-12-21", "2009-04-03"));
        datePairs.add(new Pair<String, String>("2065-12-22", "2009-04-04"));
        datePairs.add(new Pair<String, String>("2065-12-23", "2009-04-05"));
        datePairs.add(new Pair<String, String>("2065-12-24", "2009-04-06"));
        datePairs.add(new Pair<String, String>("2065-12-25", "2009-04-07"));
        datePairs.add(new Pair<String, String>("2065-12-26", "2009-04-08"));
        datePairs.add(new Pair<String, String>("2065-12-27", "2009-04-09"));
        datePairs.add(new Pair<String, String>("2065-12-28", "2009-04-10"));
        datePairs.add(new Pair<String, String>("2065-12-29", "2009-04-11"));
        datePairs.add(new Pair<String, String>("2065-12-30", "2009-04-12"));
        datePairs.add(new Pair<String, String>("2065-12-31", "2009-04-13"));
        datePairs.add(new Pair<String, String>("2066-01-01", "2009-04-14"));
        datePairs.add(new Pair<String, String>("2066-01-02", "2009-04-15"));
        datePairs.add(new Pair<String, String>("2066-01-03", "2009-04-16"));
        datePairs.add(new Pair<String, String>("2066-01-04", "2009-04-17"));
        datePairs.add(new Pair<String, String>("2066-01-05", "2009-04-18"));
        datePairs.add(new Pair<String, String>("2066-01-06", "2009-04-19"));
        datePairs.add(new Pair<String, String>("2066-01-07", "2009-04-20"));
        datePairs.add(new Pair<String, String>("2066-01-08", "2009-04-21"));
        datePairs.add(new Pair<String, String>("2066-01-09", "2009-04-22"));
        datePairs.add(new Pair<String, String>("2066-01-10", "2009-04-23"));
        datePairs.add(new Pair<String, String>("2066-01-11", "2009-04-24"));
        datePairs.add(new Pair<String, String>("2066-01-12", "2009-04-25"));
        datePairs.add(new Pair<String, String>("2066-01-13", "2009-04-26"));
        datePairs.add(new Pair<String, String>("2066-01-14", "2009-04-27"));
        datePairs.add(new Pair<String, String>("2066-01-15", "2009-04-28"));
        datePairs.add(new Pair<String, String>("2066-01-16", "2009-04-29"));
        datePairs.add(new Pair<String, String>("2066-01-17", "2009-04-30"));
        datePairs.add(new Pair<String, String>("2066-01-18", "2009-05-01"));
        datePairs.add(new Pair<String, String>("2066-01-19", "2009-05-02"));
        datePairs.add(new Pair<String, String>("2066-01-20", "2009-05-03"));
        datePairs.add(new Pair<String, String>("2066-01-21", "2009-05-04"));
        datePairs.add(new Pair<String, String>("2066-01-22", "2009-05-05"));
        datePairs.add(new Pair<String, String>("2066-01-23", "2009-05-06"));
        datePairs.add(new Pair<String, String>("2066-01-24", "2009-05-07"));
        datePairs.add(new Pair<String, String>("2066-01-25", "2009-05-08"));
        datePairs.add(new Pair<String, String>("2066-01-26", "2009-05-09"));
        datePairs.add(new Pair<String, String>("2066-01-27", "2009-05-10"));
        datePairs.add(new Pair<String, String>("2066-01-28", "2009-05-11"));
        datePairs.add(new Pair<String, String>("2066-01-29", "2009-05-12"));
        datePairs.add(new Pair<String, String>("2066-01-30", "2009-05-13"));
        datePairs.add(new Pair<String, String>("2066-01-31", "2009-05-14"));
        datePairs.add(new Pair<String, String>("2066-02-01", "2009-05-15"));
        datePairs.add(new Pair<String, String>("2066-02-02", "2009-05-16"));
        datePairs.add(new Pair<String, String>("2066-02-03", "2009-05-17"));
        datePairs.add(new Pair<String, String>("2066-02-04", "2009-05-18"));
        datePairs.add(new Pair<String, String>("2066-02-05", "2009-05-19"));
        datePairs.add(new Pair<String, String>("2066-02-06", "2009-05-20"));
        datePairs.add(new Pair<String, String>("2066-02-07", "2009-05-21"));
        datePairs.add(new Pair<String, String>("2066-02-08", "2009-05-22"));
        datePairs.add(new Pair<String, String>("2066-02-09", "2009-05-23"));
        datePairs.add(new Pair<String, String>("2066-02-10", "2009-05-24"));
        datePairs.add(new Pair<String, String>("2066-02-11", "2009-05-25"));
        datePairs.add(new Pair<String, String>("2066-02-12", "2009-05-26"));
        datePairs.add(new Pair<String, String>("2066-02-13", "2009-05-27"));
        datePairs.add(new Pair<String, String>("2066-02-14", "2009-05-28"));
        datePairs.add(new Pair<String, String>("2066-02-15", "2009-05-29"));
        datePairs.add(new Pair<String, String>("2066-02-16", "2009-05-30"));
        datePairs.add(new Pair<String, String>("2066-02-17", "2009-05-31"));
        datePairs.add(new Pair<String, String>("2066-02-18", "2009-06-01"));
        datePairs.add(new Pair<String, String>("2066-02-19", "2009-06-02"));
        datePairs.add(new Pair<String, String>("2066-02-20", "2009-06-03"));
        datePairs.add(new Pair<String, String>("2066-02-21", "2009-06-04"));
        datePairs.add(new Pair<String, String>("2066-02-22", "2009-06-05"));
        datePairs.add(new Pair<String, String>("2066-02-23", "2009-06-06"));
        datePairs.add(new Pair<String, String>("2066-02-24", "2009-06-07"));
        datePairs.add(new Pair<String, String>("2066-02-25", "2009-06-08"));
        datePairs.add(new Pair<String, String>("2066-02-26", "2009-06-09"));
        datePairs.add(new Pair<String, String>("2066-02-27", "2009-06-10"));
        datePairs.add(new Pair<String, String>("2066-02-28", "2009-06-11"));
        datePairs.add(new Pair<String, String>("2066-02-29", "2009-06-12"));
        datePairs.add(new Pair<String, String>("2066-02-30", "2009-06-13"));
        datePairs.add(new Pair<String, String>("2066-02-31", "2009-06-14"));
        datePairs.add(new Pair<String, String>("2066-03-01", "2009-06-15"));
        datePairs.add(new Pair<String, String>("2066-03-02", "2009-06-16"));
        datePairs.add(new Pair<String, String>("2066-03-03", "2009-06-17"));
        datePairs.add(new Pair<String, String>("2066-03-04", "2009-06-18"));
        datePairs.add(new Pair<String, String>("2066-03-05", "2009-06-19"));
        datePairs.add(new Pair<String, String>("2066-03-06", "2009-06-20"));
        datePairs.add(new Pair<String, String>("2066-03-07", "2009-06-21"));
        datePairs.add(new Pair<String, String>("2066-03-08", "2009-06-22"));
        datePairs.add(new Pair<String, String>("2066-03-09", "2009-06-23"));
        datePairs.add(new Pair<String, String>("2066-03-10", "2009-06-24"));
        datePairs.add(new Pair<String, String>("2066-03-11", "2009-06-25"));
        datePairs.add(new Pair<String, String>("2066-03-12", "2009-06-26"));
        datePairs.add(new Pair<String, String>("2066-03-13", "2009-06-27"));
        datePairs.add(new Pair<String, String>("2066-03-14", "2009-06-28"));
        datePairs.add(new Pair<String, String>("2066-03-15", "2009-06-29"));
        datePairs.add(new Pair<String, String>("2066-03-16", "2009-06-30"));
        datePairs.add(new Pair<String, String>("2066-03-17", "2009-07-01"));
        datePairs.add(new Pair<String, String>("2066-03-18", "2009-07-02"));
        datePairs.add(new Pair<String, String>("2066-03-19", "2009-07-03"));
        datePairs.add(new Pair<String, String>("2066-03-20", "2009-07-04"));
        datePairs.add(new Pair<String, String>("2066-03-21", "2009-07-05"));
        datePairs.add(new Pair<String, String>("2066-03-22", "2009-07-06"));
        datePairs.add(new Pair<String, String>("2066-03-23", "2009-07-07"));
        datePairs.add(new Pair<String, String>("2066-03-24", "2009-07-08"));
        datePairs.add(new Pair<String, String>("2066-03-25", "2009-07-09"));
        datePairs.add(new Pair<String, String>("2066-03-26", "2009-07-10"));
        datePairs.add(new Pair<String, String>("2066-03-27", "2009-07-11"));
        datePairs.add(new Pair<String, String>("2066-03-28", "2009-07-12"));
        datePairs.add(new Pair<String, String>("2066-03-29", "2009-07-13"));
        datePairs.add(new Pair<String, String>("2066-03-30", "2009-07-14"));
        datePairs.add(new Pair<String, String>("2066-03-31", "2009-07-15"));
        datePairs.add(new Pair<String, String>("2066-04-01", "2009-07-16"));
        datePairs.add(new Pair<String, String>("2066-04-02", "2009-07-17"));
        datePairs.add(new Pair<String, String>("2066-04-03", "2009-07-18"));
        datePairs.add(new Pair<String, String>("2066-04-04", "2009-07-19"));
        datePairs.add(new Pair<String, String>("2066-04-05", "2009-07-20"));
        datePairs.add(new Pair<String, String>("2066-04-06", "2009-07-21"));
        datePairs.add(new Pair<String, String>("2066-04-07", "2009-07-22"));
        datePairs.add(new Pair<String, String>("2066-04-08", "2009-07-23"));
        datePairs.add(new Pair<String, String>("2066-04-09", "2009-07-24"));
        datePairs.add(new Pair<String, String>("2066-04-10", "2009-07-25"));
        datePairs.add(new Pair<String, String>("2066-04-11", "2009-07-26"));
        datePairs.add(new Pair<String, String>("2066-04-12", "2009-07-27"));
        datePairs.add(new Pair<String, String>("2066-04-13", "2009-07-28"));
        datePairs.add(new Pair<String, String>("2066-04-14", "2009-07-29"));
        datePairs.add(new Pair<String, String>("2066-04-15", "2009-07-30"));
        datePairs.add(new Pair<String, String>("2066-04-16", "2009-07-31"));
        datePairs.add(new Pair<String, String>("2066-04-17", "2009-08-01"));
        datePairs.add(new Pair<String, String>("2066-04-18", "2009-08-02"));
        datePairs.add(new Pair<String, String>("2066-04-19", "2009-08-03"));
        datePairs.add(new Pair<String, String>("2066-04-20", "2009-08-04"));
        datePairs.add(new Pair<String, String>("2066-04-21", "2009-08-05"));
        datePairs.add(new Pair<String, String>("2066-04-22", "2009-08-06"));
        datePairs.add(new Pair<String, String>("2066-04-23", "2009-08-07"));
        datePairs.add(new Pair<String, String>("2066-04-24", "2009-08-08"));
        datePairs.add(new Pair<String, String>("2066-04-25", "2009-08-09"));
        datePairs.add(new Pair<String, String>("2066-04-26", "2009-08-10"));
        datePairs.add(new Pair<String, String>("2066-04-27", "2009-08-11"));
        datePairs.add(new Pair<String, String>("2066-04-28", "2009-08-12"));
        datePairs.add(new Pair<String, String>("2066-04-29", "2009-08-13"));
        datePairs.add(new Pair<String, String>("2066-04-30", "2009-08-14"));
        datePairs.add(new Pair<String, String>("2066-04-31", "2009-08-15"));
        datePairs.add(new Pair<String, String>("2066-04-32", "2009-08-16"));
        datePairs.add(new Pair<String, String>("2066-05-01", "2009-08-17"));
        datePairs.add(new Pair<String, String>("2066-05-02", "2009-08-18"));
        datePairs.add(new Pair<String, String>("2066-05-03", "2009-08-19"));
        datePairs.add(new Pair<String, String>("2066-05-04", "2009-08-20"));
        datePairs.add(new Pair<String, String>("2066-05-05", "2009-08-21"));
        datePairs.add(new Pair<String, String>("2066-05-06", "2009-08-22"));
        datePairs.add(new Pair<String, String>("2066-05-07", "2009-08-23"));
        datePairs.add(new Pair<String, String>("2066-05-08", "2009-08-24"));
        datePairs.add(new Pair<String, String>("2066-05-09", "2009-08-25"));
        datePairs.add(new Pair<String, String>("2066-05-10", "2009-08-26"));
        datePairs.add(new Pair<String, String>("2066-05-11", "2009-08-27"));
        datePairs.add(new Pair<String, String>("2066-05-12", "2009-08-28"));
        datePairs.add(new Pair<String, String>("2066-05-13", "2009-08-29"));
        datePairs.add(new Pair<String, String>("2066-05-14", "2009-08-30"));
        datePairs.add(new Pair<String, String>("2066-05-15", "2009-08-31"));
        datePairs.add(new Pair<String, String>("2066-05-16", "2009-09-01"));
        datePairs.add(new Pair<String, String>("2066-05-17", "2009-09-02"));
        datePairs.add(new Pair<String, String>("2066-05-18", "2009-09-03"));
        datePairs.add(new Pair<String, String>("2066-05-19", "2009-09-04"));
        datePairs.add(new Pair<String, String>("2066-05-20", "2009-09-05"));
        datePairs.add(new Pair<String, String>("2066-05-21", "2009-09-06"));
        datePairs.add(new Pair<String, String>("2066-05-22", "2009-09-07"));
        datePairs.add(new Pair<String, String>("2066-05-23", "2009-09-08"));
        datePairs.add(new Pair<String, String>("2066-05-24", "2009-09-09"));
        datePairs.add(new Pair<String, String>("2066-05-25", "2009-09-10"));
        datePairs.add(new Pair<String, String>("2066-05-26", "2009-09-11"));
        datePairs.add(new Pair<String, String>("2066-05-27", "2009-09-12"));
        datePairs.add(new Pair<String, String>("2066-05-28", "2009-09-13"));
        datePairs.add(new Pair<String, String>("2066-05-29", "2009-09-14"));
        datePairs.add(new Pair<String, String>("2066-05-30", "2009-09-15"));
        datePairs.add(new Pair<String, String>("2066-05-31", "2009-09-16"));
        datePairs.add(new Pair<String, String>("2066-06-01", "2009-09-17"));
        datePairs.add(new Pair<String, String>("2066-06-02", "2009-09-18"));
        datePairs.add(new Pair<String, String>("2066-06-03", "2009-09-19"));
        datePairs.add(new Pair<String, String>("2066-06-04", "2009-09-20"));
        datePairs.add(new Pair<String, String>("2066-06-05", "2009-09-21"));
        datePairs.add(new Pair<String, String>("2066-06-06", "2009-09-22"));
        datePairs.add(new Pair<String, String>("2066-06-07", "2009-09-23"));
        datePairs.add(new Pair<String, String>("2066-06-08", "2009-09-24"));
        datePairs.add(new Pair<String, String>("2066-06-09", "2009-09-25"));
        datePairs.add(new Pair<String, String>("2066-06-10", "2009-09-26"));
        datePairs.add(new Pair<String, String>("2066-06-11", "2009-09-27"));
        datePairs.add(new Pair<String, String>("2066-06-12", "2009-09-28"));
        datePairs.add(new Pair<String, String>("2066-06-13", "2009-09-29"));
        datePairs.add(new Pair<String, String>("2066-06-14", "2009-09-30"));
        datePairs.add(new Pair<String, String>("2066-06-15", "2009-10-01"));
        datePairs.add(new Pair<String, String>("2066-06-16", "2009-10-02"));
        datePairs.add(new Pair<String, String>("2066-06-17", "2009-10-03"));
        datePairs.add(new Pair<String, String>("2066-06-18", "2009-10-04"));
        datePairs.add(new Pair<String, String>("2066-06-19", "2009-10-05"));
        datePairs.add(new Pair<String, String>("2066-06-20", "2009-10-06"));
        datePairs.add(new Pair<String, String>("2066-06-21", "2009-10-07"));
        datePairs.add(new Pair<String, String>("2066-06-22", "2009-10-08"));
        datePairs.add(new Pair<String, String>("2066-06-23", "2009-10-09"));
        datePairs.add(new Pair<String, String>("2066-06-24", "2009-10-10"));
        datePairs.add(new Pair<String, String>("2066-06-25", "2009-10-11"));
        datePairs.add(new Pair<String, String>("2066-06-26", "2009-10-12"));
        datePairs.add(new Pair<String, String>("2066-06-27", "2009-10-13"));
        datePairs.add(new Pair<String, String>("2066-06-28", "2009-10-14"));
        datePairs.add(new Pair<String, String>("2066-06-29", "2009-10-15"));
        datePairs.add(new Pair<String, String>("2066-06-30", "2009-10-16"));
        datePairs.add(new Pair<String, String>("2066-06-31", "2009-10-17"));
        datePairs.add(new Pair<String, String>("2066-07-01", "2009-10-18"));
        datePairs.add(new Pair<String, String>("2066-07-02", "2009-10-19"));
        datePairs.add(new Pair<String, String>("2066-07-03", "2009-10-20"));
        datePairs.add(new Pair<String, String>("2066-07-04", "2009-10-21"));
        datePairs.add(new Pair<String, String>("2066-07-05", "2009-10-22"));
        datePairs.add(new Pair<String, String>("2066-07-06", "2009-10-23"));
        datePairs.add(new Pair<String, String>("2066-07-07", "2009-10-24"));
        datePairs.add(new Pair<String, String>("2066-07-08", "2009-10-25"));
        datePairs.add(new Pair<String, String>("2066-07-09", "2009-10-26"));
        datePairs.add(new Pair<String, String>("2066-07-10", "2009-10-27"));
        datePairs.add(new Pair<String, String>("2066-07-11", "2009-10-28"));
        datePairs.add(new Pair<String, String>("2066-07-12", "2009-10-29"));
        datePairs.add(new Pair<String, String>("2066-07-13", "2009-10-30"));
        datePairs.add(new Pair<String, String>("2066-07-14", "2009-10-31"));
        datePairs.add(new Pair<String, String>("2066-07-15", "2009-11-01"));
        datePairs.add(new Pair<String, String>("2066-07-16", "2009-11-02"));
        datePairs.add(new Pair<String, String>("2066-07-17", "2009-11-03"));
        datePairs.add(new Pair<String, String>("2066-07-18", "2009-11-04"));
        datePairs.add(new Pair<String, String>("2066-07-19", "2009-11-05"));
        datePairs.add(new Pair<String, String>("2066-07-20", "2009-11-06"));
        datePairs.add(new Pair<String, String>("2066-07-21", "2009-11-07"));
        datePairs.add(new Pair<String, String>("2066-07-22", "2009-11-08"));
        datePairs.add(new Pair<String, String>("2066-07-23", "2009-11-09"));
        datePairs.add(new Pair<String, String>("2066-07-24", "2009-11-10"));
        datePairs.add(new Pair<String, String>("2066-07-25", "2009-11-11"));
        datePairs.add(new Pair<String, String>("2066-07-26", "2009-11-12"));
        datePairs.add(new Pair<String, String>("2066-07-27", "2009-11-13"));
        datePairs.add(new Pair<String, String>("2066-07-28", "2009-11-14"));
        datePairs.add(new Pair<String, String>("2066-07-29", "2009-11-15"));
        datePairs.add(new Pair<String, String>("2066-08-01", "2009-11-16"));
        datePairs.add(new Pair<String, String>("2066-08-02", "2009-11-17"));
        datePairs.add(new Pair<String, String>("2066-08-03", "2009-11-18"));
        datePairs.add(new Pair<String, String>("2066-08-04", "2009-11-19"));
        datePairs.add(new Pair<String, String>("2066-08-05", "2009-11-20"));
        datePairs.add(new Pair<String, String>("2066-08-06", "2009-11-21"));
        datePairs.add(new Pair<String, String>("2066-08-07", "2009-11-22"));
        datePairs.add(new Pair<String, String>("2066-08-08", "2009-11-23"));
        datePairs.add(new Pair<String, String>("2066-08-09", "2009-11-24"));
        datePairs.add(new Pair<String, String>("2066-08-10", "2009-11-25"));
        datePairs.add(new Pair<String, String>("2066-08-11", "2009-11-26"));
        datePairs.add(new Pair<String, String>("2066-08-12", "2009-11-27"));
        datePairs.add(new Pair<String, String>("2066-08-13", "2009-11-28"));
        datePairs.add(new Pair<String, String>("2066-08-14", "2009-11-29"));
        datePairs.add(new Pair<String, String>("2066-08-15", "2009-11-30"));
        datePairs.add(new Pair<String, String>("2066-08-16", "2009-12-01"));
        datePairs.add(new Pair<String, String>("2066-08-17", "2009-12-02"));
        datePairs.add(new Pair<String, String>("2066-08-18", "2009-12-03"));
        datePairs.add(new Pair<String, String>("2066-08-19", "2009-12-04"));
        datePairs.add(new Pair<String, String>("2066-08-20", "2009-12-05"));
        datePairs.add(new Pair<String, String>("2066-08-21", "2009-12-06"));
        datePairs.add(new Pair<String, String>("2066-08-22", "2009-12-07"));
        datePairs.add(new Pair<String, String>("2066-08-23", "2009-12-08"));
        datePairs.add(new Pair<String, String>("2066-08-24", "2009-12-09"));
        datePairs.add(new Pair<String, String>("2066-08-25", "2009-12-10"));
        datePairs.add(new Pair<String, String>("2066-08-26", "2009-12-11"));
        datePairs.add(new Pair<String, String>("2066-08-27", "2009-12-12"));
        datePairs.add(new Pair<String, String>("2066-08-28", "2009-12-13"));
        datePairs.add(new Pair<String, String>("2066-08-29", "2009-12-14"));
        datePairs.add(new Pair<String, String>("2066-08-30", "2009-12-15"));
        datePairs.add(new Pair<String, String>("2066-09-01", "2009-12-16"));
        datePairs.add(new Pair<String, String>("2066-09-02", "2009-12-17"));
        datePairs.add(new Pair<String, String>("2066-09-03", "2009-12-18"));
        datePairs.add(new Pair<String, String>("2066-09-04", "2009-12-19"));
        datePairs.add(new Pair<String, String>("2066-09-05", "2009-12-20"));
        datePairs.add(new Pair<String, String>("2066-09-06", "2009-12-21"));
        datePairs.add(new Pair<String, String>("2066-09-07", "2009-12-22"));
        datePairs.add(new Pair<String, String>("2066-09-08", "2009-12-23"));
        datePairs.add(new Pair<String, String>("2066-09-09", "2009-12-24"));
        datePairs.add(new Pair<String, String>("2066-09-10", "2009-12-25"));
        datePairs.add(new Pair<String, String>("2066-09-11", "2009-12-26"));
        datePairs.add(new Pair<String, String>("2066-09-12", "2009-12-27"));
        datePairs.add(new Pair<String, String>("2066-09-13", "2009-12-28"));
        datePairs.add(new Pair<String, String>("2066-09-14", "2009-12-29"));
        datePairs.add(new Pair<String, String>("2066-09-15", "2009-12-30"));
        datePairs.add(new Pair<String, String>("2066-09-16", "2009-12-31"));
        datePairs.add(new Pair<String, String>("2066-09-17", "2010-01-01"));
        datePairs.add(new Pair<String, String>("2066-09-18", "2010-01-02"));
        datePairs.add(new Pair<String, String>("2066-09-19", "2010-01-03"));
        datePairs.add(new Pair<String, String>("2066-09-20", "2010-01-04"));
        datePairs.add(new Pair<String, String>("2066-09-21", "2010-01-05"));
        datePairs.add(new Pair<String, String>("2066-09-22", "2010-01-06"));
        datePairs.add(new Pair<String, String>("2066-09-23", "2010-01-07"));
        datePairs.add(new Pair<String, String>("2066-09-24", "2010-01-08"));
        datePairs.add(new Pair<String, String>("2066-09-25", "2010-01-09"));
        datePairs.add(new Pair<String, String>("2066-09-26", "2010-01-10"));
        datePairs.add(new Pair<String, String>("2066-09-27", "2010-01-11"));
        datePairs.add(new Pair<String, String>("2066-09-28", "2010-01-12"));
        datePairs.add(new Pair<String, String>("2066-09-29", "2010-01-13"));
        datePairs.add(new Pair<String, String>("2066-09-30", "2010-01-14"));
        datePairs.add(new Pair<String, String>("2066-10-01", "2010-01-15"));
        datePairs.add(new Pair<String, String>("2066-10-02", "2010-01-16"));
        datePairs.add(new Pair<String, String>("2066-10-03", "2010-01-17"));
        datePairs.add(new Pair<String, String>("2066-10-04", "2010-01-18"));
        datePairs.add(new Pair<String, String>("2066-10-05", "2010-01-19"));
        datePairs.add(new Pair<String, String>("2066-10-06", "2010-01-20"));
        datePairs.add(new Pair<String, String>("2066-10-07", "2010-01-21"));
        datePairs.add(new Pair<String, String>("2066-10-08", "2010-01-22"));
        datePairs.add(new Pair<String, String>("2066-10-09", "2010-01-23"));
        datePairs.add(new Pair<String, String>("2066-10-10", "2010-01-24"));
        datePairs.add(new Pair<String, String>("2066-10-11", "2010-01-25"));
        datePairs.add(new Pair<String, String>("2066-10-12", "2010-01-26"));
        datePairs.add(new Pair<String, String>("2066-10-13", "2010-01-27"));
        datePairs.add(new Pair<String, String>("2066-10-14", "2010-01-28"));
        datePairs.add(new Pair<String, String>("2066-10-15", "2010-01-29"));
        datePairs.add(new Pair<String, String>("2066-10-16", "2010-01-30"));
        datePairs.add(new Pair<String, String>("2066-10-17", "2010-01-31"));
        datePairs.add(new Pair<String, String>("2066-10-18", "2010-02-01"));
        datePairs.add(new Pair<String, String>("2066-10-19", "2010-02-02"));
        datePairs.add(new Pair<String, String>("2066-10-20", "2010-02-03"));
        datePairs.add(new Pair<String, String>("2066-10-21", "2010-02-04"));
        datePairs.add(new Pair<String, String>("2066-10-22", "2010-02-05"));
        datePairs.add(new Pair<String, String>("2066-10-23", "2010-02-06"));
        datePairs.add(new Pair<String, String>("2066-10-24", "2010-02-07"));
        datePairs.add(new Pair<String, String>("2066-10-25", "2010-02-08"));
        datePairs.add(new Pair<String, String>("2066-10-26", "2010-02-09"));
        datePairs.add(new Pair<String, String>("2066-10-27", "2010-02-10"));
        datePairs.add(new Pair<String, String>("2066-10-28", "2010-02-11"));
        datePairs.add(new Pair<String, String>("2066-10-29", "2010-02-12"));
        datePairs.add(new Pair<String, String>("2066-11-01", "2010-02-13"));
        datePairs.add(new Pair<String, String>("2066-11-02", "2010-02-14"));
        datePairs.add(new Pair<String, String>("2066-11-03", "2010-02-15"));
        datePairs.add(new Pair<String, String>("2066-11-04", "2010-02-16"));
        datePairs.add(new Pair<String, String>("2066-11-05", "2010-02-17"));
        datePairs.add(new Pair<String, String>("2066-11-06", "2010-02-18"));
        datePairs.add(new Pair<String, String>("2066-11-07", "2010-02-19"));
        datePairs.add(new Pair<String, String>("2066-11-08", "2010-02-20"));
        datePairs.add(new Pair<String, String>("2066-11-09", "2010-02-21"));
        datePairs.add(new Pair<String, String>("2066-11-10", "2010-02-22"));
        datePairs.add(new Pair<String, String>("2066-11-11", "2010-02-23"));
        datePairs.add(new Pair<String, String>("2066-11-12", "2010-02-24"));
        datePairs.add(new Pair<String, String>("2066-11-13", "2010-02-25"));
        datePairs.add(new Pair<String, String>("2066-11-14", "2010-02-26"));
        datePairs.add(new Pair<String, String>("2066-11-15", "2010-02-27"));
        datePairs.add(new Pair<String, String>("2066-11-16", "2010-02-28"));
        datePairs.add(new Pair<String, String>("2066-11-17", "2010-03-01"));
        datePairs.add(new Pair<String, String>("2066-11-18", "2010-03-02"));
        datePairs.add(new Pair<String, String>("2066-11-19", "2010-03-03"));
        datePairs.add(new Pair<String, String>("2066-11-20", "2010-03-04"));
        datePairs.add(new Pair<String, String>("2066-11-21", "2010-03-05"));
        datePairs.add(new Pair<String, String>("2066-11-22", "2010-03-06"));
        datePairs.add(new Pair<String, String>("2066-11-23", "2010-03-07"));
        datePairs.add(new Pair<String, String>("2066-11-24", "2010-03-08"));
        datePairs.add(new Pair<String, String>("2066-11-25", "2010-03-09"));
        datePairs.add(new Pair<String, String>("2066-11-26", "2010-03-10"));
        datePairs.add(new Pair<String, String>("2066-11-27", "2010-03-11"));
        datePairs.add(new Pair<String, String>("2066-11-28", "2010-03-12"));
        datePairs.add(new Pair<String, String>("2066-11-29", "2010-03-13"));
        datePairs.add(new Pair<String, String>("2066-12-01", "2010-03-14"));
        datePairs.add(new Pair<String, String>("2066-12-02", "2010-03-15"));
        datePairs.add(new Pair<String, String>("2066-12-03", "2010-03-16"));
        datePairs.add(new Pair<String, String>("2066-12-04", "2010-03-17"));
        datePairs.add(new Pair<String, String>("2066-12-05", "2010-03-18"));
        datePairs.add(new Pair<String, String>("2066-12-06", "2010-03-19"));
        datePairs.add(new Pair<String, String>("2066-12-07", "2010-03-20"));
        datePairs.add(new Pair<String, String>("2066-12-08", "2010-03-21"));
        datePairs.add(new Pair<String, String>("2066-12-09", "2010-03-22"));
        datePairs.add(new Pair<String, String>("2066-12-10", "2010-03-23"));
        datePairs.add(new Pair<String, String>("2066-12-11", "2010-03-24"));
        datePairs.add(new Pair<String, String>("2066-12-12", "2010-03-25"));
        datePairs.add(new Pair<String, String>("2066-12-13", "2010-03-26"));
        datePairs.add(new Pair<String, String>("2066-12-14", "2010-03-27"));
        datePairs.add(new Pair<String, String>("2066-12-15", "2010-03-28"));
        datePairs.add(new Pair<String, String>("2066-12-16", "2010-03-29"));
        datePairs.add(new Pair<String, String>("2066-12-17", "2010-03-30"));
        datePairs.add(new Pair<String, String>("2066-12-18", "2010-03-31"));
        datePairs.add(new Pair<String, String>("2066-12-19", "2010-04-01"));
        datePairs.add(new Pair<String, String>("2066-12-20", "2010-04-02"));
        datePairs.add(new Pair<String, String>("2066-12-21", "2010-04-03"));
        datePairs.add(new Pair<String, String>("2066-12-22", "2010-04-04"));
        datePairs.add(new Pair<String, String>("2066-12-23", "2010-04-05"));
        datePairs.add(new Pair<String, String>("2066-12-24", "2010-04-06"));
        datePairs.add(new Pair<String, String>("2066-12-25", "2010-04-07"));
        datePairs.add(new Pair<String, String>("2066-12-26", "2010-04-08"));
        datePairs.add(new Pair<String, String>("2066-12-27", "2010-04-09"));
        datePairs.add(new Pair<String, String>("2066-12-28", "2010-04-10"));
        datePairs.add(new Pair<String, String>("2066-12-29", "2010-04-11"));
        datePairs.add(new Pair<String, String>("2066-12-30", "2010-04-12"));
        datePairs.add(new Pair<String, String>("2066-12-31", "2010-04-13"));
        datePairs.add(new Pair<String, String>("2067-01-01", "2010-04-14"));
        datePairs.add(new Pair<String, String>("2067-01-02", "2010-04-15"));
        datePairs.add(new Pair<String, String>("2067-01-03", "2010-04-16"));
        datePairs.add(new Pair<String, String>("2067-01-04", "2010-04-17"));
        datePairs.add(new Pair<String, String>("2067-01-05", "2010-04-18"));
        datePairs.add(new Pair<String, String>("2067-01-06", "2010-04-19"));
        datePairs.add(new Pair<String, String>("2067-01-07", "2010-04-20"));
        datePairs.add(new Pair<String, String>("2067-01-08", "2010-04-21"));
        datePairs.add(new Pair<String, String>("2067-01-09", "2010-04-22"));
        datePairs.add(new Pair<String, String>("2067-01-10", "2010-04-23"));
        datePairs.add(new Pair<String, String>("2067-01-11", "2010-04-24"));
        datePairs.add(new Pair<String, String>("2067-01-12", "2010-04-25"));
        datePairs.add(new Pair<String, String>("2067-01-13", "2010-04-26"));
        datePairs.add(new Pair<String, String>("2067-01-14", "2010-04-27"));
        datePairs.add(new Pair<String, String>("2067-01-15", "2010-04-28"));
        datePairs.add(new Pair<String, String>("2067-01-16", "2010-04-29"));
        datePairs.add(new Pair<String, String>("2067-01-17", "2010-04-30"));
        datePairs.add(new Pair<String, String>("2067-01-18", "2010-05-01"));
        datePairs.add(new Pair<String, String>("2067-01-19", "2010-05-02"));
        datePairs.add(new Pair<String, String>("2067-01-20", "2010-05-03"));
        datePairs.add(new Pair<String, String>("2067-01-21", "2010-05-04"));
        datePairs.add(new Pair<String, String>("2067-01-22", "2010-05-05"));
        datePairs.add(new Pair<String, String>("2067-01-23", "2010-05-06"));
        datePairs.add(new Pair<String, String>("2067-01-24", "2010-05-07"));
        datePairs.add(new Pair<String, String>("2067-01-25", "2010-05-08"));
        datePairs.add(new Pair<String, String>("2067-01-26", "2010-05-09"));
        datePairs.add(new Pair<String, String>("2067-01-27", "2010-05-10"));
        datePairs.add(new Pair<String, String>("2067-01-28", "2010-05-11"));
        datePairs.add(new Pair<String, String>("2067-01-29", "2010-05-12"));
        datePairs.add(new Pair<String, String>("2067-01-30", "2010-05-13"));
        datePairs.add(new Pair<String, String>("2067-01-31", "2010-05-14"));
        datePairs.add(new Pair<String, String>("2067-02-01", "2010-05-15"));
        datePairs.add(new Pair<String, String>("2067-02-02", "2010-05-16"));
        datePairs.add(new Pair<String, String>("2067-02-03", "2010-05-17"));
        datePairs.add(new Pair<String, String>("2067-02-04", "2010-05-18"));
        datePairs.add(new Pair<String, String>("2067-02-05", "2010-05-19"));
        datePairs.add(new Pair<String, String>("2067-02-06", "2010-05-20"));
        datePairs.add(new Pair<String, String>("2067-02-07", "2010-05-21"));
        datePairs.add(new Pair<String, String>("2067-02-08", "2010-05-22"));
        datePairs.add(new Pair<String, String>("2067-02-09", "2010-05-23"));
        datePairs.add(new Pair<String, String>("2067-02-10", "2010-05-24"));
        datePairs.add(new Pair<String, String>("2067-02-11", "2010-05-25"));
        datePairs.add(new Pair<String, String>("2067-02-12", "2010-05-26"));
        datePairs.add(new Pair<String, String>("2067-02-13", "2010-05-27"));
        datePairs.add(new Pair<String, String>("2067-02-14", "2010-05-28"));
        datePairs.add(new Pair<String, String>("2067-02-15", "2010-05-29"));
        datePairs.add(new Pair<String, String>("2067-02-16", "2010-05-30"));
        datePairs.add(new Pair<String, String>("2067-02-17", "2010-05-31"));
        datePairs.add(new Pair<String, String>("2067-02-18", "2010-06-01"));
        datePairs.add(new Pair<String, String>("2067-02-19", "2010-06-02"));
        datePairs.add(new Pair<String, String>("2067-02-20", "2010-06-03"));
        datePairs.add(new Pair<String, String>("2067-02-21", "2010-06-04"));
        datePairs.add(new Pair<String, String>("2067-02-22", "2010-06-05"));
        datePairs.add(new Pair<String, String>("2067-02-23", "2010-06-06"));
        datePairs.add(new Pair<String, String>("2067-02-24", "2010-06-07"));
        datePairs.add(new Pair<String, String>("2067-02-25", "2010-06-08"));
        datePairs.add(new Pair<String, String>("2067-02-26", "2010-06-09"));
        datePairs.add(new Pair<String, String>("2067-02-27", "2010-06-10"));
        datePairs.add(new Pair<String, String>("2067-02-28", "2010-06-11"));
        datePairs.add(new Pair<String, String>("2067-02-29", "2010-06-12"));
        datePairs.add(new Pair<String, String>("2067-02-30", "2010-06-13"));
        datePairs.add(new Pair<String, String>("2067-02-31", "2010-06-14"));
        datePairs.add(new Pair<String, String>("2067-03-01", "2010-06-15"));
        datePairs.add(new Pair<String, String>("2067-03-02", "2010-06-16"));
        datePairs.add(new Pair<String, String>("2067-03-03", "2010-06-17"));
        datePairs.add(new Pair<String, String>("2067-03-04", "2010-06-18"));
        datePairs.add(new Pair<String, String>("2067-03-05", "2010-06-19"));
        datePairs.add(new Pair<String, String>("2067-03-06", "2010-06-20"));
        datePairs.add(new Pair<String, String>("2067-03-07", "2010-06-21"));
        datePairs.add(new Pair<String, String>("2067-03-08", "2010-06-22"));
        datePairs.add(new Pair<String, String>("2067-03-09", "2010-06-23"));
        datePairs.add(new Pair<String, String>("2067-03-10", "2010-06-24"));
        datePairs.add(new Pair<String, String>("2067-03-11", "2010-06-25"));
        datePairs.add(new Pair<String, String>("2067-03-12", "2010-06-26"));
        datePairs.add(new Pair<String, String>("2067-03-13", "2010-06-27"));
        datePairs.add(new Pair<String, String>("2067-03-14", "2010-06-28"));
        datePairs.add(new Pair<String, String>("2067-03-15", "2010-06-29"));
        datePairs.add(new Pair<String, String>("2067-03-16", "2010-06-30"));
        datePairs.add(new Pair<String, String>("2067-03-17", "2010-07-01"));
        datePairs.add(new Pair<String, String>("2067-03-18", "2010-07-02"));
        datePairs.add(new Pair<String, String>("2067-03-19", "2010-07-03"));
        datePairs.add(new Pair<String, String>("2067-03-20", "2010-07-04"));
        datePairs.add(new Pair<String, String>("2067-03-21", "2010-07-05"));
        datePairs.add(new Pair<String, String>("2067-03-22", "2010-07-06"));
        datePairs.add(new Pair<String, String>("2067-03-23", "2010-07-07"));
        datePairs.add(new Pair<String, String>("2067-03-24", "2010-07-08"));
        datePairs.add(new Pair<String, String>("2067-03-25", "2010-07-09"));
        datePairs.add(new Pair<String, String>("2067-03-26", "2010-07-10"));
        datePairs.add(new Pair<String, String>("2067-03-27", "2010-07-11"));
        datePairs.add(new Pair<String, String>("2067-03-28", "2010-07-12"));
        datePairs.add(new Pair<String, String>("2067-03-29", "2010-07-13"));
        datePairs.add(new Pair<String, String>("2067-03-30", "2010-07-14"));
        datePairs.add(new Pair<String, String>("2067-03-31", "2010-07-15"));
        datePairs.add(new Pair<String, String>("2067-03-32", "2010-07-16"));
        datePairs.add(new Pair<String, String>("2067-04-01", "2010-07-17"));
        datePairs.add(new Pair<String, String>("2067-04-02", "2010-07-18"));
        datePairs.add(new Pair<String, String>("2067-04-03", "2010-07-19"));
        datePairs.add(new Pair<String, String>("2067-04-04", "2010-07-20"));
        datePairs.add(new Pair<String, String>("2067-04-05", "2010-07-21"));
        datePairs.add(new Pair<String, String>("2067-04-06", "2010-07-22"));
        datePairs.add(new Pair<String, String>("2067-04-07", "2010-07-23"));
        datePairs.add(new Pair<String, String>("2067-04-08", "2010-07-24"));
        datePairs.add(new Pair<String, String>("2067-04-09", "2010-07-25"));
        datePairs.add(new Pair<String, String>("2067-04-10", "2010-07-26"));
        datePairs.add(new Pair<String, String>("2067-04-11", "2010-07-27"));
        datePairs.add(new Pair<String, String>("2067-04-12", "2010-07-28"));
        datePairs.add(new Pair<String, String>("2067-04-13", "2010-07-29"));
        datePairs.add(new Pair<String, String>("2067-04-14", "2010-07-30"));
        datePairs.add(new Pair<String, String>("2067-04-15", "2010-07-31"));
        datePairs.add(new Pair<String, String>("2067-04-16", "2010-08-01"));
        datePairs.add(new Pair<String, String>("2067-04-17", "2010-08-02"));
        datePairs.add(new Pair<String, String>("2067-04-18", "2010-08-03"));
        datePairs.add(new Pair<String, String>("2067-04-19", "2010-08-04"));
        datePairs.add(new Pair<String, String>("2067-04-20", "2010-08-05"));
        datePairs.add(new Pair<String, String>("2067-04-21", "2010-08-06"));
        datePairs.add(new Pair<String, String>("2067-04-22", "2010-08-07"));
        datePairs.add(new Pair<String, String>("2067-04-23", "2010-08-08"));
        datePairs.add(new Pair<String, String>("2067-04-24", "2010-08-09"));
        datePairs.add(new Pair<String, String>("2067-04-25", "2010-08-10"));
        datePairs.add(new Pair<String, String>("2067-04-26", "2010-08-11"));
        datePairs.add(new Pair<String, String>("2067-04-27", "2010-08-12"));
        datePairs.add(new Pair<String, String>("2067-04-28", "2010-08-13"));
        datePairs.add(new Pair<String, String>("2067-04-29", "2010-08-14"));
        datePairs.add(new Pair<String, String>("2067-04-30", "2010-08-15"));
        datePairs.add(new Pair<String, String>("2067-04-31", "2010-08-16"));
        datePairs.add(new Pair<String, String>("2067-05-01", "2010-08-17"));
        datePairs.add(new Pair<String, String>("2067-05-02", "2010-08-18"));
        datePairs.add(new Pair<String, String>("2067-05-03", "2010-08-19"));
        datePairs.add(new Pair<String, String>("2067-05-04", "2010-08-20"));
        datePairs.add(new Pair<String, String>("2067-05-05", "2010-08-21"));
        datePairs.add(new Pair<String, String>("2067-05-06", "2010-08-22"));
        datePairs.add(new Pair<String, String>("2067-05-07", "2010-08-23"));
        datePairs.add(new Pair<String, String>("2067-05-08", "2010-08-24"));
        datePairs.add(new Pair<String, String>("2067-05-09", "2010-08-25"));
        datePairs.add(new Pair<String, String>("2067-05-10", "2010-08-26"));
        datePairs.add(new Pair<String, String>("2067-05-11", "2010-08-27"));
        datePairs.add(new Pair<String, String>("2067-05-12", "2010-08-28"));
        datePairs.add(new Pair<String, String>("2067-05-13", "2010-08-29"));
        datePairs.add(new Pair<String, String>("2067-05-14", "2010-08-30"));
        datePairs.add(new Pair<String, String>("2067-05-15", "2010-08-31"));
        datePairs.add(new Pair<String, String>("2067-05-16", "2010-09-01"));
        datePairs.add(new Pair<String, String>("2067-05-17", "2010-09-02"));
        datePairs.add(new Pair<String, String>("2067-05-18", "2010-09-03"));
        datePairs.add(new Pair<String, String>("2067-05-19", "2010-09-04"));
        datePairs.add(new Pair<String, String>("2067-05-20", "2010-09-05"));
        datePairs.add(new Pair<String, String>("2067-05-21", "2010-09-06"));
        datePairs.add(new Pair<String, String>("2067-05-22", "2010-09-07"));
        datePairs.add(new Pair<String, String>("2067-05-23", "2010-09-08"));
        datePairs.add(new Pair<String, String>("2067-05-24", "2010-09-09"));
        datePairs.add(new Pair<String, String>("2067-05-25", "2010-09-10"));
        datePairs.add(new Pair<String, String>("2067-05-26", "2010-09-11"));
        datePairs.add(new Pair<String, String>("2067-05-27", "2010-09-12"));
        datePairs.add(new Pair<String, String>("2067-05-28", "2010-09-13"));
        datePairs.add(new Pair<String, String>("2067-05-29", "2010-09-14"));
        datePairs.add(new Pair<String, String>("2067-05-30", "2010-09-15"));
        datePairs.add(new Pair<String, String>("2067-05-31", "2010-09-16"));
        datePairs.add(new Pair<String, String>("2067-06-01", "2010-09-17"));
        datePairs.add(new Pair<String, String>("2067-06-02", "2010-09-18"));
        datePairs.add(new Pair<String, String>("2067-06-03", "2010-09-19"));
        datePairs.add(new Pair<String, String>("2067-06-04", "2010-09-20"));
        datePairs.add(new Pair<String, String>("2067-06-05", "2010-09-21"));
        datePairs.add(new Pair<String, String>("2067-06-06", "2010-09-22"));
        datePairs.add(new Pair<String, String>("2067-06-07", "2010-09-23"));
        datePairs.add(new Pair<String, String>("2067-06-08", "2010-09-24"));
        datePairs.add(new Pair<String, String>("2067-06-09", "2010-09-25"));
        datePairs.add(new Pair<String, String>("2067-06-10", "2010-09-26"));
        datePairs.add(new Pair<String, String>("2067-06-11", "2010-09-27"));
        datePairs.add(new Pair<String, String>("2067-06-12", "2010-09-28"));
        datePairs.add(new Pair<String, String>("2067-06-13", "2010-09-29"));
        datePairs.add(new Pair<String, String>("2067-06-14", "2010-09-30"));
        datePairs.add(new Pair<String, String>("2067-06-15", "2010-10-01"));
        datePairs.add(new Pair<String, String>("2067-06-16", "2010-10-02"));
        datePairs.add(new Pair<String, String>("2067-06-17", "2010-10-03"));
        datePairs.add(new Pair<String, String>("2067-06-18", "2010-10-04"));
        datePairs.add(new Pair<String, String>("2067-06-19", "2010-10-05"));
        datePairs.add(new Pair<String, String>("2067-06-20", "2010-10-06"));
        datePairs.add(new Pair<String, String>("2067-06-21", "2010-10-07"));
        datePairs.add(new Pair<String, String>("2067-06-22", "2010-10-08"));
        datePairs.add(new Pair<String, String>("2067-06-23", "2010-10-09"));
        datePairs.add(new Pair<String, String>("2067-06-24", "2010-10-10"));
        datePairs.add(new Pair<String, String>("2067-06-25", "2010-10-11"));
        datePairs.add(new Pair<String, String>("2067-06-26", "2010-10-12"));
        datePairs.add(new Pair<String, String>("2067-06-27", "2010-10-13"));
        datePairs.add(new Pair<String, String>("2067-06-28", "2010-10-14"));
        datePairs.add(new Pair<String, String>("2067-06-29", "2010-10-15"));
        datePairs.add(new Pair<String, String>("2067-06-30", "2010-10-16"));
        datePairs.add(new Pair<String, String>("2067-06-31", "2010-10-17"));
        datePairs.add(new Pair<String, String>("2067-07-01", "2010-10-18"));
        datePairs.add(new Pair<String, String>("2067-07-02", "2010-10-19"));
        datePairs.add(new Pair<String, String>("2067-07-03", "2010-10-20"));
        datePairs.add(new Pair<String, String>("2067-07-04", "2010-10-21"));
        datePairs.add(new Pair<String, String>("2067-07-05", "2010-10-22"));
        datePairs.add(new Pair<String, String>("2067-07-06", "2010-10-23"));
        datePairs.add(new Pair<String, String>("2067-07-07", "2010-10-24"));
        datePairs.add(new Pair<String, String>("2067-07-08", "2010-10-25"));
        datePairs.add(new Pair<String, String>("2067-07-09", "2010-10-26"));
        datePairs.add(new Pair<String, String>("2067-07-10", "2010-10-27"));
        datePairs.add(new Pair<String, String>("2067-07-11", "2010-10-28"));
        datePairs.add(new Pair<String, String>("2067-07-12", "2010-10-29"));
        datePairs.add(new Pair<String, String>("2067-07-13", "2010-10-30"));
        datePairs.add(new Pair<String, String>("2067-07-14", "2010-10-31"));
        datePairs.add(new Pair<String, String>("2067-07-15", "2010-11-01"));
        datePairs.add(new Pair<String, String>("2067-07-16", "2010-11-02"));
        datePairs.add(new Pair<String, String>("2067-07-17", "2010-11-03"));
        datePairs.add(new Pair<String, String>("2067-07-18", "2010-11-04"));
        datePairs.add(new Pair<String, String>("2067-07-19", "2010-11-05"));
        datePairs.add(new Pair<String, String>("2067-07-20", "2010-11-06"));
        datePairs.add(new Pair<String, String>("2067-07-21", "2010-11-07"));
        datePairs.add(new Pair<String, String>("2067-07-22", "2010-11-08"));
        datePairs.add(new Pair<String, String>("2067-07-23", "2010-11-09"));
        datePairs.add(new Pair<String, String>("2067-07-24", "2010-11-10"));
        datePairs.add(new Pair<String, String>("2067-07-25", "2010-11-11"));
        datePairs.add(new Pair<String, String>("2067-07-26", "2010-11-12"));
        datePairs.add(new Pair<String, String>("2067-07-27", "2010-11-13"));
        datePairs.add(new Pair<String, String>("2067-07-28", "2010-11-14"));
        datePairs.add(new Pair<String, String>("2067-07-29", "2010-11-15"));
        datePairs.add(new Pair<String, String>("2067-07-30", "2010-11-16"));
        datePairs.add(new Pair<String, String>("2067-08-01", "2010-11-17"));
        datePairs.add(new Pair<String, String>("2067-08-02", "2010-11-18"));
        datePairs.add(new Pair<String, String>("2067-08-03", "2010-11-19"));
        datePairs.add(new Pair<String, String>("2067-08-04", "2010-11-20"));
        datePairs.add(new Pair<String, String>("2067-08-05", "2010-11-21"));
        datePairs.add(new Pair<String, String>("2067-08-06", "2010-11-22"));
        datePairs.add(new Pair<String, String>("2067-08-07", "2010-11-23"));
        datePairs.add(new Pair<String, String>("2067-08-08", "2010-11-24"));
        datePairs.add(new Pair<String, String>("2067-08-09", "2010-11-25"));
        datePairs.add(new Pair<String, String>("2067-08-10", "2010-11-26"));
        datePairs.add(new Pair<String, String>("2067-08-11", "2010-11-27"));
        datePairs.add(new Pair<String, String>("2067-08-12", "2010-11-28"));
        datePairs.add(new Pair<String, String>("2067-08-13", "2010-11-29"));
        datePairs.add(new Pair<String, String>("2067-08-14", "2010-11-30"));
        datePairs.add(new Pair<String, String>("2067-08-15", "2010-12-01"));
        datePairs.add(new Pair<String, String>("2067-08-16", "2010-12-02"));
        datePairs.add(new Pair<String, String>("2067-08-17", "2010-12-03"));
        datePairs.add(new Pair<String, String>("2067-08-18", "2010-12-04"));
        datePairs.add(new Pair<String, String>("2067-08-19", "2010-12-05"));
        datePairs.add(new Pair<String, String>("2067-08-20", "2010-12-06"));
        datePairs.add(new Pair<String, String>("2067-08-21", "2010-12-07"));
        datePairs.add(new Pair<String, String>("2067-08-22", "2010-12-08"));
        datePairs.add(new Pair<String, String>("2067-08-23", "2010-12-09"));
        datePairs.add(new Pair<String, String>("2067-08-24", "2010-12-10"));
        datePairs.add(new Pair<String, String>("2067-08-25", "2010-12-11"));
        datePairs.add(new Pair<String, String>("2067-08-26", "2010-12-12"));
        datePairs.add(new Pair<String, String>("2067-08-27", "2010-12-13"));
        datePairs.add(new Pair<String, String>("2067-08-28", "2010-12-14"));
        datePairs.add(new Pair<String, String>("2067-08-29", "2010-12-15"));
        datePairs.add(new Pair<String, String>("2067-09-01", "2010-12-16"));
        datePairs.add(new Pair<String, String>("2067-09-02", "2010-12-17"));
        datePairs.add(new Pair<String, String>("2067-09-03", "2010-12-18"));
        datePairs.add(new Pair<String, String>("2067-09-04", "2010-12-19"));
        datePairs.add(new Pair<String, String>("2067-09-05", "2010-12-20"));
        datePairs.add(new Pair<String, String>("2067-09-06", "2010-12-21"));
        datePairs.add(new Pair<String, String>("2067-09-07", "2010-12-22"));
        datePairs.add(new Pair<String, String>("2067-09-08", "2010-12-23"));
        datePairs.add(new Pair<String, String>("2067-09-09", "2010-12-24"));
        datePairs.add(new Pair<String, String>("2067-09-10", "2010-12-25"));
        datePairs.add(new Pair<String, String>("2067-09-11", "2010-12-26"));
        datePairs.add(new Pair<String, String>("2067-09-12", "2010-12-27"));
        datePairs.add(new Pair<String, String>("2067-09-13", "2010-12-28"));
        datePairs.add(new Pair<String, String>("2067-09-14", "2010-12-29"));
        datePairs.add(new Pair<String, String>("2067-09-15", "2010-12-30"));
        datePairs.add(new Pair<String, String>("2067-09-16", "2010-12-31"));
        datePairs.add(new Pair<String, String>("2067-09-17", "2011-01-01"));
        datePairs.add(new Pair<String, String>("2067-09-18", "2011-01-02"));
        datePairs.add(new Pair<String, String>("2067-09-19", "2011-01-03"));
        datePairs.add(new Pair<String, String>("2067-09-20", "2011-01-04"));
        datePairs.add(new Pair<String, String>("2067-09-21", "2011-01-05"));
        datePairs.add(new Pair<String, String>("2067-09-22", "2011-01-06"));
        datePairs.add(new Pair<String, String>("2067-09-23", "2011-01-07"));
        datePairs.add(new Pair<String, String>("2067-09-24", "2011-01-08"));
        datePairs.add(new Pair<String, String>("2067-09-25", "2011-01-09"));
        datePairs.add(new Pair<String, String>("2067-09-26", "2011-01-10"));
        datePairs.add(new Pair<String, String>("2067-09-27", "2011-01-11"));
        datePairs.add(new Pair<String, String>("2067-09-28", "2011-01-12"));
        datePairs.add(new Pair<String, String>("2067-09-29", "2011-01-13"));
        datePairs.add(new Pair<String, String>("2067-09-30", "2011-01-14"));
        datePairs.add(new Pair<String, String>("2067-10-01", "2011-01-15"));
        datePairs.add(new Pair<String, String>("2067-10-02", "2011-01-16"));
        datePairs.add(new Pair<String, String>("2067-10-03", "2011-01-17"));
        datePairs.add(new Pair<String, String>("2067-10-04", "2011-01-18"));
        datePairs.add(new Pair<String, String>("2067-10-05", "2011-01-19"));
        datePairs.add(new Pair<String, String>("2067-10-06", "2011-01-20"));
        datePairs.add(new Pair<String, String>("2067-10-07", "2011-01-21"));
        datePairs.add(new Pair<String, String>("2067-10-08", "2011-01-22"));
        datePairs.add(new Pair<String, String>("2067-10-09", "2011-01-23"));
        datePairs.add(new Pair<String, String>("2067-10-10", "2011-01-24"));
        datePairs.add(new Pair<String, String>("2067-10-11", "2011-01-25"));
        datePairs.add(new Pair<String, String>("2067-10-12", "2011-01-26"));
        datePairs.add(new Pair<String, String>("2067-10-13", "2011-01-27"));
        datePairs.add(new Pair<String, String>("2067-10-14", "2011-01-28"));
        datePairs.add(new Pair<String, String>("2067-10-15", "2011-01-29"));
        datePairs.add(new Pair<String, String>("2067-10-16", "2011-01-30"));
        datePairs.add(new Pair<String, String>("2067-10-17", "2011-01-31"));
        datePairs.add(new Pair<String, String>("2067-10-18", "2011-02-01"));
        datePairs.add(new Pair<String, String>("2067-10-19", "2011-02-02"));
        datePairs.add(new Pair<String, String>("2067-10-20", "2011-02-03"));
        datePairs.add(new Pair<String, String>("2067-10-21", "2011-02-04"));
        datePairs.add(new Pair<String, String>("2067-10-22", "2011-02-05"));
        datePairs.add(new Pair<String, String>("2067-10-23", "2011-02-06"));
        datePairs.add(new Pair<String, String>("2067-10-24", "2011-02-07"));
        datePairs.add(new Pair<String, String>("2067-10-25", "2011-02-08"));
        datePairs.add(new Pair<String, String>("2067-10-26", "2011-02-09"));
        datePairs.add(new Pair<String, String>("2067-10-27", "2011-02-10"));
        datePairs.add(new Pair<String, String>("2067-10-28", "2011-02-11"));
        datePairs.add(new Pair<String, String>("2067-10-29", "2011-02-12"));
        datePairs.add(new Pair<String, String>("2067-11-01", "2011-02-13"));
        datePairs.add(new Pair<String, String>("2067-11-02", "2011-02-14"));
        datePairs.add(new Pair<String, String>("2067-11-03", "2011-02-15"));
        datePairs.add(new Pair<String, String>("2067-11-04", "2011-02-16"));
        datePairs.add(new Pair<String, String>("2067-11-05", "2011-02-17"));
        datePairs.add(new Pair<String, String>("2067-11-06", "2011-02-18"));
        datePairs.add(new Pair<String, String>("2067-11-07", "2011-02-19"));
        datePairs.add(new Pair<String, String>("2067-11-08", "2011-02-20"));
        datePairs.add(new Pair<String, String>("2067-11-09", "2011-02-21"));
        datePairs.add(new Pair<String, String>("2067-11-10", "2011-02-22"));
        datePairs.add(new Pair<String, String>("2067-11-11", "2011-02-23"));
        datePairs.add(new Pair<String, String>("2067-11-12", "2011-02-24"));
        datePairs.add(new Pair<String, String>("2067-11-13", "2011-02-25"));
        datePairs.add(new Pair<String, String>("2067-11-14", "2011-02-26"));
        datePairs.add(new Pair<String, String>("2067-11-15", "2011-02-27"));
        datePairs.add(new Pair<String, String>("2067-11-16", "2011-02-28"));
        datePairs.add(new Pair<String, String>("2067-11-17", "2011-03-01"));
        datePairs.add(new Pair<String, String>("2067-11-18", "2011-03-02"));
        datePairs.add(new Pair<String, String>("2067-11-19", "2011-03-03"));
        datePairs.add(new Pair<String, String>("2067-11-20", "2011-03-04"));
        datePairs.add(new Pair<String, String>("2067-11-21", "2011-03-05"));
        datePairs.add(new Pair<String, String>("2067-11-22", "2011-03-06"));
        datePairs.add(new Pair<String, String>("2067-11-23", "2011-03-07"));
        datePairs.add(new Pair<String, String>("2067-11-24", "2011-03-08"));
        datePairs.add(new Pair<String, String>("2067-11-25", "2011-03-09"));
        datePairs.add(new Pair<String, String>("2067-11-26", "2011-03-10"));
        datePairs.add(new Pair<String, String>("2067-11-27", "2011-03-11"));
        datePairs.add(new Pair<String, String>("2067-11-28", "2011-03-12"));
        datePairs.add(new Pair<String, String>("2067-11-29", "2011-03-13"));
        datePairs.add(new Pair<String, String>("2067-11-30", "2011-03-14"));
        datePairs.add(new Pair<String, String>("2067-12-01", "2011-03-15"));
        datePairs.add(new Pair<String, String>("2067-12-02", "2011-03-16"));
        datePairs.add(new Pair<String, String>("2067-12-03", "2011-03-17"));
        datePairs.add(new Pair<String, String>("2067-12-04", "2011-03-18"));
        datePairs.add(new Pair<String, String>("2067-12-05", "2011-03-19"));
        datePairs.add(new Pair<String, String>("2067-12-06", "2011-03-20"));
        datePairs.add(new Pair<String, String>("2067-12-07", "2011-03-21"));
        datePairs.add(new Pair<String, String>("2067-12-08", "2011-03-22"));
        datePairs.add(new Pair<String, String>("2067-12-09", "2011-03-23"));
        datePairs.add(new Pair<String, String>("2067-12-10", "2011-03-24"));
        datePairs.add(new Pair<String, String>("2067-12-11", "2011-03-25"));
        datePairs.add(new Pair<String, String>("2067-12-12", "2011-03-26"));
        datePairs.add(new Pair<String, String>("2067-12-13", "2011-03-27"));
        datePairs.add(new Pair<String, String>("2067-12-14", "2011-03-28"));
        datePairs.add(new Pair<String, String>("2067-12-15", "2011-03-29"));
        datePairs.add(new Pair<String, String>("2067-12-16", "2011-03-30"));
        datePairs.add(new Pair<String, String>("2067-12-17", "2011-03-31"));
        datePairs.add(new Pair<String, String>("2067-12-18", "2011-04-01"));
        datePairs.add(new Pair<String, String>("2067-12-19", "2011-04-02"));
        datePairs.add(new Pair<String, String>("2067-12-20", "2011-04-03"));
        datePairs.add(new Pair<String, String>("2067-12-21", "2011-04-04"));
        datePairs.add(new Pair<String, String>("2067-12-22", "2011-04-05"));
        datePairs.add(new Pair<String, String>("2067-12-23", "2011-04-06"));
        datePairs.add(new Pair<String, String>("2067-12-24", "2011-04-07"));
        datePairs.add(new Pair<String, String>("2067-12-25", "2011-04-08"));
        datePairs.add(new Pair<String, String>("2067-12-26", "2011-04-09"));
        datePairs.add(new Pair<String, String>("2067-12-27", "2011-04-10"));
        datePairs.add(new Pair<String, String>("2067-12-28", "2011-04-11"));
        datePairs.add(new Pair<String, String>("2067-12-29", "2011-04-12"));
        datePairs.add(new Pair<String, String>("2067-12-30", "2011-04-13"));

    }

    public void appendConversionValues2() {
        datePairs.add(new Pair<String, String>("2068-01-01", "2011-04-14"));
        datePairs.add(new Pair<String, String>("2068-01-02", "2011-04-15"));
        datePairs.add(new Pair<String, String>("2068-01-03", "2011-04-16"));
        datePairs.add(new Pair<String, String>("2068-01-04", "2011-04-17"));
        datePairs.add(new Pair<String, String>("2068-01-05", "2011-04-18"));
        datePairs.add(new Pair<String, String>("2068-01-06", "2011-04-19"));
        datePairs.add(new Pair<String, String>("2068-01-07", "2011-04-20"));
        datePairs.add(new Pair<String, String>("2068-01-08", "2011-04-21"));
        datePairs.add(new Pair<String, String>("2068-01-09", "2011-04-22"));
        datePairs.add(new Pair<String, String>("2068-01-10", "2011-04-23"));
        datePairs.add(new Pair<String, String>("2068-01-11", "2011-04-24"));
        datePairs.add(new Pair<String, String>("2068-01-12", "2011-04-25"));
        datePairs.add(new Pair<String, String>("2068-01-13", "2011-04-26"));
        datePairs.add(new Pair<String, String>("2068-01-14", "2011-04-27"));
        datePairs.add(new Pair<String, String>("2068-01-15", "2011-04-28"));
        datePairs.add(new Pair<String, String>("2068-01-16", "2011-04-29"));
        datePairs.add(new Pair<String, String>("2068-01-17", "2011-04-30"));
        datePairs.add(new Pair<String, String>("2068-01-18", "2011-05-01"));
        datePairs.add(new Pair<String, String>("2068-01-19", "2011-05-02"));
        datePairs.add(new Pair<String, String>("2068-01-20", "2011-05-03"));
        datePairs.add(new Pair<String, String>("2068-01-21", "2011-05-04"));
        datePairs.add(new Pair<String, String>("2068-01-22", "2011-05-05"));
        datePairs.add(new Pair<String, String>("2068-01-23", "2011-05-06"));
        datePairs.add(new Pair<String, String>("2068-01-24", "2011-05-07"));
        datePairs.add(new Pair<String, String>("2068-01-25", "2011-05-08"));
        datePairs.add(new Pair<String, String>("2068-01-26", "2011-05-09"));
        datePairs.add(new Pair<String, String>("2068-01-27", "2011-05-10"));
        datePairs.add(new Pair<String, String>("2068-01-28", "2011-05-11"));
        datePairs.add(new Pair<String, String>("2068-01-29", "2011-05-12"));
        datePairs.add(new Pair<String, String>("2068-01-30", "2011-05-13"));
        datePairs.add(new Pair<String, String>("2068-01-31", "2011-05-14"));
        datePairs.add(new Pair<String, String>("2068-02-01", "2011-05-15"));
        datePairs.add(new Pair<String, String>("2068-02-02", "2011-05-16"));
        datePairs.add(new Pair<String, String>("2068-02-03", "2011-05-17"));
        datePairs.add(new Pair<String, String>("2068-02-04", "2011-05-18"));
        datePairs.add(new Pair<String, String>("2068-02-05", "2011-05-19"));
        datePairs.add(new Pair<String, String>("2068-02-06", "2011-05-20"));
        datePairs.add(new Pair<String, String>("2068-02-07", "2011-05-21"));
        datePairs.add(new Pair<String, String>("2068-02-08", "2011-05-22"));
        datePairs.add(new Pair<String, String>("2068-02-09", "2011-05-23"));
        datePairs.add(new Pair<String, String>("2068-02-10", "2011-05-24"));
        datePairs.add(new Pair<String, String>("2068-02-11", "2011-05-25"));
        datePairs.add(new Pair<String, String>("2068-02-12", "2011-05-26"));
        datePairs.add(new Pair<String, String>("2068-02-13", "2011-05-27"));
        datePairs.add(new Pair<String, String>("2068-02-14", "2011-05-28"));
        datePairs.add(new Pair<String, String>("2068-02-15", "2011-05-29"));
        datePairs.add(new Pair<String, String>("2068-02-16", "2011-05-30"));
        datePairs.add(new Pair<String, String>("2068-02-17", "2011-05-31"));
        datePairs.add(new Pair<String, String>("2068-02-18", "2011-06-01"));
        datePairs.add(new Pair<String, String>("2068-02-19", "2011-06-02"));
        datePairs.add(new Pair<String, String>("2068-02-20", "2011-06-03"));
        datePairs.add(new Pair<String, String>("2068-02-21", "2011-06-04"));
        datePairs.add(new Pair<String, String>("2068-02-22", "2011-06-05"));
        datePairs.add(new Pair<String, String>("2068-02-23", "2011-06-06"));
        datePairs.add(new Pair<String, String>("2068-02-24", "2011-06-07"));
        datePairs.add(new Pair<String, String>("2068-02-25", "2011-06-08"));
        datePairs.add(new Pair<String, String>("2068-02-26", "2011-06-09"));
        datePairs.add(new Pair<String, String>("2068-02-27", "2011-06-10"));
        datePairs.add(new Pair<String, String>("2068-02-28", "2011-06-11"));
        datePairs.add(new Pair<String, String>("2068-02-29", "2011-06-12"));
        datePairs.add(new Pair<String, String>("2068-02-30", "2011-06-13"));
        datePairs.add(new Pair<String, String>("2068-02-31", "2011-06-14"));
        datePairs.add(new Pair<String, String>("2068-03-01", "2011-06-15"));
        datePairs.add(new Pair<String, String>("2068-03-02", "2011-06-16"));
        datePairs.add(new Pair<String, String>("2068-03-03", "2011-06-17"));
        datePairs.add(new Pair<String, String>("2068-03-04", "2011-06-18"));
        datePairs.add(new Pair<String, String>("2068-03-05", "2011-06-19"));
        datePairs.add(new Pair<String, String>("2068-03-06", "2011-06-20"));
        datePairs.add(new Pair<String, String>("2068-03-07", "2011-06-21"));
        datePairs.add(new Pair<String, String>("2068-03-08", "2011-06-22"));
        datePairs.add(new Pair<String, String>("2068-03-09", "2011-06-23"));
        datePairs.add(new Pair<String, String>("2068-03-10", "2011-06-24"));
        datePairs.add(new Pair<String, String>("2068-03-11", "2011-06-25"));
        datePairs.add(new Pair<String, String>("2068-03-12", "2011-06-26"));
        datePairs.add(new Pair<String, String>("2068-03-13", "2011-06-27"));
        datePairs.add(new Pair<String, String>("2068-03-14", "2011-06-28"));
        datePairs.add(new Pair<String, String>("2068-03-15", "2011-06-29"));
        datePairs.add(new Pair<String, String>("2068-03-16", "2011-06-30"));
        datePairs.add(new Pair<String, String>("2068-03-17", "2011-07-01"));
        datePairs.add(new Pair<String, String>("2068-03-18", "2011-07-02"));
        datePairs.add(new Pair<String, String>("2068-03-19", "2011-07-03"));
        datePairs.add(new Pair<String, String>("2068-03-20", "2011-07-04"));
        datePairs.add(new Pair<String, String>("2068-03-21", "2011-07-05"));
        datePairs.add(new Pair<String, String>("2068-03-22", "2011-07-06"));
        datePairs.add(new Pair<String, String>("2068-03-23", "2011-07-07"));
        datePairs.add(new Pair<String, String>("2068-03-24", "2011-07-08"));
        datePairs.add(new Pair<String, String>("2068-03-25", "2011-07-09"));
        datePairs.add(new Pair<String, String>("2068-03-26", "2011-07-10"));
        datePairs.add(new Pair<String, String>("2068-03-27", "2011-07-11"));
        datePairs.add(new Pair<String, String>("2068-03-28", "2011-07-12"));
        datePairs.add(new Pair<String, String>("2068-03-29", "2011-07-13"));
        datePairs.add(new Pair<String, String>("2068-03-30", "2011-07-14"));
        datePairs.add(new Pair<String, String>("2068-03-31", "2011-07-15"));
        datePairs.add(new Pair<String, String>("2068-03-32", "2011-07-16"));
        datePairs.add(new Pair<String, String>("2068-04-01", "2011-07-17"));
        datePairs.add(new Pair<String, String>("2068-04-02", "2011-07-18"));
        datePairs.add(new Pair<String, String>("2068-04-03", "2011-07-19"));
        datePairs.add(new Pair<String, String>("2068-04-04", "2011-07-20"));
        datePairs.add(new Pair<String, String>("2068-04-05", "2011-07-21"));
        datePairs.add(new Pair<String, String>("2068-04-06", "2011-07-22"));
        datePairs.add(new Pair<String, String>("2068-04-07", "2011-07-23"));
        datePairs.add(new Pair<String, String>("2068-04-08", "2011-07-24"));
        datePairs.add(new Pair<String, String>("2068-04-09", "2011-07-25"));
        datePairs.add(new Pair<String, String>("2068-04-10", "2011-07-26"));
        datePairs.add(new Pair<String, String>("2068-04-11", "2011-07-27"));
        datePairs.add(new Pair<String, String>("2068-04-12", "2011-07-28"));
        datePairs.add(new Pair<String, String>("2068-04-13", "2011-07-29"));
        datePairs.add(new Pair<String, String>("2068-04-14", "2011-07-30"));
        datePairs.add(new Pair<String, String>("2068-04-15", "2011-07-31"));
        datePairs.add(new Pair<String, String>("2068-04-16", "2011-08-01"));
        datePairs.add(new Pair<String, String>("2068-04-17", "2011-08-02"));
        datePairs.add(new Pair<String, String>("2068-04-18", "2011-08-03"));
        datePairs.add(new Pair<String, String>("2068-04-19", "2011-08-04"));
        datePairs.add(new Pair<String, String>("2068-04-20", "2011-08-05"));
        datePairs.add(new Pair<String, String>("2068-04-21", "2011-08-06"));
        datePairs.add(new Pair<String, String>("2068-04-22", "2011-08-07"));
        datePairs.add(new Pair<String, String>("2068-04-23", "2011-08-08"));
        datePairs.add(new Pair<String, String>("2068-04-24", "2011-08-09"));
        datePairs.add(new Pair<String, String>("2068-04-25", "2011-08-10"));
        datePairs.add(new Pair<String, String>("2068-04-26", "2011-08-11"));
        datePairs.add(new Pair<String, String>("2068-04-27", "2011-08-12"));
        datePairs.add(new Pair<String, String>("2068-04-28", "2011-08-13"));
        datePairs.add(new Pair<String, String>("2068-04-29", "2011-08-14"));
        datePairs.add(new Pair<String, String>("2068-04-30", "2011-08-15"));
        datePairs.add(new Pair<String, String>("2068-04-31", "2011-08-16"));
        datePairs.add(new Pair<String, String>("2068-04-32", "2011-08-17"));
        datePairs.add(new Pair<String, String>("2068-05-01", "2011-08-18"));
        datePairs.add(new Pair<String, String>("2068-05-02", "2011-08-19"));
        datePairs.add(new Pair<String, String>("2068-05-03", "2011-08-20"));
        datePairs.add(new Pair<String, String>("2068-05-04", "2011-08-21"));
        datePairs.add(new Pair<String, String>("2068-05-05", "2011-08-22"));
        datePairs.add(new Pair<String, String>("2068-05-06", "2011-08-23"));
        datePairs.add(new Pair<String, String>("2068-05-07", "2011-08-24"));
        datePairs.add(new Pair<String, String>("2068-05-08", "2011-08-25"));
        datePairs.add(new Pair<String, String>("2068-05-09", "2011-08-26"));
        datePairs.add(new Pair<String, String>("2068-05-10", "2011-08-27"));
        datePairs.add(new Pair<String, String>("2068-05-11", "2011-08-28"));
        datePairs.add(new Pair<String, String>("2068-05-12", "2011-08-29"));
        datePairs.add(new Pair<String, String>("2068-05-13", "2011-08-30"));
        datePairs.add(new Pair<String, String>("2068-05-14", "2011-08-31"));
        datePairs.add(new Pair<String, String>("2068-05-15", "2011-09-01"));
        datePairs.add(new Pair<String, String>("2068-05-16", "2011-09-02"));
        datePairs.add(new Pair<String, String>("2068-05-17", "2011-09-03"));
        datePairs.add(new Pair<String, String>("2068-05-18", "2011-09-04"));
        datePairs.add(new Pair<String, String>("2068-05-19", "2011-09-05"));
        datePairs.add(new Pair<String, String>("2068-05-20", "2011-09-06"));
        datePairs.add(new Pair<String, String>("2068-05-21", "2011-09-07"));
        datePairs.add(new Pair<String, String>("2068-05-22", "2011-09-08"));
        datePairs.add(new Pair<String, String>("2068-05-23", "2011-09-09"));
        datePairs.add(new Pair<String, String>("2068-05-24", "2011-09-10"));
        datePairs.add(new Pair<String, String>("2068-05-25", "2011-09-11"));
        datePairs.add(new Pair<String, String>("2068-05-26", "2011-09-12"));
        datePairs.add(new Pair<String, String>("2068-05-27", "2011-09-13"));
        datePairs.add(new Pair<String, String>("2068-05-28", "2011-09-14"));
        datePairs.add(new Pair<String, String>("2068-05-29", "2011-09-15"));
        datePairs.add(new Pair<String, String>("2068-05-30", "2011-09-16"));
        datePairs.add(new Pair<String, String>("2068-05-31", "2011-09-17"));
        datePairs.add(new Pair<String, String>("2068-06-01", "2011-09-18"));
        datePairs.add(new Pair<String, String>("2068-06-02", "2011-09-19"));
        datePairs.add(new Pair<String, String>("2068-06-03", "2011-09-20"));
        datePairs.add(new Pair<String, String>("2068-06-04", "2011-09-21"));
        datePairs.add(new Pair<String, String>("2068-06-05", "2011-09-22"));
        datePairs.add(new Pair<String, String>("2068-06-06", "2011-09-23"));
        datePairs.add(new Pair<String, String>("2068-06-07", "2011-09-24"));
        datePairs.add(new Pair<String, String>("2068-06-08", "2011-09-25"));
        datePairs.add(new Pair<String, String>("2068-06-09", "2011-09-26"));
        datePairs.add(new Pair<String, String>("2068-06-10", "2011-09-27"));
        datePairs.add(new Pair<String, String>("2068-06-11", "2011-09-28"));
        datePairs.add(new Pair<String, String>("2068-06-12", "2011-09-29"));
        datePairs.add(new Pair<String, String>("2068-06-13", "2011-09-30"));
        datePairs.add(new Pair<String, String>("2068-06-14", "2011-10-01"));
        datePairs.add(new Pair<String, String>("2068-06-15", "2011-10-02"));
        datePairs.add(new Pair<String, String>("2068-06-16", "2011-10-03"));
        datePairs.add(new Pair<String, String>("2068-06-17", "2011-10-04"));
        datePairs.add(new Pair<String, String>("2068-06-18", "2011-10-05"));
        datePairs.add(new Pair<String, String>("2068-06-19", "2011-10-06"));
        datePairs.add(new Pair<String, String>("2068-06-20", "2011-10-07"));
        datePairs.add(new Pair<String, String>("2068-06-21", "2011-10-08"));
        datePairs.add(new Pair<String, String>("2068-06-22", "2011-10-09"));
        datePairs.add(new Pair<String, String>("2068-06-23", "2011-10-10"));
        datePairs.add(new Pair<String, String>("2068-06-24", "2011-10-11"));
        datePairs.add(new Pair<String, String>("2068-06-25", "2011-10-12"));
        datePairs.add(new Pair<String, String>("2068-06-26", "2011-10-13"));
        datePairs.add(new Pair<String, String>("2068-06-27", "2011-10-14"));
        datePairs.add(new Pair<String, String>("2068-06-28", "2011-10-15"));
        datePairs.add(new Pair<String, String>("2068-06-29", "2011-10-16"));
        datePairs.add(new Pair<String, String>("2068-06-30", "2011-10-17"));
        datePairs.add(new Pair<String, String>("2068-07-01", "2011-10-18"));
        datePairs.add(new Pair<String, String>("2068-07-02", "2011-10-19"));
        datePairs.add(new Pair<String, String>("2068-07-03", "2011-10-20"));
        datePairs.add(new Pair<String, String>("2068-07-04", "2011-10-21"));
        datePairs.add(new Pair<String, String>("2068-07-05", "2011-10-22"));
        datePairs.add(new Pair<String, String>("2068-07-06", "2011-10-23"));
        datePairs.add(new Pair<String, String>("2068-07-07", "2011-10-24"));
        datePairs.add(new Pair<String, String>("2068-07-08", "2011-10-25"));
        datePairs.add(new Pair<String, String>("2068-07-09", "2011-10-26"));
        datePairs.add(new Pair<String, String>("2068-07-10", "2011-10-27"));
        datePairs.add(new Pair<String, String>("2068-07-11", "2011-10-28"));
        datePairs.add(new Pair<String, String>("2068-07-12", "2011-10-29"));
        datePairs.add(new Pair<String, String>("2068-07-13", "2011-10-30"));
        datePairs.add(new Pair<String, String>("2068-07-14", "2011-10-31"));
        datePairs.add(new Pair<String, String>("2068-07-15", "2011-11-01"));
        datePairs.add(new Pair<String, String>("2068-07-16", "2011-11-02"));
        datePairs.add(new Pair<String, String>("2068-07-17", "2011-11-03"));
        datePairs.add(new Pair<String, String>("2068-07-18", "2011-11-04"));
        datePairs.add(new Pair<String, String>("2068-07-19", "2011-11-05"));
        datePairs.add(new Pair<String, String>("2068-07-20", "2011-11-06"));
        datePairs.add(new Pair<String, String>("2068-07-21", "2011-11-07"));
        datePairs.add(new Pair<String, String>("2068-07-22", "2011-11-08"));
        datePairs.add(new Pair<String, String>("2068-07-23", "2011-11-09"));
        datePairs.add(new Pair<String, String>("2068-07-24", "2011-11-10"));
        datePairs.add(new Pair<String, String>("2068-07-25", "2011-11-11"));
        datePairs.add(new Pair<String, String>("2068-07-26", "2011-11-12"));
        datePairs.add(new Pair<String, String>("2068-07-27", "2011-11-13"));
        datePairs.add(new Pair<String, String>("2068-07-28", "2011-11-14"));
        datePairs.add(new Pair<String, String>("2068-07-29", "2011-11-15"));
        datePairs.add(new Pair<String, String>("2068-07-30", "2011-11-16"));
        datePairs.add(new Pair<String, String>("2068-08-01", "2011-11-17"));
        datePairs.add(new Pair<String, String>("2068-08-02", "2011-11-18"));
        datePairs.add(new Pair<String, String>("2068-08-03", "2011-11-19"));
        datePairs.add(new Pair<String, String>("2068-08-04", "2011-11-20"));
        datePairs.add(new Pair<String, String>("2068-08-05", "2011-11-21"));
        datePairs.add(new Pair<String, String>("2068-08-06", "2011-11-22"));
        datePairs.add(new Pair<String, String>("2068-08-07", "2011-11-23"));
        datePairs.add(new Pair<String, String>("2068-08-08", "2011-11-24"));
        datePairs.add(new Pair<String, String>("2068-08-09", "2011-11-25"));
        datePairs.add(new Pair<String, String>("2068-08-10", "2011-11-26"));
        datePairs.add(new Pair<String, String>("2068-08-11", "2011-11-27"));
        datePairs.add(new Pair<String, String>("2068-08-12", "2011-11-28"));
        datePairs.add(new Pair<String, String>("2068-08-13", "2011-11-29"));
        datePairs.add(new Pair<String, String>("2068-08-14", "2011-11-30"));
        datePairs.add(new Pair<String, String>("2068-08-15", "2011-12-01"));
        datePairs.add(new Pair<String, String>("2068-08-16", "2011-12-02"));
        datePairs.add(new Pair<String, String>("2068-08-17", "2011-12-03"));
        datePairs.add(new Pair<String, String>("2068-08-18", "2011-12-04"));
        datePairs.add(new Pair<String, String>("2068-08-19", "2011-12-05"));
        datePairs.add(new Pair<String, String>("2068-08-20", "2011-12-06"));
        datePairs.add(new Pair<String, String>("2068-08-21", "2011-12-07"));
        datePairs.add(new Pair<String, String>("2068-08-22", "2011-12-08"));
        datePairs.add(new Pair<String, String>("2068-08-23", "2011-12-09"));
        datePairs.add(new Pair<String, String>("2068-08-24", "2011-12-10"));
        datePairs.add(new Pair<String, String>("2068-08-25", "2011-12-11"));
        datePairs.add(new Pair<String, String>("2068-08-26", "2011-12-12"));
        datePairs.add(new Pair<String, String>("2068-08-27", "2011-12-13"));
        datePairs.add(new Pair<String, String>("2068-08-28", "2011-12-14"));
        datePairs.add(new Pair<String, String>("2068-08-29", "2011-12-15"));
        datePairs.add(new Pair<String, String>("2068-09-01", "2011-12-16"));
        datePairs.add(new Pair<String, String>("2068-09-02", "2011-12-17"));
        datePairs.add(new Pair<String, String>("2068-09-03", "2011-12-18"));
        datePairs.add(new Pair<String, String>("2068-09-04", "2011-12-19"));
        datePairs.add(new Pair<String, String>("2068-09-05", "2011-12-20"));
        datePairs.add(new Pair<String, String>("2068-09-06", "2011-12-21"));
        datePairs.add(new Pair<String, String>("2068-09-07", "2011-12-22"));
        datePairs.add(new Pair<String, String>("2068-09-08", "2011-12-23"));
        datePairs.add(new Pair<String, String>("2068-09-09", "2011-12-24"));
        datePairs.add(new Pair<String, String>("2068-09-10", "2011-12-25"));
        datePairs.add(new Pair<String, String>("2068-09-11", "2011-12-26"));
        datePairs.add(new Pair<String, String>("2068-09-12", "2011-12-27"));
        datePairs.add(new Pair<String, String>("2068-09-13", "2011-12-28"));
        datePairs.add(new Pair<String, String>("2068-09-14", "2011-12-29"));
        datePairs.add(new Pair<String, String>("2068-09-15", "2011-12-30"));
        datePairs.add(new Pair<String, String>("2068-09-16", "2011-12-31"));
        datePairs.add(new Pair<String, String>("2068-09-17", "2012-01-01"));
        datePairs.add(new Pair<String, String>("2068-09-18", "2012-01-02"));
        datePairs.add(new Pair<String, String>("2068-09-19", "2012-01-03"));
        datePairs.add(new Pair<String, String>("2068-09-20", "2012-01-04"));
        datePairs.add(new Pair<String, String>("2068-09-21", "2012-01-05"));
        datePairs.add(new Pair<String, String>("2068-09-22", "2012-01-06"));
        datePairs.add(new Pair<String, String>("2068-09-23", "2012-01-07"));
        datePairs.add(new Pair<String, String>("2068-09-24", "2012-01-08"));
        datePairs.add(new Pair<String, String>("2068-09-25", "2012-01-09"));
        datePairs.add(new Pair<String, String>("2068-09-26", "2012-01-10"));
        datePairs.add(new Pair<String, String>("2068-09-27", "2012-01-11"));
        datePairs.add(new Pair<String, String>("2068-09-28", "2012-01-12"));
        datePairs.add(new Pair<String, String>("2068-09-29", "2012-01-13"));
        datePairs.add(new Pair<String, String>("2068-09-30", "2012-01-14"));
        datePairs.add(new Pair<String, String>("2068-10-01", "2012-01-15"));
        datePairs.add(new Pair<String, String>("2068-10-02", "2012-01-16"));
        datePairs.add(new Pair<String, String>("2068-10-03", "2012-01-17"));
        datePairs.add(new Pair<String, String>("2068-10-04", "2012-01-18"));
        datePairs.add(new Pair<String, String>("2068-10-05", "2012-01-19"));
        datePairs.add(new Pair<String, String>("2068-10-06", "2012-01-20"));
        datePairs.add(new Pair<String, String>("2068-10-07", "2012-01-21"));
        datePairs.add(new Pair<String, String>("2068-10-08", "2012-01-22"));
        datePairs.add(new Pair<String, String>("2068-10-09", "2012-01-23"));
        datePairs.add(new Pair<String, String>("2068-10-10", "2012-01-24"));
        datePairs.add(new Pair<String, String>("2068-10-11", "2012-01-25"));
        datePairs.add(new Pair<String, String>("2068-10-12", "2012-01-26"));
        datePairs.add(new Pair<String, String>("2068-10-13", "2012-01-27"));
        datePairs.add(new Pair<String, String>("2068-10-14", "2012-01-28"));
        datePairs.add(new Pair<String, String>("2068-10-15", "2012-01-29"));
        datePairs.add(new Pair<String, String>("2068-10-16", "2012-01-30"));
        datePairs.add(new Pair<String, String>("2068-10-17", "2012-01-31"));
        datePairs.add(new Pair<String, String>("2068-10-18", "2012-02-01"));
        datePairs.add(new Pair<String, String>("2068-10-19", "2012-02-02"));
        datePairs.add(new Pair<String, String>("2068-10-20", "2012-02-03"));
        datePairs.add(new Pair<String, String>("2068-10-21", "2012-02-04"));
        datePairs.add(new Pair<String, String>("2068-10-22", "2012-02-05"));
        datePairs.add(new Pair<String, String>("2068-10-23", "2012-02-06"));
        datePairs.add(new Pair<String, String>("2068-10-24", "2012-02-07"));
        datePairs.add(new Pair<String, String>("2068-10-25", "2012-02-08"));
        datePairs.add(new Pair<String, String>("2068-10-26", "2012-02-09"));
        datePairs.add(new Pair<String, String>("2068-10-27", "2012-02-10"));
        datePairs.add(new Pair<String, String>("2068-10-28", "2012-02-11"));
        datePairs.add(new Pair<String, String>("2068-10-29", "2012-02-12"));
        datePairs.add(new Pair<String, String>("2068-11-01", "2012-02-13"));
        datePairs.add(new Pair<String, String>("2068-11-02", "2012-02-14"));
        datePairs.add(new Pair<String, String>("2068-11-03", "2012-02-15"));
        datePairs.add(new Pair<String, String>("2068-11-04", "2012-02-16"));
        datePairs.add(new Pair<String, String>("2068-11-05", "2012-02-17"));
        datePairs.add(new Pair<String, String>("2068-11-06", "2012-02-18"));
        datePairs.add(new Pair<String, String>("2068-11-07", "2012-02-19"));
        datePairs.add(new Pair<String, String>("2068-11-08", "2012-02-20"));
        datePairs.add(new Pair<String, String>("2068-11-09", "2012-02-21"));
        datePairs.add(new Pair<String, String>("2068-11-10", "2012-02-22"));
        datePairs.add(new Pair<String, String>("2068-11-11", "2012-02-23"));
        datePairs.add(new Pair<String, String>("2068-11-12", "2012-02-24"));
        datePairs.add(new Pair<String, String>("2068-11-13", "2012-02-25"));
        datePairs.add(new Pair<String, String>("2068-11-14", "2012-02-26"));
        datePairs.add(new Pair<String, String>("2068-11-15", "2012-02-27"));
        datePairs.add(new Pair<String, String>("2068-11-16", "2012-02-28"));
        datePairs.add(new Pair<String, String>("2068-11-17", "2012-02-29"));
        datePairs.add(new Pair<String, String>("2068-11-18", "2012-03-01"));
        datePairs.add(new Pair<String, String>("2068-11-19", "2012-03-02"));
        datePairs.add(new Pair<String, String>("2068-11-20", "2012-03-03"));
        datePairs.add(new Pair<String, String>("2068-11-21", "2012-03-04"));
        datePairs.add(new Pair<String, String>("2068-11-22", "2012-03-05"));
        datePairs.add(new Pair<String, String>("2068-11-23", "2012-03-06"));
        datePairs.add(new Pair<String, String>("2068-11-24", "2012-03-07"));
        datePairs.add(new Pair<String, String>("2068-11-25", "2012-03-08"));
        datePairs.add(new Pair<String, String>("2068-11-26", "2012-03-09"));
        datePairs.add(new Pair<String, String>("2068-11-27", "2012-03-10"));
        datePairs.add(new Pair<String, String>("2068-11-28", "2012-03-11"));
        datePairs.add(new Pair<String, String>("2068-11-29", "2012-03-12"));
        datePairs.add(new Pair<String, String>("2068-11-30", "2012-03-13"));
        datePairs.add(new Pair<String, String>("2068-12-01", "2012-03-14"));
        datePairs.add(new Pair<String, String>("2068-12-02", "2012-03-15"));
        datePairs.add(new Pair<String, String>("2068-12-03", "2012-03-16"));
        datePairs.add(new Pair<String, String>("2068-12-04", "2012-03-17"));
        datePairs.add(new Pair<String, String>("2068-12-05", "2012-03-18"));
        datePairs.add(new Pair<String, String>("2068-12-06", "2012-03-19"));
        datePairs.add(new Pair<String, String>("2068-12-07", "2012-03-20"));
        datePairs.add(new Pair<String, String>("2068-12-08", "2012-03-21"));
        datePairs.add(new Pair<String, String>("2068-12-09", "2012-03-22"));
        datePairs.add(new Pair<String, String>("2068-12-10", "2012-03-23"));
        datePairs.add(new Pair<String, String>("2068-12-11", "2012-03-24"));
        datePairs.add(new Pair<String, String>("2068-12-12", "2012-03-25"));
        datePairs.add(new Pair<String, String>("2068-12-13", "2012-03-26"));
        datePairs.add(new Pair<String, String>("2068-12-14", "2012-03-27"));
        datePairs.add(new Pair<String, String>("2068-12-15", "2012-03-28"));
        datePairs.add(new Pair<String, String>("2068-12-16", "2012-03-29"));
        datePairs.add(new Pair<String, String>("2068-12-17", "2012-03-30"));
        datePairs.add(new Pair<String, String>("2068-12-18", "2012-03-31"));
        datePairs.add(new Pair<String, String>("2068-12-19", "2012-04-01"));
        datePairs.add(new Pair<String, String>("2068-12-20", "2012-04-02"));
        datePairs.add(new Pair<String, String>("2068-12-21", "2012-04-03"));
        datePairs.add(new Pair<String, String>("2068-12-22", "2012-04-04"));
        datePairs.add(new Pair<String, String>("2068-12-23", "2012-04-05"));
        datePairs.add(new Pair<String, String>("2068-12-24", "2012-04-06"));
        datePairs.add(new Pair<String, String>("2068-12-25", "2012-04-07"));
        datePairs.add(new Pair<String, String>("2068-12-26", "2012-04-08"));
        datePairs.add(new Pair<String, String>("2068-12-27", "2012-04-09"));
        datePairs.add(new Pair<String, String>("2068-12-28", "2012-04-10"));
        datePairs.add(new Pair<String, String>("2068-12-29", "2012-04-11"));
        datePairs.add(new Pair<String, String>("2068-12-30", "2012-04-12"));
        datePairs.add(new Pair<String, String>("2069-01-01", "2012-04-13"));
        datePairs.add(new Pair<String, String>("2069-01-02", "2012-04-14"));
        datePairs.add(new Pair<String, String>("2069-01-03", "2012-04-15"));
        datePairs.add(new Pair<String, String>("2069-01-04", "2012-04-16"));
        datePairs.add(new Pair<String, String>("2069-01-05", "2012-04-17"));
        datePairs.add(new Pair<String, String>("2069-01-06", "2012-04-18"));
        datePairs.add(new Pair<String, String>("2069-01-07", "2012-04-19"));
        datePairs.add(new Pair<String, String>("2069-01-08", "2012-04-20"));
        datePairs.add(new Pair<String, String>("2069-01-09", "2012-04-21"));
        datePairs.add(new Pair<String, String>("2069-01-10", "2012-04-22"));
        datePairs.add(new Pair<String, String>("2069-01-11", "2012-04-23"));
        datePairs.add(new Pair<String, String>("2069-01-12", "2012-04-24"));
        datePairs.add(new Pair<String, String>("2069-01-13", "2012-04-25"));
        datePairs.add(new Pair<String, String>("2069-01-14", "2012-04-26"));
        datePairs.add(new Pair<String, String>("2069-01-15", "2012-04-27"));
        datePairs.add(new Pair<String, String>("2069-01-16", "2012-04-28"));
        datePairs.add(new Pair<String, String>("2069-01-17", "2012-04-29"));
        datePairs.add(new Pair<String, String>("2069-01-18", "2012-04-30"));
        datePairs.add(new Pair<String, String>("2069-01-19", "2012-05-01"));
        datePairs.add(new Pair<String, String>("2069-01-20", "2012-05-02"));
        datePairs.add(new Pair<String, String>("2069-01-21", "2012-05-03"));
        datePairs.add(new Pair<String, String>("2069-01-22", "2012-05-04"));
        datePairs.add(new Pair<String, String>("2069-01-23", "2012-05-05"));
        datePairs.add(new Pair<String, String>("2069-01-24", "2012-05-06"));
        datePairs.add(new Pair<String, String>("2069-01-25", "2012-05-07"));
        datePairs.add(new Pair<String, String>("2069-01-26", "2012-05-08"));
        datePairs.add(new Pair<String, String>("2069-01-27", "2012-05-09"));
        datePairs.add(new Pair<String, String>("2069-01-28", "2012-05-10"));
        datePairs.add(new Pair<String, String>("2069-01-29", "2012-05-11"));
        datePairs.add(new Pair<String, String>("2069-01-30", "2012-05-12"));
        datePairs.add(new Pair<String, String>("2069-01-31", "2012-05-13"));
        datePairs.add(new Pair<String, String>("2069-02-01", "2012-05-14"));
        datePairs.add(new Pair<String, String>("2069-02-02", "2012-05-15"));
        datePairs.add(new Pair<String, String>("2069-02-03", "2012-05-16"));
        datePairs.add(new Pair<String, String>("2069-02-04", "2012-05-17"));
        datePairs.add(new Pair<String, String>("2069-02-05", "2012-05-18"));
        datePairs.add(new Pair<String, String>("2069-02-06", "2012-05-19"));
        datePairs.add(new Pair<String, String>("2069-02-07", "2012-05-20"));
        datePairs.add(new Pair<String, String>("2069-02-08", "2012-05-21"));
        datePairs.add(new Pair<String, String>("2069-02-09", "2012-05-22"));
        datePairs.add(new Pair<String, String>("2069-02-10", "2012-05-23"));
        datePairs.add(new Pair<String, String>("2069-02-11", "2012-05-24"));
        datePairs.add(new Pair<String, String>("2069-02-12", "2012-05-25"));
        datePairs.add(new Pair<String, String>("2069-02-13", "2012-05-26"));
        datePairs.add(new Pair<String, String>("2069-02-14", "2012-05-27"));
        datePairs.add(new Pair<String, String>("2069-02-15", "2012-05-28"));
        datePairs.add(new Pair<String, String>("2069-02-16", "2012-05-29"));
        datePairs.add(new Pair<String, String>("2069-02-17", "2012-05-30"));
        datePairs.add(new Pair<String, String>("2069-02-18", "2012-05-31"));
        datePairs.add(new Pair<String, String>("2069-02-19", "2012-06-01"));
        datePairs.add(new Pair<String, String>("2069-02-20", "2012-06-02"));
        datePairs.add(new Pair<String, String>("2069-02-21", "2012-06-03"));
        datePairs.add(new Pair<String, String>("2069-02-22", "2012-06-04"));
        datePairs.add(new Pair<String, String>("2069-02-23", "2012-06-05"));
        datePairs.add(new Pair<String, String>("2069-02-24", "2012-06-06"));
        datePairs.add(new Pair<String, String>("2069-02-25", "2012-06-07"));
        datePairs.add(new Pair<String, String>("2069-02-26", "2012-06-08"));
        datePairs.add(new Pair<String, String>("2069-02-27", "2012-06-09"));
        datePairs.add(new Pair<String, String>("2069-02-28", "2012-06-10"));
        datePairs.add(new Pair<String, String>("2069-02-29", "2012-06-11"));
        datePairs.add(new Pair<String, String>("2069-02-30", "2012-06-12"));
        datePairs.add(new Pair<String, String>("2069-02-31", "2012-06-13"));
        datePairs.add(new Pair<String, String>("2069-02-32", "2012-06-14"));
        datePairs.add(new Pair<String, String>("2069-03-01", "2012-06-15"));
        datePairs.add(new Pair<String, String>("2069-03-02", "2012-06-16"));
        datePairs.add(new Pair<String, String>("2069-03-03", "2012-06-17"));
        datePairs.add(new Pair<String, String>("2069-03-04", "2012-06-18"));
        datePairs.add(new Pair<String, String>("2069-03-05", "2012-06-19"));
        datePairs.add(new Pair<String, String>("2069-03-06", "2012-06-20"));
        datePairs.add(new Pair<String, String>("2069-03-07", "2012-06-21"));
        datePairs.add(new Pair<String, String>("2069-03-08", "2012-06-22"));
        datePairs.add(new Pair<String, String>("2069-03-09", "2012-06-23"));
        datePairs.add(new Pair<String, String>("2069-03-10", "2012-06-24"));
        datePairs.add(new Pair<String, String>("2069-03-11", "2012-06-25"));
        datePairs.add(new Pair<String, String>("2069-03-12", "2012-06-26"));
        datePairs.add(new Pair<String, String>("2069-03-13", "2012-06-27"));
        datePairs.add(new Pair<String, String>("2069-03-14", "2012-06-28"));
        datePairs.add(new Pair<String, String>("2069-03-15", "2012-06-29"));
        datePairs.add(new Pair<String, String>("2069-03-16", "2012-06-30"));
        datePairs.add(new Pair<String, String>("2069-03-17", "2012-07-01"));
        datePairs.add(new Pair<String, String>("2069-03-18", "2012-07-02"));
        datePairs.add(new Pair<String, String>("2069-03-19", "2012-07-03"));
        datePairs.add(new Pair<String, String>("2069-03-20", "2012-07-04"));
        datePairs.add(new Pair<String, String>("2069-03-21", "2012-07-05"));
        datePairs.add(new Pair<String, String>("2069-03-22", "2012-07-06"));
        datePairs.add(new Pair<String, String>("2069-03-23", "2012-07-07"));
        datePairs.add(new Pair<String, String>("2069-03-24", "2012-07-08"));
        datePairs.add(new Pair<String, String>("2069-03-25", "2012-07-09"));
        datePairs.add(new Pair<String, String>("2069-03-26", "2012-07-10"));
        datePairs.add(new Pair<String, String>("2069-03-27", "2012-07-11"));
        datePairs.add(new Pair<String, String>("2069-03-28", "2012-07-12"));
        datePairs.add(new Pair<String, String>("2069-03-29", "2012-07-13"));
        datePairs.add(new Pair<String, String>("2069-03-30", "2012-07-14"));
        datePairs.add(new Pair<String, String>("2069-03-31", "2012-07-15"));
        datePairs.add(new Pair<String, String>("2069-04-01", "2012-07-16"));
        datePairs.add(new Pair<String, String>("2069-04-02", "2012-07-17"));
        datePairs.add(new Pair<String, String>("2069-04-03", "2012-07-18"));
        datePairs.add(new Pair<String, String>("2069-04-04", "2012-07-19"));
        datePairs.add(new Pair<String, String>("2069-04-05", "2012-07-20"));
        datePairs.add(new Pair<String, String>("2069-04-06", "2012-07-21"));
        datePairs.add(new Pair<String, String>("2069-04-07", "2012-07-22"));
        datePairs.add(new Pair<String, String>("2069-04-08", "2012-07-23"));
        datePairs.add(new Pair<String, String>("2069-04-09", "2012-07-24"));
        datePairs.add(new Pair<String, String>("2069-04-10", "2012-07-25"));
        datePairs.add(new Pair<String, String>("2069-04-11", "2012-07-26"));
        datePairs.add(new Pair<String, String>("2069-04-12", "2012-07-27"));
        datePairs.add(new Pair<String, String>("2069-04-13", "2012-07-28"));
        datePairs.add(new Pair<String, String>("2069-04-14", "2012-07-29"));
        datePairs.add(new Pair<String, String>("2069-04-15", "2012-07-30"));
        datePairs.add(new Pair<String, String>("2069-04-16", "2012-07-31"));
        datePairs.add(new Pair<String, String>("2069-04-17", "2012-08-01"));
        datePairs.add(new Pair<String, String>("2069-04-18", "2012-08-02"));
        datePairs.add(new Pair<String, String>("2069-04-19", "2012-08-03"));
        datePairs.add(new Pair<String, String>("2069-04-20", "2012-08-04"));
        datePairs.add(new Pair<String, String>("2069-04-21", "2012-08-05"));
        datePairs.add(new Pair<String, String>("2069-04-22", "2012-08-06"));
        datePairs.add(new Pair<String, String>("2069-04-23", "2012-08-07"));
        datePairs.add(new Pair<String, String>("2069-04-24", "2012-08-08"));
        datePairs.add(new Pair<String, String>("2069-04-25", "2012-08-09"));
        datePairs.add(new Pair<String, String>("2069-04-26", "2012-08-10"));
        datePairs.add(new Pair<String, String>("2069-04-27", "2012-08-11"));
        datePairs.add(new Pair<String, String>("2069-04-28", "2012-08-12"));
        datePairs.add(new Pair<String, String>("2069-04-29", "2012-08-13"));
        datePairs.add(new Pair<String, String>("2069-04-30", "2012-08-14"));
        datePairs.add(new Pair<String, String>("2069-04-31", "2012-08-15"));
        datePairs.add(new Pair<String, String>("2069-04-32", "2012-08-16"));
        datePairs.add(new Pair<String, String>("2069-05-01", "2012-08-17"));
        datePairs.add(new Pair<String, String>("2069-05-02", "2012-08-18"));
        datePairs.add(new Pair<String, String>("2069-05-03", "2012-08-19"));
        datePairs.add(new Pair<String, String>("2069-05-04", "2012-08-20"));
        datePairs.add(new Pair<String, String>("2069-05-05", "2012-08-21"));
        datePairs.add(new Pair<String, String>("2069-05-06", "2012-08-22"));
        datePairs.add(new Pair<String, String>("2069-05-07", "2012-08-23"));
        datePairs.add(new Pair<String, String>("2069-05-08", "2012-08-24"));
        datePairs.add(new Pair<String, String>("2069-05-09", "2012-08-25"));
        datePairs.add(new Pair<String, String>("2069-05-10", "2012-08-26"));
        datePairs.add(new Pair<String, String>("2069-05-11", "2012-08-27"));
        datePairs.add(new Pair<String, String>("2069-05-12", "2012-08-28"));
        datePairs.add(new Pair<String, String>("2069-05-13", "2012-08-29"));
        datePairs.add(new Pair<String, String>("2069-05-14", "2012-08-30"));
        datePairs.add(new Pair<String, String>("2069-05-15", "2012-08-31"));
        datePairs.add(new Pair<String, String>("2069-05-16", "2012-09-01"));
        datePairs.add(new Pair<String, String>("2069-05-17", "2012-09-02"));
        datePairs.add(new Pair<String, String>("2069-05-18", "2012-09-03"));
        datePairs.add(new Pair<String, String>("2069-05-19", "2012-09-04"));
        datePairs.add(new Pair<String, String>("2069-05-20", "2012-09-05"));
        datePairs.add(new Pair<String, String>("2069-05-21", "2012-09-06"));
        datePairs.add(new Pair<String, String>("2069-05-22", "2012-09-07"));
        datePairs.add(new Pair<String, String>("2069-05-23", "2012-09-08"));
        datePairs.add(new Pair<String, String>("2069-05-24", "2012-09-09"));
        datePairs.add(new Pair<String, String>("2069-05-25", "2012-09-10"));
        datePairs.add(new Pair<String, String>("2069-05-26", "2012-09-11"));
        datePairs.add(new Pair<String, String>("2069-05-27", "2012-09-12"));
        datePairs.add(new Pair<String, String>("2069-05-28", "2012-09-13"));
        datePairs.add(new Pair<String, String>("2069-05-29", "2012-09-14"));
        datePairs.add(new Pair<String, String>("2069-05-30", "2012-09-15"));
        datePairs.add(new Pair<String, String>("2069-05-31", "2012-09-16"));
        datePairs.add(new Pair<String, String>("2069-06-01", "2012-09-17"));
        datePairs.add(new Pair<String, String>("2069-06-02", "2012-09-18"));
        datePairs.add(new Pair<String, String>("2069-06-03", "2012-09-19"));
        datePairs.add(new Pair<String, String>("2069-06-04", "2012-09-20"));
        datePairs.add(new Pair<String, String>("2069-06-05", "2012-09-21"));
        datePairs.add(new Pair<String, String>("2069-06-06", "2012-09-22"));
        datePairs.add(new Pair<String, String>("2069-06-07", "2012-09-23"));
        datePairs.add(new Pair<String, String>("2069-06-08", "2012-09-24"));
        datePairs.add(new Pair<String, String>("2069-06-09", "2012-09-25"));
        datePairs.add(new Pair<String, String>("2069-06-10", "2012-09-26"));
        datePairs.add(new Pair<String, String>("2069-06-11", "2012-09-27"));
        datePairs.add(new Pair<String, String>("2069-06-12", "2012-09-28"));
        datePairs.add(new Pair<String, String>("2069-06-13", "2012-09-29"));
        datePairs.add(new Pair<String, String>("2069-06-14", "2012-09-30"));
        datePairs.add(new Pair<String, String>("2069-06-15", "2012-10-01"));
        datePairs.add(new Pair<String, String>("2069-06-16", "2012-10-02"));
        datePairs.add(new Pair<String, String>("2069-06-17", "2012-10-03"));
        datePairs.add(new Pair<String, String>("2069-06-18", "2012-10-04"));
        datePairs.add(new Pair<String, String>("2069-06-19", "2012-10-05"));
        datePairs.add(new Pair<String, String>("2069-06-20", "2012-10-06"));
        datePairs.add(new Pair<String, String>("2069-06-21", "2012-10-07"));
        datePairs.add(new Pair<String, String>("2069-06-22", "2012-10-08"));
        datePairs.add(new Pair<String, String>("2069-06-23", "2012-10-09"));
        datePairs.add(new Pair<String, String>("2069-06-24", "2012-10-10"));
        datePairs.add(new Pair<String, String>("2069-06-25", "2012-10-11"));
        datePairs.add(new Pair<String, String>("2069-06-26", "2012-10-12"));
        datePairs.add(new Pair<String, String>("2069-06-27", "2012-10-13"));
        datePairs.add(new Pair<String, String>("2069-06-28", "2012-10-14"));
        datePairs.add(new Pair<String, String>("2069-06-29", "2012-10-15"));
        datePairs.add(new Pair<String, String>("2069-06-30", "2012-10-16"));
        datePairs.add(new Pair<String, String>("2069-07-01", "2012-10-17"));
        datePairs.add(new Pair<String, String>("2069-07-02", "2012-10-18"));
        datePairs.add(new Pair<String, String>("2069-07-03", "2012-10-19"));
        datePairs.add(new Pair<String, String>("2069-07-04", "2012-10-20"));
        datePairs.add(new Pair<String, String>("2069-07-05", "2012-10-21"));
        datePairs.add(new Pair<String, String>("2069-07-06", "2012-10-22"));
        datePairs.add(new Pair<String, String>("2069-07-07", "2012-10-23"));
        datePairs.add(new Pair<String, String>("2069-07-08", "2012-10-24"));
        datePairs.add(new Pair<String, String>("2069-07-09", "2012-10-25"));
        datePairs.add(new Pair<String, String>("2069-07-10", "2012-10-26"));
        datePairs.add(new Pair<String, String>("2069-07-11", "2012-10-27"));
        datePairs.add(new Pair<String, String>("2069-07-12", "2012-10-28"));
        datePairs.add(new Pair<String, String>("2069-07-13", "2012-10-29"));
        datePairs.add(new Pair<String, String>("2069-07-14", "2012-10-30"));
        datePairs.add(new Pair<String, String>("2069-07-15", "2012-10-31"));
        datePairs.add(new Pair<String, String>("2069-07-16", "2012-11-01"));
        datePairs.add(new Pair<String, String>("2069-07-17", "2012-11-02"));
        datePairs.add(new Pair<String, String>("2069-07-18", "2012-11-03"));
        datePairs.add(new Pair<String, String>("2069-07-19", "2012-11-04"));
        datePairs.add(new Pair<String, String>("2069-07-20", "2012-11-05"));
        datePairs.add(new Pair<String, String>("2069-07-21", "2012-11-06"));
        datePairs.add(new Pair<String, String>("2069-07-22", "2012-11-07"));
        datePairs.add(new Pair<String, String>("2069-07-23", "2012-11-08"));
        datePairs.add(new Pair<String, String>("2069-07-24", "2012-11-09"));
        datePairs.add(new Pair<String, String>("2069-07-25", "2012-11-10"));
        datePairs.add(new Pair<String, String>("2069-07-26", "2012-11-11"));
        datePairs.add(new Pair<String, String>("2069-07-27", "2012-11-12"));
        datePairs.add(new Pair<String, String>("2069-07-28", "2012-11-13"));
        datePairs.add(new Pair<String, String>("2069-07-29", "2012-11-14"));
        datePairs.add(new Pair<String, String>("2069-07-30", "2012-11-15"));
        datePairs.add(new Pair<String, String>("2069-08-01", "2012-11-16"));
        datePairs.add(new Pair<String, String>("2069-08-02", "2012-11-17"));
        datePairs.add(new Pair<String, String>("2069-08-03", "2012-11-18"));
        datePairs.add(new Pair<String, String>("2069-08-04", "2012-11-19"));
        datePairs.add(new Pair<String, String>("2069-08-05", "2012-11-20"));
        datePairs.add(new Pair<String, String>("2069-08-06", "2012-11-21"));
        datePairs.add(new Pair<String, String>("2069-08-07", "2012-11-22"));
        datePairs.add(new Pair<String, String>("2069-08-08", "2012-11-23"));
        datePairs.add(new Pair<String, String>("2069-08-09", "2012-11-24"));
        datePairs.add(new Pair<String, String>("2069-08-10", "2012-11-25"));
        datePairs.add(new Pair<String, String>("2069-08-11", "2012-11-26"));
        datePairs.add(new Pair<String, String>("2069-08-12", "2012-11-27"));
        datePairs.add(new Pair<String, String>("2069-08-13", "2012-11-28"));
        datePairs.add(new Pair<String, String>("2069-08-14", "2012-11-29"));
        datePairs.add(new Pair<String, String>("2069-08-15", "2012-11-30"));
        datePairs.add(new Pair<String, String>("2069-08-16", "2012-12-01"));
        datePairs.add(new Pair<String, String>("2069-08-17", "2012-12-02"));
        datePairs.add(new Pair<String, String>("2069-08-18", "2012-12-03"));
        datePairs.add(new Pair<String, String>("2069-08-19", "2012-12-04"));
        datePairs.add(new Pair<String, String>("2069-08-20", "2012-12-05"));
        datePairs.add(new Pair<String, String>("2069-08-21", "2012-12-06"));
        datePairs.add(new Pair<String, String>("2069-08-22", "2012-12-07"));
        datePairs.add(new Pair<String, String>("2069-08-23", "2012-12-08"));
        datePairs.add(new Pair<String, String>("2069-08-24", "2012-12-09"));
        datePairs.add(new Pair<String, String>("2069-08-25", "2012-12-10"));
        datePairs.add(new Pair<String, String>("2069-08-26", "2012-12-11"));
        datePairs.add(new Pair<String, String>("2069-08-27", "2012-12-12"));
        datePairs.add(new Pair<String, String>("2069-08-28", "2012-12-13"));
        datePairs.add(new Pair<String, String>("2069-08-29", "2012-12-14"));
        datePairs.add(new Pair<String, String>("2069-08-30", "2012-12-15"));
        datePairs.add(new Pair<String, String>("2069-09-01", "2012-12-16"));
        datePairs.add(new Pair<String, String>("2069-09-02", "2012-12-17"));
        datePairs.add(new Pair<String, String>("2069-09-03", "2012-12-18"));
        datePairs.add(new Pair<String, String>("2069-09-04", "2012-12-19"));
        datePairs.add(new Pair<String, String>("2069-09-05", "2012-12-20"));
        datePairs.add(new Pair<String, String>("2069-09-06", "2012-12-21"));
        datePairs.add(new Pair<String, String>("2069-09-07", "2012-12-22"));
        datePairs.add(new Pair<String, String>("2069-09-08", "2012-12-23"));
        datePairs.add(new Pair<String, String>("2069-09-09", "2012-12-24"));
        datePairs.add(new Pair<String, String>("2069-09-10", "2012-12-25"));
        datePairs.add(new Pair<String, String>("2069-09-11", "2012-12-26"));
        datePairs.add(new Pair<String, String>("2069-09-12", "2012-12-27"));
        datePairs.add(new Pair<String, String>("2069-09-13", "2012-12-28"));
        datePairs.add(new Pair<String, String>("2069-09-14", "2012-12-29"));
        datePairs.add(new Pair<String, String>("2069-09-15", "2012-12-30"));
        datePairs.add(new Pair<String, String>("2069-09-16", "2012-12-31"));
        datePairs.add(new Pair<String, String>("2069-09-17", "2013-01-01"));
        datePairs.add(new Pair<String, String>("2069-09-18", "2013-01-02"));
        datePairs.add(new Pair<String, String>("2069-09-19", "2013-01-03"));
        datePairs.add(new Pair<String, String>("2069-09-20", "2013-01-04"));
        datePairs.add(new Pair<String, String>("2069-09-21", "2013-01-05"));
        datePairs.add(new Pair<String, String>("2069-09-22", "2013-01-06"));
        datePairs.add(new Pair<String, String>("2069-09-23", "2013-01-07"));
        datePairs.add(new Pair<String, String>("2069-09-24", "2013-01-08"));
        datePairs.add(new Pair<String, String>("2069-09-25", "2013-01-09"));
        datePairs.add(new Pair<String, String>("2069-09-26", "2013-01-10"));
        datePairs.add(new Pair<String, String>("2069-09-27", "2013-01-11"));
        datePairs.add(new Pair<String, String>("2069-09-28", "2013-01-12"));
        datePairs.add(new Pair<String, String>("2069-09-29", "2013-01-13"));
        datePairs.add(new Pair<String, String>("2069-10-01", "2013-01-14"));
        datePairs.add(new Pair<String, String>("2069-10-02", "2013-01-15"));
        datePairs.add(new Pair<String, String>("2069-10-03", "2013-01-16"));
        datePairs.add(new Pair<String, String>("2069-10-04", "2013-01-17"));
        datePairs.add(new Pair<String, String>("2069-10-05", "2013-01-18"));
        datePairs.add(new Pair<String, String>("2069-10-06", "2013-01-19"));
        datePairs.add(new Pair<String, String>("2069-10-07", "2013-01-20"));
        datePairs.add(new Pair<String, String>("2069-10-08", "2013-01-21"));
        datePairs.add(new Pair<String, String>("2069-10-09", "2013-01-22"));
        datePairs.add(new Pair<String, String>("2069-10-10", "2013-01-23"));
        datePairs.add(new Pair<String, String>("2069-10-11", "2013-01-24"));
        datePairs.add(new Pair<String, String>("2069-10-12", "2013-01-25"));
        datePairs.add(new Pair<String, String>("2069-10-13", "2013-01-26"));
        datePairs.add(new Pair<String, String>("2069-10-14", "2013-01-27"));
        datePairs.add(new Pair<String, String>("2069-10-15", "2013-01-28"));
        datePairs.add(new Pair<String, String>("2069-10-16", "2013-01-29"));
        datePairs.add(new Pair<String, String>("2069-10-17", "2013-01-30"));
        datePairs.add(new Pair<String, String>("2069-10-18", "2013-01-31"));
        datePairs.add(new Pair<String, String>("2069-10-19", "2013-02-01"));
        datePairs.add(new Pair<String, String>("2069-10-20", "2013-02-02"));
        datePairs.add(new Pair<String, String>("2069-10-21", "2013-02-03"));
        datePairs.add(new Pair<String, String>("2069-10-22", "2013-02-04"));
        datePairs.add(new Pair<String, String>("2069-10-23", "2013-02-05"));
        datePairs.add(new Pair<String, String>("2069-10-24", "2013-02-06"));
        datePairs.add(new Pair<String, String>("2069-10-25", "2013-02-07"));
        datePairs.add(new Pair<String, String>("2069-10-26", "2013-02-08"));
        datePairs.add(new Pair<String, String>("2069-10-27", "2013-02-09"));
        datePairs.add(new Pair<String, String>("2069-10-28", "2013-02-10"));
        datePairs.add(new Pair<String, String>("2069-10-29", "2013-02-11"));
        datePairs.add(new Pair<String, String>("2069-11-01", "2013-02-12"));
        datePairs.add(new Pair<String, String>("2069-11-02", "2013-02-13"));
        datePairs.add(new Pair<String, String>("2069-11-03", "2013-02-14"));
        datePairs.add(new Pair<String, String>("2069-11-04", "2013-02-15"));
        datePairs.add(new Pair<String, String>("2069-11-05", "2013-02-16"));
        datePairs.add(new Pair<String, String>("2069-11-06", "2013-02-17"));
        datePairs.add(new Pair<String, String>("2069-11-07", "2013-02-18"));
        datePairs.add(new Pair<String, String>("2069-11-08", "2013-02-19"));
        datePairs.add(new Pair<String, String>("2069-11-09", "2013-02-20"));
        datePairs.add(new Pair<String, String>("2069-11-10", "2013-02-21"));
        datePairs.add(new Pair<String, String>("2069-11-11", "2013-02-22"));
        datePairs.add(new Pair<String, String>("2069-11-12", "2013-02-23"));
        datePairs.add(new Pair<String, String>("2069-11-13", "2013-02-24"));
        datePairs.add(new Pair<String, String>("2069-11-14", "2013-02-25"));
        datePairs.add(new Pair<String, String>("2069-11-15", "2013-02-26"));
        datePairs.add(new Pair<String, String>("2069-11-16", "2013-02-27"));
        datePairs.add(new Pair<String, String>("2069-11-17", "2013-02-28"));
        datePairs.add(new Pair<String, String>("2069-11-18", "2013-03-01"));
        datePairs.add(new Pair<String, String>("2069-11-19", "2013-03-02"));
        datePairs.add(new Pair<String, String>("2069-11-20", "2013-03-03"));
        datePairs.add(new Pair<String, String>("2069-11-21", "2013-03-04"));
        datePairs.add(new Pair<String, String>("2069-11-22", "2013-03-05"));
        datePairs.add(new Pair<String, String>("2069-11-23", "2013-03-06"));
        datePairs.add(new Pair<String, String>("2069-11-24", "2013-03-07"));
        datePairs.add(new Pair<String, String>("2069-11-25", "2013-03-08"));
        datePairs.add(new Pair<String, String>("2069-11-26", "2013-03-09"));
        datePairs.add(new Pair<String, String>("2069-11-27", "2013-03-10"));
        datePairs.add(new Pair<String, String>("2069-11-28", "2013-03-11"));
        datePairs.add(new Pair<String, String>("2069-11-29", "2013-03-12"));
        datePairs.add(new Pair<String, String>("2069-11-30", "2013-03-13"));
        datePairs.add(new Pair<String, String>("2069-12-01", "2013-03-14"));
        datePairs.add(new Pair<String, String>("2069-12-02", "2013-03-15"));
        datePairs.add(new Pair<String, String>("2069-12-03", "2013-03-16"));
        datePairs.add(new Pair<String, String>("2069-12-04", "2013-03-17"));
        datePairs.add(new Pair<String, String>("2069-12-05", "2013-03-18"));
        datePairs.add(new Pair<String, String>("2069-12-06", "2013-03-19"));
        datePairs.add(new Pair<String, String>("2069-12-07", "2013-03-20"));
        datePairs.add(new Pair<String, String>("2069-12-08", "2013-03-21"));
        datePairs.add(new Pair<String, String>("2069-12-09", "2013-03-22"));
        datePairs.add(new Pair<String, String>("2069-12-10", "2013-03-23"));
        datePairs.add(new Pair<String, String>("2069-12-11", "2013-03-24"));
        datePairs.add(new Pair<String, String>("2069-12-12", "2013-03-25"));
        datePairs.add(new Pair<String, String>("2069-12-13", "2013-03-26"));
        datePairs.add(new Pair<String, String>("2069-12-14", "2013-03-27"));
        datePairs.add(new Pair<String, String>("2069-12-15", "2013-03-28"));
        datePairs.add(new Pair<String, String>("2069-12-16", "2013-03-29"));
        datePairs.add(new Pair<String, String>("2069-12-17", "2013-03-30"));
        datePairs.add(new Pair<String, String>("2069-12-18", "2013-03-31"));
        datePairs.add(new Pair<String, String>("2069-12-19", "2013-04-01"));
        datePairs.add(new Pair<String, String>("2069-12-20", "2013-04-02"));
        datePairs.add(new Pair<String, String>("2069-12-21", "2013-04-03"));
        datePairs.add(new Pair<String, String>("2069-12-22", "2013-04-04"));
        datePairs.add(new Pair<String, String>("2069-12-23", "2013-04-05"));
        datePairs.add(new Pair<String, String>("2069-12-24", "2013-04-06"));
        datePairs.add(new Pair<String, String>("2069-12-25", "2013-04-07"));
        datePairs.add(new Pair<String, String>("2069-12-26", "2013-04-08"));
        datePairs.add(new Pair<String, String>("2069-12-27", "2013-04-09"));
        datePairs.add(new Pair<String, String>("2069-12-28", "2013-04-10"));
        datePairs.add(new Pair<String, String>("2069-12-29", "2013-04-11"));
        datePairs.add(new Pair<String, String>("2069-12-30", "2013-04-12"));
        datePairs.add(new Pair<String, String>("2069-12-31", "2013-04-13"));
        datePairs.add(new Pair<String, String>("2070-01-01", "2013-04-14"));
        datePairs.add(new Pair<String, String>("2070-01-02", "2013-04-15"));
        datePairs.add(new Pair<String, String>("2070-01-03", "2013-04-16"));
        datePairs.add(new Pair<String, String>("2070-01-04", "2013-04-17"));
        datePairs.add(new Pair<String, String>("2070-01-05", "2013-04-18"));
        datePairs.add(new Pair<String, String>("2070-01-06", "2013-04-19"));
        datePairs.add(new Pair<String, String>("2070-01-07", "2013-04-20"));
        datePairs.add(new Pair<String, String>("2070-01-08", "2013-04-21"));
        datePairs.add(new Pair<String, String>("2070-01-09", "2013-04-22"));
        datePairs.add(new Pair<String, String>("2070-01-10", "2013-04-23"));
        datePairs.add(new Pair<String, String>("2070-01-11", "2013-04-24"));
        datePairs.add(new Pair<String, String>("2070-01-12", "2013-04-25"));
        datePairs.add(new Pair<String, String>("2070-01-13", "2013-04-26"));
        datePairs.add(new Pair<String, String>("2070-01-14", "2013-04-27"));
        datePairs.add(new Pair<String, String>("2070-01-15", "2013-04-28"));
        datePairs.add(new Pair<String, String>("2070-01-16", "2013-04-29"));
        datePairs.add(new Pair<String, String>("2070-01-17", "2013-04-30"));
        datePairs.add(new Pair<String, String>("2070-01-18", "2013-05-01"));
        datePairs.add(new Pair<String, String>("2070-01-19", "2013-05-02"));
        datePairs.add(new Pair<String, String>("2070-01-20", "2013-05-03"));
        datePairs.add(new Pair<String, String>("2070-01-21", "2013-05-04"));
        datePairs.add(new Pair<String, String>("2070-01-22", "2013-05-05"));
        datePairs.add(new Pair<String, String>("2070-01-23", "2013-05-06"));
        datePairs.add(new Pair<String, String>("2070-01-24", "2013-05-07"));
        datePairs.add(new Pair<String, String>("2070-01-25", "2013-05-08"));
        datePairs.add(new Pair<String, String>("2070-01-26", "2013-05-09"));
        datePairs.add(new Pair<String, String>("2070-01-27", "2013-05-10"));
        datePairs.add(new Pair<String, String>("2070-01-28", "2013-05-11"));
        datePairs.add(new Pair<String, String>("2070-01-29", "2013-05-12"));
        datePairs.add(new Pair<String, String>("2070-01-30", "2013-05-13"));
        datePairs.add(new Pair<String, String>("2070-01-31", "2013-05-14"));
        datePairs.add(new Pair<String, String>("2070-02-01", "2013-05-15"));
        datePairs.add(new Pair<String, String>("2070-02-02", "2013-05-16"));
        datePairs.add(new Pair<String, String>("2070-02-03", "2013-05-17"));
        datePairs.add(new Pair<String, String>("2070-02-04", "2013-05-18"));
        datePairs.add(new Pair<String, String>("2070-02-05", "2013-05-19"));
        datePairs.add(new Pair<String, String>("2070-02-06", "2013-05-20"));
        datePairs.add(new Pair<String, String>("2070-02-07", "2013-05-21"));
        datePairs.add(new Pair<String, String>("2070-02-08", "2013-05-22"));
        datePairs.add(new Pair<String, String>("2070-02-09", "2013-05-23"));
        datePairs.add(new Pair<String, String>("2070-02-10", "2013-05-24"));
        datePairs.add(new Pair<String, String>("2070-02-11", "2013-05-25"));
        datePairs.add(new Pair<String, String>("2070-02-12", "2013-05-26"));
        datePairs.add(new Pair<String, String>("2070-02-13", "2013-05-27"));
        datePairs.add(new Pair<String, String>("2070-02-14", "2013-05-28"));
        datePairs.add(new Pair<String, String>("2070-02-15", "2013-05-29"));
        datePairs.add(new Pair<String, String>("2070-02-16", "2013-05-30"));
        datePairs.add(new Pair<String, String>("2070-02-17", "2013-05-31"));
        datePairs.add(new Pair<String, String>("2070-02-18", "2013-06-01"));
        datePairs.add(new Pair<String, String>("2070-02-19", "2013-06-02"));
        datePairs.add(new Pair<String, String>("2070-02-20", "2013-06-03"));
        datePairs.add(new Pair<String, String>("2070-02-21", "2013-06-04"));
        datePairs.add(new Pair<String, String>("2070-02-22", "2013-06-05"));
        datePairs.add(new Pair<String, String>("2070-02-23", "2013-06-06"));
        datePairs.add(new Pair<String, String>("2070-02-24", "2013-06-07"));
        datePairs.add(new Pair<String, String>("2070-02-25", "2013-06-08"));
        datePairs.add(new Pair<String, String>("2070-02-26", "2013-06-09"));
        datePairs.add(new Pair<String, String>("2070-02-27", "2013-06-10"));
        datePairs.add(new Pair<String, String>("2070-02-28", "2013-06-11"));
        datePairs.add(new Pair<String, String>("2070-02-29", "2013-06-12"));
        datePairs.add(new Pair<String, String>("2070-02-30", "2013-06-13"));
        datePairs.add(new Pair<String, String>("2070-02-31", "2013-06-14"));
        datePairs.add(new Pair<String, String>("2070-03-01", "2013-06-15"));
        datePairs.add(new Pair<String, String>("2070-03-02", "2013-06-16"));
        datePairs.add(new Pair<String, String>("2070-03-03", "2013-06-17"));
        datePairs.add(new Pair<String, String>("2070-03-04", "2013-06-18"));
        datePairs.add(new Pair<String, String>("2070-03-05", "2013-06-19"));
        datePairs.add(new Pair<String, String>("2070-03-06", "2013-06-20"));
        datePairs.add(new Pair<String, String>("2070-03-07", "2013-06-21"));
        datePairs.add(new Pair<String, String>("2070-03-08", "2013-06-22"));
        datePairs.add(new Pair<String, String>("2070-03-09", "2013-06-23"));
        datePairs.add(new Pair<String, String>("2070-03-10", "2013-06-24"));
        datePairs.add(new Pair<String, String>("2070-03-11", "2013-06-25"));
        datePairs.add(new Pair<String, String>("2070-03-12", "2013-06-26"));
        datePairs.add(new Pair<String, String>("2070-03-13", "2013-06-27"));
        datePairs.add(new Pair<String, String>("2070-03-14", "2013-06-28"));
        datePairs.add(new Pair<String, String>("2070-03-15", "2013-06-29"));
        datePairs.add(new Pair<String, String>("2070-03-16", "2013-06-30"));
        datePairs.add(new Pair<String, String>("2070-03-17", "2013-07-01"));
        datePairs.add(new Pair<String, String>("2070-03-18", "2013-07-02"));
        datePairs.add(new Pair<String, String>("2070-03-19", "2013-07-03"));
        datePairs.add(new Pair<String, String>("2070-03-20", "2013-07-04"));
        datePairs.add(new Pair<String, String>("2070-03-21", "2013-07-05"));
        datePairs.add(new Pair<String, String>("2070-03-22", "2013-07-06"));
        datePairs.add(new Pair<String, String>("2070-03-23", "2013-07-07"));
        datePairs.add(new Pair<String, String>("2070-03-24", "2013-07-08"));
        datePairs.add(new Pair<String, String>("2070-03-25", "2013-07-09"));
        datePairs.add(new Pair<String, String>("2070-03-26", "2013-07-10"));
        datePairs.add(new Pair<String, String>("2070-03-27", "2013-07-11"));
        datePairs.add(new Pair<String, String>("2070-03-28", "2013-07-12"));
        datePairs.add(new Pair<String, String>("2070-03-29", "2013-07-13"));
        datePairs.add(new Pair<String, String>("2070-03-30", "2013-07-14"));
        datePairs.add(new Pair<String, String>("2070-03-31", "2013-07-15"));
        datePairs.add(new Pair<String, String>("2070-04-01", "2013-07-16"));
        datePairs.add(new Pair<String, String>("2070-04-02", "2013-07-17"));
        datePairs.add(new Pair<String, String>("2070-04-03", "2013-07-18"));
        datePairs.add(new Pair<String, String>("2070-04-04", "2013-07-19"));
        datePairs.add(new Pair<String, String>("2070-04-05", "2013-07-20"));
        datePairs.add(new Pair<String, String>("2070-04-06", "2013-07-21"));
        datePairs.add(new Pair<String, String>("2070-04-07", "2013-07-22"));
        datePairs.add(new Pair<String, String>("2070-04-08", "2013-07-23"));
        datePairs.add(new Pair<String, String>("2070-04-09", "2013-07-24"));
        datePairs.add(new Pair<String, String>("2070-04-10", "2013-07-25"));
        datePairs.add(new Pair<String, String>("2070-04-11", "2013-07-26"));
        datePairs.add(new Pair<String, String>("2070-04-12", "2013-07-27"));
        datePairs.add(new Pair<String, String>("2070-04-13", "2013-07-28"));
        datePairs.add(new Pair<String, String>("2070-04-14", "2013-07-29"));
        datePairs.add(new Pair<String, String>("2070-04-15", "2013-07-30"));
        datePairs.add(new Pair<String, String>("2070-04-16", "2013-07-31"));
        datePairs.add(new Pair<String, String>("2070-04-17", "2013-08-01"));
        datePairs.add(new Pair<String, String>("2070-04-18", "2013-08-02"));
        datePairs.add(new Pair<String, String>("2070-04-19", "2013-08-03"));
        datePairs.add(new Pair<String, String>("2070-04-20", "2013-08-04"));
        datePairs.add(new Pair<String, String>("2070-04-21", "2013-08-05"));
        datePairs.add(new Pair<String, String>("2070-04-22", "2013-08-06"));
        datePairs.add(new Pair<String, String>("2070-04-23", "2013-08-07"));
        datePairs.add(new Pair<String, String>("2070-04-24", "2013-08-08"));
        datePairs.add(new Pair<String, String>("2070-04-25", "2013-08-09"));
        datePairs.add(new Pair<String, String>("2070-04-26", "2013-08-10"));
        datePairs.add(new Pair<String, String>("2070-04-27", "2013-08-11"));
        datePairs.add(new Pair<String, String>("2070-04-28", "2013-08-12"));
        datePairs.add(new Pair<String, String>("2070-04-29", "2013-08-13"));
        datePairs.add(new Pair<String, String>("2070-04-30", "2013-08-14"));
        datePairs.add(new Pair<String, String>("2070-04-31", "2013-08-15"));
        datePairs.add(new Pair<String, String>("2070-04-32", "2013-08-16"));
        datePairs.add(new Pair<String, String>("2070-05-01", "2013-08-17"));
        datePairs.add(new Pair<String, String>("2070-05-02", "2013-08-18"));
        datePairs.add(new Pair<String, String>("2070-05-03", "2013-08-19"));
        datePairs.add(new Pair<String, String>("2070-05-04", "2013-08-20"));
        datePairs.add(new Pair<String, String>("2070-05-05", "2013-08-21"));
        datePairs.add(new Pair<String, String>("2070-05-06", "2013-08-22"));
        datePairs.add(new Pair<String, String>("2070-05-07", "2013-08-23"));
        datePairs.add(new Pair<String, String>("2070-05-08", "2013-08-24"));
        datePairs.add(new Pair<String, String>("2070-05-09", "2013-08-25"));
        datePairs.add(new Pair<String, String>("2070-05-10", "2013-08-26"));
        datePairs.add(new Pair<String, String>("2070-05-11", "2013-08-27"));
        datePairs.add(new Pair<String, String>("2070-05-12", "2013-08-28"));
        datePairs.add(new Pair<String, String>("2070-05-13", "2013-08-29"));
        datePairs.add(new Pair<String, String>("2070-05-14", "2013-08-30"));
        datePairs.add(new Pair<String, String>("2070-05-15", "2013-08-31"));
        datePairs.add(new Pair<String, String>("2070-05-16", "2013-09-01"));
        datePairs.add(new Pair<String, String>("2070-05-17", "2013-09-02"));
        datePairs.add(new Pair<String, String>("2070-05-18", "2013-09-03"));
        datePairs.add(new Pair<String, String>("2070-05-19", "2013-09-04"));
        datePairs.add(new Pair<String, String>("2070-05-20", "2013-09-05"));
        datePairs.add(new Pair<String, String>("2070-05-21", "2013-09-06"));
        datePairs.add(new Pair<String, String>("2070-05-22", "2013-09-07"));
        datePairs.add(new Pair<String, String>("2070-05-23", "2013-09-08"));
        datePairs.add(new Pair<String, String>("2070-05-24", "2013-09-09"));
        datePairs.add(new Pair<String, String>("2070-05-25", "2013-09-10"));
        datePairs.add(new Pair<String, String>("2070-05-26", "2013-09-11"));
        datePairs.add(new Pair<String, String>("2070-05-27", "2013-09-12"));
        datePairs.add(new Pair<String, String>("2070-05-28", "2013-09-13"));
        datePairs.add(new Pair<String, String>("2070-05-29", "2013-09-14"));
        datePairs.add(new Pair<String, String>("2070-05-30", "2013-09-15"));
        datePairs.add(new Pair<String, String>("2070-05-31", "2013-09-16"));
        datePairs.add(new Pair<String, String>("2070-06-01", "2013-09-17"));
        datePairs.add(new Pair<String, String>("2070-06-02", "2013-09-18"));
        datePairs.add(new Pair<String, String>("2070-06-03", "2013-09-19"));
        datePairs.add(new Pair<String, String>("2070-06-04", "2013-09-20"));
        datePairs.add(new Pair<String, String>("2070-06-05", "2013-09-21"));
        datePairs.add(new Pair<String, String>("2070-06-06", "2013-09-22"));
        datePairs.add(new Pair<String, String>("2070-06-07", "2013-09-23"));
        datePairs.add(new Pair<String, String>("2070-06-08", "2013-09-24"));
        datePairs.add(new Pair<String, String>("2070-06-09", "2013-09-25"));
        datePairs.add(new Pair<String, String>("2070-06-10", "2013-09-26"));
        datePairs.add(new Pair<String, String>("2070-06-11", "2013-09-27"));
        datePairs.add(new Pair<String, String>("2070-06-12", "2013-09-28"));
        datePairs.add(new Pair<String, String>("2070-06-13", "2013-09-29"));
        datePairs.add(new Pair<String, String>("2070-06-14", "2013-09-30"));
        datePairs.add(new Pair<String, String>("2070-06-15", "2013-10-01"));
        datePairs.add(new Pair<String, String>("2070-06-16", "2013-10-02"));
        datePairs.add(new Pair<String, String>("2070-06-17", "2013-10-03"));
        datePairs.add(new Pair<String, String>("2070-06-18", "2013-10-04"));
        datePairs.add(new Pair<String, String>("2070-06-19", "2013-10-05"));
        datePairs.add(new Pair<String, String>("2070-06-20", "2013-10-06"));
        datePairs.add(new Pair<String, String>("2070-06-21", "2013-10-07"));
        datePairs.add(new Pair<String, String>("2070-06-22", "2013-10-08"));
        datePairs.add(new Pair<String, String>("2070-06-23", "2013-10-09"));
        datePairs.add(new Pair<String, String>("2070-06-24", "2013-10-10"));
        datePairs.add(new Pair<String, String>("2070-06-25", "2013-10-11"));
        datePairs.add(new Pair<String, String>("2070-06-26", "2013-10-12"));
        datePairs.add(new Pair<String, String>("2070-06-27", "2013-10-13"));
        datePairs.add(new Pair<String, String>("2070-06-28", "2013-10-14"));
        datePairs.add(new Pair<String, String>("2070-06-29", "2013-10-15"));
        datePairs.add(new Pair<String, String>("2070-06-30", "2013-10-16"));
        datePairs.add(new Pair<String, String>("2070-06-31", "2013-10-17"));
        datePairs.add(new Pair<String, String>("2070-07-01", "2013-10-18"));
        datePairs.add(new Pair<String, String>("2070-07-02", "2013-10-19"));
        datePairs.add(new Pair<String, String>("2070-07-03", "2013-10-20"));
        datePairs.add(new Pair<String, String>("2070-07-04", "2013-10-21"));
        datePairs.add(new Pair<String, String>("2070-07-05", "2013-10-22"));
        datePairs.add(new Pair<String, String>("2070-07-06", "2013-10-23"));
        datePairs.add(new Pair<String, String>("2070-07-07", "2013-10-24"));
        datePairs.add(new Pair<String, String>("2070-07-08", "2013-10-25"));
        datePairs.add(new Pair<String, String>("2070-07-09", "2013-10-26"));
        datePairs.add(new Pair<String, String>("2070-07-10", "2013-10-27"));
        datePairs.add(new Pair<String, String>("2070-07-11", "2013-10-28"));
        datePairs.add(new Pair<String, String>("2070-07-12", "2013-10-29"));
        datePairs.add(new Pair<String, String>("2070-07-13", "2013-10-30"));
        datePairs.add(new Pair<String, String>("2070-07-14", "2013-10-31"));
        datePairs.add(new Pair<String, String>("2070-07-15", "2013-11-01"));
        datePairs.add(new Pair<String, String>("2070-07-16", "2013-11-02"));
        datePairs.add(new Pair<String, String>("2070-07-17", "2013-11-03"));
        datePairs.add(new Pair<String, String>("2070-07-18", "2013-11-04"));
        datePairs.add(new Pair<String, String>("2070-07-19", "2013-11-05"));
        datePairs.add(new Pair<String, String>("2070-07-20", "2013-11-06"));
        datePairs.add(new Pair<String, String>("2070-07-21", "2013-11-07"));
        datePairs.add(new Pair<String, String>("2070-07-22", "2013-11-08"));
        datePairs.add(new Pair<String, String>("2070-07-23", "2013-11-09"));
        datePairs.add(new Pair<String, String>("2070-07-24", "2013-11-10"));
        datePairs.add(new Pair<String, String>("2070-07-25", "2013-11-11"));
        datePairs.add(new Pair<String, String>("2070-07-26", "2013-11-12"));
        datePairs.add(new Pair<String, String>("2070-07-27", "2013-11-13"));
        datePairs.add(new Pair<String, String>("2070-07-28", "2013-11-14"));
        datePairs.add(new Pair<String, String>("2070-07-29", "2013-11-15"));
        datePairs.add(new Pair<String, String>("2070-08-01", "2013-11-16"));
        datePairs.add(new Pair<String, String>("2070-08-02", "2013-11-17"));
        datePairs.add(new Pair<String, String>("2070-08-03", "2013-11-18"));
        datePairs.add(new Pair<String, String>("2070-08-04", "2013-11-19"));
        datePairs.add(new Pair<String, String>("2070-08-05", "2013-11-20"));
        datePairs.add(new Pair<String, String>("2070-08-06", "2013-11-21"));
        datePairs.add(new Pair<String, String>("2070-08-07", "2013-11-22"));
        datePairs.add(new Pair<String, String>("2070-08-08", "2013-11-23"));
        datePairs.add(new Pair<String, String>("2070-08-09", "2013-11-24"));
        datePairs.add(new Pair<String, String>("2070-08-10", "2013-11-25"));
        datePairs.add(new Pair<String, String>("2070-08-11", "2013-11-26"));
        datePairs.add(new Pair<String, String>("2070-08-12", "2013-11-27"));
        datePairs.add(new Pair<String, String>("2070-08-13", "2013-11-28"));
        datePairs.add(new Pair<String, String>("2070-08-14", "2013-11-29"));
        datePairs.add(new Pair<String, String>("2070-08-15", "2013-11-30"));
        datePairs.add(new Pair<String, String>("2070-08-16", "2013-12-01"));
        datePairs.add(new Pair<String, String>("2070-08-17", "2013-12-02"));
        datePairs.add(new Pair<String, String>("2070-08-18", "2013-12-03"));
        datePairs.add(new Pair<String, String>("2070-08-19", "2013-12-04"));
        datePairs.add(new Pair<String, String>("2070-08-20", "2013-12-05"));
        datePairs.add(new Pair<String, String>("2070-08-21", "2013-12-06"));
        datePairs.add(new Pair<String, String>("2070-08-22", "2013-12-07"));
        datePairs.add(new Pair<String, String>("2070-08-23", "2013-12-08"));
        datePairs.add(new Pair<String, String>("2070-08-24", "2013-12-09"));
        datePairs.add(new Pair<String, String>("2070-08-25", "2013-12-10"));
        datePairs.add(new Pair<String, String>("2070-08-26", "2013-12-11"));
        datePairs.add(new Pair<String, String>("2070-08-27", "2013-12-12"));
        datePairs.add(new Pair<String, String>("2070-08-28", "2013-12-13"));
        datePairs.add(new Pair<String, String>("2070-08-29", "2013-12-14"));
        datePairs.add(new Pair<String, String>("2070-08-30", "2013-12-15"));
        datePairs.add(new Pair<String, String>("2070-09-01", "2013-12-16"));
        datePairs.add(new Pair<String, String>("2070-09-02", "2013-12-17"));
        datePairs.add(new Pair<String, String>("2070-09-03", "2013-12-18"));
        datePairs.add(new Pair<String, String>("2070-09-04", "2013-12-19"));
        datePairs.add(new Pair<String, String>("2070-09-05", "2013-12-20"));
        datePairs.add(new Pair<String, String>("2070-09-06", "2013-12-21"));
        datePairs.add(new Pair<String, String>("2070-09-07", "2013-12-22"));
        datePairs.add(new Pair<String, String>("2070-09-08", "2013-12-23"));
        datePairs.add(new Pair<String, String>("2070-09-09", "2013-12-24"));
        datePairs.add(new Pair<String, String>("2070-09-10", "2013-12-25"));
        datePairs.add(new Pair<String, String>("2070-09-11", "2013-12-26"));
        datePairs.add(new Pair<String, String>("2070-09-12", "2013-12-27"));
        datePairs.add(new Pair<String, String>("2070-09-13", "2013-12-28"));
        datePairs.add(new Pair<String, String>("2070-09-14", "2013-12-29"));
        datePairs.add(new Pair<String, String>("2070-09-15", "2013-12-30"));
        datePairs.add(new Pair<String, String>("2070-09-16", "2013-12-31"));
        datePairs.add(new Pair<String, String>("2070-09-17", "2014-01-01"));
        datePairs.add(new Pair<String, String>("2070-09-18", "2014-01-02"));
        datePairs.add(new Pair<String, String>("2070-09-19", "2014-01-03"));
        datePairs.add(new Pair<String, String>("2070-09-20", "2014-01-04"));
        datePairs.add(new Pair<String, String>("2070-09-21", "2014-01-05"));
        datePairs.add(new Pair<String, String>("2070-09-22", "2014-01-06"));
        datePairs.add(new Pair<String, String>("2070-09-23", "2014-01-07"));
        datePairs.add(new Pair<String, String>("2070-09-24", "2014-01-08"));
        datePairs.add(new Pair<String, String>("2070-09-25", "2014-01-09"));
        datePairs.add(new Pair<String, String>("2070-09-26", "2014-01-10"));
        datePairs.add(new Pair<String, String>("2070-09-27", "2014-01-11"));
        datePairs.add(new Pair<String, String>("2070-09-28", "2014-01-12"));
        datePairs.add(new Pair<String, String>("2070-09-29", "2014-01-13"));
        datePairs.add(new Pair<String, String>("2070-09-30", "2014-01-14"));
        datePairs.add(new Pair<String, String>("2070-10-01", "2014-01-15"));
        datePairs.add(new Pair<String, String>("2070-10-02", "2014-01-16"));
        datePairs.add(new Pair<String, String>("2070-10-03", "2014-01-17"));
        datePairs.add(new Pair<String, String>("2070-10-04", "2014-01-18"));
        datePairs.add(new Pair<String, String>("2070-10-05", "2014-01-19"));
        datePairs.add(new Pair<String, String>("2070-10-06", "2014-01-20"));
        datePairs.add(new Pair<String, String>("2070-10-07", "2014-01-21"));
        datePairs.add(new Pair<String, String>("2070-10-08", "2014-01-22"));
        datePairs.add(new Pair<String, String>("2070-10-09", "2014-01-23"));
        datePairs.add(new Pair<String, String>("2070-10-10", "2014-01-24"));
        datePairs.add(new Pair<String, String>("2070-10-11", "2014-01-25"));
        datePairs.add(new Pair<String, String>("2070-10-12", "2014-01-26"));
        datePairs.add(new Pair<String, String>("2070-10-13", "2014-01-27"));
        datePairs.add(new Pair<String, String>("2070-10-14", "2014-01-28"));
        datePairs.add(new Pair<String, String>("2070-10-15", "2014-01-29"));
        datePairs.add(new Pair<String, String>("2070-10-16", "2014-01-30"));
        datePairs.add(new Pair<String, String>("2070-10-17", "2014-01-31"));
        datePairs.add(new Pair<String, String>("2070-10-18", "2014-02-01"));
        datePairs.add(new Pair<String, String>("2070-10-19", "2014-02-02"));
        datePairs.add(new Pair<String, String>("2070-10-20", "2014-02-03"));
        datePairs.add(new Pair<String, String>("2070-10-21", "2014-02-04"));
        datePairs.add(new Pair<String, String>("2070-10-22", "2014-02-05"));
        datePairs.add(new Pair<String, String>("2070-10-23", "2014-02-06"));
        datePairs.add(new Pair<String, String>("2070-10-24", "2014-02-07"));
        datePairs.add(new Pair<String, String>("2070-10-25", "2014-02-08"));
        datePairs.add(new Pair<String, String>("2070-10-26", "2014-02-09"));
        datePairs.add(new Pair<String, String>("2070-10-27", "2014-02-10"));
        datePairs.add(new Pair<String, String>("2070-10-28", "2014-02-11"));
        datePairs.add(new Pair<String, String>("2070-10-29", "2014-02-12"));
        datePairs.add(new Pair<String, String>("2070-11-01", "2014-02-13"));
        datePairs.add(new Pair<String, String>("2070-11-02", "2014-02-14"));
        datePairs.add(new Pair<String, String>("2070-11-03", "2014-02-15"));
        datePairs.add(new Pair<String, String>("2070-11-04", "2014-02-16"));
        datePairs.add(new Pair<String, String>("2070-11-05", "2014-02-17"));
        datePairs.add(new Pair<String, String>("2070-11-06", "2014-02-18"));
        datePairs.add(new Pair<String, String>("2070-11-07", "2014-02-19"));
        datePairs.add(new Pair<String, String>("2070-11-08", "2014-02-20"));
        datePairs.add(new Pair<String, String>("2070-11-09", "2014-02-21"));
        datePairs.add(new Pair<String, String>("2070-11-10", "2014-02-22"));
        datePairs.add(new Pair<String, String>("2070-11-11", "2014-02-23"));
        datePairs.add(new Pair<String, String>("2070-11-12", "2014-02-24"));
        datePairs.add(new Pair<String, String>("2070-11-13", "2014-02-25"));
        datePairs.add(new Pair<String, String>("2070-11-14", "2014-02-26"));
        datePairs.add(new Pair<String, String>("2070-11-15", "2014-02-27"));
        datePairs.add(new Pair<String, String>("2070-11-16", "2014-02-28"));
        datePairs.add(new Pair<String, String>("2070-11-17", "2014-03-01"));
        datePairs.add(new Pair<String, String>("2070-11-18", "2014-03-02"));
        datePairs.add(new Pair<String, String>("2070-11-19", "2014-03-03"));
        datePairs.add(new Pair<String, String>("2070-11-20", "2014-03-04"));
        datePairs.add(new Pair<String, String>("2070-11-21", "2014-03-05"));
        datePairs.add(new Pair<String, String>("2070-11-22", "2014-03-06"));
        datePairs.add(new Pair<String, String>("2070-11-23", "2014-03-07"));
        datePairs.add(new Pair<String, String>("2070-11-24", "2014-03-08"));
        datePairs.add(new Pair<String, String>("2070-11-25", "2014-03-09"));
        datePairs.add(new Pair<String, String>("2070-11-26", "2014-03-10"));
        datePairs.add(new Pair<String, String>("2070-11-27", "2014-03-11"));
        datePairs.add(new Pair<String, String>("2070-11-28", "2014-03-12"));
        datePairs.add(new Pair<String, String>("2070-11-29", "2014-03-13"));
        datePairs.add(new Pair<String, String>("2070-11-30", "2014-03-14"));
        datePairs.add(new Pair<String, String>("2070-12-01", "2014-03-15"));
        datePairs.add(new Pair<String, String>("2070-12-02", "2014-03-16"));
        datePairs.add(new Pair<String, String>("2070-12-03", "2014-03-17"));
        datePairs.add(new Pair<String, String>("2070-12-04", "2014-03-18"));
        datePairs.add(new Pair<String, String>("2070-12-05", "2014-03-19"));
        datePairs.add(new Pair<String, String>("2070-12-06", "2014-03-20"));
        datePairs.add(new Pair<String, String>("2070-12-07", "2014-03-21"));
        datePairs.add(new Pair<String, String>("2070-12-08", "2014-03-22"));
        datePairs.add(new Pair<String, String>("2070-12-09", "2014-03-23"));
        datePairs.add(new Pair<String, String>("2070-12-10", "2014-03-24"));
        datePairs.add(new Pair<String, String>("2070-12-11", "2014-03-25"));
        datePairs.add(new Pair<String, String>("2070-12-12", "2014-03-26"));
        datePairs.add(new Pair<String, String>("2070-12-13", "2014-03-27"));
        datePairs.add(new Pair<String, String>("2070-12-14", "2014-03-28"));
        datePairs.add(new Pair<String, String>("2070-12-15", "2014-03-29"));
        datePairs.add(new Pair<String, String>("2070-12-16", "2014-03-30"));
        datePairs.add(new Pair<String, String>("2070-12-17", "2014-03-31"));
        datePairs.add(new Pair<String, String>("2070-12-18", "2014-04-01"));
        datePairs.add(new Pair<String, String>("2070-12-19", "2014-04-02"));
        datePairs.add(new Pair<String, String>("2070-12-20", "2014-04-03"));
        datePairs.add(new Pair<String, String>("2070-12-21", "2014-04-04"));
        datePairs.add(new Pair<String, String>("2070-12-22", "2014-04-05"));
        datePairs.add(new Pair<String, String>("2070-12-23", "2014-04-06"));
        datePairs.add(new Pair<String, String>("2070-12-24", "2014-04-07"));
        datePairs.add(new Pair<String, String>("2070-12-25", "2014-04-08"));
        datePairs.add(new Pair<String, String>("2070-12-26", "2014-04-09"));
        datePairs.add(new Pair<String, String>("2070-12-27", "2014-04-10"));
        datePairs.add(new Pair<String, String>("2070-12-28", "2014-04-11"));
        datePairs.add(new Pair<String, String>("2070-12-29", "2014-04-12"));
        datePairs.add(new Pair<String, String>("2070-12-30", "2014-04-13"));
        datePairs.add(new Pair<String, String>("2071-01-01", "2014-04-14"));
        datePairs.add(new Pair<String, String>("2071-01-02", "2014-04-15"));
        datePairs.add(new Pair<String, String>("2071-01-03", "2014-04-16"));
        datePairs.add(new Pair<String, String>("2071-01-04", "2014-04-17"));
        datePairs.add(new Pair<String, String>("2071-01-05", "2014-04-18"));
        datePairs.add(new Pair<String, String>("2071-01-06", "2014-04-19"));
        datePairs.add(new Pair<String, String>("2071-01-07", "2014-04-20"));
        datePairs.add(new Pair<String, String>("2071-01-08", "2014-04-21"));
        datePairs.add(new Pair<String, String>("2071-01-09", "2014-04-22"));
        datePairs.add(new Pair<String, String>("2071-01-10", "2014-04-23"));
        datePairs.add(new Pair<String, String>("2071-01-11", "2014-04-24"));
        datePairs.add(new Pair<String, String>("2071-01-12", "2014-04-25"));
        datePairs.add(new Pair<String, String>("2071-01-13", "2014-04-26"));
        datePairs.add(new Pair<String, String>("2071-01-14", "2014-04-27"));
        datePairs.add(new Pair<String, String>("2071-01-15", "2014-04-28"));
        datePairs.add(new Pair<String, String>("2071-01-16", "2014-04-29"));
        datePairs.add(new Pair<String, String>("2071-01-17", "2014-04-30"));
        datePairs.add(new Pair<String, String>("2071-01-18", "2014-05-01"));
        datePairs.add(new Pair<String, String>("2071-01-19", "2014-05-02"));
        datePairs.add(new Pair<String, String>("2071-01-20", "2014-05-03"));
        datePairs.add(new Pair<String, String>("2071-01-21", "2014-05-04"));
        datePairs.add(new Pair<String, String>("2071-01-22", "2014-05-05"));
        datePairs.add(new Pair<String, String>("2071-01-23", "2014-05-06"));
        datePairs.add(new Pair<String, String>("2071-01-24", "2014-05-07"));
        datePairs.add(new Pair<String, String>("2071-01-25", "2014-05-08"));
        datePairs.add(new Pair<String, String>("2071-01-26", "2014-05-09"));
        datePairs.add(new Pair<String, String>("2071-01-27", "2014-05-10"));
        datePairs.add(new Pair<String, String>("2071-01-28", "2014-05-11"));
        datePairs.add(new Pair<String, String>("2071-01-29", "2014-05-12"));
        datePairs.add(new Pair<String, String>("2071-01-30", "2014-05-13"));
        datePairs.add(new Pair<String, String>("2071-01-31", "2014-05-14"));
        datePairs.add(new Pair<String, String>("2071-02-01", "2014-05-15"));
        datePairs.add(new Pair<String, String>("2071-02-02", "2014-05-16"));
        datePairs.add(new Pair<String, String>("2071-02-03", "2014-05-17"));
        datePairs.add(new Pair<String, String>("2071-02-04", "2014-05-18"));
        datePairs.add(new Pair<String, String>("2071-02-05", "2014-05-19"));
        datePairs.add(new Pair<String, String>("2071-02-06", "2014-05-20"));
        datePairs.add(new Pair<String, String>("2071-02-07", "2014-05-21"));
        datePairs.add(new Pair<String, String>("2071-02-08", "2014-05-22"));
        datePairs.add(new Pair<String, String>("2071-02-09", "2014-05-23"));
        datePairs.add(new Pair<String, String>("2071-02-10", "2014-05-24"));
        datePairs.add(new Pair<String, String>("2071-02-11", "2014-05-25"));
        datePairs.add(new Pair<String, String>("2071-02-12", "2014-05-26"));
        datePairs.add(new Pair<String, String>("2071-02-13", "2014-05-27"));
        datePairs.add(new Pair<String, String>("2071-02-14", "2014-05-28"));
        datePairs.add(new Pair<String, String>("2071-02-15", "2014-05-29"));
        datePairs.add(new Pair<String, String>("2071-02-16", "2014-05-30"));
        datePairs.add(new Pair<String, String>("2071-02-17", "2014-05-31"));
        datePairs.add(new Pair<String, String>("2071-02-18", "2014-06-01"));
        datePairs.add(new Pair<String, String>("2071-02-19", "2014-06-02"));
        datePairs.add(new Pair<String, String>("2071-02-20", "2014-06-03"));
        datePairs.add(new Pair<String, String>("2071-02-21", "2014-06-04"));
        datePairs.add(new Pair<String, String>("2071-02-22", "2014-06-05"));
        datePairs.add(new Pair<String, String>("2071-02-23", "2014-06-06"));
        datePairs.add(new Pair<String, String>("2071-02-24", "2014-06-07"));
        datePairs.add(new Pair<String, String>("2071-02-25", "2014-06-08"));
        datePairs.add(new Pair<String, String>("2071-02-26", "2014-06-09"));
        datePairs.add(new Pair<String, String>("2071-02-27", "2014-06-10"));
        datePairs.add(new Pair<String, String>("2071-02-28", "2014-06-11"));
        datePairs.add(new Pair<String, String>("2071-02-29", "2014-06-12"));
        datePairs.add(new Pair<String, String>("2071-02-30", "2014-06-13"));
        datePairs.add(new Pair<String, String>("2071-02-31", "2014-06-14"));
        datePairs.add(new Pair<String, String>("2071-03-01", "2014-06-15"));
        datePairs.add(new Pair<String, String>("2071-03-02", "2014-06-16"));
        datePairs.add(new Pair<String, String>("2071-03-03", "2014-06-17"));
        datePairs.add(new Pair<String, String>("2071-03-04", "2014-06-18"));
        datePairs.add(new Pair<String, String>("2071-03-05", "2014-06-19"));
        datePairs.add(new Pair<String, String>("2071-03-06", "2014-06-20"));
        datePairs.add(new Pair<String, String>("2071-03-07", "2014-06-21"));
        datePairs.add(new Pair<String, String>("2071-03-08", "2014-06-22"));
        datePairs.add(new Pair<String, String>("2071-03-09", "2014-06-23"));
        datePairs.add(new Pair<String, String>("2071-03-10", "2014-06-24"));
        datePairs.add(new Pair<String, String>("2071-03-11", "2014-06-25"));
        datePairs.add(new Pair<String, String>("2071-03-12", "2014-06-26"));
        datePairs.add(new Pair<String, String>("2071-03-13", "2014-06-27"));
        datePairs.add(new Pair<String, String>("2071-03-14", "2014-06-28"));
        datePairs.add(new Pair<String, String>("2071-03-15", "2014-06-29"));
        datePairs.add(new Pair<String, String>("2071-03-16", "2014-06-30"));
        datePairs.add(new Pair<String, String>("2071-03-17", "2014-07-01"));
        datePairs.add(new Pair<String, String>("2071-03-18", "2014-07-02"));
        datePairs.add(new Pair<String, String>("2071-03-19", "2014-07-03"));
        datePairs.add(new Pair<String, String>("2071-03-20", "2014-07-04"));
        datePairs.add(new Pair<String, String>("2071-03-21", "2014-07-05"));
        datePairs.add(new Pair<String, String>("2071-03-22", "2014-07-06"));
        datePairs.add(new Pair<String, String>("2071-03-23", "2014-07-07"));
        datePairs.add(new Pair<String, String>("2071-03-24", "2014-07-08"));
        datePairs.add(new Pair<String, String>("2071-03-25", "2014-07-09"));
        datePairs.add(new Pair<String, String>("2071-03-26", "2014-07-10"));
        datePairs.add(new Pair<String, String>("2071-03-27", "2014-07-11"));
        datePairs.add(new Pair<String, String>("2071-03-28", "2014-07-12"));
        datePairs.add(new Pair<String, String>("2071-03-29", "2014-07-13"));
        datePairs.add(new Pair<String, String>("2071-03-30", "2014-07-14"));
        datePairs.add(new Pair<String, String>("2071-03-31", "2014-07-15"));
        datePairs.add(new Pair<String, String>("2071-03-32", "2014-07-16"));
        datePairs.add(new Pair<String, String>("2071-04-01", "2014-07-17"));
        datePairs.add(new Pair<String, String>("2071-04-02", "2014-07-18"));
        datePairs.add(new Pair<String, String>("2071-04-03", "2014-07-19"));
        datePairs.add(new Pair<String, String>("2071-04-04", "2014-07-20"));
        datePairs.add(new Pair<String, String>("2071-04-05", "2014-07-21"));
        datePairs.add(new Pair<String, String>("2071-04-06", "2014-07-22"));
        datePairs.add(new Pair<String, String>("2071-04-07", "2014-07-23"));
        datePairs.add(new Pair<String, String>("2071-04-08", "2014-07-24"));
        datePairs.add(new Pair<String, String>("2071-04-09", "2014-07-25"));
        datePairs.add(new Pair<String, String>("2071-04-10", "2014-07-26"));
        datePairs.add(new Pair<String, String>("2071-04-11", "2014-07-27"));
        datePairs.add(new Pair<String, String>("2071-04-12", "2014-07-28"));
        datePairs.add(new Pair<String, String>("2071-04-13", "2014-07-29"));
        datePairs.add(new Pair<String, String>("2071-04-14", "2014-07-30"));
        datePairs.add(new Pair<String, String>("2071-04-15", "2014-07-31"));
        datePairs.add(new Pair<String, String>("2071-04-16", "2014-08-01"));
        datePairs.add(new Pair<String, String>("2071-04-17", "2014-08-02"));
        datePairs.add(new Pair<String, String>("2071-04-18", "2014-08-03"));
        datePairs.add(new Pair<String, String>("2071-04-19", "2014-08-04"));
        datePairs.add(new Pair<String, String>("2071-04-20", "2014-08-05"));
        datePairs.add(new Pair<String, String>("2071-04-21", "2014-08-06"));
        datePairs.add(new Pair<String, String>("2071-04-22", "2014-08-07"));
        datePairs.add(new Pair<String, String>("2071-04-23", "2014-08-08"));
        datePairs.add(new Pair<String, String>("2071-04-24", "2014-08-09"));
        datePairs.add(new Pair<String, String>("2071-04-25", "2014-08-10"));
        datePairs.add(new Pair<String, String>("2071-04-26", "2014-08-11"));
        datePairs.add(new Pair<String, String>("2071-04-27", "2014-08-12"));
        datePairs.add(new Pair<String, String>("2071-04-28", "2014-08-13"));
        datePairs.add(new Pair<String, String>("2071-04-29", "2014-08-14"));
        datePairs.add(new Pair<String, String>("2071-04-30", "2014-08-15"));
        datePairs.add(new Pair<String, String>("2071-04-31", "2014-08-16"));
        datePairs.add(new Pair<String, String>("2071-05-01", "2014-08-17"));
        datePairs.add(new Pair<String, String>("2071-05-02", "2014-08-18"));
        datePairs.add(new Pair<String, String>("2071-05-03", "2014-08-19"));
        datePairs.add(new Pair<String, String>("2071-05-04", "2014-08-20"));
        datePairs.add(new Pair<String, String>("2071-05-05", "2014-08-21"));
        datePairs.add(new Pair<String, String>("2071-05-06", "2014-08-22"));
        datePairs.add(new Pair<String, String>("2071-05-07", "2014-08-23"));
        datePairs.add(new Pair<String, String>("2071-05-08", "2014-08-24"));
        datePairs.add(new Pair<String, String>("2071-05-09", "2014-08-25"));
        datePairs.add(new Pair<String, String>("2071-05-10", "2014-08-26"));
        datePairs.add(new Pair<String, String>("2071-05-11", "2014-08-27"));
        datePairs.add(new Pair<String, String>("2071-05-12", "2014-08-28"));
        datePairs.add(new Pair<String, String>("2071-05-13", "2014-08-29"));
        datePairs.add(new Pair<String, String>("2071-05-14", "2014-08-30"));
        datePairs.add(new Pair<String, String>("2071-05-15", "2014-08-31"));
        datePairs.add(new Pair<String, String>("2071-05-16", "2014-09-01"));
        datePairs.add(new Pair<String, String>("2071-05-17", "2014-09-02"));
        datePairs.add(new Pair<String, String>("2071-05-18", "2014-09-03"));
        datePairs.add(new Pair<String, String>("2071-05-19", "2014-09-04"));
        datePairs.add(new Pair<String, String>("2071-05-20", "2014-09-05"));
        datePairs.add(new Pair<String, String>("2071-05-21", "2014-09-06"));
        datePairs.add(new Pair<String, String>("2071-05-22", "2014-09-07"));
        datePairs.add(new Pair<String, String>("2071-05-23", "2014-09-08"));
        datePairs.add(new Pair<String, String>("2071-05-24", "2014-09-09"));
        datePairs.add(new Pair<String, String>("2071-05-25", "2014-09-10"));
        datePairs.add(new Pair<String, String>("2071-05-26", "2014-09-11"));
        datePairs.add(new Pair<String, String>("2071-05-27", "2014-09-12"));
        datePairs.add(new Pair<String, String>("2071-05-28", "2014-09-13"));
        datePairs.add(new Pair<String, String>("2071-05-29", "2014-09-14"));
        datePairs.add(new Pair<String, String>("2071-05-30", "2014-09-15"));
        datePairs.add(new Pair<String, String>("2071-05-31", "2014-09-16"));
        datePairs.add(new Pair<String, String>("2071-06-01", "2014-09-17"));
        datePairs.add(new Pair<String, String>("2071-06-02", "2014-09-18"));
        datePairs.add(new Pair<String, String>("2071-06-03", "2014-09-19"));
        datePairs.add(new Pair<String, String>("2071-06-04", "2014-09-20"));
        datePairs.add(new Pair<String, String>("2071-06-05", "2014-09-21"));
        datePairs.add(new Pair<String, String>("2071-06-06", "2014-09-22"));
        datePairs.add(new Pair<String, String>("2071-06-07", "2014-09-23"));
        datePairs.add(new Pair<String, String>("2071-06-08", "2014-09-24"));
        datePairs.add(new Pair<String, String>("2071-06-09", "2014-09-25"));
        datePairs.add(new Pair<String, String>("2071-06-10", "2014-09-26"));
        datePairs.add(new Pair<String, String>("2071-06-11", "2014-09-27"));
        datePairs.add(new Pair<String, String>("2071-06-12", "2014-09-28"));
        datePairs.add(new Pair<String, String>("2071-06-13", "2014-09-29"));
        datePairs.add(new Pair<String, String>("2071-06-14", "2014-09-30"));
        datePairs.add(new Pair<String, String>("2071-06-15", "2014-10-01"));
        datePairs.add(new Pair<String, String>("2071-06-16", "2014-10-02"));
        datePairs.add(new Pair<String, String>("2071-06-17", "2014-10-03"));
        datePairs.add(new Pair<String, String>("2071-06-18", "2014-10-04"));
        datePairs.add(new Pair<String, String>("2071-06-19", "2014-10-05"));
        datePairs.add(new Pair<String, String>("2071-06-20", "2014-10-06"));
        datePairs.add(new Pair<String, String>("2071-06-21", "2014-10-07"));
        datePairs.add(new Pair<String, String>("2071-06-22", "2014-10-08"));
        datePairs.add(new Pair<String, String>("2071-06-23", "2014-10-09"));
        datePairs.add(new Pair<String, String>("2071-06-24", "2014-10-10"));
        datePairs.add(new Pair<String, String>("2071-06-25", "2014-10-11"));
        datePairs.add(new Pair<String, String>("2071-06-26", "2014-10-12"));
        datePairs.add(new Pair<String, String>("2071-06-27", "2014-10-13"));
        datePairs.add(new Pair<String, String>("2071-06-28", "2014-10-14"));
        datePairs.add(new Pair<String, String>("2071-06-29", "2014-10-15"));
        datePairs.add(new Pair<String, String>("2071-06-30", "2014-10-16"));
        datePairs.add(new Pair<String, String>("2071-06-31", "2014-10-17"));
        datePairs.add(new Pair<String, String>("2071-07-01", "2014-10-18"));
        datePairs.add(new Pair<String, String>("2071-07-02", "2014-10-19"));
        datePairs.add(new Pair<String, String>("2071-07-03", "2014-10-20"));
        datePairs.add(new Pair<String, String>("2071-07-04", "2014-10-21"));
        datePairs.add(new Pair<String, String>("2071-07-05", "2014-10-22"));
        datePairs.add(new Pair<String, String>("2071-07-06", "2014-10-23"));
        datePairs.add(new Pair<String, String>("2071-07-07", "2014-10-24"));
        datePairs.add(new Pair<String, String>("2071-07-08", "2014-10-25"));
        datePairs.add(new Pair<String, String>("2071-07-09", "2014-10-26"));
        datePairs.add(new Pair<String, String>("2071-07-10", "2014-10-27"));
        datePairs.add(new Pair<String, String>("2071-07-11", "2014-10-28"));
        datePairs.add(new Pair<String, String>("2071-07-12", "2014-10-29"));
        datePairs.add(new Pair<String, String>("2071-07-13", "2014-10-30"));
        datePairs.add(new Pair<String, String>("2071-07-14", "2014-10-31"));
        datePairs.add(new Pair<String, String>("2071-07-15", "2014-11-01"));
        datePairs.add(new Pair<String, String>("2071-07-16", "2014-11-02"));
        datePairs.add(new Pair<String, String>("2071-07-17", "2014-11-03"));
        datePairs.add(new Pair<String, String>("2071-07-18", "2014-11-04"));
        datePairs.add(new Pair<String, String>("2071-07-19", "2014-11-05"));
        datePairs.add(new Pair<String, String>("2071-07-20", "2014-11-06"));
        datePairs.add(new Pair<String, String>("2071-07-21", "2014-11-07"));
        datePairs.add(new Pair<String, String>("2071-07-22", "2014-11-08"));
        datePairs.add(new Pair<String, String>("2071-07-23", "2014-11-09"));
        datePairs.add(new Pair<String, String>("2071-07-24", "2014-11-10"));
        datePairs.add(new Pair<String, String>("2071-07-25", "2014-11-11"));
        datePairs.add(new Pair<String, String>("2071-07-26", "2014-11-12"));
        datePairs.add(new Pair<String, String>("2071-07-27", "2014-11-13"));
        datePairs.add(new Pair<String, String>("2071-07-28", "2014-11-14"));
        datePairs.add(new Pair<String, String>("2071-07-29", "2014-11-15"));
        datePairs.add(new Pair<String, String>("2071-07-30", "2014-11-16"));
        datePairs.add(new Pair<String, String>("2071-08-01", "2014-11-17"));
        datePairs.add(new Pair<String, String>("2071-08-02", "2014-11-18"));
        datePairs.add(new Pair<String, String>("2071-08-03", "2014-11-19"));
        datePairs.add(new Pair<String, String>("2071-08-04", "2014-11-20"));
        datePairs.add(new Pair<String, String>("2071-08-05", "2014-11-21"));
        datePairs.add(new Pair<String, String>("2071-08-06", "2014-11-22"));
        datePairs.add(new Pair<String, String>("2071-08-07", "2014-11-23"));
        datePairs.add(new Pair<String, String>("2071-08-08", "2014-11-24"));
        datePairs.add(new Pair<String, String>("2071-08-09", "2014-11-25"));
        datePairs.add(new Pair<String, String>("2071-08-10", "2014-11-26"));
        datePairs.add(new Pair<String, String>("2071-08-11", "2014-11-27"));
        datePairs.add(new Pair<String, String>("2071-08-12", "2014-11-28"));
        datePairs.add(new Pair<String, String>("2071-08-13", "2014-11-29"));
        datePairs.add(new Pair<String, String>("2071-08-14", "2014-11-30"));
        datePairs.add(new Pair<String, String>("2071-08-15", "2014-12-01"));
        datePairs.add(new Pair<String, String>("2071-08-16", "2014-12-02"));
        datePairs.add(new Pair<String, String>("2071-08-17", "2014-12-03"));
        datePairs.add(new Pair<String, String>("2071-08-18", "2014-12-04"));
        datePairs.add(new Pair<String, String>("2071-08-19", "2014-12-05"));
        datePairs.add(new Pair<String, String>("2071-08-20", "2014-12-06"));
        datePairs.add(new Pair<String, String>("2071-08-21", "2014-12-07"));
        datePairs.add(new Pair<String, String>("2071-08-22", "2014-12-08"));
        datePairs.add(new Pair<String, String>("2071-08-23", "2014-12-09"));
        datePairs.add(new Pair<String, String>("2071-08-24", "2014-12-10"));
        datePairs.add(new Pair<String, String>("2071-08-25", "2014-12-11"));
        datePairs.add(new Pair<String, String>("2071-08-26", "2014-12-12"));
        datePairs.add(new Pair<String, String>("2071-08-27", "2014-12-13"));
        datePairs.add(new Pair<String, String>("2071-08-28", "2014-12-14"));
        datePairs.add(new Pair<String, String>("2071-08-29", "2014-12-15"));
        datePairs.add(new Pair<String, String>("2071-09-01", "2014-12-16"));
        datePairs.add(new Pair<String, String>("2071-09-02", "2014-12-17"));
        datePairs.add(new Pair<String, String>("2071-09-03", "2014-12-18"));
        datePairs.add(new Pair<String, String>("2071-09-04", "2014-12-19"));
        datePairs.add(new Pair<String, String>("2071-09-05", "2014-12-20"));
        datePairs.add(new Pair<String, String>("2071-09-06", "2014-12-21"));
        datePairs.add(new Pair<String, String>("2071-09-07", "2014-12-22"));
        datePairs.add(new Pair<String, String>("2071-09-08", "2014-12-23"));
        datePairs.add(new Pair<String, String>("2071-09-09", "2014-12-24"));
        datePairs.add(new Pair<String, String>("2071-09-10", "2014-12-25"));
        datePairs.add(new Pair<String, String>("2071-09-11", "2014-12-26"));
        datePairs.add(new Pair<String, String>("2071-09-12", "2014-12-27"));
        datePairs.add(new Pair<String, String>("2071-09-13", "2014-12-28"));
        datePairs.add(new Pair<String, String>("2071-09-14", "2014-12-29"));
        datePairs.add(new Pair<String, String>("2071-09-15", "2014-12-30"));
        datePairs.add(new Pair<String, String>("2071-09-16", "2014-12-31"));
        datePairs.add(new Pair<String, String>("2071-09-17", "2015-01-01"));
        datePairs.add(new Pair<String, String>("2071-09-18", "2015-01-02"));
        datePairs.add(new Pair<String, String>("2071-09-19", "2015-01-03"));
        datePairs.add(new Pair<String, String>("2071-09-20", "2015-01-04"));
        datePairs.add(new Pair<String, String>("2071-09-21", "2015-01-05"));
        datePairs.add(new Pair<String, String>("2071-09-22", "2015-01-06"));
        datePairs.add(new Pair<String, String>("2071-09-23", "2015-01-07"));
        datePairs.add(new Pair<String, String>("2071-09-24", "2015-01-08"));
        datePairs.add(new Pair<String, String>("2071-09-25", "2015-01-09"));
        datePairs.add(new Pair<String, String>("2071-09-26", "2015-01-10"));
        datePairs.add(new Pair<String, String>("2071-09-27", "2015-01-11"));
        datePairs.add(new Pair<String, String>("2071-09-28", "2015-01-12"));
        datePairs.add(new Pair<String, String>("2071-09-29", "2015-01-13"));
        datePairs.add(new Pair<String, String>("2071-09-30", "2015-01-14"));
        datePairs.add(new Pair<String, String>("2071-10-01", "2015-01-15"));
        datePairs.add(new Pair<String, String>("2071-10-02", "2015-01-16"));
        datePairs.add(new Pair<String, String>("2071-10-03", "2015-01-17"));
        datePairs.add(new Pair<String, String>("2071-10-04", "2015-01-18"));
        datePairs.add(new Pair<String, String>("2071-10-05", "2015-01-19"));
        datePairs.add(new Pair<String, String>("2071-10-06", "2015-01-20"));
        datePairs.add(new Pair<String, String>("2071-10-07", "2015-01-21"));
        datePairs.add(new Pair<String, String>("2071-10-08", "2015-01-22"));
        datePairs.add(new Pair<String, String>("2071-10-09", "2015-01-23"));
        datePairs.add(new Pair<String, String>("2071-10-10", "2015-01-24"));
        datePairs.add(new Pair<String, String>("2071-10-11", "2015-01-25"));
        datePairs.add(new Pair<String, String>("2071-10-12", "2015-01-26"));
        datePairs.add(new Pair<String, String>("2071-10-13", "2015-01-27"));
        datePairs.add(new Pair<String, String>("2071-10-14", "2015-01-28"));
        datePairs.add(new Pair<String, String>("2071-10-15", "2015-01-29"));
        datePairs.add(new Pair<String, String>("2071-10-16", "2015-01-30"));
        datePairs.add(new Pair<String, String>("2071-10-17", "2015-01-31"));
        datePairs.add(new Pair<String, String>("2071-10-18", "2015-02-01"));
        datePairs.add(new Pair<String, String>("2071-10-19", "2015-02-02"));
        datePairs.add(new Pair<String, String>("2071-10-20", "2015-02-03"));
        datePairs.add(new Pair<String, String>("2071-10-21", "2015-02-04"));
        datePairs.add(new Pair<String, String>("2071-10-22", "2015-02-05"));
        datePairs.add(new Pair<String, String>("2071-10-23", "2015-02-06"));
        datePairs.add(new Pair<String, String>("2071-10-24", "2015-02-07"));
        datePairs.add(new Pair<String, String>("2071-10-25", "2015-02-08"));
        datePairs.add(new Pair<String, String>("2071-10-26", "2015-02-09"));
        datePairs.add(new Pair<String, String>("2071-10-27", "2015-02-10"));
        datePairs.add(new Pair<String, String>("2071-10-28", "2015-02-11"));
        datePairs.add(new Pair<String, String>("2071-10-29", "2015-02-12"));
        datePairs.add(new Pair<String, String>("2071-11-01", "2015-02-13"));
        datePairs.add(new Pair<String, String>("2071-11-02", "2015-02-14"));
        datePairs.add(new Pair<String, String>("2071-11-03", "2015-02-15"));
        datePairs.add(new Pair<String, String>("2071-11-04", "2015-02-16"));
        datePairs.add(new Pair<String, String>("2071-11-05", "2015-02-17"));
        datePairs.add(new Pair<String, String>("2071-11-06", "2015-02-18"));
        datePairs.add(new Pair<String, String>("2071-11-07", "2015-02-19"));
        datePairs.add(new Pair<String, String>("2071-11-08", "2015-02-20"));
        datePairs.add(new Pair<String, String>("2071-11-09", "2015-02-21"));
        datePairs.add(new Pair<String, String>("2071-11-10", "2015-02-22"));
        datePairs.add(new Pair<String, String>("2071-11-11", "2015-02-23"));
        datePairs.add(new Pair<String, String>("2071-11-12", "2015-02-24"));
        datePairs.add(new Pair<String, String>("2071-11-13", "2015-02-25"));
        datePairs.add(new Pair<String, String>("2071-11-14", "2015-02-26"));
        datePairs.add(new Pair<String, String>("2071-11-15", "2015-02-27"));
        datePairs.add(new Pair<String, String>("2071-11-16", "2015-02-28"));
        datePairs.add(new Pair<String, String>("2071-11-17", "2015-03-01"));
        datePairs.add(new Pair<String, String>("2071-11-18", "2015-03-02"));
        datePairs.add(new Pair<String, String>("2071-11-19", "2015-03-03"));
        datePairs.add(new Pair<String, String>("2071-11-20", "2015-03-04"));
        datePairs.add(new Pair<String, String>("2071-11-21", "2015-03-05"));
        datePairs.add(new Pair<String, String>("2071-11-22", "2015-03-06"));
        datePairs.add(new Pair<String, String>("2071-11-23", "2015-03-07"));
        datePairs.add(new Pair<String, String>("2071-11-24", "2015-03-08"));
        datePairs.add(new Pair<String, String>("2071-11-25", "2015-03-09"));
        datePairs.add(new Pair<String, String>("2071-11-26", "2015-03-10"));
        datePairs.add(new Pair<String, String>("2071-11-27", "2015-03-11"));
        datePairs.add(new Pair<String, String>("2071-11-28", "2015-03-12"));
        datePairs.add(new Pair<String, String>("2071-11-29", "2015-03-13"));
        datePairs.add(new Pair<String, String>("2071-11-30", "2015-03-14"));
        datePairs.add(new Pair<String, String>("2071-12-01", "2015-03-15"));
        datePairs.add(new Pair<String, String>("2071-12-02", "2015-03-16"));
        datePairs.add(new Pair<String, String>("2071-12-03", "2015-03-17"));
        datePairs.add(new Pair<String, String>("2071-12-04", "2015-03-18"));
        datePairs.add(new Pair<String, String>("2071-12-05", "2015-03-19"));
        datePairs.add(new Pair<String, String>("2071-12-06", "2015-03-20"));
        datePairs.add(new Pair<String, String>("2071-12-07", "2015-03-21"));
        datePairs.add(new Pair<String, String>("2071-12-08", "2015-03-22"));
        datePairs.add(new Pair<String, String>("2071-12-09", "2015-03-23"));
        datePairs.add(new Pair<String, String>("2071-12-10", "2015-03-24"));
        datePairs.add(new Pair<String, String>("2071-12-11", "2015-03-25"));
        datePairs.add(new Pair<String, String>("2071-12-12", "2015-03-26"));
        datePairs.add(new Pair<String, String>("2071-12-13", "2015-03-27"));
        datePairs.add(new Pair<String, String>("2071-12-14", "2015-03-28"));
        datePairs.add(new Pair<String, String>("2071-12-15", "2015-03-29"));
        datePairs.add(new Pair<String, String>("2071-12-16", "2015-03-30"));
        datePairs.add(new Pair<String, String>("2071-12-17", "2015-03-31"));
        datePairs.add(new Pair<String, String>("2071-12-18", "2015-04-01"));
        datePairs.add(new Pair<String, String>("2071-12-19", "2015-04-02"));
        datePairs.add(new Pair<String, String>("2071-12-20", "2015-04-03"));
        datePairs.add(new Pair<String, String>("2071-12-21", "2015-04-04"));
        datePairs.add(new Pair<String, String>("2071-12-22", "2015-04-05"));
        datePairs.add(new Pair<String, String>("2071-12-23", "2015-04-06"));
        datePairs.add(new Pair<String, String>("2071-12-24", "2015-04-07"));
        datePairs.add(new Pair<String, String>("2071-12-25", "2015-04-08"));
        datePairs.add(new Pair<String, String>("2071-12-26", "2015-04-09"));
        datePairs.add(new Pair<String, String>("2071-12-27", "2015-04-10"));
        datePairs.add(new Pair<String, String>("2071-12-28", "2015-04-11"));
        datePairs.add(new Pair<String, String>("2071-12-29", "2015-04-12"));
        datePairs.add(new Pair<String, String>("2071-12-30", "2015-04-13"));
        datePairs.add(new Pair<String, String>("2072-01-01", "2015-04-14"));
        datePairs.add(new Pair<String, String>("2072-01-02", "2015-04-15"));
        datePairs.add(new Pair<String, String>("2072-01-03", "2015-04-16"));
        datePairs.add(new Pair<String, String>("2072-01-04", "2015-04-17"));
        datePairs.add(new Pair<String, String>("2072-01-05", "2015-04-18"));
        datePairs.add(new Pair<String, String>("2072-01-06", "2015-04-19"));
        datePairs.add(new Pair<String, String>("2072-01-07", "2015-04-20"));
        datePairs.add(new Pair<String, String>("2072-01-08", "2015-04-21"));
        datePairs.add(new Pair<String, String>("2072-01-09", "2015-04-22"));
        datePairs.add(new Pair<String, String>("2072-01-10", "2015-04-23"));
        datePairs.add(new Pair<String, String>("2072-01-11", "2015-04-24"));
        datePairs.add(new Pair<String, String>("2072-01-12", "2015-04-25"));
        datePairs.add(new Pair<String, String>("2072-01-13", "2015-04-26"));
        datePairs.add(new Pair<String, String>("2072-01-14", "2015-04-27"));
        datePairs.add(new Pair<String, String>("2072-01-15", "2015-04-28"));
        datePairs.add(new Pair<String, String>("2072-01-16", "2015-04-29"));
        datePairs.add(new Pair<String, String>("2072-01-17", "2015-04-30"));
        datePairs.add(new Pair<String, String>("2072-01-18", "2015-05-01"));
        datePairs.add(new Pair<String, String>("2072-01-19", "2015-05-02"));
        datePairs.add(new Pair<String, String>("2072-01-20", "2015-05-03"));
        datePairs.add(new Pair<String, String>("2072-01-21", "2015-05-04"));
        datePairs.add(new Pair<String, String>("2072-01-22", "2015-05-05"));
        datePairs.add(new Pair<String, String>("2072-01-23", "2015-05-06"));
        datePairs.add(new Pair<String, String>("2072-01-24", "2015-05-07"));
        datePairs.add(new Pair<String, String>("2072-01-25", "2015-05-08"));
        datePairs.add(new Pair<String, String>("2072-01-26", "2015-05-09"));
        datePairs.add(new Pair<String, String>("2072-01-27", "2015-05-10"));
        datePairs.add(new Pair<String, String>("2072-01-28", "2015-05-11"));
        datePairs.add(new Pair<String, String>("2072-01-29", "2015-05-12"));
        datePairs.add(new Pair<String, String>("2072-01-30", "2015-05-13"));
        datePairs.add(new Pair<String, String>("2072-01-31", "2015-05-14"));
        datePairs.add(new Pair<String, String>("2072-02-01", "2015-05-15"));
        datePairs.add(new Pair<String, String>("2072-02-02", "2015-05-16"));
        datePairs.add(new Pair<String, String>("2072-02-03", "2015-05-17"));
        datePairs.add(new Pair<String, String>("2072-02-04", "2015-05-18"));
        datePairs.add(new Pair<String, String>("2072-02-05", "2015-05-19"));
        datePairs.add(new Pair<String, String>("2072-02-06", "2015-05-20"));
        datePairs.add(new Pair<String, String>("2072-02-07", "2015-05-21"));
        datePairs.add(new Pair<String, String>("2072-02-08", "2015-05-22"));
        datePairs.add(new Pair<String, String>("2072-02-09", "2015-05-23"));
        datePairs.add(new Pair<String, String>("2072-02-10", "2015-05-24"));
        datePairs.add(new Pair<String, String>("2072-02-11", "2015-05-25"));
        datePairs.add(new Pair<String, String>("2072-02-12", "2015-05-26"));
        datePairs.add(new Pair<String, String>("2072-02-13", "2015-05-27"));
        datePairs.add(new Pair<String, String>("2072-02-14", "2015-05-28"));
        datePairs.add(new Pair<String, String>("2072-02-15", "2015-05-29"));
        datePairs.add(new Pair<String, String>("2072-02-16", "2015-05-30"));
        datePairs.add(new Pair<String, String>("2072-02-17", "2015-05-31"));
        datePairs.add(new Pair<String, String>("2072-02-18", "2015-06-01"));
        datePairs.add(new Pair<String, String>("2072-02-19", "2015-06-02"));
        datePairs.add(new Pair<String, String>("2072-02-20", "2015-06-03"));
        datePairs.add(new Pair<String, String>("2072-02-21", "2015-06-04"));
        datePairs.add(new Pair<String, String>("2072-02-22", "2015-06-05"));
        datePairs.add(new Pair<String, String>("2072-02-23", "2015-06-06"));
        datePairs.add(new Pair<String, String>("2072-02-24", "2015-06-07"));
        datePairs.add(new Pair<String, String>("2072-02-25", "2015-06-08"));
        datePairs.add(new Pair<String, String>("2072-02-26", "2015-06-09"));
        datePairs.add(new Pair<String, String>("2072-02-27", "2015-06-10"));
        datePairs.add(new Pair<String, String>("2072-02-28", "2015-06-11"));
        datePairs.add(new Pair<String, String>("2072-02-29", "2015-06-12"));
        datePairs.add(new Pair<String, String>("2072-02-30", "2015-06-13"));
        datePairs.add(new Pair<String, String>("2072-02-31", "2015-06-14"));
        datePairs.add(new Pair<String, String>("2072-02-32", "2015-06-15"));
        datePairs.add(new Pair<String, String>("2072-03-01", "2015-06-16"));
        datePairs.add(new Pair<String, String>("2072-03-02", "2015-06-17"));
        datePairs.add(new Pair<String, String>("2072-03-03", "2015-06-18"));
        datePairs.add(new Pair<String, String>("2072-03-04", "2015-06-19"));
        datePairs.add(new Pair<String, String>("2072-03-05", "2015-06-20"));
        datePairs.add(new Pair<String, String>("2072-03-06", "2015-06-21"));
        datePairs.add(new Pair<String, String>("2072-03-07", "2015-06-22"));
        datePairs.add(new Pair<String, String>("2072-03-08", "2015-06-23"));
        datePairs.add(new Pair<String, String>("2072-03-09", "2015-06-24"));
        datePairs.add(new Pair<String, String>("2072-03-10", "2015-06-25"));
        datePairs.add(new Pair<String, String>("2072-03-11", "2015-06-26"));
        datePairs.add(new Pair<String, String>("2072-03-12", "2015-06-27"));
        datePairs.add(new Pair<String, String>("2072-03-13", "2015-06-28"));
        datePairs.add(new Pair<String, String>("2072-03-14", "2015-06-29"));
        datePairs.add(new Pair<String, String>("2072-03-15", "2015-06-30"));
        datePairs.add(new Pair<String, String>("2072-03-16", "2015-07-01"));
        datePairs.add(new Pair<String, String>("2072-03-17", "2015-07-02"));
        datePairs.add(new Pair<String, String>("2072-03-18", "2015-07-03"));
        datePairs.add(new Pair<String, String>("2072-03-19", "2015-07-04"));
        datePairs.add(new Pair<String, String>("2072-03-20", "2015-07-05"));
        datePairs.add(new Pair<String, String>("2072-03-21", "2015-07-06"));
        datePairs.add(new Pair<String, String>("2072-03-22", "2015-07-07"));
        datePairs.add(new Pair<String, String>("2072-03-23", "2015-07-08"));
        datePairs.add(new Pair<String, String>("2072-03-24", "2015-07-09"));
        datePairs.add(new Pair<String, String>("2072-03-25", "2015-07-10"));
        datePairs.add(new Pair<String, String>("2072-03-26", "2015-07-11"));
        datePairs.add(new Pair<String, String>("2072-03-27", "2015-07-12"));
        datePairs.add(new Pair<String, String>("2072-03-28", "2015-07-13"));
        datePairs.add(new Pair<String, String>("2072-03-29", "2015-07-14"));
        datePairs.add(new Pair<String, String>("2072-03-30", "2015-07-15"));
        datePairs.add(new Pair<String, String>("2072-03-31", "2015-07-16"));
        datePairs.add(new Pair<String, String>("2072-04-01", "2015-07-17"));
        datePairs.add(new Pair<String, String>("2072-04-02", "2015-07-18"));
        datePairs.add(new Pair<String, String>("2072-04-03", "2015-07-19"));
        datePairs.add(new Pair<String, String>("2072-04-04", "2015-07-20"));
        datePairs.add(new Pair<String, String>("2072-04-05", "2015-07-21"));
        datePairs.add(new Pair<String, String>("2072-04-06", "2015-07-22"));
        datePairs.add(new Pair<String, String>("2072-04-07", "2015-07-23"));
        datePairs.add(new Pair<String, String>("2072-04-08", "2015-07-24"));
        datePairs.add(new Pair<String, String>("2072-04-09", "2015-07-25"));
        datePairs.add(new Pair<String, String>("2072-04-10", "2015-07-26"));
        datePairs.add(new Pair<String, String>("2072-04-11", "2015-07-27"));
        datePairs.add(new Pair<String, String>("2072-04-12", "2015-07-28"));
        datePairs.add(new Pair<String, String>("2072-04-13", "2015-07-29"));
        datePairs.add(new Pair<String, String>("2072-04-14", "2015-07-30"));
        datePairs.add(new Pair<String, String>("2072-04-15", "2015-07-31"));
        datePairs.add(new Pair<String, String>("2072-04-16", "2015-08-01"));
        datePairs.add(new Pair<String, String>("2072-04-17", "2015-08-02"));
        datePairs.add(new Pair<String, String>("2072-04-18", "2015-08-03"));
        datePairs.add(new Pair<String, String>("2072-04-19", "2015-08-04"));
        datePairs.add(new Pair<String, String>("2072-04-20", "2015-08-05"));
        datePairs.add(new Pair<String, String>("2072-04-21", "2015-08-06"));
        datePairs.add(new Pair<String, String>("2072-04-22", "2015-08-07"));
        datePairs.add(new Pair<String, String>("2072-04-23", "2015-08-08"));
        datePairs.add(new Pair<String, String>("2072-04-24", "2015-08-09"));
        datePairs.add(new Pair<String, String>("2072-04-25", "2015-08-10"));
        datePairs.add(new Pair<String, String>("2072-04-26", "2015-08-11"));
        datePairs.add(new Pair<String, String>("2072-04-27", "2015-08-12"));
        datePairs.add(new Pair<String, String>("2072-04-28", "2015-08-13"));
        datePairs.add(new Pair<String, String>("2072-04-29", "2015-08-14"));
        datePairs.add(new Pair<String, String>("2072-04-30", "2015-08-15"));
        datePairs.add(new Pair<String, String>("2072-04-31", "2015-08-16"));
        datePairs.add(new Pair<String, String>("2072-04-32", "2015-08-17"));
        datePairs.add(new Pair<String, String>("2072-05-01", "2015-08-18"));
        datePairs.add(new Pair<String, String>("2072-05-02", "2015-08-19"));
        datePairs.add(new Pair<String, String>("2072-05-03", "2015-08-20"));
        datePairs.add(new Pair<String, String>("2072-05-04", "2015-08-21"));
        datePairs.add(new Pair<String, String>("2072-05-05", "2015-08-22"));
        datePairs.add(new Pair<String, String>("2072-05-06", "2015-08-23"));
        datePairs.add(new Pair<String, String>("2072-05-07", "2015-08-24"));
        datePairs.add(new Pair<String, String>("2072-05-08", "2015-08-25"));
        datePairs.add(new Pair<String, String>("2072-05-09", "2015-08-26"));
        datePairs.add(new Pair<String, String>("2072-05-10", "2015-08-27"));
        datePairs.add(new Pair<String, String>("2072-05-11", "2015-08-28"));
        datePairs.add(new Pair<String, String>("2072-05-12", "2015-08-29"));
        datePairs.add(new Pair<String, String>("2072-05-13", "2015-08-30"));
        datePairs.add(new Pair<String, String>("2072-05-14", "2015-08-31"));
        datePairs.add(new Pair<String, String>("2072-05-15", "2015-09-01"));
        datePairs.add(new Pair<String, String>("2072-05-16", "2015-09-02"));
        datePairs.add(new Pair<String, String>("2072-05-17", "2015-09-03"));
        datePairs.add(new Pair<String, String>("2072-05-18", "2015-09-04"));
        datePairs.add(new Pair<String, String>("2072-05-19", "2015-09-05"));
        datePairs.add(new Pair<String, String>("2072-05-20", "2015-09-06"));
        datePairs.add(new Pair<String, String>("2072-05-21", "2015-09-07"));
        datePairs.add(new Pair<String, String>("2072-05-22", "2015-09-08"));
        datePairs.add(new Pair<String, String>("2072-05-23", "2015-09-09"));
        datePairs.add(new Pair<String, String>("2072-05-24", "2015-09-10"));
        datePairs.add(new Pair<String, String>("2072-05-25", "2015-09-11"));
        datePairs.add(new Pair<String, String>("2072-05-26", "2015-09-12"));
        datePairs.add(new Pair<String, String>("2072-05-27", "2015-09-13"));
        datePairs.add(new Pair<String, String>("2072-05-28", "2015-09-14"));
        datePairs.add(new Pair<String, String>("2072-05-29", "2015-09-15"));
        datePairs.add(new Pair<String, String>("2072-05-30", "2015-09-16"));
        datePairs.add(new Pair<String, String>("2072-05-31", "2015-09-17"));
        datePairs.add(new Pair<String, String>("2072-06-01", "2015-09-18"));
        datePairs.add(new Pair<String, String>("2072-06-02", "2015-09-19"));
        datePairs.add(new Pair<String, String>("2072-06-03", "2015-09-20"));
        datePairs.add(new Pair<String, String>("2072-06-04", "2015-09-21"));
        datePairs.add(new Pair<String, String>("2072-06-05", "2015-09-22"));
        datePairs.add(new Pair<String, String>("2072-06-06", "2015-09-23"));
        datePairs.add(new Pair<String, String>("2072-06-07", "2015-09-24"));
        datePairs.add(new Pair<String, String>("2072-06-08", "2015-09-25"));
        datePairs.add(new Pair<String, String>("2072-06-09", "2015-09-26"));
        datePairs.add(new Pair<String, String>("2072-06-10", "2015-09-27"));
        datePairs.add(new Pair<String, String>("2072-06-11", "2015-09-28"));
        datePairs.add(new Pair<String, String>("2072-06-12", "2015-09-29"));
        datePairs.add(new Pair<String, String>("2072-06-13", "2015-09-30"));
        datePairs.add(new Pair<String, String>("2072-06-14", "2015-10-01"));
        datePairs.add(new Pair<String, String>("2072-06-15", "2015-10-02"));
        datePairs.add(new Pair<String, String>("2072-06-16", "2015-10-03"));
        datePairs.add(new Pair<String, String>("2072-06-17", "2015-10-04"));
        datePairs.add(new Pair<String, String>("2072-06-18", "2015-10-05"));
        datePairs.add(new Pair<String, String>("2072-06-19", "2015-10-06"));
        datePairs.add(new Pair<String, String>("2072-06-20", "2015-10-07"));
        datePairs.add(new Pair<String, String>("2072-06-21", "2015-10-08"));
        datePairs.add(new Pair<String, String>("2072-06-22", "2015-10-09"));
        datePairs.add(new Pair<String, String>("2072-06-23", "2015-10-10"));
        datePairs.add(new Pair<String, String>("2072-06-24", "2015-10-11"));
        datePairs.add(new Pair<String, String>("2072-06-25", "2015-10-12"));
        datePairs.add(new Pair<String, String>("2072-06-26", "2015-10-13"));
        datePairs.add(new Pair<String, String>("2072-06-27", "2015-10-14"));
        datePairs.add(new Pair<String, String>("2072-06-28", "2015-10-15"));
        datePairs.add(new Pair<String, String>("2072-06-29", "2015-10-16"));
        datePairs.add(new Pair<String, String>("2072-06-30", "2015-10-17"));
        datePairs.add(new Pair<String, String>("2072-07-01", "2015-10-18"));
        datePairs.add(new Pair<String, String>("2072-07-02", "2015-10-19"));
        datePairs.add(new Pair<String, String>("2072-07-03", "2015-10-20"));
        datePairs.add(new Pair<String, String>("2072-07-04", "2015-10-21"));
        datePairs.add(new Pair<String, String>("2072-07-05", "2015-10-22"));
        datePairs.add(new Pair<String, String>("2072-07-06", "2015-10-23"));
        datePairs.add(new Pair<String, String>("2072-07-07", "2015-10-24"));
        datePairs.add(new Pair<String, String>("2072-07-08", "2015-10-25"));
        datePairs.add(new Pair<String, String>("2072-07-09", "2015-10-26"));
        datePairs.add(new Pair<String, String>("2072-07-10", "2015-10-27"));
        datePairs.add(new Pair<String, String>("2072-07-11", "2015-10-28"));
        datePairs.add(new Pair<String, String>("2072-07-12", "2015-10-29"));
        datePairs.add(new Pair<String, String>("2072-07-13", "2015-10-30"));
        datePairs.add(new Pair<String, String>("2072-07-14", "2015-10-31"));
        datePairs.add(new Pair<String, String>("2072-07-15", "2015-11-01"));
        datePairs.add(new Pair<String, String>("2072-07-16", "2015-11-02"));
        datePairs.add(new Pair<String, String>("2072-07-17", "2015-11-03"));
        datePairs.add(new Pair<String, String>("2072-07-18", "2015-11-04"));
        datePairs.add(new Pair<String, String>("2072-07-19", "2015-11-05"));
        datePairs.add(new Pair<String, String>("2072-07-20", "2015-11-06"));
        datePairs.add(new Pair<String, String>("2072-07-21", "2015-11-07"));
        datePairs.add(new Pair<String, String>("2072-07-22", "2015-11-08"));
        datePairs.add(new Pair<String, String>("2072-07-23", "2015-11-09"));
        datePairs.add(new Pair<String, String>("2072-07-24", "2015-11-10"));
        datePairs.add(new Pair<String, String>("2072-07-25", "2015-11-11"));
        datePairs.add(new Pair<String, String>("2072-07-26", "2015-11-12"));
        datePairs.add(new Pair<String, String>("2072-07-27", "2015-11-13"));
        datePairs.add(new Pair<String, String>("2072-07-28", "2015-11-14"));
        datePairs.add(new Pair<String, String>("2072-07-29", "2015-11-15"));
        datePairs.add(new Pair<String, String>("2072-07-30", "2015-11-16"));
        datePairs.add(new Pair<String, String>("2072-08-01", "2015-11-17"));
        datePairs.add(new Pair<String, String>("2072-08-02", "2015-11-18"));
        datePairs.add(new Pair<String, String>("2072-08-03", "2015-11-19"));
        datePairs.add(new Pair<String, String>("2072-08-04", "2015-11-20"));
        datePairs.add(new Pair<String, String>("2072-08-05", "2015-11-21"));
        datePairs.add(new Pair<String, String>("2072-08-06", "2015-11-22"));
        datePairs.add(new Pair<String, String>("2072-08-07", "2015-11-23"));
        datePairs.add(new Pair<String, String>("2072-08-08", "2015-11-24"));
        datePairs.add(new Pair<String, String>("2072-08-09", "2015-11-25"));
        datePairs.add(new Pair<String, String>("2072-08-10", "2015-11-26"));
        datePairs.add(new Pair<String, String>("2072-08-11", "2015-11-27"));
        datePairs.add(new Pair<String, String>("2072-08-12", "2015-11-28"));
        datePairs.add(new Pair<String, String>("2072-08-13", "2015-11-29"));
        datePairs.add(new Pair<String, String>("2072-08-14", "2015-11-30"));
        datePairs.add(new Pair<String, String>("2072-08-15", "2015-12-01"));
        datePairs.add(new Pair<String, String>("2072-08-16", "2015-12-02"));
        datePairs.add(new Pair<String, String>("2072-08-17", "2015-12-03"));
        datePairs.add(new Pair<String, String>("2072-08-18", "2015-12-04"));
        datePairs.add(new Pair<String, String>("2072-08-19", "2015-12-05"));
        datePairs.add(new Pair<String, String>("2072-08-20", "2015-12-06"));
        datePairs.add(new Pair<String, String>("2072-08-21", "2015-12-07"));
        datePairs.add(new Pair<String, String>("2072-08-22", "2015-12-08"));
        datePairs.add(new Pair<String, String>("2072-08-23", "2015-12-09"));
        datePairs.add(new Pair<String, String>("2072-08-24", "2015-12-10"));
        datePairs.add(new Pair<String, String>("2072-08-25", "2015-12-11"));
        datePairs.add(new Pair<String, String>("2072-08-26", "2015-12-12"));
        datePairs.add(new Pair<String, String>("2072-08-27", "2015-12-13"));
        datePairs.add(new Pair<String, String>("2072-08-28", "2015-12-14"));
        datePairs.add(new Pair<String, String>("2072-08-29", "2015-12-15"));
        datePairs.add(new Pair<String, String>("2072-09-01", "2015-12-16"));
        datePairs.add(new Pair<String, String>("2072-09-02", "2015-12-17"));
        datePairs.add(new Pair<String, String>("2072-09-03", "2015-12-18"));
        datePairs.add(new Pair<String, String>("2072-09-04", "2015-12-19"));
        datePairs.add(new Pair<String, String>("2072-09-05", "2015-12-20"));
        datePairs.add(new Pair<String, String>("2072-09-06", "2015-12-21"));
        datePairs.add(new Pair<String, String>("2072-09-07", "2015-12-22"));
        datePairs.add(new Pair<String, String>("2072-09-08", "2015-12-23"));
        datePairs.add(new Pair<String, String>("2072-09-09", "2015-12-24"));
        datePairs.add(new Pair<String, String>("2072-09-10", "2015-12-25"));
        datePairs.add(new Pair<String, String>("2072-09-11", "2015-12-26"));
        datePairs.add(new Pair<String, String>("2072-09-12", "2015-12-27"));
        datePairs.add(new Pair<String, String>("2072-09-13", "2015-12-28"));
        datePairs.add(new Pair<String, String>("2072-09-14", "2015-12-29"));
        datePairs.add(new Pair<String, String>("2072-09-15", "2015-12-30"));
        datePairs.add(new Pair<String, String>("2072-09-16", "2015-12-31"));
        datePairs.add(new Pair<String, String>("2072-09-17", "2016-01-01"));
        datePairs.add(new Pair<String, String>("2072-09-18", "2016-01-02"));
        datePairs.add(new Pair<String, String>("2072-09-19", "2016-01-03"));
        datePairs.add(new Pair<String, String>("2072-09-20", "2016-01-04"));
        datePairs.add(new Pair<String, String>("2072-09-21", "2016-01-05"));
        datePairs.add(new Pair<String, String>("2072-09-22", "2016-01-06"));
        datePairs.add(new Pair<String, String>("2072-09-23", "2016-01-07"));
        datePairs.add(new Pair<String, String>("2072-09-24", "2016-01-08"));
        datePairs.add(new Pair<String, String>("2072-09-25", "2016-01-09"));
        datePairs.add(new Pair<String, String>("2072-09-26", "2016-01-10"));
        datePairs.add(new Pair<String, String>("2072-09-27", "2016-01-11"));
        datePairs.add(new Pair<String, String>("2072-09-28", "2016-01-12"));
        datePairs.add(new Pair<String, String>("2072-09-29", "2016-01-13"));
        datePairs.add(new Pair<String, String>("2072-09-30", "2016-01-14"));
        datePairs.add(new Pair<String, String>("2072-10-01", "2016-01-15"));
        datePairs.add(new Pair<String, String>("2072-10-02", "2016-01-16"));
        datePairs.add(new Pair<String, String>("2072-10-03", "2016-01-17"));
        datePairs.add(new Pair<String, String>("2072-10-04", "2016-01-18"));
        datePairs.add(new Pair<String, String>("2072-10-05", "2016-01-19"));
        datePairs.add(new Pair<String, String>("2072-10-06", "2016-01-20"));
        datePairs.add(new Pair<String, String>("2072-10-07", "2016-01-21"));
        datePairs.add(new Pair<String, String>("2072-10-08", "2016-01-22"));
        datePairs.add(new Pair<String, String>("2072-10-09", "2016-01-23"));
        datePairs.add(new Pair<String, String>("2072-10-10", "2016-01-24"));
        datePairs.add(new Pair<String, String>("2072-10-11", "2016-01-25"));
        datePairs.add(new Pair<String, String>("2072-10-12", "2016-01-26"));
        datePairs.add(new Pair<String, String>("2072-10-13", "2016-01-27"));
        datePairs.add(new Pair<String, String>("2072-10-14", "2016-01-28"));
        datePairs.add(new Pair<String, String>("2072-10-15", "2016-01-29"));
        datePairs.add(new Pair<String, String>("2072-10-16", "2016-01-30"));
        datePairs.add(new Pair<String, String>("2072-10-17", "2016-01-31"));
        datePairs.add(new Pair<String, String>("2072-10-18", "2016-02-01"));
        datePairs.add(new Pair<String, String>("2072-10-19", "2016-02-02"));
        datePairs.add(new Pair<String, String>("2072-10-20", "2016-02-03"));
        datePairs.add(new Pair<String, String>("2072-10-21", "2016-02-04"));
        datePairs.add(new Pair<String, String>("2072-10-22", "2016-02-05"));
        datePairs.add(new Pair<String, String>("2072-10-23", "2016-02-06"));
        datePairs.add(new Pair<String, String>("2072-10-24", "2016-02-07"));
        datePairs.add(new Pair<String, String>("2072-10-25", "2016-02-08"));
        datePairs.add(new Pair<String, String>("2072-10-26", "2016-02-09"));
        datePairs.add(new Pair<String, String>("2072-10-27", "2016-02-10"));
        datePairs.add(new Pair<String, String>("2072-10-28", "2016-02-11"));
        datePairs.add(new Pair<String, String>("2072-10-29", "2016-02-12"));
        datePairs.add(new Pair<String, String>("2072-11-01", "2016-02-13"));
        datePairs.add(new Pair<String, String>("2072-11-02", "2016-02-14"));
        datePairs.add(new Pair<String, String>("2072-11-03", "2016-02-15"));
        datePairs.add(new Pair<String, String>("2072-11-04", "2016-02-16"));
        datePairs.add(new Pair<String, String>("2072-11-05", "2016-02-17"));
        datePairs.add(new Pair<String, String>("2072-11-06", "2016-02-18"));
        datePairs.add(new Pair<String, String>("2072-11-07", "2016-02-19"));
        datePairs.add(new Pair<String, String>("2072-11-08", "2016-02-20"));
        datePairs.add(new Pair<String, String>("2072-11-09", "2016-02-21"));
        datePairs.add(new Pair<String, String>("2072-11-10", "2016-02-22"));
        datePairs.add(new Pair<String, String>("2072-11-11", "2016-02-23"));
        datePairs.add(new Pair<String, String>("2072-11-12", "2016-02-24"));
        datePairs.add(new Pair<String, String>("2072-11-13", "2016-02-25"));
        datePairs.add(new Pair<String, String>("2072-11-14", "2016-02-26"));
        datePairs.add(new Pair<String, String>("2072-11-15", "2016-02-27"));
        datePairs.add(new Pair<String, String>("2072-11-16", "2016-02-28"));
        datePairs.add(new Pair<String, String>("2072-11-17", "2016-02-29"));
        datePairs.add(new Pair<String, String>("2072-11-18", "2016-03-01"));
        datePairs.add(new Pair<String, String>("2072-11-19", "2016-03-02"));
        datePairs.add(new Pair<String, String>("2072-11-20", "2016-03-03"));
        datePairs.add(new Pair<String, String>("2072-11-21", "2016-03-04"));
        datePairs.add(new Pair<String, String>("2072-11-22", "2016-03-05"));
        datePairs.add(new Pair<String, String>("2072-11-23", "2016-03-06"));
        datePairs.add(new Pair<String, String>("2072-11-24", "2016-03-07"));
        datePairs.add(new Pair<String, String>("2072-11-25", "2016-03-08"));
        datePairs.add(new Pair<String, String>("2072-11-26", "2016-03-09"));
        datePairs.add(new Pair<String, String>("2072-11-27", "2016-03-10"));
        datePairs.add(new Pair<String, String>("2072-11-28", "2016-03-11"));
        datePairs.add(new Pair<String, String>("2072-11-29", "2016-03-12"));
        datePairs.add(new Pair<String, String>("2072-11-30", "2016-03-13"));
        datePairs.add(new Pair<String, String>("2072-12-01", "2016-03-14"));
        datePairs.add(new Pair<String, String>("2072-12-02", "2016-03-15"));
        datePairs.add(new Pair<String, String>("2072-12-03", "2016-03-16"));
        datePairs.add(new Pair<String, String>("2072-12-04", "2016-03-17"));
        datePairs.add(new Pair<String, String>("2072-12-05", "2016-03-18"));
        datePairs.add(new Pair<String, String>("2072-12-06", "2016-03-19"));
        datePairs.add(new Pair<String, String>("2072-12-07", "2016-03-20"));
        datePairs.add(new Pair<String, String>("2072-12-08", "2016-03-21"));
        datePairs.add(new Pair<String, String>("2072-12-09", "2016-03-22"));
        datePairs.add(new Pair<String, String>("2072-12-10", "2016-03-23"));
        datePairs.add(new Pair<String, String>("2072-12-11", "2016-03-24"));
        datePairs.add(new Pair<String, String>("2072-12-12", "2016-03-25"));
        datePairs.add(new Pair<String, String>("2072-12-13", "2016-03-26"));
        datePairs.add(new Pair<String, String>("2072-12-14", "2016-03-27"));
        datePairs.add(new Pair<String, String>("2072-12-15", "2016-03-28"));
        datePairs.add(new Pair<String, String>("2072-12-16", "2016-03-29"));
        datePairs.add(new Pair<String, String>("2072-12-17", "2016-03-30"));
        datePairs.add(new Pair<String, String>("2072-12-18", "2016-03-31"));
        datePairs.add(new Pair<String, String>("2072-12-19", "2016-04-01"));
        datePairs.add(new Pair<String, String>("2072-12-20", "2016-04-02"));
        datePairs.add(new Pair<String, String>("2072-12-21", "2016-04-03"));
        datePairs.add(new Pair<String, String>("2072-12-22", "2016-04-04"));
        datePairs.add(new Pair<String, String>("2072-12-23", "2016-04-05"));
        datePairs.add(new Pair<String, String>("2072-12-24", "2016-04-06"));
        datePairs.add(new Pair<String, String>("2072-12-25", "2016-04-07"));
        datePairs.add(new Pair<String, String>("2072-12-26", "2016-04-08"));
        datePairs.add(new Pair<String, String>("2072-12-27", "2016-04-09"));
        datePairs.add(new Pair<String, String>("2072-12-28", "2016-04-10"));
        datePairs.add(new Pair<String, String>("2072-12-29", "2016-04-11"));
        datePairs.add(new Pair<String, String>("2072-12-30", "2016-04-12"));
    }

    public void appendConversionValues3() {
        datePairs.add(new Pair<String, String>("2073-01-01", "2016-04-13"));
        datePairs.add(new Pair<String, String>("2073-01-02", "2016-04-14"));
        datePairs.add(new Pair<String, String>("2073-01-03", "2016-04-15"));
        datePairs.add(new Pair<String, String>("2073-01-04", "2016-04-16"));
        datePairs.add(new Pair<String, String>("2073-01-05", "2016-04-17"));
        datePairs.add(new Pair<String, String>("2073-01-06", "2016-04-18"));
        datePairs.add(new Pair<String, String>("2073-01-07", "2016-04-19"));
        datePairs.add(new Pair<String, String>("2073-01-08", "2016-04-20"));
        datePairs.add(new Pair<String, String>("2073-01-09", "2016-04-21"));
        datePairs.add(new Pair<String, String>("2073-01-10", "2016-04-22"));
        datePairs.add(new Pair<String, String>("2073-01-11", "2016-04-23"));
        datePairs.add(new Pair<String, String>("2073-01-12", "2016-04-24"));
        datePairs.add(new Pair<String, String>("2073-01-13", "2016-04-25"));
        datePairs.add(new Pair<String, String>("2073-01-14", "2016-04-26"));
        datePairs.add(new Pair<String, String>("2073-01-15", "2016-04-27"));
        datePairs.add(new Pair<String, String>("2073-01-16", "2016-04-28"));
        datePairs.add(new Pair<String, String>("2073-01-17", "2016-04-29"));
        datePairs.add(new Pair<String, String>("2073-01-18", "2016-04-30"));
        datePairs.add(new Pair<String, String>("2073-01-19", "2016-05-01"));
        datePairs.add(new Pair<String, String>("2073-01-20", "2016-05-02"));
        datePairs.add(new Pair<String, String>("2073-01-21", "2016-05-03"));
        datePairs.add(new Pair<String, String>("2073-01-22", "2016-05-04"));
        datePairs.add(new Pair<String, String>("2073-01-23", "2016-05-05"));
        datePairs.add(new Pair<String, String>("2073-01-24", "2016-05-06"));
        datePairs.add(new Pair<String, String>("2073-01-25", "2016-05-07"));
        datePairs.add(new Pair<String, String>("2073-01-26", "2016-05-08"));
        datePairs.add(new Pair<String, String>("2073-01-27", "2016-05-09"));
        datePairs.add(new Pair<String, String>("2073-01-28", "2016-05-10"));
        datePairs.add(new Pair<String, String>("2073-01-29", "2016-05-11"));
        datePairs.add(new Pair<String, String>("2073-01-30", "2016-05-12"));
        datePairs.add(new Pair<String, String>("2073-01-31", "2016-05-13"));
        datePairs.add(new Pair<String, String>("2073-02-01", "2016-05-14"));
        datePairs.add(new Pair<String, String>("2073-02-02", "2016-05-15"));
        datePairs.add(new Pair<String, String>("2073-02-03", "2016-05-16"));
        datePairs.add(new Pair<String, String>("2073-02-04", "2016-05-17"));
        datePairs.add(new Pair<String, String>("2073-02-05", "2016-05-18"));
        datePairs.add(new Pair<String, String>("2073-02-06", "2016-05-19"));
        datePairs.add(new Pair<String, String>("2073-02-07", "2016-05-20"));
        datePairs.add(new Pair<String, String>("2073-02-08", "2016-05-21"));
        datePairs.add(new Pair<String, String>("2073-02-09", "2016-05-22"));
        datePairs.add(new Pair<String, String>("2073-02-10", "2016-05-23"));
        datePairs.add(new Pair<String, String>("2073-02-11", "2016-05-24"));
        datePairs.add(new Pair<String, String>("2073-02-12", "2016-05-25"));
        datePairs.add(new Pair<String, String>("2073-02-13", "2016-05-26"));
        datePairs.add(new Pair<String, String>("2073-02-14", "2016-05-27"));
        datePairs.add(new Pair<String, String>("2073-02-15", "2016-05-28"));
        datePairs.add(new Pair<String, String>("2073-02-16", "2016-05-29"));
        datePairs.add(new Pair<String, String>("2073-02-17", "2016-05-30"));
        datePairs.add(new Pair<String, String>("2073-02-18", "2016-05-31"));
        datePairs.add(new Pair<String, String>("2073-02-19", "2016-06-01"));
        datePairs.add(new Pair<String, String>("2073-02-20", "2016-06-02"));
        datePairs.add(new Pair<String, String>("2073-02-21", "2016-06-03"));
        datePairs.add(new Pair<String, String>("2073-02-22", "2016-06-04"));
        datePairs.add(new Pair<String, String>("2073-02-23", "2016-06-05"));
        datePairs.add(new Pair<String, String>("2073-02-24", "2016-06-06"));
        datePairs.add(new Pair<String, String>("2073-02-25", "2016-06-07"));
        datePairs.add(new Pair<String, String>("2073-02-26", "2016-06-08"));
        datePairs.add(new Pair<String, String>("2073-02-27", "2016-06-09"));
        datePairs.add(new Pair<String, String>("2073-02-28", "2016-06-10"));
        datePairs.add(new Pair<String, String>("2073-02-29", "2016-06-11"));
        datePairs.add(new Pair<String, String>("2073-02-30", "2016-06-12"));
        datePairs.add(new Pair<String, String>("2073-02-31", "2016-06-13"));
        datePairs.add(new Pair<String, String>("2073-02-32", "2016-06-14"));
        datePairs.add(new Pair<String, String>("2073-03-01", "2016-06-15"));
        datePairs.add(new Pair<String, String>("2073-03-02", "2016-06-16"));
        datePairs.add(new Pair<String, String>("2073-03-03", "2016-06-17"));
        datePairs.add(new Pair<String, String>("2073-03-04", "2016-06-18"));
        datePairs.add(new Pair<String, String>("2073-03-05", "2016-06-19"));
        datePairs.add(new Pair<String, String>("2073-03-06", "2016-06-20"));
        datePairs.add(new Pair<String, String>("2073-03-07", "2016-06-21"));
        datePairs.add(new Pair<String, String>("2073-03-08", "2016-06-22"));
        datePairs.add(new Pair<String, String>("2073-03-09", "2016-06-23"));
        datePairs.add(new Pair<String, String>("2073-03-10", "2016-06-24"));
        datePairs.add(new Pair<String, String>("2073-03-11", "2016-06-25"));
        datePairs.add(new Pair<String, String>("2073-03-12", "2016-06-26"));
        datePairs.add(new Pair<String, String>("2073-03-13", "2016-06-27"));
        datePairs.add(new Pair<String, String>("2073-03-14", "2016-06-28"));
        datePairs.add(new Pair<String, String>("2073-03-15", "2016-06-29"));
        datePairs.add(new Pair<String, String>("2073-03-16", "2016-06-30"));
        datePairs.add(new Pair<String, String>("2073-03-17", "2016-07-01"));
        datePairs.add(new Pair<String, String>("2073-03-18", "2016-07-02"));
        datePairs.add(new Pair<String, String>("2073-03-19", "2016-07-03"));
        datePairs.add(new Pair<String, String>("2073-03-20", "2016-07-04"));
        datePairs.add(new Pair<String, String>("2073-03-21", "2016-07-05"));
        datePairs.add(new Pair<String, String>("2073-03-22", "2016-07-06"));
        datePairs.add(new Pair<String, String>("2073-03-23", "2016-07-07"));
        datePairs.add(new Pair<String, String>("2073-03-24", "2016-07-08"));
        datePairs.add(new Pair<String, String>("2073-03-25", "2016-07-09"));
        datePairs.add(new Pair<String, String>("2073-03-26", "2016-07-10"));
        datePairs.add(new Pair<String, String>("2073-03-27", "2016-07-11"));
        datePairs.add(new Pair<String, String>("2073-03-28", "2016-07-12"));
        datePairs.add(new Pair<String, String>("2073-03-29", "2016-07-13"));
        datePairs.add(new Pair<String, String>("2073-03-30", "2016-07-14"));
        datePairs.add(new Pair<String, String>("2073-03-31", "2016-07-15"));
        datePairs.add(new Pair<String, String>("2073-04-01", "2016-07-16"));
        datePairs.add(new Pair<String, String>("2073-04-02", "2016-07-17"));
        datePairs.add(new Pair<String, String>("2073-04-03", "2016-07-18"));
        datePairs.add(new Pair<String, String>("2073-04-04", "2016-07-19"));
        datePairs.add(new Pair<String, String>("2073-04-05", "2016-07-20"));
        datePairs.add(new Pair<String, String>("2073-04-06", "2016-07-21"));
        datePairs.add(new Pair<String, String>("2073-04-07", "2016-07-22"));
        datePairs.add(new Pair<String, String>("2073-04-08", "2016-07-23"));
        datePairs.add(new Pair<String, String>("2073-04-09", "2016-07-24"));
        datePairs.add(new Pair<String, String>("2073-04-10", "2016-07-25"));
        datePairs.add(new Pair<String, String>("2073-04-11", "2016-07-26"));
        datePairs.add(new Pair<String, String>("2073-04-12", "2016-07-27"));
        datePairs.add(new Pair<String, String>("2073-04-13", "2016-07-28"));
        datePairs.add(new Pair<String, String>("2073-04-14", "2016-07-29"));
        datePairs.add(new Pair<String, String>("2073-04-15", "2016-07-30"));
        datePairs.add(new Pair<String, String>("2073-04-16", "2016-07-31"));
        datePairs.add(new Pair<String, String>("2073-04-17", "2016-08-01"));
        datePairs.add(new Pair<String, String>("2073-04-18", "2016-08-02"));
        datePairs.add(new Pair<String, String>("2073-04-19", "2016-08-03"));
        datePairs.add(new Pair<String, String>("2073-04-20", "2016-08-04"));
        datePairs.add(new Pair<String, String>("2073-04-21", "2016-08-05"));
        datePairs.add(new Pair<String, String>("2073-04-22", "2016-08-06"));
        datePairs.add(new Pair<String, String>("2073-04-23", "2016-08-07"));
        datePairs.add(new Pair<String, String>("2073-04-24", "2016-08-08"));
        datePairs.add(new Pair<String, String>("2073-04-25", "2016-08-09"));
        datePairs.add(new Pair<String, String>("2073-04-26", "2016-08-10"));
        datePairs.add(new Pair<String, String>("2073-04-27", "2016-08-11"));
        datePairs.add(new Pair<String, String>("2073-04-28", "2016-08-12"));
        datePairs.add(new Pair<String, String>("2073-04-29", "2016-08-13"));
        datePairs.add(new Pair<String, String>("2073-04-30", "2016-08-14"));
        datePairs.add(new Pair<String, String>("2073-04-31", "2016-08-15"));
        datePairs.add(new Pair<String, String>("2073-04-32", "2016-08-16"));
        datePairs.add(new Pair<String, String>("2073-05-01", "2016-08-17"));
        datePairs.add(new Pair<String, String>("2073-05-02", "2016-08-18"));
        datePairs.add(new Pair<String, String>("2073-05-03", "2016-08-19"));
        datePairs.add(new Pair<String, String>("2073-05-04", "2016-08-20"));
        datePairs.add(new Pair<String, String>("2073-05-05", "2016-08-21"));
        datePairs.add(new Pair<String, String>("2073-05-06", "2016-08-22"));
        datePairs.add(new Pair<String, String>("2073-05-07", "2016-08-23"));
        datePairs.add(new Pair<String, String>("2073-05-08", "2016-08-24"));
        datePairs.add(new Pair<String, String>("2073-05-09", "2016-08-25"));
        datePairs.add(new Pair<String, String>("2073-05-10", "2016-08-26"));
        datePairs.add(new Pair<String, String>("2073-05-11", "2016-08-27"));
        datePairs.add(new Pair<String, String>("2073-05-12", "2016-08-28"));
        datePairs.add(new Pair<String, String>("2073-05-13", "2016-08-29"));
        datePairs.add(new Pair<String, String>("2073-05-14", "2016-08-30"));
        datePairs.add(new Pair<String, String>("2073-05-15", "2016-08-31"));
        datePairs.add(new Pair<String, String>("2073-05-16", "2016-09-01"));
        datePairs.add(new Pair<String, String>("2073-05-17", "2016-09-02"));
        datePairs.add(new Pair<String, String>("2073-05-18", "2016-09-03"));
        datePairs.add(new Pair<String, String>("2073-05-19", "2016-09-04"));
        datePairs.add(new Pair<String, String>("2073-05-20", "2016-09-05"));
        datePairs.add(new Pair<String, String>("2073-05-21", "2016-09-06"));
        datePairs.add(new Pair<String, String>("2073-05-22", "2016-09-07"));
        datePairs.add(new Pair<String, String>("2073-05-23", "2016-09-08"));
        datePairs.add(new Pair<String, String>("2073-05-24", "2016-09-09"));
        datePairs.add(new Pair<String, String>("2073-05-25", "2016-09-10"));
        datePairs.add(new Pair<String, String>("2073-05-26", "2016-09-11"));
        datePairs.add(new Pair<String, String>("2073-05-27", "2016-09-12"));
        datePairs.add(new Pair<String, String>("2073-05-28", "2016-09-13"));
        datePairs.add(new Pair<String, String>("2073-05-29", "2016-09-14"));
        datePairs.add(new Pair<String, String>("2073-05-30", "2016-09-15"));
        datePairs.add(new Pair<String, String>("2073-05-31", "2016-09-16"));
        datePairs.add(new Pair<String, String>("2073-06-01", "2016-09-17"));
        datePairs.add(new Pair<String, String>("2073-06-02", "2016-09-18"));
        datePairs.add(new Pair<String, String>("2073-06-03", "2016-09-19"));
        datePairs.add(new Pair<String, String>("2073-06-04", "2016-09-20"));
        datePairs.add(new Pair<String, String>("2073-06-05", "2016-09-21"));
        datePairs.add(new Pair<String, String>("2073-06-06", "2016-09-22"));
        datePairs.add(new Pair<String, String>("2073-06-07", "2016-09-23"));
        datePairs.add(new Pair<String, String>("2073-06-08", "2016-09-24"));
        datePairs.add(new Pair<String, String>("2073-06-09", "2016-09-25"));
        datePairs.add(new Pair<String, String>("2073-06-10", "2016-09-26"));
        datePairs.add(new Pair<String, String>("2073-06-11", "2016-09-27"));
        datePairs.add(new Pair<String, String>("2073-06-12", "2016-09-28"));
        datePairs.add(new Pair<String, String>("2073-06-13", "2016-09-29"));
        datePairs.add(new Pair<String, String>("2073-06-14", "2016-09-30"));
        datePairs.add(new Pair<String, String>("2073-06-15", "2016-10-01"));
        datePairs.add(new Pair<String, String>("2073-06-16", "2016-10-02"));
        datePairs.add(new Pair<String, String>("2073-06-17", "2016-10-03"));
        datePairs.add(new Pair<String, String>("2073-06-18", "2016-10-04"));
        datePairs.add(new Pair<String, String>("2073-06-19", "2016-10-05"));
        datePairs.add(new Pair<String, String>("2073-06-20", "2016-10-06"));
        datePairs.add(new Pair<String, String>("2073-06-21", "2016-10-07"));
        datePairs.add(new Pair<String, String>("2073-06-22", "2016-10-08"));
        datePairs.add(new Pair<String, String>("2073-06-23", "2016-10-09"));
        datePairs.add(new Pair<String, String>("2073-06-24", "2016-10-10"));
        datePairs.add(new Pair<String, String>("2073-06-25", "2016-10-11"));
        datePairs.add(new Pair<String, String>("2073-06-26", "2016-10-12"));
        datePairs.add(new Pair<String, String>("2073-06-27", "2016-10-13"));
        datePairs.add(new Pair<String, String>("2073-06-28", "2016-10-14"));
        datePairs.add(new Pair<String, String>("2073-06-29", "2016-10-15"));
        datePairs.add(new Pair<String, String>("2073-06-30", "2016-10-16"));
        datePairs.add(new Pair<String, String>("2073-07-01", "2016-10-17"));
        datePairs.add(new Pair<String, String>("2073-07-02", "2016-10-18"));
        datePairs.add(new Pair<String, String>("2073-07-03", "2016-10-19"));
        datePairs.add(new Pair<String, String>("2073-07-04", "2016-10-20"));
        datePairs.add(new Pair<String, String>("2073-07-05", "2016-10-21"));
        datePairs.add(new Pair<String, String>("2073-07-06", "2016-10-22"));
        datePairs.add(new Pair<String, String>("2073-07-07", "2016-10-23"));
        datePairs.add(new Pair<String, String>("2073-07-08", "2016-10-24"));
        datePairs.add(new Pair<String, String>("2073-07-09", "2016-10-25"));
        datePairs.add(new Pair<String, String>("2073-07-10", "2016-10-26"));
        datePairs.add(new Pair<String, String>("2073-07-11", "2016-10-27"));
        datePairs.add(new Pair<String, String>("2073-07-12", "2016-10-28"));
        datePairs.add(new Pair<String, String>("2073-07-13", "2016-10-29"));
        datePairs.add(new Pair<String, String>("2073-07-14", "2016-10-30"));
        datePairs.add(new Pair<String, String>("2073-07-15", "2016-10-31"));
        datePairs.add(new Pair<String, String>("2073-07-16", "2016-11-01"));
        datePairs.add(new Pair<String, String>("2073-07-17", "2016-11-02"));
        datePairs.add(new Pair<String, String>("2073-07-18", "2016-11-03"));
        datePairs.add(new Pair<String, String>("2073-07-19", "2016-11-04"));
        datePairs.add(new Pair<String, String>("2073-07-20", "2016-11-05"));
        datePairs.add(new Pair<String, String>("2073-07-21", "2016-11-06"));
        datePairs.add(new Pair<String, String>("2073-07-22", "2016-11-07"));
        datePairs.add(new Pair<String, String>("2073-07-23", "2016-11-08"));
        datePairs.add(new Pair<String, String>("2073-07-24", "2016-11-09"));
        datePairs.add(new Pair<String, String>("2073-07-25", "2016-11-10"));
        datePairs.add(new Pair<String, String>("2073-07-26", "2016-11-11"));
        datePairs.add(new Pair<String, String>("2073-07-27", "2016-11-12"));
        datePairs.add(new Pair<String, String>("2073-07-28", "2016-11-13"));
        datePairs.add(new Pair<String, String>("2073-07-29", "2016-11-14"));
        datePairs.add(new Pair<String, String>("2073-07-30", "2016-11-15"));
        datePairs.add(new Pair<String, String>("2073-08-01", "2016-11-16"));
        datePairs.add(new Pair<String, String>("2073-08-02", "2016-11-17"));
        datePairs.add(new Pair<String, String>("2073-08-03", "2016-11-18"));
        datePairs.add(new Pair<String, String>("2073-08-04", "2016-11-19"));
        datePairs.add(new Pair<String, String>("2073-08-05", "2016-11-20"));
        datePairs.add(new Pair<String, String>("2073-08-06", "2016-11-21"));
        datePairs.add(new Pair<String, String>("2073-08-07", "2016-11-22"));
        datePairs.add(new Pair<String, String>("2073-08-08", "2016-11-23"));
        datePairs.add(new Pair<String, String>("2073-08-09", "2016-11-24"));
        datePairs.add(new Pair<String, String>("2073-08-10", "2016-11-25"));
        datePairs.add(new Pair<String, String>("2073-08-11", "2016-11-26"));
        datePairs.add(new Pair<String, String>("2073-08-12", "2016-11-27"));
        datePairs.add(new Pair<String, String>("2073-08-13", "2016-11-28"));
        datePairs.add(new Pair<String, String>("2073-08-14", "2016-11-29"));
        datePairs.add(new Pair<String, String>("2073-08-15", "2016-11-30"));
        datePairs.add(new Pair<String, String>("2073-08-16", "2016-12-01"));
        datePairs.add(new Pair<String, String>("2073-08-17", "2016-12-02"));
        datePairs.add(new Pair<String, String>("2073-08-18", "2016-12-03"));
        datePairs.add(new Pair<String, String>("2073-08-19", "2016-12-04"));
        datePairs.add(new Pair<String, String>("2073-08-20", "2016-12-05"));
        datePairs.add(new Pair<String, String>("2073-08-21", "2016-12-06"));
        datePairs.add(new Pair<String, String>("2073-08-22", "2016-12-07"));
        datePairs.add(new Pair<String, String>("2073-08-23", "2016-12-08"));
        datePairs.add(new Pair<String, String>("2073-08-24", "2016-12-09"));
        datePairs.add(new Pair<String, String>("2073-08-25", "2016-12-10"));
        datePairs.add(new Pair<String, String>("2073-08-26", "2016-12-11"));
        datePairs.add(new Pair<String, String>("2073-08-27", "2016-12-12"));
        datePairs.add(new Pair<String, String>("2073-08-28", "2016-12-13"));
        datePairs.add(new Pair<String, String>("2073-08-29", "2016-12-14"));
        datePairs.add(new Pair<String, String>("2073-08-30", "2016-12-15"));
        datePairs.add(new Pair<String, String>("2073-09-01", "2016-12-16"));
        datePairs.add(new Pair<String, String>("2073-09-02", "2016-12-17"));
        datePairs.add(new Pair<String, String>("2073-09-03", "2016-12-18"));
        datePairs.add(new Pair<String, String>("2073-09-04", "2016-12-19"));
        datePairs.add(new Pair<String, String>("2073-09-05", "2016-12-20"));
        datePairs.add(new Pair<String, String>("2073-09-06", "2016-12-21"));
        datePairs.add(new Pair<String, String>("2073-09-07", "2016-12-22"));
        datePairs.add(new Pair<String, String>("2073-09-08", "2016-12-23"));
        datePairs.add(new Pair<String, String>("2073-09-09", "2016-12-24"));
        datePairs.add(new Pair<String, String>("2073-09-10", "2016-12-25"));
        datePairs.add(new Pair<String, String>("2073-09-11", "2016-12-26"));
        datePairs.add(new Pair<String, String>("2073-09-12", "2016-12-27"));
        datePairs.add(new Pair<String, String>("2073-09-13", "2016-12-28"));
        datePairs.add(new Pair<String, String>("2073-09-14", "2016-12-29"));
        datePairs.add(new Pair<String, String>("2073-09-15", "2016-12-30"));
        datePairs.add(new Pair<String, String>("2073-09-16", "2016-12-31"));
        datePairs.add(new Pair<String, String>("2073-09-17", "2017-01-01"));
        datePairs.add(new Pair<String, String>("2073-09-18", "2017-01-02"));
        datePairs.add(new Pair<String, String>("2073-09-19", "2017-01-03"));
        datePairs.add(new Pair<String, String>("2073-09-20", "2017-01-04"));
        datePairs.add(new Pair<String, String>("2073-09-21", "2017-01-05"));
        datePairs.add(new Pair<String, String>("2073-09-22", "2017-01-06"));
        datePairs.add(new Pair<String, String>("2073-09-23", "2017-01-07"));
        datePairs.add(new Pair<String, String>("2073-09-24", "2017-01-08"));
        datePairs.add(new Pair<String, String>("2073-09-25", "2017-01-09"));
        datePairs.add(new Pair<String, String>("2073-09-26", "2017-01-10"));
        datePairs.add(new Pair<String, String>("2073-09-27", "2017-01-11"));
        datePairs.add(new Pair<String, String>("2073-09-28", "2017-01-12"));
        datePairs.add(new Pair<String, String>("2073-09-29", "2017-01-13"));
        datePairs.add(new Pair<String, String>("2073-10-01", "2017-01-14"));
        datePairs.add(new Pair<String, String>("2073-10-02", "2017-01-15"));
        datePairs.add(new Pair<String, String>("2073-10-03", "2017-01-16"));
        datePairs.add(new Pair<String, String>("2073-10-04", "2017-01-17"));
        datePairs.add(new Pair<String, String>("2073-10-05", "2017-01-18"));
        datePairs.add(new Pair<String, String>("2073-10-06", "2017-01-19"));
        datePairs.add(new Pair<String, String>("2073-10-07", "2017-01-20"));
        datePairs.add(new Pair<String, String>("2073-10-08", "2017-01-21"));
        datePairs.add(new Pair<String, String>("2073-10-09", "2017-01-22"));
        datePairs.add(new Pair<String, String>("2073-10-10", "2017-01-23"));
        datePairs.add(new Pair<String, String>("2073-10-11", "2017-01-24"));
        datePairs.add(new Pair<String, String>("2073-10-12", "2017-01-25"));
        datePairs.add(new Pair<String, String>("2073-10-13", "2017-01-26"));
        datePairs.add(new Pair<String, String>("2073-10-14", "2017-01-27"));
        datePairs.add(new Pair<String, String>("2073-10-15", "2017-01-28"));
        datePairs.add(new Pair<String, String>("2073-10-16", "2017-01-29"));
        datePairs.add(new Pair<String, String>("2073-10-17", "2017-01-30"));
        datePairs.add(new Pair<String, String>("2073-10-18", "2017-01-31"));
        datePairs.add(new Pair<String, String>("2073-10-19", "2017-02-01"));
        datePairs.add(new Pair<String, String>("2073-10-20", "2017-02-02"));
        datePairs.add(new Pair<String, String>("2073-10-21", "2017-02-03"));
        datePairs.add(new Pair<String, String>("2073-10-22", "2017-02-04"));
        datePairs.add(new Pair<String, String>("2073-10-23", "2017-02-05"));
        datePairs.add(new Pair<String, String>("2073-10-24", "2017-02-06"));
        datePairs.add(new Pair<String, String>("2073-10-25", "2017-02-07"));
        datePairs.add(new Pair<String, String>("2073-10-26", "2017-02-08"));
        datePairs.add(new Pair<String, String>("2073-10-27", "2017-02-09"));
        datePairs.add(new Pair<String, String>("2073-10-28", "2017-02-10"));
        datePairs.add(new Pair<String, String>("2073-10-29", "2017-02-11"));
        datePairs.add(new Pair<String, String>("2073-11-01", "2017-02-12"));
        datePairs.add(new Pair<String, String>("2073-11-02", "2017-02-13"));
        datePairs.add(new Pair<String, String>("2073-11-03", "2017-02-14"));
        datePairs.add(new Pair<String, String>("2073-11-04", "2017-02-15"));
        datePairs.add(new Pair<String, String>("2073-11-05", "2017-02-16"));
        datePairs.add(new Pair<String, String>("2073-11-06", "2017-02-17"));
        datePairs.add(new Pair<String, String>("2073-11-07", "2017-02-18"));
        datePairs.add(new Pair<String, String>("2073-11-08", "2017-02-19"));
        datePairs.add(new Pair<String, String>("2073-11-09", "2017-02-20"));
        datePairs.add(new Pair<String, String>("2073-11-10", "2017-02-21"));
        datePairs.add(new Pair<String, String>("2073-11-11", "2017-02-22"));
        datePairs.add(new Pair<String, String>("2073-11-12", "2017-02-23"));
        datePairs.add(new Pair<String, String>("2073-11-13", "2017-02-24"));
        datePairs.add(new Pair<String, String>("2073-11-14", "2017-02-25"));
        datePairs.add(new Pair<String, String>("2073-11-15", "2017-02-26"));
        datePairs.add(new Pair<String, String>("2073-11-16", "2017-02-27"));
        datePairs.add(new Pair<String, String>("2073-11-17", "2017-02-28"));
        datePairs.add(new Pair<String, String>("2073-11-18", "2017-03-01"));
        datePairs.add(new Pair<String, String>("2073-11-19", "2017-03-02"));
        datePairs.add(new Pair<String, String>("2073-11-20", "2017-03-03"));
        datePairs.add(new Pair<String, String>("2073-11-21", "2017-03-04"));
        datePairs.add(new Pair<String, String>("2073-11-22", "2017-03-05"));
        datePairs.add(new Pair<String, String>("2073-11-23", "2017-03-06"));
        datePairs.add(new Pair<String, String>("2073-11-24", "2017-03-07"));
        datePairs.add(new Pair<String, String>("2073-11-25", "2017-03-08"));
        datePairs.add(new Pair<String, String>("2073-11-26", "2017-03-09"));
        datePairs.add(new Pair<String, String>("2073-11-27", "2017-03-10"));
        datePairs.add(new Pair<String, String>("2073-11-28", "2017-03-11"));
        datePairs.add(new Pair<String, String>("2073-11-29", "2017-03-12"));
        datePairs.add(new Pair<String, String>("2073-11-30", "2017-03-13"));
        datePairs.add(new Pair<String, String>("2073-12-01", "2017-03-14"));
        datePairs.add(new Pair<String, String>("2073-12-02", "2017-03-15"));
        datePairs.add(new Pair<String, String>("2073-12-03", "2017-03-16"));
        datePairs.add(new Pair<String, String>("2073-12-04", "2017-03-17"));
        datePairs.add(new Pair<String, String>("2073-12-05", "2017-03-18"));
        datePairs.add(new Pair<String, String>("2073-12-06", "2017-03-19"));
        datePairs.add(new Pair<String, String>("2073-12-07", "2017-03-20"));
        datePairs.add(new Pair<String, String>("2073-12-08", "2017-03-21"));
        datePairs.add(new Pair<String, String>("2073-12-09", "2017-03-22"));
        datePairs.add(new Pair<String, String>("2073-12-10", "2017-03-23"));
        datePairs.add(new Pair<String, String>("2073-12-11", "2017-03-24"));
        datePairs.add(new Pair<String, String>("2073-12-12", "2017-03-25"));
        datePairs.add(new Pair<String, String>("2073-12-13", "2017-03-26"));
        datePairs.add(new Pair<String, String>("2073-12-14", "2017-03-27"));
        datePairs.add(new Pair<String, String>("2073-12-15", "2017-03-28"));
        datePairs.add(new Pair<String, String>("2073-12-16", "2017-03-29"));
        datePairs.add(new Pair<String, String>("2073-12-17", "2017-03-30"));
        datePairs.add(new Pair<String, String>("2073-12-18", "2017-03-31"));
        datePairs.add(new Pair<String, String>("2073-12-19", "2017-04-01"));
        datePairs.add(new Pair<String, String>("2073-12-20", "2017-04-02"));
        datePairs.add(new Pair<String, String>("2073-12-21", "2017-04-03"));
        datePairs.add(new Pair<String, String>("2073-12-22", "2017-04-04"));
        datePairs.add(new Pair<String, String>("2073-12-23", "2017-04-05"));
        datePairs.add(new Pair<String, String>("2073-12-24", "2017-04-06"));
        datePairs.add(new Pair<String, String>("2073-12-25", "2017-04-07"));
        datePairs.add(new Pair<String, String>("2073-12-26", "2017-04-08"));
        datePairs.add(new Pair<String, String>("2073-12-27", "2017-04-09"));
        datePairs.add(new Pair<String, String>("2073-12-28", "2017-04-10"));
        datePairs.add(new Pair<String, String>("2073-12-29", "2017-04-11"));
        datePairs.add(new Pair<String, String>("2073-12-30", "2017-04-12"));
        datePairs.add(new Pair<String, String>("2073-12-31", "2017-04-13"));
        datePairs.add(new Pair<String, String>("2074-01-01", "2017-04-14"));
        datePairs.add(new Pair<String, String>("2074-01-02", "2017-04-15"));
        datePairs.add(new Pair<String, String>("2074-01-03", "2017-04-16"));
        datePairs.add(new Pair<String, String>("2074-01-04", "2017-04-17"));
        datePairs.add(new Pair<String, String>("2074-01-05", "2017-04-18"));
        datePairs.add(new Pair<String, String>("2074-01-06", "2017-04-19"));
        datePairs.add(new Pair<String, String>("2074-01-07", "2017-04-20"));
        datePairs.add(new Pair<String, String>("2074-01-08", "2017-04-21"));
        datePairs.add(new Pair<String, String>("2074-01-09", "2017-04-22"));
        datePairs.add(new Pair<String, String>("2074-01-10", "2017-04-23"));
        datePairs.add(new Pair<String, String>("2074-01-11", "2017-04-24"));
        datePairs.add(new Pair<String, String>("2074-01-12", "2017-04-25"));
        datePairs.add(new Pair<String, String>("2074-01-13", "2017-04-26"));
        datePairs.add(new Pair<String, String>("2074-01-14", "2017-04-27"));
        datePairs.add(new Pair<String, String>("2074-01-15", "2017-04-28"));
        datePairs.add(new Pair<String, String>("2074-01-16", "2017-04-29"));
        datePairs.add(new Pair<String, String>("2074-01-17", "2017-04-30"));
        datePairs.add(new Pair<String, String>("2074-01-18", "2017-05-01"));
        datePairs.add(new Pair<String, String>("2074-01-19", "2017-05-02"));
        datePairs.add(new Pair<String, String>("2074-01-20", "2017-05-03"));
        datePairs.add(new Pair<String, String>("2074-01-21", "2017-05-04"));
        datePairs.add(new Pair<String, String>("2074-01-22", "2017-05-05"));
        datePairs.add(new Pair<String, String>("2074-01-23", "2017-05-06"));
        datePairs.add(new Pair<String, String>("2074-01-24", "2017-05-07"));
        datePairs.add(new Pair<String, String>("2074-01-25", "2017-05-08"));
        datePairs.add(new Pair<String, String>("2074-01-26", "2017-05-09"));
        datePairs.add(new Pair<String, String>("2074-01-27", "2017-05-10"));
        datePairs.add(new Pair<String, String>("2074-01-28", "2017-05-11"));
        datePairs.add(new Pair<String, String>("2074-01-29", "2017-05-12"));
        datePairs.add(new Pair<String, String>("2074-01-30", "2017-05-13"));
        datePairs.add(new Pair<String, String>("2074-01-31", "2017-05-14"));
        datePairs.add(new Pair<String, String>("2074-02-01", "2017-05-15"));
        datePairs.add(new Pair<String, String>("2074-02-02", "2017-05-16"));
        datePairs.add(new Pair<String, String>("2074-02-03", "2017-05-17"));
        datePairs.add(new Pair<String, String>("2074-02-04", "2017-05-18"));
        datePairs.add(new Pair<String, String>("2074-02-05", "2017-05-19"));
        datePairs.add(new Pair<String, String>("2074-02-06", "2017-05-20"));
        datePairs.add(new Pair<String, String>("2074-02-07", "2017-05-21"));
        datePairs.add(new Pair<String, String>("2074-02-08", "2017-05-22"));
        datePairs.add(new Pair<String, String>("2074-02-09", "2017-05-23"));
        datePairs.add(new Pair<String, String>("2074-02-10", "2017-05-24"));
        datePairs.add(new Pair<String, String>("2074-02-11", "2017-05-25"));
        datePairs.add(new Pair<String, String>("2074-02-12", "2017-05-26"));
        datePairs.add(new Pair<String, String>("2074-02-13", "2017-05-27"));
        datePairs.add(new Pair<String, String>("2074-02-14", "2017-05-28"));
        datePairs.add(new Pair<String, String>("2074-02-15", "2017-05-29"));
        datePairs.add(new Pair<String, String>("2074-02-16", "2017-05-30"));
        datePairs.add(new Pair<String, String>("2074-02-17", "2017-05-31"));
        datePairs.add(new Pair<String, String>("2074-02-18", "2017-06-01"));
        datePairs.add(new Pair<String, String>("2074-02-19", "2017-06-02"));
        datePairs.add(new Pair<String, String>("2074-02-20", "2017-06-03"));
        datePairs.add(new Pair<String, String>("2074-02-21", "2017-06-04"));
        datePairs.add(new Pair<String, String>("2074-02-22", "2017-06-05"));
        datePairs.add(new Pair<String, String>("2074-02-23", "2017-06-06"));
        datePairs.add(new Pair<String, String>("2074-02-24", "2017-06-07"));
        datePairs.add(new Pair<String, String>("2074-02-25", "2017-06-08"));
        datePairs.add(new Pair<String, String>("2074-02-26", "2017-06-09"));
        datePairs.add(new Pair<String, String>("2074-02-27", "2017-06-10"));
        datePairs.add(new Pair<String, String>("2074-02-28", "2017-06-11"));
        datePairs.add(new Pair<String, String>("2074-02-29", "2017-06-12"));
        datePairs.add(new Pair<String, String>("2074-02-30", "2017-06-13"));
        datePairs.add(new Pair<String, String>("2074-02-31", "2017-06-14"));
        datePairs.add(new Pair<String, String>("2074-03-01", "2017-06-15"));
        datePairs.add(new Pair<String, String>("2074-03-02", "2017-06-16"));
        datePairs.add(new Pair<String, String>("2074-03-03", "2017-06-17"));
        datePairs.add(new Pair<String, String>("2074-03-04", "2017-06-18"));
        datePairs.add(new Pair<String, String>("2074-03-05", "2017-06-19"));
        datePairs.add(new Pair<String, String>("2074-03-06", "2017-06-20"));
        datePairs.add(new Pair<String, String>("2074-03-07", "2017-06-21"));
        datePairs.add(new Pair<String, String>("2074-03-08", "2017-06-22"));
        datePairs.add(new Pair<String, String>("2074-03-09", "2017-06-23"));
        datePairs.add(new Pair<String, String>("2074-03-10", "2017-06-24"));
        datePairs.add(new Pair<String, String>("2074-03-11", "2017-06-25"));
        datePairs.add(new Pair<String, String>("2074-03-12", "2017-06-26"));
        datePairs.add(new Pair<String, String>("2074-03-13", "2017-06-27"));
        datePairs.add(new Pair<String, String>("2074-03-14", "2017-06-28"));
        datePairs.add(new Pair<String, String>("2074-03-15", "2017-06-29"));
        datePairs.add(new Pair<String, String>("2074-03-16", "2017-06-30"));
        datePairs.add(new Pair<String, String>("2074-03-17", "2017-07-01"));
        datePairs.add(new Pair<String, String>("2074-03-18", "2017-07-02"));
        datePairs.add(new Pair<String, String>("2074-03-19", "2017-07-03"));
        datePairs.add(new Pair<String, String>("2074-03-20", "2017-07-04"));
        datePairs.add(new Pair<String, String>("2074-03-21", "2017-07-05"));
        datePairs.add(new Pair<String, String>("2074-03-22", "2017-07-06"));
        datePairs.add(new Pair<String, String>("2074-03-23", "2017-07-07"));
        datePairs.add(new Pair<String, String>("2074-03-24", "2017-07-08"));
        datePairs.add(new Pair<String, String>("2074-03-25", "2017-07-09"));
        datePairs.add(new Pair<String, String>("2074-03-26", "2017-07-10"));
        datePairs.add(new Pair<String, String>("2074-03-27", "2017-07-11"));
        datePairs.add(new Pair<String, String>("2074-03-28", "2017-07-12"));
        datePairs.add(new Pair<String, String>("2074-03-29", "2017-07-13"));
        datePairs.add(new Pair<String, String>("2074-03-30", "2017-07-14"));
        datePairs.add(new Pair<String, String>("2074-03-31", "2017-07-15"));
        datePairs.add(new Pair<String, String>("2074-04-01", "2017-07-16"));
        datePairs.add(new Pair<String, String>("2074-04-02", "2017-07-17"));
        datePairs.add(new Pair<String, String>("2074-04-03", "2017-07-18"));
        datePairs.add(new Pair<String, String>("2074-04-04", "2017-07-19"));
        datePairs.add(new Pair<String, String>("2074-04-05", "2017-07-20"));
        datePairs.add(new Pair<String, String>("2074-04-06", "2017-07-21"));
        datePairs.add(new Pair<String, String>("2074-04-07", "2017-07-22"));
        datePairs.add(new Pair<String, String>("2074-04-08", "2017-07-23"));
        datePairs.add(new Pair<String, String>("2074-04-09", "2017-07-24"));
        datePairs.add(new Pair<String, String>("2074-04-10", "2017-07-25"));
        datePairs.add(new Pair<String, String>("2074-04-11", "2017-07-26"));
        datePairs.add(new Pair<String, String>("2074-04-12", "2017-07-27"));
        datePairs.add(new Pair<String, String>("2074-04-13", "2017-07-28"));
        datePairs.add(new Pair<String, String>("2074-04-14", "2017-07-29"));
        datePairs.add(new Pair<String, String>("2074-04-15", "2017-07-30"));
        datePairs.add(new Pair<String, String>("2074-04-16", "2017-07-31"));
        datePairs.add(new Pair<String, String>("2074-04-17", "2017-08-01"));
        datePairs.add(new Pair<String, String>("2074-04-18", "2017-08-02"));
        datePairs.add(new Pair<String, String>("2074-04-19", "2017-08-03"));
        datePairs.add(new Pair<String, String>("2074-04-20", "2017-08-04"));
        datePairs.add(new Pair<String, String>("2074-04-21", "2017-08-05"));
        datePairs.add(new Pair<String, String>("2074-04-22", "2017-08-06"));
        datePairs.add(new Pair<String, String>("2074-04-23", "2017-08-07"));
        datePairs.add(new Pair<String, String>("2074-04-24", "2017-08-08"));
        datePairs.add(new Pair<String, String>("2074-04-25", "2017-08-09"));
        datePairs.add(new Pair<String, String>("2074-04-26", "2017-08-10"));
        datePairs.add(new Pair<String, String>("2074-04-27", "2017-08-11"));
        datePairs.add(new Pair<String, String>("2074-04-28", "2017-08-12"));
        datePairs.add(new Pair<String, String>("2074-04-29", "2017-08-13"));
        datePairs.add(new Pair<String, String>("2074-04-30", "2017-08-14"));
        datePairs.add(new Pair<String, String>("2074-04-31", "2017-08-15"));
        datePairs.add(new Pair<String, String>("2074-04-32", "2017-08-16"));
        datePairs.add(new Pair<String, String>("2074-05-01", "2017-08-17"));
        datePairs.add(new Pair<String, String>("2074-05-02", "2017-08-18"));
        datePairs.add(new Pair<String, String>("2074-05-03", "2017-08-19"));
        datePairs.add(new Pair<String, String>("2074-05-04", "2017-08-20"));
        datePairs.add(new Pair<String, String>("2074-05-05", "2017-08-21"));
        datePairs.add(new Pair<String, String>("2074-05-06", "2017-08-22"));
        datePairs.add(new Pair<String, String>("2074-05-07", "2017-08-23"));
        datePairs.add(new Pair<String, String>("2074-05-08", "2017-08-24"));
        datePairs.add(new Pair<String, String>("2074-05-09", "2017-08-25"));
        datePairs.add(new Pair<String, String>("2074-05-10", "2017-08-26"));
        datePairs.add(new Pair<String, String>("2074-05-11", "2017-08-27"));
        datePairs.add(new Pair<String, String>("2074-05-12", "2017-08-28"));
        datePairs.add(new Pair<String, String>("2074-05-13", "2017-08-29"));
        datePairs.add(new Pair<String, String>("2074-05-14", "2017-08-30"));
        datePairs.add(new Pair<String, String>("2074-05-15", "2017-08-31"));
        datePairs.add(new Pair<String, String>("2074-05-16", "2017-09-01"));
        datePairs.add(new Pair<String, String>("2074-05-17", "2017-09-02"));
        datePairs.add(new Pair<String, String>("2074-05-18", "2017-09-03"));
        datePairs.add(new Pair<String, String>("2074-05-19", "2017-09-04"));
        datePairs.add(new Pair<String, String>("2074-05-20", "2017-09-05"));
        datePairs.add(new Pair<String, String>("2074-05-21", "2017-09-06"));
        datePairs.add(new Pair<String, String>("2074-05-22", "2017-09-07"));
        datePairs.add(new Pair<String, String>("2074-05-23", "2017-09-08"));
        datePairs.add(new Pair<String, String>("2074-05-24", "2017-09-09"));
        datePairs.add(new Pair<String, String>("2074-05-25", "2017-09-10"));
        datePairs.add(new Pair<String, String>("2074-05-26", "2017-09-11"));
        datePairs.add(new Pair<String, String>("2074-05-27", "2017-09-12"));
        datePairs.add(new Pair<String, String>("2074-05-28", "2017-09-13"));
        datePairs.add(new Pair<String, String>("2074-05-29", "2017-09-14"));
        datePairs.add(new Pair<String, String>("2074-05-30", "2017-09-15"));
        datePairs.add(new Pair<String, String>("2074-05-31", "2017-09-16"));
        datePairs.add(new Pair<String, String>("2074-06-01", "2017-09-17"));
        datePairs.add(new Pair<String, String>("2074-06-02", "2017-09-18"));
        datePairs.add(new Pair<String, String>("2074-06-03", "2017-09-19"));
        datePairs.add(new Pair<String, String>("2074-06-04", "2017-09-20"));
        datePairs.add(new Pair<String, String>("2074-06-05", "2017-09-21"));
        datePairs.add(new Pair<String, String>("2074-06-06", "2017-09-22"));
        datePairs.add(new Pair<String, String>("2074-06-07", "2017-09-23"));
        datePairs.add(new Pair<String, String>("2074-06-08", "2017-09-24"));
        datePairs.add(new Pair<String, String>("2074-06-09", "2017-09-25"));
        datePairs.add(new Pair<String, String>("2074-06-10", "2017-09-26"));
        datePairs.add(new Pair<String, String>("2074-06-11", "2017-09-27"));
        datePairs.add(new Pair<String, String>("2074-06-12", "2017-09-28"));
        datePairs.add(new Pair<String, String>("2074-06-13", "2017-09-29"));
        datePairs.add(new Pair<String, String>("2074-06-14", "2017-09-30"));
        datePairs.add(new Pair<String, String>("2074-06-15", "2017-10-01"));
        datePairs.add(new Pair<String, String>("2074-06-16", "2017-10-02"));
        datePairs.add(new Pair<String, String>("2074-06-17", "2017-10-03"));
        datePairs.add(new Pair<String, String>("2074-06-18", "2017-10-04"));
        datePairs.add(new Pair<String, String>("2074-06-19", "2017-10-05"));
        datePairs.add(new Pair<String, String>("2074-06-20", "2017-10-06"));
        datePairs.add(new Pair<String, String>("2074-06-21", "2017-10-07"));
        datePairs.add(new Pair<String, String>("2074-06-22", "2017-10-08"));
        datePairs.add(new Pair<String, String>("2074-06-23", "2017-10-09"));
        datePairs.add(new Pair<String, String>("2074-06-24", "2017-10-10"));
        datePairs.add(new Pair<String, String>("2074-06-25", "2017-10-11"));
        datePairs.add(new Pair<String, String>("2074-06-26", "2017-10-12"));
        datePairs.add(new Pair<String, String>("2074-06-27", "2017-10-13"));
        datePairs.add(new Pair<String, String>("2074-06-28", "2017-10-14"));
        datePairs.add(new Pair<String, String>("2074-06-29", "2017-10-15"));
        datePairs.add(new Pair<String, String>("2074-06-30", "2017-10-16"));
        datePairs.add(new Pair<String, String>("2074-06-31", "2017-10-17"));
        datePairs.add(new Pair<String, String>("2074-07-01", "2017-10-18"));
        datePairs.add(new Pair<String, String>("2074-07-02", "2017-10-19"));
        datePairs.add(new Pair<String, String>("2074-07-03", "2017-10-20"));
        datePairs.add(new Pair<String, String>("2074-07-04", "2017-10-21"));
        datePairs.add(new Pair<String, String>("2074-07-05", "2017-10-22"));
        datePairs.add(new Pair<String, String>("2074-07-06", "2017-10-23"));
        datePairs.add(new Pair<String, String>("2074-07-07", "2017-10-24"));
        datePairs.add(new Pair<String, String>("2074-07-08", "2017-10-25"));
        datePairs.add(new Pair<String, String>("2074-07-09", "2017-10-26"));
        datePairs.add(new Pair<String, String>("2074-07-10", "2017-10-27"));
        datePairs.add(new Pair<String, String>("2074-07-11", "2017-10-28"));
        datePairs.add(new Pair<String, String>("2074-07-12", "2017-10-29"));
        datePairs.add(new Pair<String, String>("2074-07-13", "2017-10-30"));
        datePairs.add(new Pair<String, String>("2074-07-14", "2017-10-31"));
        datePairs.add(new Pair<String, String>("2074-07-15", "2017-11-01"));
        datePairs.add(new Pair<String, String>("2074-07-16", "2017-11-02"));
        datePairs.add(new Pair<String, String>("2074-07-17", "2017-11-03"));
        datePairs.add(new Pair<String, String>("2074-07-18", "2017-11-04"));
        datePairs.add(new Pair<String, String>("2074-07-19", "2017-11-05"));
        datePairs.add(new Pair<String, String>("2074-07-20", "2017-11-06"));
        datePairs.add(new Pair<String, String>("2074-07-21", "2017-11-07"));
        datePairs.add(new Pair<String, String>("2074-07-22", "2017-11-08"));
        datePairs.add(new Pair<String, String>("2074-07-23", "2017-11-09"));
        datePairs.add(new Pair<String, String>("2074-07-24", "2017-11-10"));
        datePairs.add(new Pair<String, String>("2074-07-25", "2017-11-11"));
        datePairs.add(new Pair<String, String>("2074-07-26", "2017-11-12"));
        datePairs.add(new Pair<String, String>("2074-07-27", "2017-11-13"));
        datePairs.add(new Pair<String, String>("2074-07-28", "2017-11-14"));
        datePairs.add(new Pair<String, String>("2074-07-29", "2017-11-15"));
        datePairs.add(new Pair<String, String>("2074-07-30", "2017-11-16"));
        datePairs.add(new Pair<String, String>("2074-08-01", "2017-11-17"));
        datePairs.add(new Pair<String, String>("2074-08-02", "2017-11-18"));
        datePairs.add(new Pair<String, String>("2074-08-03", "2017-11-19"));
        datePairs.add(new Pair<String, String>("2074-08-04", "2017-11-20"));
        datePairs.add(new Pair<String, String>("2074-08-05", "2017-11-21"));
        datePairs.add(new Pair<String, String>("2074-08-06", "2017-11-22"));
        datePairs.add(new Pair<String, String>("2074-08-07", "2017-11-23"));
        datePairs.add(new Pair<String, String>("2074-08-08", "2017-11-24"));
        datePairs.add(new Pair<String, String>("2074-08-09", "2017-11-25"));
        datePairs.add(new Pair<String, String>("2074-08-10", "2017-11-26"));
        datePairs.add(new Pair<String, String>("2074-08-11", "2017-11-27"));
        datePairs.add(new Pair<String, String>("2074-08-12", "2017-11-28"));
        datePairs.add(new Pair<String, String>("2074-08-13", "2017-11-29"));
        datePairs.add(new Pair<String, String>("2074-08-14", "2017-11-30"));
        datePairs.add(new Pair<String, String>("2074-08-15", "2017-12-01"));
        datePairs.add(new Pair<String, String>("2074-08-16", "2017-12-02"));
        datePairs.add(new Pair<String, String>("2074-08-17", "2017-12-03"));
        datePairs.add(new Pair<String, String>("2074-08-18", "2017-12-04"));
        datePairs.add(new Pair<String, String>("2074-08-19", "2017-12-05"));
        datePairs.add(new Pair<String, String>("2074-08-20", "2017-12-06"));
        datePairs.add(new Pair<String, String>("2074-08-21", "2017-12-07"));
        datePairs.add(new Pair<String, String>("2074-08-22", "2017-12-08"));
        datePairs.add(new Pair<String, String>("2074-08-23", "2017-12-09"));
        datePairs.add(new Pair<String, String>("2074-08-24", "2017-12-10"));
        datePairs.add(new Pair<String, String>("2074-08-25", "2017-12-11"));
        datePairs.add(new Pair<String, String>("2074-08-26", "2017-12-12"));
        datePairs.add(new Pair<String, String>("2074-08-27", "2017-12-13"));
        datePairs.add(new Pair<String, String>("2074-08-28", "2017-12-14"));
        datePairs.add(new Pair<String, String>("2074-08-29", "2017-12-15"));
        datePairs.add(new Pair<String, String>("2074-09-01", "2017-12-16"));
        datePairs.add(new Pair<String, String>("2074-09-02", "2017-12-17"));
        datePairs.add(new Pair<String, String>("2074-09-03", "2017-12-18"));
        datePairs.add(new Pair<String, String>("2074-09-04", "2017-12-19"));
        datePairs.add(new Pair<String, String>("2074-09-05", "2017-12-20"));
        datePairs.add(new Pair<String, String>("2074-09-06", "2017-12-21"));
        datePairs.add(new Pair<String, String>("2074-09-07", "2017-12-22"));
        datePairs.add(new Pair<String, String>("2074-09-08", "2017-12-23"));
        datePairs.add(new Pair<String, String>("2074-09-09", "2017-12-24"));
        datePairs.add(new Pair<String, String>("2074-09-10", "2017-12-25"));
        datePairs.add(new Pair<String, String>("2074-09-11", "2017-12-26"));
        datePairs.add(new Pair<String, String>("2074-09-12", "2017-12-27"));
        datePairs.add(new Pair<String, String>("2074-09-13", "2017-12-28"));
        datePairs.add(new Pair<String, String>("2074-09-14", "2017-12-29"));
        datePairs.add(new Pair<String, String>("2074-09-15", "2017-12-30"));
        datePairs.add(new Pair<String, String>("2074-09-16", "2017-12-31"));
        datePairs.add(new Pair<String, String>("2074-09-17", "2018-01-01"));
        datePairs.add(new Pair<String, String>("2074-09-18", "2018-01-02"));
        datePairs.add(new Pair<String, String>("2074-09-19", "2018-01-03"));
        datePairs.add(new Pair<String, String>("2074-09-20", "2018-01-04"));
        datePairs.add(new Pair<String, String>("2074-09-21", "2018-01-05"));
        datePairs.add(new Pair<String, String>("2074-09-22", "2018-01-06"));
        datePairs.add(new Pair<String, String>("2074-09-23", "2018-01-07"));
        datePairs.add(new Pair<String, String>("2074-09-24", "2018-01-08"));
        datePairs.add(new Pair<String, String>("2074-09-25", "2018-01-09"));
        datePairs.add(new Pair<String, String>("2074-09-26", "2018-01-10"));
        datePairs.add(new Pair<String, String>("2074-09-27", "2018-01-11"));
        datePairs.add(new Pair<String, String>("2074-09-28", "2018-01-12"));
        datePairs.add(new Pair<String, String>("2074-09-29", "2018-01-13"));
        datePairs.add(new Pair<String, String>("2074-09-30", "2018-01-14"));
        datePairs.add(new Pair<String, String>("2074-10-01", "2018-01-15"));
        datePairs.add(new Pair<String, String>("2074-10-02", "2018-01-16"));
        datePairs.add(new Pair<String, String>("2074-10-03", "2018-01-17"));
        datePairs.add(new Pair<String, String>("2074-10-04", "2018-01-18"));
        datePairs.add(new Pair<String, String>("2074-10-05", "2018-01-19"));
        datePairs.add(new Pair<String, String>("2074-10-06", "2018-01-20"));
        datePairs.add(new Pair<String, String>("2074-10-07", "2018-01-21"));
        datePairs.add(new Pair<String, String>("2074-10-08", "2018-01-22"));
        datePairs.add(new Pair<String, String>("2074-10-09", "2018-01-23"));
        datePairs.add(new Pair<String, String>("2074-10-10", "2018-01-24"));
        datePairs.add(new Pair<String, String>("2074-10-11", "2018-01-25"));
        datePairs.add(new Pair<String, String>("2074-10-12", "2018-01-26"));
        datePairs.add(new Pair<String, String>("2074-10-13", "2018-01-27"));
        datePairs.add(new Pair<String, String>("2074-10-14", "2018-01-28"));
        datePairs.add(new Pair<String, String>("2074-10-15", "2018-01-29"));
        datePairs.add(new Pair<String, String>("2074-10-16", "2018-01-30"));
        datePairs.add(new Pair<String, String>("2074-10-17", "2018-01-31"));
        datePairs.add(new Pair<String, String>("2074-10-18", "2018-02-01"));
        datePairs.add(new Pair<String, String>("2074-10-19", "2018-02-02"));
        datePairs.add(new Pair<String, String>("2074-10-20", "2018-02-03"));
        datePairs.add(new Pair<String, String>("2074-10-21", "2018-02-04"));
        datePairs.add(new Pair<String, String>("2074-10-22", "2018-02-05"));
        datePairs.add(new Pair<String, String>("2074-10-23", "2018-02-06"));
        datePairs.add(new Pair<String, String>("2074-10-24", "2018-02-07"));
        datePairs.add(new Pair<String, String>("2074-10-25", "2018-02-08"));
        datePairs.add(new Pair<String, String>("2074-10-26", "2018-02-09"));
        datePairs.add(new Pair<String, String>("2074-10-27", "2018-02-10"));
        datePairs.add(new Pair<String, String>("2074-10-28", "2018-02-11"));
        datePairs.add(new Pair<String, String>("2074-10-29", "2018-02-12"));
        datePairs.add(new Pair<String, String>("2074-11-01", "2018-02-13"));
        datePairs.add(new Pair<String, String>("2074-11-02", "2018-02-14"));
        datePairs.add(new Pair<String, String>("2074-11-03", "2018-02-15"));
        datePairs.add(new Pair<String, String>("2074-11-04", "2018-02-16"));
        datePairs.add(new Pair<String, String>("2074-11-05", "2018-02-17"));
        datePairs.add(new Pair<String, String>("2074-11-06", "2018-02-18"));
        datePairs.add(new Pair<String, String>("2074-11-07", "2018-02-19"));
        datePairs.add(new Pair<String, String>("2074-11-08", "2018-02-20"));
        datePairs.add(new Pair<String, String>("2074-11-09", "2018-02-21"));
        datePairs.add(new Pair<String, String>("2074-11-10", "2018-02-22"));
        datePairs.add(new Pair<String, String>("2074-11-11", "2018-02-23"));
        datePairs.add(new Pair<String, String>("2074-11-12", "2018-02-24"));
        datePairs.add(new Pair<String, String>("2074-11-13", "2018-02-25"));
        datePairs.add(new Pair<String, String>("2074-11-14", "2018-02-26"));
        datePairs.add(new Pair<String, String>("2074-11-15", "2018-02-27"));
        datePairs.add(new Pair<String, String>("2074-11-16", "2018-02-28"));
        datePairs.add(new Pair<String, String>("2074-11-17", "2018-03-01"));
        datePairs.add(new Pair<String, String>("2074-11-18", "2018-03-02"));
        datePairs.add(new Pair<String, String>("2074-11-19", "2018-03-03"));
        datePairs.add(new Pair<String, String>("2074-11-20", "2018-03-04"));
        datePairs.add(new Pair<String, String>("2074-11-21", "2018-03-05"));
        datePairs.add(new Pair<String, String>("2074-11-22", "2018-03-06"));
        datePairs.add(new Pair<String, String>("2074-11-23", "2018-03-07"));
        datePairs.add(new Pair<String, String>("2074-11-24", "2018-03-08"));
        datePairs.add(new Pair<String, String>("2074-11-25", "2018-03-09"));
        datePairs.add(new Pair<String, String>("2074-11-26", "2018-03-10"));
        datePairs.add(new Pair<String, String>("2074-11-27", "2018-03-11"));
        datePairs.add(new Pair<String, String>("2074-11-28", "2018-03-12"));
        datePairs.add(new Pair<String, String>("2074-11-29", "2018-03-13"));
        datePairs.add(new Pair<String, String>("2074-11-30", "2018-03-14"));
        datePairs.add(new Pair<String, String>("2074-12-01", "2018-03-15"));
        datePairs.add(new Pair<String, String>("2074-12-02", "2018-03-16"));
        datePairs.add(new Pair<String, String>("2074-12-03", "2018-03-17"));
        datePairs.add(new Pair<String, String>("2074-12-04", "2018-03-18"));
        datePairs.add(new Pair<String, String>("2074-12-05", "2018-03-19"));
        datePairs.add(new Pair<String, String>("2074-12-06", "2018-03-20"));
        datePairs.add(new Pair<String, String>("2074-12-07", "2018-03-21"));
        datePairs.add(new Pair<String, String>("2074-12-08", "2018-03-22"));
        datePairs.add(new Pair<String, String>("2074-12-09", "2018-03-23"));
        datePairs.add(new Pair<String, String>("2074-12-10", "2018-03-24"));
        datePairs.add(new Pair<String, String>("2074-12-11", "2018-03-25"));
        datePairs.add(new Pair<String, String>("2074-12-12", "2018-03-26"));
        datePairs.add(new Pair<String, String>("2074-12-13", "2018-03-27"));
        datePairs.add(new Pair<String, String>("2074-12-14", "2018-03-28"));
        datePairs.add(new Pair<String, String>("2074-12-15", "2018-03-29"));
        datePairs.add(new Pair<String, String>("2074-12-16", "2018-03-30"));
        datePairs.add(new Pair<String, String>("2074-12-17", "2018-03-31"));
        datePairs.add(new Pair<String, String>("2074-12-18", "2018-04-01"));
        datePairs.add(new Pair<String, String>("2074-12-19", "2018-04-02"));
        datePairs.add(new Pair<String, String>("2074-12-20", "2018-04-03"));
        datePairs.add(new Pair<String, String>("2074-12-21", "2018-04-04"));
        datePairs.add(new Pair<String, String>("2074-12-22", "2018-04-05"));
        datePairs.add(new Pair<String, String>("2074-12-23", "2018-04-06"));
        datePairs.add(new Pair<String, String>("2074-12-24", "2018-04-07"));
        datePairs.add(new Pair<String, String>("2074-12-25", "2018-04-08"));
        datePairs.add(new Pair<String, String>("2074-12-26", "2018-04-09"));
        datePairs.add(new Pair<String, String>("2074-12-27", "2018-04-10"));
        datePairs.add(new Pair<String, String>("2074-12-28", "2018-04-11"));
        datePairs.add(new Pair<String, String>("2074-12-29", "2018-04-12"));
        datePairs.add(new Pair<String, String>("2074-12-30", "2018-04-13"));
        datePairs.add(new Pair<String, String>("2075-01-01", "2018-04-14"));
        datePairs.add(new Pair<String, String>("2075-01-02", "2018-04-15"));
        datePairs.add(new Pair<String, String>("2075-01-03", "2018-04-16"));
        datePairs.add(new Pair<String, String>("2075-01-04", "2018-04-17"));
        datePairs.add(new Pair<String, String>("2075-01-05", "2018-04-18"));
        datePairs.add(new Pair<String, String>("2075-01-06", "2018-04-19"));
        datePairs.add(new Pair<String, String>("2075-01-07", "2018-04-20"));
        datePairs.add(new Pair<String, String>("2075-01-08", "2018-04-21"));
        datePairs.add(new Pair<String, String>("2075-01-09", "2018-04-22"));
        datePairs.add(new Pair<String, String>("2075-01-10", "2018-04-23"));
        datePairs.add(new Pair<String, String>("2075-01-11", "2018-04-24"));
        datePairs.add(new Pair<String, String>("2075-01-12", "2018-04-25"));
        datePairs.add(new Pair<String, String>("2075-01-13", "2018-04-26"));
        datePairs.add(new Pair<String, String>("2075-01-14", "2018-04-27"));
        datePairs.add(new Pair<String, String>("2075-01-15", "2018-04-28"));
        datePairs.add(new Pair<String, String>("2075-01-16", "2018-04-29"));
        datePairs.add(new Pair<String, String>("2075-01-17", "2018-04-30"));
        datePairs.add(new Pair<String, String>("2075-01-18", "2018-05-01"));
        datePairs.add(new Pair<String, String>("2075-01-19", "2018-05-02"));
        datePairs.add(new Pair<String, String>("2075-01-20", "2018-05-03"));
        datePairs.add(new Pair<String, String>("2075-01-21", "2018-05-04"));
        datePairs.add(new Pair<String, String>("2075-01-22", "2018-05-05"));
        datePairs.add(new Pair<String, String>("2075-01-23", "2018-05-06"));
        datePairs.add(new Pair<String, String>("2075-01-24", "2018-05-07"));
        datePairs.add(new Pair<String, String>("2075-01-25", "2018-05-08"));
        datePairs.add(new Pair<String, String>("2075-01-26", "2018-05-09"));
        datePairs.add(new Pair<String, String>("2075-01-27", "2018-05-10"));
        datePairs.add(new Pair<String, String>("2075-01-28", "2018-05-11"));
        datePairs.add(new Pair<String, String>("2075-01-29", "2018-05-12"));
        datePairs.add(new Pair<String, String>("2075-01-30", "2018-05-13"));
        datePairs.add(new Pair<String, String>("2075-01-31", "2018-05-14"));
        datePairs.add(new Pair<String, String>("2075-02-01", "2018-05-15"));
        datePairs.add(new Pair<String, String>("2075-02-02", "2018-05-16"));
        datePairs.add(new Pair<String, String>("2075-02-03", "2018-05-17"));
        datePairs.add(new Pair<String, String>("2075-02-04", "2018-05-18"));
        datePairs.add(new Pair<String, String>("2075-02-05", "2018-05-19"));
        datePairs.add(new Pair<String, String>("2075-02-06", "2018-05-20"));
        datePairs.add(new Pair<String, String>("2075-02-07", "2018-05-21"));
        datePairs.add(new Pair<String, String>("2075-02-08", "2018-05-22"));
        datePairs.add(new Pair<String, String>("2075-02-09", "2018-05-23"));
        datePairs.add(new Pair<String, String>("2075-02-10", "2018-05-24"));
        datePairs.add(new Pair<String, String>("2075-02-11", "2018-05-25"));
        datePairs.add(new Pair<String, String>("2075-02-12", "2018-05-26"));
        datePairs.add(new Pair<String, String>("2075-02-13", "2018-05-27"));
        datePairs.add(new Pair<String, String>("2075-02-14", "2018-05-28"));
        datePairs.add(new Pair<String, String>("2075-02-15", "2018-05-29"));
        datePairs.add(new Pair<String, String>("2075-02-16", "2018-05-30"));
        datePairs.add(new Pair<String, String>("2075-02-17", "2018-05-31"));
        datePairs.add(new Pair<String, String>("2075-02-18", "2018-06-01"));
        datePairs.add(new Pair<String, String>("2075-02-19", "2018-06-02"));
        datePairs.add(new Pair<String, String>("2075-02-20", "2018-06-03"));
        datePairs.add(new Pair<String, String>("2075-02-21", "2018-06-04"));
        datePairs.add(new Pair<String, String>("2075-02-22", "2018-06-05"));
        datePairs.add(new Pair<String, String>("2075-02-23", "2018-06-06"));
        datePairs.add(new Pair<String, String>("2075-02-24", "2018-06-07"));
        datePairs.add(new Pair<String, String>("2075-02-25", "2018-06-08"));
        datePairs.add(new Pair<String, String>("2075-02-26", "2018-06-09"));
        datePairs.add(new Pair<String, String>("2075-02-27", "2018-06-10"));
        datePairs.add(new Pair<String, String>("2075-02-28", "2018-06-11"));
        datePairs.add(new Pair<String, String>("2075-02-29", "2018-06-12"));
        datePairs.add(new Pair<String, String>("2075-02-30", "2018-06-13"));
        datePairs.add(new Pair<String, String>("2075-02-31", "2018-06-14"));
        datePairs.add(new Pair<String, String>("2075-03-01", "2018-06-15"));
        datePairs.add(new Pair<String, String>("2075-03-02", "2018-06-16"));
        datePairs.add(new Pair<String, String>("2075-03-03", "2018-06-17"));
        datePairs.add(new Pair<String, String>("2075-03-04", "2018-06-18"));
        datePairs.add(new Pair<String, String>("2075-03-05", "2018-06-19"));
        datePairs.add(new Pair<String, String>("2075-03-06", "2018-06-20"));
        datePairs.add(new Pair<String, String>("2075-03-07", "2018-06-21"));
        datePairs.add(new Pair<String, String>("2075-03-08", "2018-06-22"));
        datePairs.add(new Pair<String, String>("2075-03-09", "2018-06-23"));
        datePairs.add(new Pair<String, String>("2075-03-10", "2018-06-24"));
        datePairs.add(new Pair<String, String>("2075-03-11", "2018-06-25"));
        datePairs.add(new Pair<String, String>("2075-03-12", "2018-06-26"));
        datePairs.add(new Pair<String, String>("2075-03-13", "2018-06-27"));
        datePairs.add(new Pair<String, String>("2075-03-14", "2018-06-28"));
        datePairs.add(new Pair<String, String>("2075-03-15", "2018-06-29"));
        datePairs.add(new Pair<String, String>("2075-03-16", "2018-06-30"));
        datePairs.add(new Pair<String, String>("2075-03-17", "2018-07-01"));
        datePairs.add(new Pair<String, String>("2075-03-18", "2018-07-02"));
        datePairs.add(new Pair<String, String>("2075-03-19", "2018-07-03"));
        datePairs.add(new Pair<String, String>("2075-03-20", "2018-07-04"));
        datePairs.add(new Pair<String, String>("2075-03-21", "2018-07-05"));
        datePairs.add(new Pair<String, String>("2075-03-22", "2018-07-06"));
        datePairs.add(new Pair<String, String>("2075-03-23", "2018-07-07"));
        datePairs.add(new Pair<String, String>("2075-03-24", "2018-07-08"));
        datePairs.add(new Pair<String, String>("2075-03-25", "2018-07-09"));
        datePairs.add(new Pair<String, String>("2075-03-26", "2018-07-10"));
        datePairs.add(new Pair<String, String>("2075-03-27", "2018-07-11"));
        datePairs.add(new Pair<String, String>("2075-03-28", "2018-07-12"));
        datePairs.add(new Pair<String, String>("2075-03-29", "2018-07-13"));
        datePairs.add(new Pair<String, String>("2075-03-30", "2018-07-14"));
        datePairs.add(new Pair<String, String>("2075-03-31", "2018-07-15"));
        datePairs.add(new Pair<String, String>("2075-03-32", "2018-07-16"));
        datePairs.add(new Pair<String, String>("2075-04-01", "2018-07-17"));
        datePairs.add(new Pair<String, String>("2075-04-02", "2018-07-18"));
        datePairs.add(new Pair<String, String>("2075-04-03", "2018-07-19"));
        datePairs.add(new Pair<String, String>("2075-04-04", "2018-07-20"));
        datePairs.add(new Pair<String, String>("2075-04-05", "2018-07-21"));
        datePairs.add(new Pair<String, String>("2075-04-06", "2018-07-22"));
        datePairs.add(new Pair<String, String>("2075-04-07", "2018-07-23"));
        datePairs.add(new Pair<String, String>("2075-04-08", "2018-07-24"));
        datePairs.add(new Pair<String, String>("2075-04-09", "2018-07-25"));
        datePairs.add(new Pair<String, String>("2075-04-10", "2018-07-26"));
        datePairs.add(new Pair<String, String>("2075-04-11", "2018-07-27"));
        datePairs.add(new Pair<String, String>("2075-04-12", "2018-07-28"));
        datePairs.add(new Pair<String, String>("2075-04-13", "2018-07-29"));
        datePairs.add(new Pair<String, String>("2075-04-14", "2018-07-30"));
        datePairs.add(new Pair<String, String>("2075-04-15", "2018-07-31"));
        datePairs.add(new Pair<String, String>("2075-04-16", "2018-08-01"));
        datePairs.add(new Pair<String, String>("2075-04-17", "2018-08-02"));
        datePairs.add(new Pair<String, String>("2075-04-18", "2018-08-03"));
        datePairs.add(new Pair<String, String>("2075-04-19", "2018-08-04"));
        datePairs.add(new Pair<String, String>("2075-04-20", "2018-08-05"));
        datePairs.add(new Pair<String, String>("2075-04-21", "2018-08-06"));
        datePairs.add(new Pair<String, String>("2075-04-22", "2018-08-07"));
        datePairs.add(new Pair<String, String>("2075-04-23", "2018-08-08"));
        datePairs.add(new Pair<String, String>("2075-04-24", "2018-08-09"));
        datePairs.add(new Pair<String, String>("2075-04-25", "2018-08-10"));
        datePairs.add(new Pair<String, String>("2075-04-26", "2018-08-11"));
        datePairs.add(new Pair<String, String>("2075-04-27", "2018-08-12"));
        datePairs.add(new Pair<String, String>("2075-04-28", "2018-08-13"));
        datePairs.add(new Pair<String, String>("2075-04-29", "2018-08-14"));
        datePairs.add(new Pair<String, String>("2075-04-30", "2018-08-15"));
        datePairs.add(new Pair<String, String>("2075-04-31", "2018-08-16"));
        datePairs.add(new Pair<String, String>("2075-05-01", "2018-08-17"));
        datePairs.add(new Pair<String, String>("2075-05-02", "2018-08-18"));
        datePairs.add(new Pair<String, String>("2075-05-03", "2018-08-19"));
        datePairs.add(new Pair<String, String>("2075-05-04", "2018-08-20"));
        datePairs.add(new Pair<String, String>("2075-05-05", "2018-08-21"));
        datePairs.add(new Pair<String, String>("2075-05-06", "2018-08-22"));
        datePairs.add(new Pair<String, String>("2075-05-07", "2018-08-23"));
        datePairs.add(new Pair<String, String>("2075-05-08", "2018-08-24"));
        datePairs.add(new Pair<String, String>("2075-05-09", "2018-08-25"));
        datePairs.add(new Pair<String, String>("2075-05-10", "2018-08-26"));
        datePairs.add(new Pair<String, String>("2075-05-11", "2018-08-27"));
        datePairs.add(new Pair<String, String>("2075-05-12", "2018-08-28"));
        datePairs.add(new Pair<String, String>("2075-05-13", "2018-08-29"));
        datePairs.add(new Pair<String, String>("2075-05-14", "2018-08-30"));
        datePairs.add(new Pair<String, String>("2075-05-15", "2018-08-31"));
        datePairs.add(new Pair<String, String>("2075-05-16", "2018-09-01"));
        datePairs.add(new Pair<String, String>("2075-05-17", "2018-09-02"));
        datePairs.add(new Pair<String, String>("2075-05-18", "2018-09-03"));
        datePairs.add(new Pair<String, String>("2075-05-19", "2018-09-04"));
        datePairs.add(new Pair<String, String>("2075-05-20", "2018-09-05"));
        datePairs.add(new Pair<String, String>("2075-05-21", "2018-09-06"));
        datePairs.add(new Pair<String, String>("2075-05-22", "2018-09-07"));
        datePairs.add(new Pair<String, String>("2075-05-23", "2018-09-08"));
        datePairs.add(new Pair<String, String>("2075-05-24", "2018-09-09"));
        datePairs.add(new Pair<String, String>("2075-05-25", "2018-09-10"));
        datePairs.add(new Pair<String, String>("2075-05-26", "2018-09-11"));
        datePairs.add(new Pair<String, String>("2075-05-27", "2018-09-12"));
        datePairs.add(new Pair<String, String>("2075-05-28", "2018-09-13"));
        datePairs.add(new Pair<String, String>("2075-05-29", "2018-09-14"));
        datePairs.add(new Pair<String, String>("2075-05-30", "2018-09-15"));
        datePairs.add(new Pair<String, String>("2075-05-31", "2018-09-16"));
        datePairs.add(new Pair<String, String>("2075-06-01", "2018-09-17"));
        datePairs.add(new Pair<String, String>("2075-06-02", "2018-09-18"));
        datePairs.add(new Pair<String, String>("2075-06-03", "2018-09-19"));
        datePairs.add(new Pair<String, String>("2075-06-04", "2018-09-20"));
        datePairs.add(new Pair<String, String>("2075-06-05", "2018-09-21"));
        datePairs.add(new Pair<String, String>("2075-06-06", "2018-09-22"));
        datePairs.add(new Pair<String, String>("2075-06-07", "2018-09-23"));
        datePairs.add(new Pair<String, String>("2075-06-08", "2018-09-24"));
        datePairs.add(new Pair<String, String>("2075-06-09", "2018-09-25"));
        datePairs.add(new Pair<String, String>("2075-06-10", "2018-09-26"));
        datePairs.add(new Pair<String, String>("2075-06-11", "2018-09-27"));
        datePairs.add(new Pair<String, String>("2075-06-12", "2018-09-28"));
        datePairs.add(new Pair<String, String>("2075-06-13", "2018-09-29"));
        datePairs.add(new Pair<String, String>("2075-06-14", "2018-09-30"));
        datePairs.add(new Pair<String, String>("2075-06-15", "2018-10-01"));
        datePairs.add(new Pair<String, String>("2075-06-16", "2018-10-02"));
        datePairs.add(new Pair<String, String>("2075-06-17", "2018-10-03"));
        datePairs.add(new Pair<String, String>("2075-06-18", "2018-10-04"));
        datePairs.add(new Pair<String, String>("2075-06-19", "2018-10-05"));
        datePairs.add(new Pair<String, String>("2075-06-20", "2018-10-06"));
        datePairs.add(new Pair<String, String>("2075-06-21", "2018-10-07"));
        datePairs.add(new Pair<String, String>("2075-06-22", "2018-10-08"));
        datePairs.add(new Pair<String, String>("2075-06-23", "2018-10-09"));
        datePairs.add(new Pair<String, String>("2075-06-24", "2018-10-10"));
        datePairs.add(new Pair<String, String>("2075-06-25", "2018-10-11"));
        datePairs.add(new Pair<String, String>("2075-06-26", "2018-10-12"));
        datePairs.add(new Pair<String, String>("2075-06-27", "2018-10-13"));
        datePairs.add(new Pair<String, String>("2075-06-28", "2018-10-14"));
        datePairs.add(new Pair<String, String>("2075-06-29", "2018-10-15"));
        datePairs.add(new Pair<String, String>("2075-06-30", "2018-10-16"));
        datePairs.add(new Pair<String, String>("2075-06-31", "2018-10-17"));
        datePairs.add(new Pair<String, String>("2075-07-01", "2018-10-18"));
        datePairs.add(new Pair<String, String>("2075-07-02", "2018-10-19"));
        datePairs.add(new Pair<String, String>("2075-07-03", "2018-10-20"));
        datePairs.add(new Pair<String, String>("2075-07-04", "2018-10-21"));
        datePairs.add(new Pair<String, String>("2075-07-05", "2018-10-22"));
        datePairs.add(new Pair<String, String>("2075-07-06", "2018-10-23"));
        datePairs.add(new Pair<String, String>("2075-07-07", "2018-10-24"));
        datePairs.add(new Pair<String, String>("2075-07-08", "2018-10-25"));
        datePairs.add(new Pair<String, String>("2075-07-09", "2018-10-26"));
        datePairs.add(new Pair<String, String>("2075-07-10", "2018-10-27"));
        datePairs.add(new Pair<String, String>("2075-07-11", "2018-10-28"));
        datePairs.add(new Pair<String, String>("2075-07-12", "2018-10-29"));
        datePairs.add(new Pair<String, String>("2075-07-13", "2018-10-30"));
        datePairs.add(new Pair<String, String>("2075-07-14", "2018-10-31"));
        datePairs.add(new Pair<String, String>("2075-07-15", "2018-11-01"));
        datePairs.add(new Pair<String, String>("2075-07-16", "2018-11-02"));
        datePairs.add(new Pair<String, String>("2075-07-17", "2018-11-03"));
        datePairs.add(new Pair<String, String>("2075-07-18", "2018-11-04"));
        datePairs.add(new Pair<String, String>("2075-07-19", "2018-11-05"));
        datePairs.add(new Pair<String, String>("2075-07-20", "2018-11-06"));
        datePairs.add(new Pair<String, String>("2075-07-21", "2018-11-07"));
        datePairs.add(new Pair<String, String>("2075-07-22", "2018-11-08"));
        datePairs.add(new Pair<String, String>("2075-07-23", "2018-11-09"));
        datePairs.add(new Pair<String, String>("2075-07-24", "2018-11-10"));
        datePairs.add(new Pair<String, String>("2075-07-25", "2018-11-11"));
        datePairs.add(new Pair<String, String>("2075-07-26", "2018-11-12"));
        datePairs.add(new Pair<String, String>("2075-07-27", "2018-11-13"));
        datePairs.add(new Pair<String, String>("2075-07-28", "2018-11-14"));
        datePairs.add(new Pair<String, String>("2075-07-29", "2018-11-15"));
        datePairs.add(new Pair<String, String>("2075-07-30", "2018-11-16"));
        datePairs.add(new Pair<String, String>("2075-08-01", "2018-11-17"));
        datePairs.add(new Pair<String, String>("2075-08-02", "2018-11-18"));
        datePairs.add(new Pair<String, String>("2075-08-03", "2018-11-19"));
        datePairs.add(new Pair<String, String>("2075-08-04", "2018-11-20"));
        datePairs.add(new Pair<String, String>("2075-08-05", "2018-11-21"));
        datePairs.add(new Pair<String, String>("2075-08-06", "2018-11-22"));
        datePairs.add(new Pair<String, String>("2075-08-07", "2018-11-23"));
        datePairs.add(new Pair<String, String>("2075-08-08", "2018-11-24"));
        datePairs.add(new Pair<String, String>("2075-08-09", "2018-11-25"));
        datePairs.add(new Pair<String, String>("2075-08-10", "2018-11-26"));
        datePairs.add(new Pair<String, String>("2075-08-11", "2018-11-27"));
        datePairs.add(new Pair<String, String>("2075-08-12", "2018-11-28"));
        datePairs.add(new Pair<String, String>("2075-08-13", "2018-11-29"));
        datePairs.add(new Pair<String, String>("2075-08-14", "2018-11-30"));
        datePairs.add(new Pair<String, String>("2075-08-15", "2018-12-01"));
        datePairs.add(new Pair<String, String>("2075-08-16", "2018-12-02"));
        datePairs.add(new Pair<String, String>("2075-08-17", "2018-12-03"));
        datePairs.add(new Pair<String, String>("2075-08-18", "2018-12-04"));
        datePairs.add(new Pair<String, String>("2075-08-19", "2018-12-05"));
        datePairs.add(new Pair<String, String>("2075-08-20", "2018-12-06"));
        datePairs.add(new Pair<String, String>("2075-08-21", "2018-12-07"));
        datePairs.add(new Pair<String, String>("2075-08-22", "2018-12-08"));
        datePairs.add(new Pair<String, String>("2075-08-23", "2018-12-09"));
        datePairs.add(new Pair<String, String>("2075-08-24", "2018-12-10"));
        datePairs.add(new Pair<String, String>("2075-08-25", "2018-12-11"));
        datePairs.add(new Pair<String, String>("2075-08-26", "2018-12-12"));
        datePairs.add(new Pair<String, String>("2075-08-27", "2018-12-13"));
        datePairs.add(new Pair<String, String>("2075-08-28", "2018-12-14"));
        datePairs.add(new Pair<String, String>("2075-08-29", "2018-12-15"));
        datePairs.add(new Pair<String, String>("2075-09-01", "2018-12-16"));
        datePairs.add(new Pair<String, String>("2075-09-02", "2018-12-17"));
        datePairs.add(new Pair<String, String>("2075-09-03", "2018-12-18"));
        datePairs.add(new Pair<String, String>("2075-09-04", "2018-12-19"));
        datePairs.add(new Pair<String, String>("2075-09-05", "2018-12-20"));
        datePairs.add(new Pair<String, String>("2075-09-06", "2018-12-21"));
        datePairs.add(new Pair<String, String>("2075-09-07", "2018-12-22"));
        datePairs.add(new Pair<String, String>("2075-09-08", "2018-12-23"));
        datePairs.add(new Pair<String, String>("2075-09-09", "2018-12-24"));
        datePairs.add(new Pair<String, String>("2075-09-10", "2018-12-25"));
        datePairs.add(new Pair<String, String>("2075-09-11", "2018-12-26"));
        datePairs.add(new Pair<String, String>("2075-09-12", "2018-12-27"));
        datePairs.add(new Pair<String, String>("2075-09-13", "2018-12-28"));
        datePairs.add(new Pair<String, String>("2075-09-14", "2018-12-29"));
        datePairs.add(new Pair<String, String>("2075-09-15", "2018-12-30"));
        datePairs.add(new Pair<String, String>("2075-09-16", "2018-12-31"));
        datePairs.add(new Pair<String, String>("2075-09-17", "2019-01-01"));
        datePairs.add(new Pair<String, String>("2075-09-18", "2019-01-02"));
        datePairs.add(new Pair<String, String>("2075-09-19", "2019-01-03"));
        datePairs.add(new Pair<String, String>("2075-09-20", "2019-01-04"));
        datePairs.add(new Pair<String, String>("2075-09-21", "2019-01-05"));
        datePairs.add(new Pair<String, String>("2075-09-22", "2019-01-06"));
        datePairs.add(new Pair<String, String>("2075-09-23", "2019-01-07"));
        datePairs.add(new Pair<String, String>("2075-09-24", "2019-01-08"));
        datePairs.add(new Pair<String, String>("2075-09-25", "2019-01-09"));
        datePairs.add(new Pair<String, String>("2075-09-26", "2019-01-10"));
        datePairs.add(new Pair<String, String>("2075-09-27", "2019-01-11"));
        datePairs.add(new Pair<String, String>("2075-09-28", "2019-01-12"));
        datePairs.add(new Pair<String, String>("2075-09-29", "2019-01-13"));
        datePairs.add(new Pair<String, String>("2075-09-30", "2019-01-14"));
        datePairs.add(new Pair<String, String>("2075-10-01", "2019-01-15"));
        datePairs.add(new Pair<String, String>("2075-10-02", "2019-01-16"));
        datePairs.add(new Pair<String, String>("2075-10-03", "2019-01-17"));
        datePairs.add(new Pair<String, String>("2075-10-04", "2019-01-18"));
        datePairs.add(new Pair<String, String>("2075-10-05", "2019-01-19"));
        datePairs.add(new Pair<String, String>("2075-10-06", "2019-01-20"));
        datePairs.add(new Pair<String, String>("2075-10-07", "2019-01-21"));
        datePairs.add(new Pair<String, String>("2075-10-08", "2019-01-22"));
        datePairs.add(new Pair<String, String>("2075-10-09", "2019-01-23"));
        datePairs.add(new Pair<String, String>("2075-10-10", "2019-01-24"));
        datePairs.add(new Pair<String, String>("2075-10-11", "2019-01-25"));
        datePairs.add(new Pair<String, String>("2075-10-12", "2019-01-26"));
        datePairs.add(new Pair<String, String>("2075-10-13", "2019-01-27"));
        datePairs.add(new Pair<String, String>("2075-10-14", "2019-01-28"));
        datePairs.add(new Pair<String, String>("2075-10-15", "2019-01-29"));
        datePairs.add(new Pair<String, String>("2075-10-16", "2019-01-30"));
        datePairs.add(new Pair<String, String>("2075-10-17", "2019-01-31"));
        datePairs.add(new Pair<String, String>("2075-10-18", "2019-02-01"));
        datePairs.add(new Pair<String, String>("2075-10-19", "2019-02-02"));
        datePairs.add(new Pair<String, String>("2075-10-20", "2019-02-03"));
        datePairs.add(new Pair<String, String>("2075-10-21", "2019-02-04"));
        datePairs.add(new Pair<String, String>("2075-10-22", "2019-02-05"));
        datePairs.add(new Pair<String, String>("2075-10-23", "2019-02-06"));
        datePairs.add(new Pair<String, String>("2075-10-24", "2019-02-07"));
        datePairs.add(new Pair<String, String>("2075-10-25", "2019-02-08"));
        datePairs.add(new Pair<String, String>("2075-10-26", "2019-02-09"));
        datePairs.add(new Pair<String, String>("2075-10-27", "2019-02-10"));
        datePairs.add(new Pair<String, String>("2075-10-28", "2019-02-11"));
        datePairs.add(new Pair<String, String>("2075-10-29", "2019-02-12"));
        datePairs.add(new Pair<String, String>("2075-11-01", "2019-02-13"));
        datePairs.add(new Pair<String, String>("2075-11-02", "2019-02-14"));
        datePairs.add(new Pair<String, String>("2075-11-03", "2019-02-15"));
        datePairs.add(new Pair<String, String>("2075-11-04", "2019-02-16"));
        datePairs.add(new Pair<String, String>("2075-11-05", "2019-02-17"));
        datePairs.add(new Pair<String, String>("2075-11-06", "2019-02-18"));
        datePairs.add(new Pair<String, String>("2075-11-07", "2019-02-19"));
        datePairs.add(new Pair<String, String>("2075-11-08", "2019-02-20"));
        datePairs.add(new Pair<String, String>("2075-11-09", "2019-02-21"));
        datePairs.add(new Pair<String, String>("2075-11-10", "2019-02-22"));
        datePairs.add(new Pair<String, String>("2075-11-11", "2019-02-23"));
        datePairs.add(new Pair<String, String>("2075-11-12", "2019-02-24"));
        datePairs.add(new Pair<String, String>("2075-11-13", "2019-02-25"));
        datePairs.add(new Pair<String, String>("2075-11-14", "2019-02-26"));
        datePairs.add(new Pair<String, String>("2075-11-15", "2019-02-27"));
        datePairs.add(new Pair<String, String>("2075-11-16", "2019-02-28"));
        datePairs.add(new Pair<String, String>("2075-11-17", "2019-03-01"));
        datePairs.add(new Pair<String, String>("2075-11-18", "2019-03-02"));
        datePairs.add(new Pair<String, String>("2075-11-19", "2019-03-03"));
        datePairs.add(new Pair<String, String>("2075-11-20", "2019-03-04"));
        datePairs.add(new Pair<String, String>("2075-11-21", "2019-03-05"));
        datePairs.add(new Pair<String, String>("2075-11-22", "2019-03-06"));
        datePairs.add(new Pair<String, String>("2075-11-23", "2019-03-07"));
        datePairs.add(new Pair<String, String>("2075-11-24", "2019-03-08"));
        datePairs.add(new Pair<String, String>("2075-11-25", "2019-03-09"));
        datePairs.add(new Pair<String, String>("2075-11-26", "2019-03-10"));
        datePairs.add(new Pair<String, String>("2075-11-27", "2019-03-11"));
        datePairs.add(new Pair<String, String>("2075-11-28", "2019-03-12"));
        datePairs.add(new Pair<String, String>("2075-11-29", "2019-03-13"));
        datePairs.add(new Pair<String, String>("2075-11-30", "2019-03-14"));
        datePairs.add(new Pair<String, String>("2075-12-01", "2019-03-15"));
        datePairs.add(new Pair<String, String>("2075-12-02", "2019-03-16"));
        datePairs.add(new Pair<String, String>("2075-12-03", "2019-03-17"));
        datePairs.add(new Pair<String, String>("2075-12-04", "2019-03-18"));
        datePairs.add(new Pair<String, String>("2075-12-05", "2019-03-19"));
        datePairs.add(new Pair<String, String>("2075-12-06", "2019-03-20"));
        datePairs.add(new Pair<String, String>("2075-12-07", "2019-03-21"));
        datePairs.add(new Pair<String, String>("2075-12-08", "2019-03-22"));
        datePairs.add(new Pair<String, String>("2075-12-09", "2019-03-23"));
        datePairs.add(new Pair<String, String>("2075-12-10", "2019-03-24"));
        datePairs.add(new Pair<String, String>("2075-12-11", "2019-03-25"));
        datePairs.add(new Pair<String, String>("2075-12-12", "2019-03-26"));
        datePairs.add(new Pair<String, String>("2075-12-13", "2019-03-27"));
        datePairs.add(new Pair<String, String>("2075-12-14", "2019-03-28"));
        datePairs.add(new Pair<String, String>("2075-12-15", "2019-03-29"));
        datePairs.add(new Pair<String, String>("2075-12-16", "2019-03-30"));
        datePairs.add(new Pair<String, String>("2075-12-17", "2019-03-31"));
        datePairs.add(new Pair<String, String>("2075-12-18", "2019-04-01"));
        datePairs.add(new Pair<String, String>("2075-12-19", "2019-04-02"));
        datePairs.add(new Pair<String, String>("2075-12-20", "2019-04-03"));
        datePairs.add(new Pair<String, String>("2075-12-21", "2019-04-04"));
        datePairs.add(new Pair<String, String>("2075-12-22", "2019-04-05"));
        datePairs.add(new Pair<String, String>("2075-12-23", "2019-04-06"));
        datePairs.add(new Pair<String, String>("2075-12-24", "2019-04-07"));
        datePairs.add(new Pair<String, String>("2075-12-25", "2019-04-08"));
        datePairs.add(new Pair<String, String>("2075-12-26", "2019-04-09"));
        datePairs.add(new Pair<String, String>("2075-12-27", "2019-04-10"));
        datePairs.add(new Pair<String, String>("2075-12-28", "2019-04-11"));
        datePairs.add(new Pair<String, String>("2075-12-29", "2019-04-12"));
        datePairs.add(new Pair<String, String>("2075-12-30", "2019-04-13"));
        datePairs.add(new Pair<String, String>("2076-01-01", "2019-04-14"));
        datePairs.add(new Pair<String, String>("2076-01-02", "2019-04-15"));
        datePairs.add(new Pair<String, String>("2076-01-03", "2019-04-16"));
        datePairs.add(new Pair<String, String>("2076-01-04", "2019-04-17"));
        datePairs.add(new Pair<String, String>("2076-01-05", "2019-04-18"));
        datePairs.add(new Pair<String, String>("2076-01-06", "2019-04-19"));
        datePairs.add(new Pair<String, String>("2076-01-07", "2019-04-20"));
        datePairs.add(new Pair<String, String>("2076-01-08", "2019-04-21"));
        datePairs.add(new Pair<String, String>("2076-01-09", "2019-04-22"));
        datePairs.add(new Pair<String, String>("2076-01-10", "2019-04-23"));
        datePairs.add(new Pair<String, String>("2076-01-11", "2019-04-24"));
        datePairs.add(new Pair<String, String>("2076-01-12", "2019-04-25"));
        datePairs.add(new Pair<String, String>("2076-01-13", "2019-04-26"));
        datePairs.add(new Pair<String, String>("2076-01-14", "2019-04-27"));
        datePairs.add(new Pair<String, String>("2076-01-15", "2019-04-28"));
        datePairs.add(new Pair<String, String>("2076-01-16", "2019-04-29"));
        datePairs.add(new Pair<String, String>("2076-01-17", "2019-04-30"));
        datePairs.add(new Pair<String, String>("2076-01-18", "2019-05-01"));
        datePairs.add(new Pair<String, String>("2076-01-19", "2019-05-02"));
        datePairs.add(new Pair<String, String>("2076-01-20", "2019-05-03"));
        datePairs.add(new Pair<String, String>("2076-01-21", "2019-05-04"));
        datePairs.add(new Pair<String, String>("2076-01-22", "2019-05-05"));
        datePairs.add(new Pair<String, String>("2076-01-23", "2019-05-06"));
        datePairs.add(new Pair<String, String>("2076-01-24", "2019-05-07"));
        datePairs.add(new Pair<String, String>("2076-01-25", "2019-05-08"));
        datePairs.add(new Pair<String, String>("2076-01-26", "2019-05-09"));
        datePairs.add(new Pair<String, String>("2076-01-27", "2019-05-10"));
        datePairs.add(new Pair<String, String>("2076-01-28", "2019-05-11"));
        datePairs.add(new Pair<String, String>("2076-01-29", "2019-05-12"));
        datePairs.add(new Pair<String, String>("2076-01-30", "2019-05-13"));
        datePairs.add(new Pair<String, String>("2076-01-31", "2019-05-14"));
        datePairs.add(new Pair<String, String>("2076-02-01", "2019-05-15"));
        datePairs.add(new Pair<String, String>("2076-02-02", "2019-05-16"));
        datePairs.add(new Pair<String, String>("2076-02-03", "2019-05-17"));
        datePairs.add(new Pair<String, String>("2076-02-04", "2019-05-18"));
        datePairs.add(new Pair<String, String>("2076-02-05", "2019-05-19"));
        datePairs.add(new Pair<String, String>("2076-02-06", "2019-05-20"));
        datePairs.add(new Pair<String, String>("2076-02-07", "2019-05-21"));
        datePairs.add(new Pair<String, String>("2076-02-08", "2019-05-22"));
        datePairs.add(new Pair<String, String>("2076-02-09", "2019-05-23"));
        datePairs.add(new Pair<String, String>("2076-02-10", "2019-05-24"));
        datePairs.add(new Pair<String, String>("2076-02-11", "2019-05-25"));
        datePairs.add(new Pair<String, String>("2076-02-12", "2019-05-26"));
        datePairs.add(new Pair<String, String>("2076-02-13", "2019-05-27"));
        datePairs.add(new Pair<String, String>("2076-02-14", "2019-05-28"));
        datePairs.add(new Pair<String, String>("2076-02-15", "2019-05-29"));
        datePairs.add(new Pair<String, String>("2076-02-16", "2019-05-30"));
        datePairs.add(new Pair<String, String>("2076-02-17", "2019-05-31"));
        datePairs.add(new Pair<String, String>("2076-02-18", "2019-06-01"));
        datePairs.add(new Pair<String, String>("2076-02-19", "2019-06-02"));
        datePairs.add(new Pair<String, String>("2076-02-20", "2019-06-03"));
        datePairs.add(new Pair<String, String>("2076-02-21", "2019-06-04"));
        datePairs.add(new Pair<String, String>("2076-02-22", "2019-06-05"));
        datePairs.add(new Pair<String, String>("2076-02-23", "2019-06-06"));
        datePairs.add(new Pair<String, String>("2076-02-24", "2019-06-07"));
        datePairs.add(new Pair<String, String>("2076-02-25", "2019-06-08"));
        datePairs.add(new Pair<String, String>("2076-02-26", "2019-06-09"));
        datePairs.add(new Pair<String, String>("2076-02-27", "2019-06-10"));
        datePairs.add(new Pair<String, String>("2076-02-28", "2019-06-11"));
        datePairs.add(new Pair<String, String>("2076-02-29", "2019-06-12"));
        datePairs.add(new Pair<String, String>("2076-02-30", "2019-06-13"));
        datePairs.add(new Pair<String, String>("2076-02-31", "2019-06-14"));
        datePairs.add(new Pair<String, String>("2076-02-32", "2019-06-15"));
        datePairs.add(new Pair<String, String>("2076-03-01", "2019-06-16"));
        datePairs.add(new Pair<String, String>("2076-03-02", "2019-06-17"));
        datePairs.add(new Pair<String, String>("2076-03-03", "2019-06-18"));
        datePairs.add(new Pair<String, String>("2076-03-04", "2019-06-19"));
        datePairs.add(new Pair<String, String>("2076-03-05", "2019-06-20"));
        datePairs.add(new Pair<String, String>("2076-03-06", "2019-06-21"));
        datePairs.add(new Pair<String, String>("2076-03-07", "2019-06-22"));
        datePairs.add(new Pair<String, String>("2076-03-08", "2019-06-23"));
        datePairs.add(new Pair<String, String>("2076-03-09", "2019-06-24"));
        datePairs.add(new Pair<String, String>("2076-03-10", "2019-06-25"));
        datePairs.add(new Pair<String, String>("2076-03-11", "2019-06-26"));
        datePairs.add(new Pair<String, String>("2076-03-12", "2019-06-27"));
        datePairs.add(new Pair<String, String>("2076-03-13", "2019-06-28"));
        datePairs.add(new Pair<String, String>("2076-03-14", "2019-06-29"));
        datePairs.add(new Pair<String, String>("2076-03-15", "2019-06-30"));
        datePairs.add(new Pair<String, String>("2076-03-16", "2019-07-01"));
        datePairs.add(new Pair<String, String>("2076-03-17", "2019-07-02"));
        datePairs.add(new Pair<String, String>("2076-03-18", "2019-07-03"));
        datePairs.add(new Pair<String, String>("2076-03-19", "2019-07-04"));
        datePairs.add(new Pair<String, String>("2076-03-20", "2019-07-05"));
        datePairs.add(new Pair<String, String>("2076-03-21", "2019-07-06"));
        datePairs.add(new Pair<String, String>("2076-03-22", "2019-07-07"));
        datePairs.add(new Pair<String, String>("2076-03-23", "2019-07-08"));
        datePairs.add(new Pair<String, String>("2076-03-24", "2019-07-09"));
        datePairs.add(new Pair<String, String>("2076-03-25", "2019-07-10"));
        datePairs.add(new Pair<String, String>("2076-03-26", "2019-07-11"));
        datePairs.add(new Pair<String, String>("2076-03-27", "2019-07-12"));
        datePairs.add(new Pair<String, String>("2076-03-28", "2019-07-13"));
        datePairs.add(new Pair<String, String>("2076-03-29", "2019-07-14"));
        datePairs.add(new Pair<String, String>("2076-03-30", "2019-07-15"));
        datePairs.add(new Pair<String, String>("2076-03-31", "2019-07-16"));
        datePairs.add(new Pair<String, String>("2076-04-01", "2019-07-17"));
        datePairs.add(new Pair<String, String>("2076-04-02", "2019-07-18"));
        datePairs.add(new Pair<String, String>("2076-04-03", "2019-07-19"));
        datePairs.add(new Pair<String, String>("2076-04-04", "2019-07-20"));
        datePairs.add(new Pair<String, String>("2076-04-05", "2019-07-21"));
        datePairs.add(new Pair<String, String>("2076-04-06", "2019-07-22"));
        datePairs.add(new Pair<String, String>("2076-04-07", "2019-07-23"));
        datePairs.add(new Pair<String, String>("2076-04-08", "2019-07-24"));
        datePairs.add(new Pair<String, String>("2076-04-09", "2019-07-25"));
        datePairs.add(new Pair<String, String>("2076-04-10", "2019-07-26"));
        datePairs.add(new Pair<String, String>("2076-04-11", "2019-07-27"));
        datePairs.add(new Pair<String, String>("2076-04-12", "2019-07-28"));
        datePairs.add(new Pair<String, String>("2076-04-13", "2019-07-29"));
        datePairs.add(new Pair<String, String>("2076-04-14", "2019-07-30"));
        datePairs.add(new Pair<String, String>("2076-04-15", "2019-07-31"));
        datePairs.add(new Pair<String, String>("2076-04-16", "2019-08-01"));
        datePairs.add(new Pair<String, String>("2076-04-17", "2019-08-02"));
        datePairs.add(new Pair<String, String>("2076-04-18", "2019-08-03"));
        datePairs.add(new Pair<String, String>("2076-04-19", "2019-08-04"));
        datePairs.add(new Pair<String, String>("2076-04-20", "2019-08-05"));
        datePairs.add(new Pair<String, String>("2076-04-21", "2019-08-06"));
        datePairs.add(new Pair<String, String>("2076-04-22", "2019-08-07"));
        datePairs.add(new Pair<String, String>("2076-04-23", "2019-08-08"));
        datePairs.add(new Pair<String, String>("2076-04-24", "2019-08-09"));
        datePairs.add(new Pair<String, String>("2076-04-25", "2019-08-10"));
        datePairs.add(new Pair<String, String>("2076-04-26", "2019-08-11"));
        datePairs.add(new Pair<String, String>("2076-04-27", "2019-08-12"));
        datePairs.add(new Pair<String, String>("2076-04-28", "2019-08-13"));
        datePairs.add(new Pair<String, String>("2076-04-29", "2019-08-14"));
        datePairs.add(new Pair<String, String>("2076-04-30", "2019-08-15"));
        datePairs.add(new Pair<String, String>("2076-04-31", "2019-08-16"));
        datePairs.add(new Pair<String, String>("2076-04-32", "2019-08-17"));
        datePairs.add(new Pair<String, String>("2076-05-01", "2019-08-18"));
        datePairs.add(new Pair<String, String>("2076-05-02", "2019-08-19"));
        datePairs.add(new Pair<String, String>("2076-05-03", "2019-08-20"));
        datePairs.add(new Pair<String, String>("2076-05-04", "2019-08-21"));
        datePairs.add(new Pair<String, String>("2076-05-05", "2019-08-22"));
        datePairs.add(new Pair<String, String>("2076-05-06", "2019-08-23"));
        datePairs.add(new Pair<String, String>("2076-05-07", "2019-08-24"));
        datePairs.add(new Pair<String, String>("2076-05-08", "2019-08-25"));
        datePairs.add(new Pair<String, String>("2076-05-09", "2019-08-26"));
        datePairs.add(new Pair<String, String>("2076-05-10", "2019-08-27"));
        datePairs.add(new Pair<String, String>("2076-05-11", "2019-08-28"));
        datePairs.add(new Pair<String, String>("2076-05-12", "2019-08-29"));
        datePairs.add(new Pair<String, String>("2076-05-13", "2019-08-30"));
        datePairs.add(new Pair<String, String>("2076-05-14", "2019-08-31"));
        datePairs.add(new Pair<String, String>("2076-05-15", "2019-09-01"));
        datePairs.add(new Pair<String, String>("2076-05-16", "2019-09-02"));
        datePairs.add(new Pair<String, String>("2076-05-17", "2019-09-03"));
        datePairs.add(new Pair<String, String>("2076-05-18", "2019-09-04"));
        datePairs.add(new Pair<String, String>("2076-05-19", "2019-09-05"));
        datePairs.add(new Pair<String, String>("2076-05-20", "2019-09-06"));
        datePairs.add(new Pair<String, String>("2076-05-21", "2019-09-07"));
        datePairs.add(new Pair<String, String>("2076-05-22", "2019-09-08"));
        datePairs.add(new Pair<String, String>("2076-05-23", "2019-09-09"));
        datePairs.add(new Pair<String, String>("2076-05-24", "2019-09-10"));
        datePairs.add(new Pair<String, String>("2076-05-25", "2019-09-11"));
        datePairs.add(new Pair<String, String>("2076-05-26", "2019-09-12"));
        datePairs.add(new Pair<String, String>("2076-05-27", "2019-09-13"));
        datePairs.add(new Pair<String, String>("2076-05-28", "2019-09-14"));
        datePairs.add(new Pair<String, String>("2076-05-29", "2019-09-15"));
        datePairs.add(new Pair<String, String>("2076-05-30", "2019-09-16"));
        datePairs.add(new Pair<String, String>("2076-05-31", "2019-09-17"));
        datePairs.add(new Pair<String, String>("2076-06-01", "2019-09-18"));
        datePairs.add(new Pair<String, String>("2076-06-02", "2019-09-19"));
        datePairs.add(new Pair<String, String>("2076-06-03", "2019-09-20"));
        datePairs.add(new Pair<String, String>("2076-06-04", "2019-09-21"));
        datePairs.add(new Pair<String, String>("2076-06-05", "2019-09-22"));
        datePairs.add(new Pair<String, String>("2076-06-06", "2019-09-23"));
        datePairs.add(new Pair<String, String>("2076-06-07", "2019-09-24"));
        datePairs.add(new Pair<String, String>("2076-06-08", "2019-09-25"));
        datePairs.add(new Pair<String, String>("2076-06-09", "2019-09-26"));
        datePairs.add(new Pair<String, String>("2076-06-10", "2019-09-27"));
        datePairs.add(new Pair<String, String>("2076-06-11", "2019-09-28"));
        datePairs.add(new Pair<String, String>("2076-06-12", "2019-09-29"));
        datePairs.add(new Pair<String, String>("2076-06-13", "2019-09-30"));
        datePairs.add(new Pair<String, String>("2076-06-14", "2019-10-01"));
        datePairs.add(new Pair<String, String>("2076-06-15", "2019-10-02"));
        datePairs.add(new Pair<String, String>("2076-06-16", "2019-10-03"));
        datePairs.add(new Pair<String, String>("2076-06-17", "2019-10-04"));
        datePairs.add(new Pair<String, String>("2076-06-18", "2019-10-05"));
        datePairs.add(new Pair<String, String>("2076-06-19", "2019-10-06"));
        datePairs.add(new Pair<String, String>("2076-06-20", "2019-10-07"));
        datePairs.add(new Pair<String, String>("2076-06-21", "2019-10-08"));
        datePairs.add(new Pair<String, String>("2076-06-22", "2019-10-09"));
        datePairs.add(new Pair<String, String>("2076-06-23", "2019-10-10"));
        datePairs.add(new Pair<String, String>("2076-06-24", "2019-10-11"));
        datePairs.add(new Pair<String, String>("2076-06-25", "2019-10-12"));
        datePairs.add(new Pair<String, String>("2076-06-26", "2019-10-13"));
        datePairs.add(new Pair<String, String>("2076-06-27", "2019-10-14"));
        datePairs.add(new Pair<String, String>("2076-06-28", "2019-10-15"));
        datePairs.add(new Pair<String, String>("2076-06-29", "2019-10-16"));
        datePairs.add(new Pair<String, String>("2076-06-30", "2019-10-17"));
        datePairs.add(new Pair<String, String>("2076-07-01", "2019-10-18"));
        datePairs.add(new Pair<String, String>("2076-07-02", "2019-10-19"));
        datePairs.add(new Pair<String, String>("2076-07-03", "2019-10-20"));
        datePairs.add(new Pair<String, String>("2076-07-04", "2019-10-21"));
        datePairs.add(new Pair<String, String>("2076-07-05", "2019-10-22"));
        datePairs.add(new Pair<String, String>("2076-07-06", "2019-10-23"));
        datePairs.add(new Pair<String, String>("2076-07-07", "2019-10-24"));
        datePairs.add(new Pair<String, String>("2076-07-08", "2019-10-25"));
        datePairs.add(new Pair<String, String>("2076-07-09", "2019-10-26"));
        datePairs.add(new Pair<String, String>("2076-07-10", "2019-10-27"));
        datePairs.add(new Pair<String, String>("2076-07-11", "2019-10-28"));
        datePairs.add(new Pair<String, String>("2076-07-12", "2019-10-29"));
        datePairs.add(new Pair<String, String>("2076-07-13", "2019-10-30"));
        datePairs.add(new Pair<String, String>("2076-07-14", "2019-10-31"));
        datePairs.add(new Pair<String, String>("2076-07-15", "2019-11-01"));
        datePairs.add(new Pair<String, String>("2076-07-16", "2019-11-02"));
        datePairs.add(new Pair<String, String>("2076-07-17", "2019-11-03"));
        datePairs.add(new Pair<String, String>("2076-07-18", "2019-11-04"));
        datePairs.add(new Pair<String, String>("2076-07-19", "2019-11-05"));
        datePairs.add(new Pair<String, String>("2076-07-20", "2019-11-06"));
        datePairs.add(new Pair<String, String>("2076-07-21", "2019-11-07"));
        datePairs.add(new Pair<String, String>("2076-07-22", "2019-11-08"));
        datePairs.add(new Pair<String, String>("2076-07-23", "2019-11-09"));
        datePairs.add(new Pair<String, String>("2076-07-24", "2019-11-10"));
        datePairs.add(new Pair<String, String>("2076-07-25", "2019-11-11"));
        datePairs.add(new Pair<String, String>("2076-07-26", "2019-11-12"));
        datePairs.add(new Pair<String, String>("2076-07-27", "2019-11-13"));
        datePairs.add(new Pair<String, String>("2076-07-28", "2019-11-14"));
        datePairs.add(new Pair<String, String>("2076-07-29", "2019-11-15"));
        datePairs.add(new Pair<String, String>("2076-07-30", "2019-11-16"));
        datePairs.add(new Pair<String, String>("2076-08-01", "2019-11-17"));
        datePairs.add(new Pair<String, String>("2076-08-02", "2019-11-18"));
        datePairs.add(new Pair<String, String>("2076-08-03", "2019-11-19"));
        datePairs.add(new Pair<String, String>("2076-08-04", "2019-11-20"));
        datePairs.add(new Pair<String, String>("2076-08-05", "2019-11-21"));
        datePairs.add(new Pair<String, String>("2076-08-06", "2019-11-22"));
        datePairs.add(new Pair<String, String>("2076-08-07", "2019-11-23"));
        datePairs.add(new Pair<String, String>("2076-08-08", "2019-11-24"));
        datePairs.add(new Pair<String, String>("2076-08-09", "2019-11-25"));
        datePairs.add(new Pair<String, String>("2076-08-10", "2019-11-26"));
        datePairs.add(new Pair<String, String>("2076-08-11", "2019-11-27"));
        datePairs.add(new Pair<String, String>("2076-08-12", "2019-11-28"));
        datePairs.add(new Pair<String, String>("2076-08-13", "2019-11-29"));
        datePairs.add(new Pair<String, String>("2076-08-14", "2019-11-30"));
        datePairs.add(new Pair<String, String>("2076-08-15", "2019-12-01"));
        datePairs.add(new Pair<String, String>("2076-08-16", "2019-12-02"));
        datePairs.add(new Pair<String, String>("2076-08-17", "2019-12-03"));
        datePairs.add(new Pair<String, String>("2076-08-18", "2019-12-04"));
        datePairs.add(new Pair<String, String>("2076-08-19", "2019-12-05"));
        datePairs.add(new Pair<String, String>("2076-08-20", "2019-12-06"));
        datePairs.add(new Pair<String, String>("2076-08-21", "2019-12-07"));
        datePairs.add(new Pair<String, String>("2076-08-23", "2019-12-09"));
        datePairs.add(new Pair<String, String>("2076-08-24", "2019-12-10"));
        datePairs.add(new Pair<String, String>("2076-08-25", "2019-12-11"));
        datePairs.add(new Pair<String, String>("2076-08-26", "2019-12-12"));
        datePairs.add(new Pair<String, String>("2076-08-27", "2019-12-13"));
        datePairs.add(new Pair<String, String>("2076-08-28", "2019-12-14"));
        datePairs.add(new Pair<String, String>("2076-08-29", "2019-12-15"));
        datePairs.add(new Pair<String, String>("2076-08-30", "2019-12-16"));
        datePairs.add(new Pair<String, String>("2076-09-01", "2019-12-17"));
        datePairs.add(new Pair<String, String>("2076-09-02", "2019-12-18"));
        datePairs.add(new Pair<String, String>("2076-09-03", "2019-12-19"));
        datePairs.add(new Pair<String, String>("2076-09-04", "2019-12-20"));
        datePairs.add(new Pair<String, String>("2076-09-05", "2019-12-21"));
        datePairs.add(new Pair<String, String>("2076-09-06", "2019-12-22"));
        datePairs.add(new Pair<String, String>("2076-09-07", "2019-12-23"));
        datePairs.add(new Pair<String, String>("2076-09-08", "2019-12-24"));
        datePairs.add(new Pair<String, String>("2076-09-09", "2019-12-25"));
        datePairs.add(new Pair<String, String>("2076-09-10", "2019-12-26"));
        datePairs.add(new Pair<String, String>("2076-09-11", "2019-12-27"));
        datePairs.add(new Pair<String, String>("2076-09-12", "2019-12-28"));
        datePairs.add(new Pair<String, String>("2076-09-13", "2019-12-29"));
        datePairs.add(new Pair<String, String>("2076-09-14", "2019-12-30"));
        datePairs.add(new Pair<String, String>("2076-09-15", "2019-12-31"));
        datePairs.add(new Pair<String, String>("2076-09-16", "2020-01-01"));
        datePairs.add(new Pair<String, String>("2076-09-17", "2020-01-02"));
        datePairs.add(new Pair<String, String>("2076-09-18", "2020-01-03"));
        datePairs.add(new Pair<String, String>("2076-09-19", "2020-01-04"));
        datePairs.add(new Pair<String, String>("2076-09-20", "2020-01-05"));
        datePairs.add(new Pair<String, String>("2076-09-21", "2020-01-06"));
        datePairs.add(new Pair<String, String>("2076-09-22", "2020-01-07"));
        datePairs.add(new Pair<String, String>("2076-09-23", "2020-01-08"));
        datePairs.add(new Pair<String, String>("2076-09-24", "2020-01-09"));
        datePairs.add(new Pair<String, String>("2076-09-25", "2020-01-10"));
        datePairs.add(new Pair<String, String>("2076-09-26", "2020-01-11"));
        datePairs.add(new Pair<String, String>("2076-09-27", "2020-01-12"));
        datePairs.add(new Pair<String, String>("2076-09-28", "2020-01-13"));
        datePairs.add(new Pair<String, String>("2076-09-29", "2020-01-14"));
        datePairs.add(new Pair<String, String>("2076-10-01", "2020-01-15"));
        datePairs.add(new Pair<String, String>("2076-10-02", "2020-01-16"));
        datePairs.add(new Pair<String, String>("2076-10-03", "2020-01-17"));
        datePairs.add(new Pair<String, String>("2076-10-04", "2020-01-18"));
        datePairs.add(new Pair<String, String>("2076-10-05", "2020-01-19"));
        datePairs.add(new Pair<String, String>("2076-10-06", "2020-01-20"));
        datePairs.add(new Pair<String, String>("2076-10-07", "2020-01-21"));
        datePairs.add(new Pair<String, String>("2076-10-08", "2020-01-22"));
        datePairs.add(new Pair<String, String>("2076-10-09", "2020-01-23"));
        datePairs.add(new Pair<String, String>("2076-10-10", "2020-01-24"));
        datePairs.add(new Pair<String, String>("2076-10-11", "2020-01-25"));
        datePairs.add(new Pair<String, String>("2076-10-12", "2020-01-26"));
        datePairs.add(new Pair<String, String>("2076-10-13", "2020-01-27"));
        datePairs.add(new Pair<String, String>("2076-10-14", "2020-01-28"));
        datePairs.add(new Pair<String, String>("2076-10-15", "2020-01-29"));
        datePairs.add(new Pair<String, String>("2076-10-16", "2020-01-30"));
        datePairs.add(new Pair<String, String>("2076-10-17", "2020-01-31"));
        datePairs.add(new Pair<String, String>("2076-10-18", "2020-02-01"));
        datePairs.add(new Pair<String, String>("2076-10-19", "2020-02-02"));
        datePairs.add(new Pair<String, String>("2076-10-20", "2020-02-03"));
        datePairs.add(new Pair<String, String>("2076-10-21", "2020-02-04"));
        datePairs.add(new Pair<String, String>("2076-10-22", "2020-02-05"));
        datePairs.add(new Pair<String, String>("2076-10-23", "2020-02-06"));
        datePairs.add(new Pair<String, String>("2076-10-24", "2020-02-07"));
        datePairs.add(new Pair<String, String>("2076-10-25", "2020-02-08"));
        datePairs.add(new Pair<String, String>("2076-10-26", "2020-02-09"));
        datePairs.add(new Pair<String, String>("2076-10-27", "2020-02-10"));
        datePairs.add(new Pair<String, String>("2076-10-28", "2020-02-11"));
        datePairs.add(new Pair<String, String>("2076-10-29", "2020-02-12"));
        datePairs.add(new Pair<String, String>("2076-11-01", "2020-02-13"));
        datePairs.add(new Pair<String, String>("2076-11-02", "2020-02-14"));
        datePairs.add(new Pair<String, String>("2076-11-03", "2020-02-15"));
        datePairs.add(new Pair<String, String>("2076-11-04", "2020-02-16"));
        datePairs.add(new Pair<String, String>("2076-11-05", "2020-02-17"));
        datePairs.add(new Pair<String, String>("2076-11-06", "2020-02-18"));
        datePairs.add(new Pair<String, String>("2076-11-07", "2020-02-19"));
        datePairs.add(new Pair<String, String>("2076-11-08", "2020-02-20"));
        datePairs.add(new Pair<String, String>("2076-11-09", "2020-02-21"));
        datePairs.add(new Pair<String, String>("2076-11-10", "2020-02-22"));
        datePairs.add(new Pair<String, String>("2076-11-11", "2020-02-23"));
        datePairs.add(new Pair<String, String>("2076-11-12", "2020-02-24"));
        datePairs.add(new Pair<String, String>("2076-11-13", "2020-02-25"));
        datePairs.add(new Pair<String, String>("2076-11-14", "2020-02-26"));
        datePairs.add(new Pair<String, String>("2076-11-15", "2020-02-27"));
        datePairs.add(new Pair<String, String>("2076-11-16", "2020-02-28"));
        datePairs.add(new Pair<String, String>("2076-11-17", "2020-02-29"));
        datePairs.add(new Pair<String, String>("2076-11-18", "2020-03-01"));
        datePairs.add(new Pair<String, String>("2076-11-19", "2020-03-02"));
        datePairs.add(new Pair<String, String>("2076-11-20", "2020-03-03"));
        datePairs.add(new Pair<String, String>("2076-11-21", "2020-03-04"));
        datePairs.add(new Pair<String, String>("2076-11-22", "2020-03-05"));
        datePairs.add(new Pair<String, String>("2076-11-23", "2020-03-06"));
        datePairs.add(new Pair<String, String>("2076-11-24", "2020-03-07"));
        datePairs.add(new Pair<String, String>("2076-11-25", "2020-03-08"));
        datePairs.add(new Pair<String, String>("2076-11-26", "2020-03-09"));
        datePairs.add(new Pair<String, String>("2076-11-27", "2020-03-10"));
        datePairs.add(new Pair<String, String>("2076-11-28", "2020-03-11"));
        datePairs.add(new Pair<String, String>("2076-11-29", "2020-03-12"));
        datePairs.add(new Pair<String, String>("2076-11-30", "2020-03-13"));
        datePairs.add(new Pair<String, String>("2076-12-01", "2020-03-14"));
        datePairs.add(new Pair<String, String>("2076-12-02", "2020-03-15"));
        datePairs.add(new Pair<String, String>("2076-12-03", "2020-03-16"));
        datePairs.add(new Pair<String, String>("2076-12-04", "2020-03-17"));
        datePairs.add(new Pair<String, String>("2076-12-05", "2020-03-18"));
        datePairs.add(new Pair<String, String>("2076-12-06", "2020-03-19"));
        datePairs.add(new Pair<String, String>("2076-12-07", "2020-03-20"));
        datePairs.add(new Pair<String, String>("2076-12-08", "2020-03-21"));
        datePairs.add(new Pair<String, String>("2076-12-09", "2020-03-22"));
        datePairs.add(new Pair<String, String>("2076-12-10", "2020-03-23"));
        datePairs.add(new Pair<String, String>("2076-12-11", "2020-03-24"));
        datePairs.add(new Pair<String, String>("2076-12-12", "2020-03-25"));
        datePairs.add(new Pair<String, String>("2076-12-13", "2020-03-26"));
        datePairs.add(new Pair<String, String>("2076-12-14", "2020-03-27"));
        datePairs.add(new Pair<String, String>("2076-12-15", "2020-03-28"));
        datePairs.add(new Pair<String, String>("2076-12-16", "2020-03-29"));
        datePairs.add(new Pair<String, String>("2076-12-17", "2020-03-30"));
        datePairs.add(new Pair<String, String>("2076-12-18", "2020-03-31"));
        datePairs.add(new Pair<String, String>("2076-12-19", "2020-04-01"));
        datePairs.add(new Pair<String, String>("2076-12-20", "2020-04-02"));
        datePairs.add(new Pair<String, String>("2076-12-21", "2020-04-03"));
        datePairs.add(new Pair<String, String>("2076-12-22", "2020-04-04"));
        datePairs.add(new Pair<String, String>("2076-12-23", "2020-04-05"));
        datePairs.add(new Pair<String, String>("2076-12-24", "2020-04-06"));
        datePairs.add(new Pair<String, String>("2076-12-25", "2020-04-07"));
        datePairs.add(new Pair<String, String>("2076-12-26", "2020-04-08"));
        datePairs.add(new Pair<String, String>("2076-12-27", "2020-04-09"));
        datePairs.add(new Pair<String, String>("2076-12-28", "2020-04-10"));
        datePairs.add(new Pair<String, String>("2076-12-29", "2020-04-11"));
        datePairs.add(new Pair<String, String>("2076-12-30", "2020-04-12"));
        datePairs.add(new Pair<String, String>("2077-01-01", "2020-04-13"));
        datePairs.add(new Pair<String, String>("2077-01-02", "2020-04-14"));
        datePairs.add(new Pair<String, String>("2077-01-03", "2020-04-15"));
        datePairs.add(new Pair<String, String>("2077-01-04", "2020-04-16"));
        datePairs.add(new Pair<String, String>("2077-01-05", "2020-04-17"));
        datePairs.add(new Pair<String, String>("2077-01-06", "2020-04-18"));
        datePairs.add(new Pair<String, String>("2077-01-07", "2020-04-19"));
        datePairs.add(new Pair<String, String>("2077-01-08", "2020-04-20"));
        datePairs.add(new Pair<String, String>("2077-01-09", "2020-04-21"));
        datePairs.add(new Pair<String, String>("2077-01-10", "2020-04-22"));
        datePairs.add(new Pair<String, String>("2077-01-11", "2020-04-23"));
        datePairs.add(new Pair<String, String>("2077-01-12", "2020-04-24"));
        datePairs.add(new Pair<String, String>("2077-01-13", "2020-04-25"));
        datePairs.add(new Pair<String, String>("2077-01-14", "2020-04-26"));
        datePairs.add(new Pair<String, String>("2077-01-15", "2020-04-27"));
        datePairs.add(new Pair<String, String>("2077-01-16", "2020-04-28"));
        datePairs.add(new Pair<String, String>("2077-01-17", "2020-04-29"));
        datePairs.add(new Pair<String, String>("2077-01-18", "2020-04-30"));
        datePairs.add(new Pair<String, String>("2077-01-19", "2020-05-01"));
        datePairs.add(new Pair<String, String>("2077-01-20", "2020-05-02"));
        datePairs.add(new Pair<String, String>("2077-01-21", "2020-05-03"));
        datePairs.add(new Pair<String, String>("2077-01-22", "2020-05-04"));
        datePairs.add(new Pair<String, String>("2077-01-23", "2020-05-05"));
        datePairs.add(new Pair<String, String>("2077-01-24", "2020-05-06"));
        datePairs.add(new Pair<String, String>("2077-01-25", "2020-05-07"));
        datePairs.add(new Pair<String, String>("2077-01-26", "2020-05-08"));
        datePairs.add(new Pair<String, String>("2077-01-27", "2020-05-09"));
        datePairs.add(new Pair<String, String>("2077-01-28", "2020-05-10"));
        datePairs.add(new Pair<String, String>("2077-01-29", "2020-05-11"));
        datePairs.add(new Pair<String, String>("2077-01-30", "2020-05-12"));
        datePairs.add(new Pair<String, String>("2077-01-31", "2020-05-13"));
        datePairs.add(new Pair<String, String>("2077-02-01", "2020-05-14"));
        datePairs.add(new Pair<String, String>("2077-02-02", "2020-05-15"));
        datePairs.add(new Pair<String, String>("2077-02-03", "2020-05-16"));
        datePairs.add(new Pair<String, String>("2077-02-04", "2020-05-17"));
        datePairs.add(new Pair<String, String>("2077-02-05", "2020-05-18"));
        datePairs.add(new Pair<String, String>("2077-02-06", "2020-05-19"));
        datePairs.add(new Pair<String, String>("2077-02-07", "2020-05-20"));
        datePairs.add(new Pair<String, String>("2077-02-08", "2020-05-21"));
        datePairs.add(new Pair<String, String>("2077-02-09", "2020-05-22"));
        datePairs.add(new Pair<String, String>("2077-02-10", "2020-05-23"));
        datePairs.add(new Pair<String, String>("2077-02-11", "2020-05-24"));
        datePairs.add(new Pair<String, String>("2077-02-12", "2020-05-25"));
        datePairs.add(new Pair<String, String>("2077-02-13", "2020-05-26"));
        datePairs.add(new Pair<String, String>("2077-02-14", "2020-05-27"));
        datePairs.add(new Pair<String, String>("2077-02-15", "2020-05-28"));
        datePairs.add(new Pair<String, String>("2077-02-16", "2020-05-29"));
        datePairs.add(new Pair<String, String>("2077-02-17", "2020-05-30"));
        datePairs.add(new Pair<String, String>("2077-02-18", "2020-05-31"));
        datePairs.add(new Pair<String, String>("2077-02-19", "2020-06-01"));
        datePairs.add(new Pair<String, String>("2077-02-20", "2020-06-02"));
        datePairs.add(new Pair<String, String>("2077-02-21", "2020-06-03"));
        datePairs.add(new Pair<String, String>("2077-02-22", "2020-06-04"));
        datePairs.add(new Pair<String, String>("2077-02-23", "2020-06-05"));
        datePairs.add(new Pair<String, String>("2077-02-24", "2020-06-06"));
        datePairs.add(new Pair<String, String>("2077-02-25", "2020-06-07"));
        datePairs.add(new Pair<String, String>("2077-02-26", "2020-06-08"));
        datePairs.add(new Pair<String, String>("2077-02-27", "2020-06-09"));
        datePairs.add(new Pair<String, String>("2077-02-28", "2020-06-10"));
        datePairs.add(new Pair<String, String>("2077-02-29", "2020-06-11"));
        datePairs.add(new Pair<String, String>("2077-02-30", "2020-06-12"));
        datePairs.add(new Pair<String, String>("2077-02-31", "2020-06-13"));
        datePairs.add(new Pair<String, String>("2077-02-32", "2020-06-14"));
        datePairs.add(new Pair<String, String>("2077-03-01", "2020-06-15"));
        datePairs.add(new Pair<String, String>("2077-03-02", "2020-06-16"));
        datePairs.add(new Pair<String, String>("2077-03-03", "2020-06-17"));
        datePairs.add(new Pair<String, String>("2077-03-04", "2020-06-18"));
        datePairs.add(new Pair<String, String>("2077-03-05", "2020-06-19"));
        datePairs.add(new Pair<String, String>("2077-03-06", "2020-06-20"));
        datePairs.add(new Pair<String, String>("2077-03-07", "2020-06-21"));
        datePairs.add(new Pair<String, String>("2077-03-08", "2020-06-22"));
        datePairs.add(new Pair<String, String>("2077-03-09", "2020-06-23"));
        datePairs.add(new Pair<String, String>("2077-03-10", "2020-06-24"));
        datePairs.add(new Pair<String, String>("2077-03-11", "2020-06-25"));
        datePairs.add(new Pair<String, String>("2077-03-12", "2020-06-26"));
        datePairs.add(new Pair<String, String>("2077-03-13", "2020-06-27"));
        datePairs.add(new Pair<String, String>("2077-03-14", "2020-06-28"));
        datePairs.add(new Pair<String, String>("2077-03-15", "2020-06-29"));
        datePairs.add(new Pair<String, String>("2077-03-16", "2020-06-30"));
        datePairs.add(new Pair<String, String>("2077-03-17", "2020-07-01"));
        datePairs.add(new Pair<String, String>("2077-03-18", "2020-07-02"));
        datePairs.add(new Pair<String, String>("2077-03-19", "2020-07-03"));
        datePairs.add(new Pair<String, String>("2077-03-20", "2020-07-04"));
        datePairs.add(new Pair<String, String>("2077-03-21", "2020-07-05"));
        datePairs.add(new Pair<String, String>("2077-03-22", "2020-07-06"));
        datePairs.add(new Pair<String, String>("2077-03-23", "2020-07-07"));
        datePairs.add(new Pair<String, String>("2077-03-24", "2020-07-08"));
        datePairs.add(new Pair<String, String>("2077-03-25", "2020-07-09"));
        datePairs.add(new Pair<String, String>("2077-03-26", "2020-07-10"));
        datePairs.add(new Pair<String, String>("2077-03-27", "2020-07-11"));
        datePairs.add(new Pair<String, String>("2077-03-28", "2020-07-12"));
        datePairs.add(new Pair<String, String>("2077-03-29", "2020-07-13"));
        datePairs.add(new Pair<String, String>("2077-03-30", "2020-07-14"));
        datePairs.add(new Pair<String, String>("2077-03-31", "2020-07-15"));
        datePairs.add(new Pair<String, String>("2077-04-01", "2020-07-16"));
        datePairs.add(new Pair<String, String>("2077-04-02", "2020-07-17"));
        datePairs.add(new Pair<String, String>("2077-04-03", "2020-07-18"));
        datePairs.add(new Pair<String, String>("2077-04-04", "2020-07-19"));
        datePairs.add(new Pair<String, String>("2077-04-05", "2020-07-20"));
        datePairs.add(new Pair<String, String>("2077-04-06", "2020-07-21"));
        datePairs.add(new Pair<String, String>("2077-04-07", "2020-07-22"));
        datePairs.add(new Pair<String, String>("2077-04-08", "2020-07-23"));
        datePairs.add(new Pair<String, String>("2077-04-09", "2020-07-24"));
        datePairs.add(new Pair<String, String>("2077-04-10", "2020-07-25"));
        datePairs.add(new Pair<String, String>("2077-04-11", "2020-07-26"));
        datePairs.add(new Pair<String, String>("2077-04-12", "2020-07-27"));
        datePairs.add(new Pair<String, String>("2077-04-13", "2020-07-28"));
        datePairs.add(new Pair<String, String>("2077-04-14", "2020-07-29"));
        datePairs.add(new Pair<String, String>("2077-04-15", "2020-07-30"));
        datePairs.add(new Pair<String, String>("2077-04-16", "2020-07-31"));
        datePairs.add(new Pair<String, String>("2077-04-17", "2020-08-01"));
        datePairs.add(new Pair<String, String>("2077-04-18", "2020-08-02"));
        datePairs.add(new Pair<String, String>("2077-04-19", "2020-08-03"));
        datePairs.add(new Pair<String, String>("2077-04-20", "2020-08-04"));
        datePairs.add(new Pair<String, String>("2077-04-21", "2020-08-05"));
        datePairs.add(new Pair<String, String>("2077-04-22", "2020-08-06"));
        datePairs.add(new Pair<String, String>("2077-04-23", "2020-08-07"));
        datePairs.add(new Pair<String, String>("2077-04-24", "2020-08-08"));
        datePairs.add(new Pair<String, String>("2077-04-25", "2020-08-09"));
        datePairs.add(new Pair<String, String>("2077-04-26", "2020-08-10"));
        datePairs.add(new Pair<String, String>("2077-04-27", "2020-08-11"));
        datePairs.add(new Pair<String, String>("2077-04-28", "2020-08-12"));
        datePairs.add(new Pair<String, String>("2077-04-29", "2020-08-13"));
        datePairs.add(new Pair<String, String>("2077-04-30", "2020-08-14"));
        datePairs.add(new Pair<String, String>("2077-04-31", "2020-08-15"));
        datePairs.add(new Pair<String, String>("2077-04-32", "2020-08-16"));
        datePairs.add(new Pair<String, String>("2077-05-01", "2020-08-17"));
        datePairs.add(new Pair<String, String>("2077-05-02", "2020-08-18"));
        datePairs.add(new Pair<String, String>("2077-05-03", "2020-08-19"));
        datePairs.add(new Pair<String, String>("2077-05-04", "2020-08-20"));
        datePairs.add(new Pair<String, String>("2077-05-05", "2020-08-21"));
        datePairs.add(new Pair<String, String>("2077-05-06", "2020-08-22"));
        datePairs.add(new Pair<String, String>("2077-05-07", "2020-08-23"));
        datePairs.add(new Pair<String, String>("2077-05-08", "2020-08-24"));
        datePairs.add(new Pair<String, String>("2077-05-09", "2020-08-25"));
        datePairs.add(new Pair<String, String>("2077-05-10", "2020-08-26"));
        datePairs.add(new Pair<String, String>("2077-05-11", "2020-08-27"));
        datePairs.add(new Pair<String, String>("2077-05-12", "2020-08-28"));
        datePairs.add(new Pair<String, String>("2077-05-13", "2020-08-29"));
        datePairs.add(new Pair<String, String>("2077-05-14", "2020-08-30"));
        datePairs.add(new Pair<String, String>("2077-05-15", "2020-08-31"));
        datePairs.add(new Pair<String, String>("2077-05-16", "2020-09-01"));
        datePairs.add(new Pair<String, String>("2077-05-17", "2020-09-02"));
        datePairs.add(new Pair<String, String>("2077-05-18", "2020-09-03"));
        datePairs.add(new Pair<String, String>("2077-05-19", "2020-09-04"));
        datePairs.add(new Pair<String, String>("2077-05-20", "2020-09-05"));
        datePairs.add(new Pair<String, String>("2077-05-21", "2020-09-06"));
        datePairs.add(new Pair<String, String>("2077-05-22", "2020-09-07"));
        datePairs.add(new Pair<String, String>("2077-05-23", "2020-09-08"));
        datePairs.add(new Pair<String, String>("2077-05-24", "2020-09-09"));
        datePairs.add(new Pair<String, String>("2077-05-25", "2020-09-10"));
        datePairs.add(new Pair<String, String>("2077-05-26", "2020-09-11"));
        datePairs.add(new Pair<String, String>("2077-05-27", "2020-09-12"));
        datePairs.add(new Pair<String, String>("2077-05-28", "2020-09-13"));
        datePairs.add(new Pair<String, String>("2077-05-29", "2020-09-14"));
        datePairs.add(new Pair<String, String>("2077-05-30", "2020-09-15"));
        datePairs.add(new Pair<String, String>("2077-05-31", "2020-09-16"));
        datePairs.add(new Pair<String, String>("2077-06-01", "2020-09-17"));
        datePairs.add(new Pair<String, String>("2077-06-02", "2020-09-18"));
        datePairs.add(new Pair<String, String>("2077-06-03", "2020-09-19"));
        datePairs.add(new Pair<String, String>("2077-06-04", "2020-09-20"));
        datePairs.add(new Pair<String, String>("2077-06-05", "2020-09-21"));
        datePairs.add(new Pair<String, String>("2077-06-06", "2020-09-22"));
        datePairs.add(new Pair<String, String>("2077-06-07", "2020-09-23"));
        datePairs.add(new Pair<String, String>("2077-06-08", "2020-09-24"));
        datePairs.add(new Pair<String, String>("2077-06-09", "2020-09-25"));
        datePairs.add(new Pair<String, String>("2077-06-10", "2020-09-26"));
        datePairs.add(new Pair<String, String>("2077-06-11", "2020-09-27"));
        datePairs.add(new Pair<String, String>("2077-06-12", "2020-09-28"));
        datePairs.add(new Pair<String, String>("2077-06-13", "2020-09-29"));
        datePairs.add(new Pair<String, String>("2077-06-14", "2020-09-30"));
        datePairs.add(new Pair<String, String>("2077-06-15", "2020-10-01"));
        datePairs.add(new Pair<String, String>("2077-06-16", "2020-10-02"));
        datePairs.add(new Pair<String, String>("2077-06-17", "2020-10-03"));
        datePairs.add(new Pair<String, String>("2077-06-18", "2020-10-04"));
        datePairs.add(new Pair<String, String>("2077-06-19", "2020-10-05"));
        datePairs.add(new Pair<String, String>("2077-06-20", "2020-10-06"));
        datePairs.add(new Pair<String, String>("2077-06-21", "2020-10-07"));
        datePairs.add(new Pair<String, String>("2077-06-22", "2020-10-08"));
        datePairs.add(new Pair<String, String>("2077-06-23", "2020-10-09"));
        datePairs.add(new Pair<String, String>("2077-06-24", "2020-10-10"));
        datePairs.add(new Pair<String, String>("2077-06-25", "2020-10-11"));
        datePairs.add(new Pair<String, String>("2077-06-26", "2020-10-12"));
        datePairs.add(new Pair<String, String>("2077-06-27", "2020-10-13"));
        datePairs.add(new Pair<String, String>("2077-06-28", "2020-10-14"));
        datePairs.add(new Pair<String, String>("2077-06-29", "2020-10-15"));
        datePairs.add(new Pair<String, String>("2077-06-30", "2020-10-16"));
        datePairs.add(new Pair<String, String>("2077-07-01", "2020-10-17"));
        datePairs.add(new Pair<String, String>("2077-07-02", "2020-10-18"));
        datePairs.add(new Pair<String, String>("2077-07-03", "2020-10-19"));
        datePairs.add(new Pair<String, String>("2077-07-04", "2020-10-20"));
        datePairs.add(new Pair<String, String>("2077-07-05", "2020-10-21"));
        datePairs.add(new Pair<String, String>("2077-07-06", "2020-10-22"));
        datePairs.add(new Pair<String, String>("2077-07-07", "2020-10-23"));
        datePairs.add(new Pair<String, String>("2077-07-08", "2020-10-24"));
        datePairs.add(new Pair<String, String>("2077-07-09", "2020-10-25"));
        datePairs.add(new Pair<String, String>("2077-07-10", "2020-10-26"));
        datePairs.add(new Pair<String, String>("2077-07-11", "2020-10-27"));
        datePairs.add(new Pair<String, String>("2077-07-12", "2020-10-28"));
        datePairs.add(new Pair<String, String>("2077-07-13", "2020-10-29"));
        datePairs.add(new Pair<String, String>("2077-07-14", "2020-10-30"));
        datePairs.add(new Pair<String, String>("2077-07-15", "2020-10-31"));
        datePairs.add(new Pair<String, String>("2077-07-16", "2020-11-01"));
        datePairs.add(new Pair<String, String>("2077-07-17", "2020-11-02"));
        datePairs.add(new Pair<String, String>("2077-07-18", "2020-11-03"));
        datePairs.add(new Pair<String, String>("2077-07-19", "2020-11-04"));
        datePairs.add(new Pair<String, String>("2077-07-20", "2020-11-05"));
        datePairs.add(new Pair<String, String>("2077-07-21", "2020-11-06"));
        datePairs.add(new Pair<String, String>("2077-07-22", "2020-11-07"));
        datePairs.add(new Pair<String, String>("2077-07-23", "2020-11-08"));
        datePairs.add(new Pair<String, String>("2077-07-24", "2020-11-09"));
        datePairs.add(new Pair<String, String>("2077-07-25", "2020-11-10"));
        datePairs.add(new Pair<String, String>("2077-07-26", "2020-11-11"));
        datePairs.add(new Pair<String, String>("2077-07-27", "2020-11-12"));
        datePairs.add(new Pair<String, String>("2077-07-28", "2020-11-13"));
        datePairs.add(new Pair<String, String>("2077-07-29", "2020-11-14"));
        datePairs.add(new Pair<String, String>("2077-07-30", "2020-11-15"));
        datePairs.add(new Pair<String, String>("2077-08-01", "2020-11-16"));
        datePairs.add(new Pair<String, String>("2077-08-02", "2020-11-17"));
        datePairs.add(new Pair<String, String>("2077-08-03", "2020-11-18"));
        datePairs.add(new Pair<String, String>("2077-08-04", "2020-11-19"));
        datePairs.add(new Pair<String, String>("2077-08-05", "2020-11-20"));
        datePairs.add(new Pair<String, String>("2077-08-06", "2020-11-21"));
        datePairs.add(new Pair<String, String>("2077-08-07", "2020-11-22"));
        datePairs.add(new Pair<String, String>("2077-08-08", "2020-11-23"));
        datePairs.add(new Pair<String, String>("2077-08-09", "2020-11-24"));
        datePairs.add(new Pair<String, String>("2077-08-10", "2020-11-25"));
        datePairs.add(new Pair<String, String>("2077-08-11", "2020-11-26"));
        datePairs.add(new Pair<String, String>("2077-08-12", "2020-11-27"));
        datePairs.add(new Pair<String, String>("2077-08-13", "2020-11-28"));
        datePairs.add(new Pair<String, String>("2077-08-14", "2020-11-29"));
        datePairs.add(new Pair<String, String>("2077-08-15", "2020-11-30"));
        datePairs.add(new Pair<String, String>("2077-08-16", "2020-12-01"));
        datePairs.add(new Pair<String, String>("2077-08-17", "2020-12-02"));
        datePairs.add(new Pair<String, String>("2077-08-18", "2020-12-03"));
        datePairs.add(new Pair<String, String>("2077-08-19", "2020-12-04"));
        datePairs.add(new Pair<String, String>("2077-08-20", "2020-12-05"));
        datePairs.add(new Pair<String, String>("2077-08-21", "2020-12-06"));
        datePairs.add(new Pair<String, String>("2077-08-22", "2020-12-07"));
        datePairs.add(new Pair<String, String>("2077-08-23", "2020-12-08"));
        datePairs.add(new Pair<String, String>("2077-08-24", "2020-12-09"));
        datePairs.add(new Pair<String, String>("2077-08-25", "2020-12-10"));
        datePairs.add(new Pair<String, String>("2077-08-26", "2020-12-11"));
        datePairs.add(new Pair<String, String>("2077-08-27", "2020-12-12"));
        datePairs.add(new Pair<String, String>("2077-08-28", "2020-12-13"));
        datePairs.add(new Pair<String, String>("2077-08-29", "2020-12-14"));
        datePairs.add(new Pair<String, String>("2077-08-30", "2020-12-15"));
        datePairs.add(new Pair<String, String>("2077-09-01", "2020-12-16"));
        datePairs.add(new Pair<String, String>("2077-09-02", "2020-12-17"));
        datePairs.add(new Pair<String, String>("2077-09-03", "2020-12-18"));
        datePairs.add(new Pair<String, String>("2077-09-04", "2020-12-19"));
        datePairs.add(new Pair<String, String>("2077-09-05", "2020-12-20"));
        datePairs.add(new Pair<String, String>("2077-09-06", "2020-12-21"));
        datePairs.add(new Pair<String, String>("2077-09-07", "2020-12-22"));
        datePairs.add(new Pair<String, String>("2077-09-08", "2020-12-23"));
        datePairs.add(new Pair<String, String>("2077-09-09", "2020-12-24"));
        datePairs.add(new Pair<String, String>("2077-09-10", "2020-12-25"));
        datePairs.add(new Pair<String, String>("2077-09-11", "2020-12-26"));
        datePairs.add(new Pair<String, String>("2077-09-12", "2020-12-27"));
        datePairs.add(new Pair<String, String>("2077-09-13", "2020-12-28"));
        datePairs.add(new Pair<String, String>("2077-09-14", "2020-12-29"));
        datePairs.add(new Pair<String, String>("2077-09-15", "2020-12-30"));
        datePairs.add(new Pair<String, String>("2077-09-16", "2020-12-31"));
        datePairs.add(new Pair<String, String>("2077-09-17", "2021-01-01"));
        datePairs.add(new Pair<String, String>("2077-09-18", "2021-01-02"));
        datePairs.add(new Pair<String, String>("2077-09-19", "2021-01-03"));
        datePairs.add(new Pair<String, String>("2077-09-20", "2021-01-04"));
        datePairs.add(new Pair<String, String>("2077-09-21", "2021-01-05"));
        datePairs.add(new Pair<String, String>("2077-09-22", "2021-01-06"));
        datePairs.add(new Pair<String, String>("2077-09-23", "2021-01-07"));
        datePairs.add(new Pair<String, String>("2077-09-24", "2021-01-08"));
        datePairs.add(new Pair<String, String>("2077-09-25", "2021-01-09"));
        datePairs.add(new Pair<String, String>("2077-09-26", "2021-01-10"));
        datePairs.add(new Pair<String, String>("2077-09-27", "2021-01-11"));
        datePairs.add(new Pair<String, String>("2077-09-28", "2021-01-12"));
        datePairs.add(new Pair<String, String>("2077-09-29", "2021-01-13"));
        datePairs.add(new Pair<String, String>("2077-10-01", "2021-01-14"));
        datePairs.add(new Pair<String, String>("2077-10-02", "2021-01-15"));
        datePairs.add(new Pair<String, String>("2077-10-03", "2021-01-16"));
        datePairs.add(new Pair<String, String>("2077-10-04", "2021-01-17"));
        datePairs.add(new Pair<String, String>("2077-10-05", "2021-01-18"));
        datePairs.add(new Pair<String, String>("2077-10-06", "2021-01-19"));
        datePairs.add(new Pair<String, String>("2077-10-07", "2021-01-20"));
        datePairs.add(new Pair<String, String>("2077-10-08", "2021-01-21"));
        datePairs.add(new Pair<String, String>("2077-10-09", "2021-01-22"));
        datePairs.add(new Pair<String, String>("2077-10-10", "2021-01-23"));
        datePairs.add(new Pair<String, String>("2077-10-11", "2021-01-24"));
        datePairs.add(new Pair<String, String>("2077-10-12", "2021-01-25"));
        datePairs.add(new Pair<String, String>("2077-10-13", "2021-01-26"));
        datePairs.add(new Pair<String, String>("2077-10-14", "2021-01-27"));
        datePairs.add(new Pair<String, String>("2077-10-15", "2021-01-28"));
        datePairs.add(new Pair<String, String>("2077-10-16", "2021-01-29"));
        datePairs.add(new Pair<String, String>("2077-10-17", "2021-01-30"));
        datePairs.add(new Pair<String, String>("2077-10-18", "2021-01-31"));
        datePairs.add(new Pair<String, String>("2077-10-19", "2021-02-01"));
        datePairs.add(new Pair<String, String>("2077-10-20", "2021-02-02"));
        datePairs.add(new Pair<String, String>("2077-10-21", "2021-02-03"));
        datePairs.add(new Pair<String, String>("2077-10-22", "2021-02-04"));
        datePairs.add(new Pair<String, String>("2077-10-23", "2021-02-05"));
        datePairs.add(new Pair<String, String>("2077-10-24", "2021-02-06"));
        datePairs.add(new Pair<String, String>("2077-10-25", "2021-02-07"));
        datePairs.add(new Pair<String, String>("2077-10-26", "2021-02-08"));
        datePairs.add(new Pair<String, String>("2077-10-27", "2021-02-09"));
        datePairs.add(new Pair<String, String>("2077-10-28", "2021-02-10"));
        datePairs.add(new Pair<String, String>("2077-10-29", "2021-02-11"));
        datePairs.add(new Pair<String, String>("2077-10-30", "2021-02-12"));
        datePairs.add(new Pair<String, String>("2077-11-01", "2021-02-13"));
        datePairs.add(new Pair<String, String>("2077-11-02", "2021-02-14"));
        datePairs.add(new Pair<String, String>("2077-11-03", "2021-02-15"));
        datePairs.add(new Pair<String, String>("2077-11-04", "2021-02-16"));
        datePairs.add(new Pair<String, String>("2077-11-05", "2021-02-17"));
        datePairs.add(new Pair<String, String>("2077-11-06", "2021-02-18"));
        datePairs.add(new Pair<String, String>("2077-11-07", "2021-02-19"));
        datePairs.add(new Pair<String, String>("2077-11-08", "2021-02-20"));
        datePairs.add(new Pair<String, String>("2077-11-09", "2021-02-21"));
        datePairs.add(new Pair<String, String>("2077-11-10", "2021-02-22"));
        datePairs.add(new Pair<String, String>("2077-11-11", "2021-02-23"));
        datePairs.add(new Pair<String, String>("2077-11-12", "2021-02-24"));
        datePairs.add(new Pair<String, String>("2077-11-13", "2021-02-25"));
        datePairs.add(new Pair<String, String>("2077-11-14", "2021-02-26"));
        datePairs.add(new Pair<String, String>("2077-11-15", "2021-02-27"));
        datePairs.add(new Pair<String, String>("2077-11-16", "2021-02-28"));
        datePairs.add(new Pair<String, String>("2077-11-17", "2021-03-01"));
        datePairs.add(new Pair<String, String>("2077-11-18", "2021-03-02"));
        datePairs.add(new Pair<String, String>("2077-11-19", "2021-03-03"));
        datePairs.add(new Pair<String, String>("2077-11-20", "2021-03-04"));
        datePairs.add(new Pair<String, String>("2077-11-21", "2021-03-05"));
        datePairs.add(new Pair<String, String>("2077-11-22", "2021-03-06"));
        datePairs.add(new Pair<String, String>("2077-11-23", "2021-03-07"));
        datePairs.add(new Pair<String, String>("2077-11-24", "2021-03-08"));
        datePairs.add(new Pair<String, String>("2077-11-25", "2021-03-09"));
        datePairs.add(new Pair<String, String>("2077-11-26", "2021-03-10"));
        datePairs.add(new Pair<String, String>("2077-11-27", "2021-03-11"));
        datePairs.add(new Pair<String, String>("2077-11-28", "2021-03-12"));
        datePairs.add(new Pair<String, String>("2077-11-29", "2021-03-13"));
        datePairs.add(new Pair<String, String>("2077-12-01", "2021-03-14"));
        datePairs.add(new Pair<String, String>("2077-12-02", "2021-03-15"));
        datePairs.add(new Pair<String, String>("2077-12-03", "2021-03-16"));
        datePairs.add(new Pair<String, String>("2077-12-04", "2021-03-17"));
        datePairs.add(new Pair<String, String>("2077-12-05", "2021-03-18"));
        datePairs.add(new Pair<String, String>("2077-12-06", "2021-03-19"));
        datePairs.add(new Pair<String, String>("2077-12-07", "2021-03-20"));
        datePairs.add(new Pair<String, String>("2077-12-08", "2021-03-21"));
        datePairs.add(new Pair<String, String>("2077-12-09", "2021-03-22"));
        datePairs.add(new Pair<String, String>("2077-12-10", "2021-03-23"));
        datePairs.add(new Pair<String, String>("2077-12-11", "2021-03-24"));
        datePairs.add(new Pair<String, String>("2077-12-12", "2021-03-25"));
        datePairs.add(new Pair<String, String>("2077-12-13", "2021-03-26"));
        datePairs.add(new Pair<String, String>("2077-12-14", "2021-03-27"));
        datePairs.add(new Pair<String, String>("2077-12-15", "2021-03-28"));
        datePairs.add(new Pair<String, String>("2077-12-16", "2021-03-29"));
        datePairs.add(new Pair<String, String>("2077-12-17", "2021-03-30"));
        datePairs.add(new Pair<String, String>("2077-12-18", "2021-03-31"));
        datePairs.add(new Pair<String, String>("2077-12-19", "2021-04-01"));
        datePairs.add(new Pair<String, String>("2077-12-20", "2021-04-02"));
        datePairs.add(new Pair<String, String>("2077-12-21", "2021-04-03"));
        datePairs.add(new Pair<String, String>("2077-12-22", "2021-04-04"));
        datePairs.add(new Pair<String, String>("2077-12-23", "2021-04-05"));
        datePairs.add(new Pair<String, String>("2077-12-24", "2021-04-06"));
        datePairs.add(new Pair<String, String>("2077-12-25", "2021-04-07"));
        datePairs.add(new Pair<String, String>("2077-12-26", "2021-04-08"));
        datePairs.add(new Pair<String, String>("2077-12-27", "2021-04-09"));
        datePairs.add(new Pair<String, String>("2077-12-28", "2021-04-10"));
        datePairs.add(new Pair<String, String>("2077-12-29", "2021-04-11"));
        datePairs.add(new Pair<String, String>("2077-12-30", "2021-04-12"));
        datePairs.add(new Pair<String, String>("2077-12-31", "2021-04-13"));
    }

    public void appendConversionValues4() {
        datePairs.add(new Pair<String, String>("2078-01-01", "2021-04-14"));
        datePairs.add(new Pair<String, String>("2078-01-02", "2021-04-15"));
        datePairs.add(new Pair<String, String>("2078-01-03", "2021-04-16"));
        datePairs.add(new Pair<String, String>("2078-01-04", "2021-04-17"));
        datePairs.add(new Pair<String, String>("2078-01-05", "2021-04-18"));
        datePairs.add(new Pair<String, String>("2078-01-06", "2021-04-19"));
        datePairs.add(new Pair<String, String>("2078-01-07", "2021-04-20"));
        datePairs.add(new Pair<String, String>("2078-01-08", "2021-04-21"));
        datePairs.add(new Pair<String, String>("2078-01-09", "2021-04-22"));
        datePairs.add(new Pair<String, String>("2078-01-10", "2021-04-23"));
        datePairs.add(new Pair<String, String>("2078-01-11", "2021-04-24"));
        datePairs.add(new Pair<String, String>("2078-01-12", "2021-04-25"));
        datePairs.add(new Pair<String, String>("2078-01-13", "2021-04-26"));
        datePairs.add(new Pair<String, String>("2078-01-14", "2021-04-27"));
        datePairs.add(new Pair<String, String>("2078-01-15", "2021-04-28"));
        datePairs.add(new Pair<String, String>("2078-01-16", "2021-04-29"));
        datePairs.add(new Pair<String, String>("2078-01-17", "2021-04-30"));
        datePairs.add(new Pair<String, String>("2078-01-18", "2021-05-01"));
        datePairs.add(new Pair<String, String>("2078-01-19", "2021-05-02"));
        datePairs.add(new Pair<String, String>("2078-01-20", "2021-05-03"));
        datePairs.add(new Pair<String, String>("2078-01-21", "2021-05-04"));
        datePairs.add(new Pair<String, String>("2078-01-22", "2021-05-05"));
        datePairs.add(new Pair<String, String>("2078-01-23", "2021-05-06"));
        datePairs.add(new Pair<String, String>("2078-01-24", "2021-05-07"));
        datePairs.add(new Pair<String, String>("2078-01-25", "2021-05-08"));
        datePairs.add(new Pair<String, String>("2078-01-26", "2021-05-09"));
        datePairs.add(new Pair<String, String>("2078-01-27", "2021-05-10"));
        datePairs.add(new Pair<String, String>("2078-01-28", "2021-05-11"));
        datePairs.add(new Pair<String, String>("2078-01-29", "2021-05-12"));
        datePairs.add(new Pair<String, String>("2078-01-30", "2021-05-13"));
        datePairs.add(new Pair<String, String>("2078-01-31", "2021-05-14"));
        datePairs.add(new Pair<String, String>("2078-02-01", "2021-05-15"));
        datePairs.add(new Pair<String, String>("2078-02-02", "2021-05-16"));
        datePairs.add(new Pair<String, String>("2078-02-03", "2021-05-17"));
        datePairs.add(new Pair<String, String>("2078-02-04", "2021-05-18"));
        datePairs.add(new Pair<String, String>("2078-02-05", "2021-05-19"));
        datePairs.add(new Pair<String, String>("2078-02-06", "2021-05-20"));
        datePairs.add(new Pair<String, String>("2078-02-07", "2021-05-21"));
        datePairs.add(new Pair<String, String>("2078-02-08", "2021-05-22"));
        datePairs.add(new Pair<String, String>("2078-02-09", "2021-05-23"));
        datePairs.add(new Pair<String, String>("2078-02-10", "2021-05-24"));
        datePairs.add(new Pair<String, String>("2078-02-11", "2021-05-25"));
        datePairs.add(new Pair<String, String>("2078-02-12", "2021-05-26"));
        datePairs.add(new Pair<String, String>("2078-02-13", "2021-05-27"));
        datePairs.add(new Pair<String, String>("2078-02-14", "2021-05-28"));
        datePairs.add(new Pair<String, String>("2078-02-15", "2021-05-29"));
        datePairs.add(new Pair<String, String>("2078-02-16", "2021-05-30"));
        datePairs.add(new Pair<String, String>("2078-02-17", "2021-05-31"));
        datePairs.add(new Pair<String, String>("2078-02-18", "2021-06-01"));
        datePairs.add(new Pair<String, String>("2078-02-19", "2021-06-02"));
        datePairs.add(new Pair<String, String>("2078-02-20", "2021-06-03"));
        datePairs.add(new Pair<String, String>("2078-02-21", "2021-06-04"));
        datePairs.add(new Pair<String, String>("2078-02-22", "2021-06-05"));
        datePairs.add(new Pair<String, String>("2078-02-23", "2021-06-06"));
        datePairs.add(new Pair<String, String>("2078-02-24", "2021-06-07"));
        datePairs.add(new Pair<String, String>("2078-02-25", "2021-06-08"));
        datePairs.add(new Pair<String, String>("2078-02-26", "2021-06-09"));
        datePairs.add(new Pair<String, String>("2078-02-27", "2021-06-10"));
        datePairs.add(new Pair<String, String>("2078-02-28", "2021-06-11"));
        datePairs.add(new Pair<String, String>("2078-02-29", "2021-06-12"));
        datePairs.add(new Pair<String, String>("2078-02-30", "2021-06-13"));
        datePairs.add(new Pair<String, String>("2078-02-31", "2021-06-14"));
        datePairs.add(new Pair<String, String>("2078-03-01", "2021-06-15"));
        datePairs.add(new Pair<String, String>("2078-03-02", "2021-06-16"));
        datePairs.add(new Pair<String, String>("2078-03-03", "2021-06-17"));
        datePairs.add(new Pair<String, String>("2078-03-04", "2021-06-18"));
        datePairs.add(new Pair<String, String>("2078-03-05", "2021-06-19"));
        datePairs.add(new Pair<String, String>("2078-03-06", "2021-06-20"));
        datePairs.add(new Pair<String, String>("2078-03-07", "2021-06-21"));
        datePairs.add(new Pair<String, String>("2078-03-08", "2021-06-22"));
        datePairs.add(new Pair<String, String>("2078-03-09", "2021-06-23"));
        datePairs.add(new Pair<String, String>("2078-03-10", "2021-06-24"));
        datePairs.add(new Pair<String, String>("2078-03-11", "2021-06-25"));
        datePairs.add(new Pair<String, String>("2078-03-12", "2021-06-26"));
        datePairs.add(new Pair<String, String>("2078-03-13", "2021-06-27"));
        datePairs.add(new Pair<String, String>("2078-03-14", "2021-06-28"));
        datePairs.add(new Pair<String, String>("2078-03-15", "2021-06-29"));
        datePairs.add(new Pair<String, String>("2078-03-16", "2021-06-30"));
        datePairs.add(new Pair<String, String>("2078-03-17", "2021-07-01"));
        datePairs.add(new Pair<String, String>("2078-03-18", "2021-07-02"));
        datePairs.add(new Pair<String, String>("2078-03-19", "2021-07-03"));
        datePairs.add(new Pair<String, String>("2078-03-20", "2021-07-04"));
        datePairs.add(new Pair<String, String>("2078-03-21", "2021-07-05"));
        datePairs.add(new Pair<String, String>("2078-03-22", "2021-07-06"));
        datePairs.add(new Pair<String, String>("2078-03-23", "2021-07-07"));
        datePairs.add(new Pair<String, String>("2078-03-24", "2021-07-08"));
        datePairs.add(new Pair<String, String>("2078-03-25", "2021-07-09"));
        datePairs.add(new Pair<String, String>("2078-03-26", "2021-07-10"));
        datePairs.add(new Pair<String, String>("2078-03-27", "2021-07-11"));
        datePairs.add(new Pair<String, String>("2078-03-28", "2021-07-12"));
        datePairs.add(new Pair<String, String>("2078-03-29", "2021-07-13"));
        datePairs.add(new Pair<String, String>("2078-03-30", "2021-07-14"));
        datePairs.add(new Pair<String, String>("2078-03-31", "2021-07-15"));
        datePairs.add(new Pair<String, String>("2078-04-01", "2021-07-16"));
        datePairs.add(new Pair<String, String>("2078-04-02", "2021-07-17"));
        datePairs.add(new Pair<String, String>("2078-04-03", "2021-07-18"));
        datePairs.add(new Pair<String, String>("2078-04-04", "2021-07-19"));
        datePairs.add(new Pair<String, String>("2078-04-05", "2021-07-20"));
        datePairs.add(new Pair<String, String>("2078-04-06", "2021-07-21"));
        datePairs.add(new Pair<String, String>("2078-04-07", "2021-07-22"));
        datePairs.add(new Pair<String, String>("2078-04-08", "2021-07-23"));
        datePairs.add(new Pair<String, String>("2078-04-09", "2021-07-24"));
        datePairs.add(new Pair<String, String>("2078-04-10", "2021-07-25"));
        datePairs.add(new Pair<String, String>("2078-04-11", "2021-07-26"));
        datePairs.add(new Pair<String, String>("2078-04-12", "2021-07-27"));
        datePairs.add(new Pair<String, String>("2078-04-13", "2021-07-28"));
        datePairs.add(new Pair<String, String>("2078-04-14", "2021-07-29"));
        datePairs.add(new Pair<String, String>("2078-04-15", "2021-07-30"));
        datePairs.add(new Pair<String, String>("2078-04-16", "2021-07-31"));
        datePairs.add(new Pair<String, String>("2078-04-17", "2021-08-01"));
        datePairs.add(new Pair<String, String>("2078-04-18", "2021-08-02"));
        datePairs.add(new Pair<String, String>("2078-04-19", "2021-08-03"));
        datePairs.add(new Pair<String, String>("2078-04-20", "2021-08-04"));
        datePairs.add(new Pair<String, String>("2078-04-21", "2021-08-05"));
        datePairs.add(new Pair<String, String>("2078-04-22", "2021-08-06"));
        datePairs.add(new Pair<String, String>("2078-04-23", "2021-08-07"));
        datePairs.add(new Pair<String, String>("2078-04-24", "2021-08-08"));
        datePairs.add(new Pair<String, String>("2078-04-25", "2021-08-09"));
        datePairs.add(new Pair<String, String>("2078-04-26", "2021-08-10"));
        datePairs.add(new Pair<String, String>("2078-04-27", "2021-08-11"));
        datePairs.add(new Pair<String, String>("2078-04-28", "2021-08-12"));
        datePairs.add(new Pair<String, String>("2078-04-29", "2021-08-13"));
        datePairs.add(new Pair<String, String>("2078-04-30", "2021-08-14"));
        datePairs.add(new Pair<String, String>("2078-04-31", "2021-08-15"));
        datePairs.add(new Pair<String, String>("2078-04-32", "2021-08-16"));
        datePairs.add(new Pair<String, String>("2078-05-01", "2021-08-17"));
        datePairs.add(new Pair<String, String>("2078-05-02", "2021-08-18"));
        datePairs.add(new Pair<String, String>("2078-05-03", "2021-08-19"));
        datePairs.add(new Pair<String, String>("2078-05-04", "2021-08-20"));
        datePairs.add(new Pair<String, String>("2078-05-05", "2021-08-21"));
        datePairs.add(new Pair<String, String>("2078-05-06", "2021-08-22"));
        datePairs.add(new Pair<String, String>("2078-05-07", "2021-08-23"));
        datePairs.add(new Pair<String, String>("2078-05-08", "2021-08-24"));
        datePairs.add(new Pair<String, String>("2078-05-09", "2021-08-25"));
        datePairs.add(new Pair<String, String>("2078-05-10", "2021-08-26"));
        datePairs.add(new Pair<String, String>("2078-05-11", "2021-08-27"));
        datePairs.add(new Pair<String, String>("2078-05-12", "2021-08-28"));
        datePairs.add(new Pair<String, String>("2078-05-13", "2021-08-29"));
        datePairs.add(new Pair<String, String>("2078-05-14", "2021-08-30"));
        datePairs.add(new Pair<String, String>("2078-05-15", "2021-08-31"));
        datePairs.add(new Pair<String, String>("2078-05-16", "2021-09-01"));
        datePairs.add(new Pair<String, String>("2078-05-17", "2021-09-02"));
        datePairs.add(new Pair<String, String>("2078-05-18", "2021-09-03"));
        datePairs.add(new Pair<String, String>("2078-05-19", "2021-09-04"));
        datePairs.add(new Pair<String, String>("2078-05-20", "2021-09-05"));
        datePairs.add(new Pair<String, String>("2078-05-21", "2021-09-06"));
        datePairs.add(new Pair<String, String>("2078-05-22", "2021-09-07"));
        datePairs.add(new Pair<String, String>("2078-05-23", "2021-09-08"));
        datePairs.add(new Pair<String, String>("2078-05-24", "2021-09-09"));
        datePairs.add(new Pair<String, String>("2078-05-25", "2021-09-10"));
        datePairs.add(new Pair<String, String>("2078-05-26", "2021-09-11"));
        datePairs.add(new Pair<String, String>("2078-05-27", "2021-09-12"));
        datePairs.add(new Pair<String, String>("2078-05-28", "2021-09-13"));
        datePairs.add(new Pair<String, String>("2078-05-29", "2021-09-14"));
        datePairs.add(new Pair<String, String>("2078-05-30", "2021-09-15"));
        datePairs.add(new Pair<String, String>("2078-05-31", "2021-09-16"));
        datePairs.add(new Pair<String, String>("2078-06-01", "2021-09-17"));
        datePairs.add(new Pair<String, String>("2078-06-02", "2021-09-18"));
        datePairs.add(new Pair<String, String>("2078-06-03", "2021-09-19"));
        datePairs.add(new Pair<String, String>("2078-06-04", "2021-09-20"));
        datePairs.add(new Pair<String, String>("2078-06-05", "2021-09-21"));
        datePairs.add(new Pair<String, String>("2078-06-06", "2021-09-22"));
        datePairs.add(new Pair<String, String>("2078-06-07", "2021-09-23"));
        datePairs.add(new Pair<String, String>("2078-06-08", "2021-09-24"));
        datePairs.add(new Pair<String, String>("2078-06-09", "2021-09-25"));
        datePairs.add(new Pair<String, String>("2078-06-10", "2021-09-26"));
        datePairs.add(new Pair<String, String>("2078-06-11", "2021-09-27"));
        datePairs.add(new Pair<String, String>("2078-06-12", "2021-09-28"));
        datePairs.add(new Pair<String, String>("2078-06-13", "2021-09-29"));
        datePairs.add(new Pair<String, String>("2078-06-14", "2021-09-30"));
        datePairs.add(new Pair<String, String>("2078-06-15", "2021-10-01"));
        datePairs.add(new Pair<String, String>("2078-06-16", "2021-10-02"));
        datePairs.add(new Pair<String, String>("2078-06-17", "2021-10-03"));
        datePairs.add(new Pair<String, String>("2078-06-18", "2021-10-04"));
        datePairs.add(new Pair<String, String>("2078-06-19", "2021-10-05"));
        datePairs.add(new Pair<String, String>("2078-06-20", "2021-10-06"));
        datePairs.add(new Pair<String, String>("2078-06-21", "2021-10-07"));
        datePairs.add(new Pair<String, String>("2078-06-22", "2021-10-08"));
        datePairs.add(new Pair<String, String>("2078-06-23", "2021-10-09"));
        datePairs.add(new Pair<String, String>("2078-06-24", "2021-10-10"));
        datePairs.add(new Pair<String, String>("2078-06-25", "2021-10-11"));
        datePairs.add(new Pair<String, String>("2078-06-26", "2021-10-12"));
        datePairs.add(new Pair<String, String>("2078-06-27", "2021-10-13"));
        datePairs.add(new Pair<String, String>("2078-06-28", "2021-10-14"));
        datePairs.add(new Pair<String, String>("2078-06-29", "2021-10-15"));
        datePairs.add(new Pair<String, String>("2078-06-30", "2021-10-16"));
        datePairs.add(new Pair<String, String>("2078-06-31", "2021-10-17"));
        datePairs.add(new Pair<String, String>("2078-07-01", "2021-10-18"));
        datePairs.add(new Pair<String, String>("2078-07-02", "2021-10-19"));
        datePairs.add(new Pair<String, String>("2078-07-03", "2021-10-20"));
        datePairs.add(new Pair<String, String>("2078-07-04", "2021-10-21"));
        datePairs.add(new Pair<String, String>("2078-07-05", "2021-10-22"));
        datePairs.add(new Pair<String, String>("2078-07-06", "2021-10-23"));
        datePairs.add(new Pair<String, String>("2078-07-07", "2021-10-24"));
        datePairs.add(new Pair<String, String>("2078-07-08", "2021-10-25"));
        datePairs.add(new Pair<String, String>("2078-07-09", "2021-10-26"));
        datePairs.add(new Pair<String, String>("2078-07-10", "2021-10-27"));
        datePairs.add(new Pair<String, String>("2078-07-11", "2021-10-28"));
        datePairs.add(new Pair<String, String>("2078-07-12", "2021-10-29"));
        datePairs.add(new Pair<String, String>("2078-07-13", "2021-10-30"));
        datePairs.add(new Pair<String, String>("2078-07-14", "2021-10-31"));
        datePairs.add(new Pair<String, String>("2078-07-15", "2021-11-01"));
        datePairs.add(new Pair<String, String>("2078-07-16", "2021-11-02"));
        datePairs.add(new Pair<String, String>("2078-07-17", "2021-11-03"));
        datePairs.add(new Pair<String, String>("2078-07-18", "2021-11-04"));
        datePairs.add(new Pair<String, String>("2078-07-19", "2021-11-05"));
        datePairs.add(new Pair<String, String>("2078-07-20", "2021-11-06"));
        datePairs.add(new Pair<String, String>("2078-07-21", "2021-11-07"));
        datePairs.add(new Pair<String, String>("2078-07-22", "2021-11-08"));
        datePairs.add(new Pair<String, String>("2078-07-23", "2021-11-09"));
        datePairs.add(new Pair<String, String>("2078-07-24", "2021-11-10"));
        datePairs.add(new Pair<String, String>("2078-07-25", "2021-11-11"));
        datePairs.add(new Pair<String, String>("2078-07-26", "2021-11-12"));
        datePairs.add(new Pair<String, String>("2078-07-27", "2021-11-13"));
        datePairs.add(new Pair<String, String>("2078-07-28", "2021-11-14"));
        datePairs.add(new Pair<String, String>("2078-07-29", "2021-11-15"));
        datePairs.add(new Pair<String, String>("2078-07-30", "2021-11-16"));
        datePairs.add(new Pair<String, String>("2078-08-01", "2021-11-17"));
        datePairs.add(new Pair<String, String>("2078-08-02", "2021-11-18"));
        datePairs.add(new Pair<String, String>("2078-08-03", "2021-11-19"));
        datePairs.add(new Pair<String, String>("2078-08-04", "2021-11-20"));
        datePairs.add(new Pair<String, String>("2078-08-05", "2021-11-21"));
        datePairs.add(new Pair<String, String>("2078-08-06", "2021-11-22"));
        datePairs.add(new Pair<String, String>("2078-08-07", "2021-11-23"));
        datePairs.add(new Pair<String, String>("2078-08-08", "2021-11-24"));
        datePairs.add(new Pair<String, String>("2078-08-09", "2021-11-25"));
        datePairs.add(new Pair<String, String>("2078-08-10", "2021-11-26"));
        datePairs.add(new Pair<String, String>("2078-08-11", "2021-11-27"));
        datePairs.add(new Pair<String, String>("2078-08-12", "2021-11-28"));
        datePairs.add(new Pair<String, String>("2078-08-13", "2021-11-29"));
        datePairs.add(new Pair<String, String>("2078-08-14", "2021-11-30"));
        datePairs.add(new Pair<String, String>("2078-08-15", "2021-12-01"));
        datePairs.add(new Pair<String, String>("2078-08-16", "2021-12-02"));
        datePairs.add(new Pair<String, String>("2078-08-17", "2021-12-03"));
        datePairs.add(new Pair<String, String>("2078-08-18", "2021-12-04"));
        datePairs.add(new Pair<String, String>("2078-08-19", "2021-12-05"));
        datePairs.add(new Pair<String, String>("2078-08-20", "2021-12-06"));
        datePairs.add(new Pair<String, String>("2078-08-21", "2021-12-07"));
        datePairs.add(new Pair<String, String>("2078-08-22", "2021-12-08"));
        datePairs.add(new Pair<String, String>("2078-08-23", "2021-12-09"));
        datePairs.add(new Pair<String, String>("2078-08-24", "2021-12-10"));
        datePairs.add(new Pair<String, String>("2078-08-25", "2021-12-11"));
        datePairs.add(new Pair<String, String>("2078-08-26", "2021-12-12"));
        datePairs.add(new Pair<String, String>("2078-08-27", "2021-12-13"));
        datePairs.add(new Pair<String, String>("2078-08-28", "2021-12-14"));
        datePairs.add(new Pair<String, String>("2078-08-29", "2021-12-15"));
        datePairs.add(new Pair<String, String>("2078-09-01", "2021-12-16"));
        datePairs.add(new Pair<String, String>("2078-09-02", "2021-12-17"));
        datePairs.add(new Pair<String, String>("2078-09-03", "2021-12-18"));
        datePairs.add(new Pair<String, String>("2078-09-04", "2021-12-19"));
        datePairs.add(new Pair<String, String>("2078-09-05", "2021-12-20"));
        datePairs.add(new Pair<String, String>("2078-09-06", "2021-12-21"));
        datePairs.add(new Pair<String, String>("2078-09-07", "2021-12-22"));
        datePairs.add(new Pair<String, String>("2078-09-08", "2021-12-23"));
        datePairs.add(new Pair<String, String>("2078-09-09", "2021-12-24"));
        datePairs.add(new Pair<String, String>("2078-09-10", "2021-12-25"));
        datePairs.add(new Pair<String, String>("2078-09-11", "2021-12-26"));
        datePairs.add(new Pair<String, String>("2078-09-12", "2021-12-27"));
        datePairs.add(new Pair<String, String>("2078-09-13", "2021-12-28"));
        datePairs.add(new Pair<String, String>("2078-09-14", "2021-12-29"));
        datePairs.add(new Pair<String, String>("2078-09-15", "2021-12-30"));
        datePairs.add(new Pair<String, String>("2078-09-16", "2021-12-31"));
        datePairs.add(new Pair<String, String>("2078-09-17", "2022-01-01"));
        datePairs.add(new Pair<String, String>("2078-09-18", "2022-01-02"));
        datePairs.add(new Pair<String, String>("2078-09-19", "2022-01-03"));
        datePairs.add(new Pair<String, String>("2078-09-20", "2022-01-04"));
        datePairs.add(new Pair<String, String>("2078-09-21", "2022-01-05"));
        datePairs.add(new Pair<String, String>("2078-09-22", "2022-01-06"));
        datePairs.add(new Pair<String, String>("2078-09-23", "2022-01-07"));
        datePairs.add(new Pair<String, String>("2078-09-24", "2022-01-08"));
        datePairs.add(new Pair<String, String>("2078-09-25", "2022-01-09"));
        datePairs.add(new Pair<String, String>("2078-09-26", "2022-01-10"));
        datePairs.add(new Pair<String, String>("2078-09-27", "2022-01-11"));
        datePairs.add(new Pair<String, String>("2078-09-28", "2022-01-12"));
        datePairs.add(new Pair<String, String>("2078-09-29", "2022-01-13"));
        datePairs.add(new Pair<String, String>("2078-09-30", "2022-01-14"));
        datePairs.add(new Pair<String, String>("2078-10-01", "2022-01-15"));
        datePairs.add(new Pair<String, String>("2078-10-02", "2022-01-16"));
        datePairs.add(new Pair<String, String>("2078-10-03", "2022-01-17"));
        datePairs.add(new Pair<String, String>("2078-10-04", "2022-01-18"));
        datePairs.add(new Pair<String, String>("2078-10-05", "2022-01-19"));
        datePairs.add(new Pair<String, String>("2078-10-06", "2022-01-20"));
        datePairs.add(new Pair<String, String>("2078-10-07", "2022-01-21"));
        datePairs.add(new Pair<String, String>("2078-10-08", "2022-01-22"));
        datePairs.add(new Pair<String, String>("2078-10-09", "2022-01-23"));
        datePairs.add(new Pair<String, String>("2078-10-10", "2022-01-24"));
        datePairs.add(new Pair<String, String>("2078-10-11", "2022-01-25"));
        datePairs.add(new Pair<String, String>("2078-10-12", "2022-01-26"));
        datePairs.add(new Pair<String, String>("2078-10-13", "2022-01-27"));
        datePairs.add(new Pair<String, String>("2078-10-14", "2022-01-28"));
        datePairs.add(new Pair<String, String>("2078-10-15", "2022-01-29"));
        datePairs.add(new Pair<String, String>("2078-10-16", "2022-01-30"));
        datePairs.add(new Pair<String, String>("2078-10-17", "2022-01-31"));
        datePairs.add(new Pair<String, String>("2078-10-18", "2022-02-01"));
        datePairs.add(new Pair<String, String>("2078-10-19", "2022-02-02"));
        datePairs.add(new Pair<String, String>("2078-10-20", "2022-02-03"));
        datePairs.add(new Pair<String, String>("2078-10-21", "2022-02-04"));
        datePairs.add(new Pair<String, String>("2078-10-22", "2022-02-05"));
        datePairs.add(new Pair<String, String>("2078-10-23", "2022-02-06"));
        datePairs.add(new Pair<String, String>("2078-10-24", "2022-02-07"));
        datePairs.add(new Pair<String, String>("2078-10-25", "2022-02-08"));
        datePairs.add(new Pair<String, String>("2078-10-26", "2022-02-09"));
        datePairs.add(new Pair<String, String>("2078-10-27", "2022-02-10"));
        datePairs.add(new Pair<String, String>("2078-10-28", "2022-02-11"));
        datePairs.add(new Pair<String, String>("2078-10-29", "2022-02-12"));
        datePairs.add(new Pair<String, String>("2078-11-01", "2022-02-13"));
        datePairs.add(new Pair<String, String>("2078-11-02", "2022-02-14"));
        datePairs.add(new Pair<String, String>("2078-11-03", "2022-02-15"));
        datePairs.add(new Pair<String, String>("2078-11-04", "2022-02-16"));
        datePairs.add(new Pair<String, String>("2078-11-05", "2022-02-17"));
        datePairs.add(new Pair<String, String>("2078-11-06", "2022-02-18"));
        datePairs.add(new Pair<String, String>("2078-11-07", "2022-02-19"));
        datePairs.add(new Pair<String, String>("2078-11-08", "2022-02-20"));
        datePairs.add(new Pair<String, String>("2078-11-09", "2022-02-21"));
        datePairs.add(new Pair<String, String>("2078-11-10", "2022-02-22"));
        datePairs.add(new Pair<String, String>("2078-11-11", "2022-02-23"));
        datePairs.add(new Pair<String, String>("2078-11-12", "2022-02-24"));
        datePairs.add(new Pair<String, String>("2078-11-13", "2022-02-25"));
        datePairs.add(new Pair<String, String>("2078-11-14", "2022-02-26"));
        datePairs.add(new Pair<String, String>("2078-11-15", "2022-02-27"));
        datePairs.add(new Pair<String, String>("2078-11-16", "2022-02-28"));
        datePairs.add(new Pair<String, String>("2078-11-17", "2022-03-01"));
        datePairs.add(new Pair<String, String>("2078-11-18", "2022-03-02"));
        datePairs.add(new Pair<String, String>("2078-11-19", "2022-03-03"));
        datePairs.add(new Pair<String, String>("2078-11-20", "2022-03-04"));
        datePairs.add(new Pair<String, String>("2078-11-21", "2022-03-05"));
        datePairs.add(new Pair<String, String>("2078-11-22", "2022-03-06"));
        datePairs.add(new Pair<String, String>("2078-11-23", "2022-03-07"));
        datePairs.add(new Pair<String, String>("2078-11-24", "2022-03-08"));
        datePairs.add(new Pair<String, String>("2078-11-25", "2022-03-09"));
        datePairs.add(new Pair<String, String>("2078-11-26", "2022-03-10"));
        datePairs.add(new Pair<String, String>("2078-11-27", "2022-03-11"));
        datePairs.add(new Pair<String, String>("2078-11-28", "2022-03-12"));
        datePairs.add(new Pair<String, String>("2078-11-29", "2022-03-13"));
        datePairs.add(new Pair<String, String>("2078-11-30", "2022-03-14"));
        datePairs.add(new Pair<String, String>("2078-12-01", "2022-03-15"));
        datePairs.add(new Pair<String, String>("2078-12-02", "2022-03-16"));
        datePairs.add(new Pair<String, String>("2078-12-03", "2022-03-17"));
        datePairs.add(new Pair<String, String>("2078-12-04", "2022-03-18"));
        datePairs.add(new Pair<String, String>("2078-12-05", "2022-03-19"));
        datePairs.add(new Pair<String, String>("2078-12-06", "2022-03-20"));
        datePairs.add(new Pair<String, String>("2078-12-07", "2022-03-21"));
        datePairs.add(new Pair<String, String>("2078-12-08", "2022-03-22"));
        datePairs.add(new Pair<String, String>("2078-12-09", "2022-03-23"));
        datePairs.add(new Pair<String, String>("2078-12-10", "2022-03-24"));
        datePairs.add(new Pair<String, String>("2078-12-11", "2022-03-25"));
        datePairs.add(new Pair<String, String>("2078-12-12", "2022-03-26"));
        datePairs.add(new Pair<String, String>("2078-12-13", "2022-03-27"));
        datePairs.add(new Pair<String, String>("2078-12-14", "2022-03-28"));
        datePairs.add(new Pair<String, String>("2078-12-15", "2022-03-29"));
        datePairs.add(new Pair<String, String>("2078-12-16", "2022-03-30"));
        datePairs.add(new Pair<String, String>("2078-12-17", "2022-03-31"));
        datePairs.add(new Pair<String, String>("2078-12-18", "2022-04-01"));
        datePairs.add(new Pair<String, String>("2078-12-19", "2022-04-02"));
        datePairs.add(new Pair<String, String>("2078-12-20", "2022-04-03"));
        datePairs.add(new Pair<String, String>("2078-12-21", "2022-04-04"));
        datePairs.add(new Pair<String, String>("2078-12-22", "2022-04-05"));
        datePairs.add(new Pair<String, String>("2078-12-23", "2022-04-06"));
        datePairs.add(new Pair<String, String>("2078-12-24", "2022-04-07"));
        datePairs.add(new Pair<String, String>("2078-12-25", "2022-04-08"));
        datePairs.add(new Pair<String, String>("2078-12-26", "2022-04-09"));
        datePairs.add(new Pair<String, String>("2078-12-27", "2022-04-10"));
        datePairs.add(new Pair<String, String>("2078-12-28", "2022-04-11"));
        datePairs.add(new Pair<String, String>("2078-12-29", "2022-04-12"));
        datePairs.add(new Pair<String, String>("2078-12-30", "2022-04-13"));
        datePairs.add(new Pair<String, String>("2079-01-01", "2022-04-14"));
        datePairs.add(new Pair<String, String>("2079-01-02", "2022-04-15"));
        datePairs.add(new Pair<String, String>("2079-01-03", "2022-04-16"));
        datePairs.add(new Pair<String, String>("2079-01-04", "2022-04-17"));
        datePairs.add(new Pair<String, String>("2079-01-05", "2022-04-18"));
        datePairs.add(new Pair<String, String>("2079-01-06", "2022-04-19"));
        datePairs.add(new Pair<String, String>("2079-01-07", "2022-04-20"));
        datePairs.add(new Pair<String, String>("2079-01-08", "2022-04-21"));
        datePairs.add(new Pair<String, String>("2079-01-09", "2022-04-22"));
        datePairs.add(new Pair<String, String>("2079-01-10", "2022-04-23"));
        datePairs.add(new Pair<String, String>("2079-01-11", "2022-04-24"));
        datePairs.add(new Pair<String, String>("2079-01-12", "2022-04-25"));
        datePairs.add(new Pair<String, String>("2079-01-13", "2022-04-26"));
        datePairs.add(new Pair<String, String>("2079-01-14", "2022-04-27"));
        datePairs.add(new Pair<String, String>("2079-01-15", "2022-04-28"));
        datePairs.add(new Pair<String, String>("2079-01-16", "2022-04-29"));
        datePairs.add(new Pair<String, String>("2079-01-17", "2022-04-30"));
        datePairs.add(new Pair<String, String>("2079-01-18", "2022-05-01"));
        datePairs.add(new Pair<String, String>("2079-01-19", "2022-05-02"));
        datePairs.add(new Pair<String, String>("2079-01-20", "2022-05-03"));
        datePairs.add(new Pair<String, String>("2079-01-21", "2022-05-04"));
        datePairs.add(new Pair<String, String>("2079-01-22", "2022-05-05"));
        datePairs.add(new Pair<String, String>("2079-01-23", "2022-05-06"));
        datePairs.add(new Pair<String, String>("2079-01-24", "2022-05-07"));
        datePairs.add(new Pair<String, String>("2079-01-25", "2022-05-08"));
        datePairs.add(new Pair<String, String>("2079-01-26", "2022-05-09"));
        datePairs.add(new Pair<String, String>("2079-01-27", "2022-05-10"));
        datePairs.add(new Pair<String, String>("2079-01-28", "2022-05-11"));
        datePairs.add(new Pair<String, String>("2079-01-29", "2022-05-12"));
        datePairs.add(new Pair<String, String>("2079-01-30", "2022-05-13"));
        datePairs.add(new Pair<String, String>("2079-01-31", "2022-05-14"));
        datePairs.add(new Pair<String, String>("2079-02-01", "2022-05-15"));
        datePairs.add(new Pair<String, String>("2079-02-02", "2022-05-16"));
        datePairs.add(new Pair<String, String>("2079-02-03", "2022-05-17"));
        datePairs.add(new Pair<String, String>("2079-02-04", "2022-05-18"));
        datePairs.add(new Pair<String, String>("2079-02-05", "2022-05-19"));
        datePairs.add(new Pair<String, String>("2079-02-06", "2022-05-20"));
        datePairs.add(new Pair<String, String>("2079-02-07", "2022-05-21"));
        datePairs.add(new Pair<String, String>("2079-02-08", "2022-05-22"));
        datePairs.add(new Pair<String, String>("2079-02-09", "2022-05-23"));
        datePairs.add(new Pair<String, String>("2079-02-10", "2022-05-24"));
        datePairs.add(new Pair<String, String>("2079-02-11", "2022-05-25"));
        datePairs.add(new Pair<String, String>("2079-02-12", "2022-05-26"));
        datePairs.add(new Pair<String, String>("2079-02-13", "2022-05-27"));
        datePairs.add(new Pair<String, String>("2079-02-14", "2022-05-28"));
        datePairs.add(new Pair<String, String>("2079-02-15", "2022-05-29"));
        datePairs.add(new Pair<String, String>("2079-02-16", "2022-05-30"));
        datePairs.add(new Pair<String, String>("2079-02-17", "2022-05-31"));
        datePairs.add(new Pair<String, String>("2079-02-18", "2022-06-01"));
        datePairs.add(new Pair<String, String>("2079-02-19", "2022-06-02"));
        datePairs.add(new Pair<String, String>("2079-02-20", "2022-06-03"));
        datePairs.add(new Pair<String, String>("2079-02-21", "2022-06-04"));
        datePairs.add(new Pair<String, String>("2079-02-22", "2022-06-05"));
        datePairs.add(new Pair<String, String>("2079-02-23", "2022-06-06"));
        datePairs.add(new Pair<String, String>("2079-02-24", "2022-06-07"));
        datePairs.add(new Pair<String, String>("2079-02-25", "2022-06-08"));
        datePairs.add(new Pair<String, String>("2079-02-26", "2022-06-09"));
        datePairs.add(new Pair<String, String>("2079-02-27", "2022-06-10"));
        datePairs.add(new Pair<String, String>("2079-02-28", "2022-06-11"));
        datePairs.add(new Pair<String, String>("2079-02-29", "2022-06-12"));
        datePairs.add(new Pair<String, String>("2079-02-30", "2022-06-13"));
        datePairs.add(new Pair<String, String>("2079-02-31", "2022-06-14"));
        datePairs.add(new Pair<String, String>("2079-03-01", "2022-06-15"));
        datePairs.add(new Pair<String, String>("2079-03-02", "2022-06-16"));
        datePairs.add(new Pair<String, String>("2079-03-03", "2022-06-17"));
        datePairs.add(new Pair<String, String>("2079-03-04", "2022-06-18"));
        datePairs.add(new Pair<String, String>("2079-03-05", "2022-06-19"));
        datePairs.add(new Pair<String, String>("2079-03-06", "2022-06-20"));
        datePairs.add(new Pair<String, String>("2079-03-07", "2022-06-21"));
        datePairs.add(new Pair<String, String>("2079-03-08", "2022-06-22"));
        datePairs.add(new Pair<String, String>("2079-03-09", "2022-06-23"));
        datePairs.add(new Pair<String, String>("2079-03-10", "2022-06-24"));
        datePairs.add(new Pair<String, String>("2079-03-11", "2022-06-25"));
        datePairs.add(new Pair<String, String>("2079-03-12", "2022-06-26"));
        datePairs.add(new Pair<String, String>("2079-03-13", "2022-06-27"));
        datePairs.add(new Pair<String, String>("2079-03-14", "2022-06-28"));
        datePairs.add(new Pair<String, String>("2079-03-15", "2022-06-29"));
        datePairs.add(new Pair<String, String>("2079-03-16", "2022-06-30"));
        datePairs.add(new Pair<String, String>("2079-03-17", "2022-07-01"));
        datePairs.add(new Pair<String, String>("2079-03-18", "2022-07-02"));
        datePairs.add(new Pair<String, String>("2079-03-19", "2022-07-03"));
        datePairs.add(new Pair<String, String>("2079-03-20", "2022-07-04"));
        datePairs.add(new Pair<String, String>("2079-03-21", "2022-07-05"));
        datePairs.add(new Pair<String, String>("2079-03-22", "2022-07-06"));
        datePairs.add(new Pair<String, String>("2079-03-23", "2022-07-07"));
        datePairs.add(new Pair<String, String>("2079-03-24", "2022-07-08"));
        datePairs.add(new Pair<String, String>("2079-03-25", "2022-07-09"));
        datePairs.add(new Pair<String, String>("2079-03-26", "2022-07-10"));
        datePairs.add(new Pair<String, String>("2079-03-27", "2022-07-11"));
        datePairs.add(new Pair<String, String>("2079-03-28", "2022-07-12"));
        datePairs.add(new Pair<String, String>("2079-03-29", "2022-07-13"));
        datePairs.add(new Pair<String, String>("2079-03-30", "2022-07-14"));
        datePairs.add(new Pair<String, String>("2079-03-31", "2022-07-15"));
        datePairs.add(new Pair<String, String>("2079-03-32", "2022-07-16"));
        datePairs.add(new Pair<String, String>("2079-04-01", "2022-07-17"));
        datePairs.add(new Pair<String, String>("2079-04-02", "2022-07-18"));
        datePairs.add(new Pair<String, String>("2079-04-03", "2022-07-19"));
        datePairs.add(new Pair<String, String>("2079-04-04", "2022-07-20"));
        datePairs.add(new Pair<String, String>("2079-04-05", "2022-07-21"));
        datePairs.add(new Pair<String, String>("2079-04-06", "2022-07-22"));
        datePairs.add(new Pair<String, String>("2079-04-07", "2022-07-23"));
        datePairs.add(new Pair<String, String>("2079-04-08", "2022-07-24"));
        datePairs.add(new Pair<String, String>("2079-04-09", "2022-07-25"));
        datePairs.add(new Pair<String, String>("2079-04-10", "2022-07-26"));
        datePairs.add(new Pair<String, String>("2079-04-11", "2022-07-27"));
        datePairs.add(new Pair<String, String>("2079-04-12", "2022-07-28"));
        datePairs.add(new Pair<String, String>("2079-04-13", "2022-07-29"));
        datePairs.add(new Pair<String, String>("2079-04-14", "2022-07-30"));
        datePairs.add(new Pair<String, String>("2079-04-15", "2022-07-31"));
        datePairs.add(new Pair<String, String>("2079-04-16", "2022-08-01"));
        datePairs.add(new Pair<String, String>("2079-04-17", "2022-08-02"));
        datePairs.add(new Pair<String, String>("2079-04-18", "2022-08-03"));
        datePairs.add(new Pair<String, String>("2079-04-19", "2022-08-04"));
        datePairs.add(new Pair<String, String>("2079-04-20", "2022-08-05"));
        datePairs.add(new Pair<String, String>("2079-04-21", "2022-08-06"));
        datePairs.add(new Pair<String, String>("2079-04-22", "2022-08-07"));
        datePairs.add(new Pair<String, String>("2079-04-23", "2022-08-08"));
        datePairs.add(new Pair<String, String>("2079-04-24", "2022-08-09"));
        datePairs.add(new Pair<String, String>("2079-04-25", "2022-08-10"));
        datePairs.add(new Pair<String, String>("2079-04-26", "2022-08-11"));
        datePairs.add(new Pair<String, String>("2079-04-27", "2022-08-12"));
        datePairs.add(new Pair<String, String>("2079-04-28", "2022-08-13"));
        datePairs.add(new Pair<String, String>("2079-04-29", "2022-08-14"));
        datePairs.add(new Pair<String, String>("2079-04-30", "2022-08-15"));
        datePairs.add(new Pair<String, String>("2079-04-31", "2022-08-16"));
        datePairs.add(new Pair<String, String>("2079-05-01", "2022-08-17"));
        datePairs.add(new Pair<String, String>("2079-05-02", "2022-08-18"));
        datePairs.add(new Pair<String, String>("2079-05-03", "2022-08-19"));
        datePairs.add(new Pair<String, String>("2079-05-04", "2022-08-20"));
        datePairs.add(new Pair<String, String>("2079-05-05", "2022-08-21"));
        datePairs.add(new Pair<String, String>("2079-05-06", "2022-08-22"));
        datePairs.add(new Pair<String, String>("2079-05-07", "2022-08-23"));
        datePairs.add(new Pair<String, String>("2079-05-08", "2022-08-24"));
        datePairs.add(new Pair<String, String>("2079-05-09", "2022-08-25"));
        datePairs.add(new Pair<String, String>("2079-05-10", "2022-08-26"));
        datePairs.add(new Pair<String, String>("2079-05-11", "2022-08-27"));
        datePairs.add(new Pair<String, String>("2079-05-12", "2022-08-28"));
        datePairs.add(new Pair<String, String>("2079-05-13", "2022-08-29"));
        datePairs.add(new Pair<String, String>("2079-05-14", "2022-08-30"));
        datePairs.add(new Pair<String, String>("2079-05-15", "2022-08-31"));
        datePairs.add(new Pair<String, String>("2079-05-16", "2022-09-01"));
        datePairs.add(new Pair<String, String>("2079-05-17", "2022-09-02"));
        datePairs.add(new Pair<String, String>("2079-05-18", "2022-09-03"));
        datePairs.add(new Pair<String, String>("2079-05-19", "2022-09-04"));
        datePairs.add(new Pair<String, String>("2079-05-20", "2022-09-05"));
        datePairs.add(new Pair<String, String>("2079-05-21", "2022-09-06"));
        datePairs.add(new Pair<String, String>("2079-05-22", "2022-09-07"));
        datePairs.add(new Pair<String, String>("2079-05-23", "2022-09-08"));
        datePairs.add(new Pair<String, String>("2079-05-24", "2022-09-09"));
        datePairs.add(new Pair<String, String>("2079-05-25", "2022-09-10"));
        datePairs.add(new Pair<String, String>("2079-05-26", "2022-09-11"));
        datePairs.add(new Pair<String, String>("2079-05-27", "2022-09-12"));
        datePairs.add(new Pair<String, String>("2079-05-28", "2022-09-13"));
        datePairs.add(new Pair<String, String>("2079-05-29", "2022-09-14"));
        datePairs.add(new Pair<String, String>("2079-05-30", "2022-09-15"));
        datePairs.add(new Pair<String, String>("2079-05-31", "2022-09-16"));
        datePairs.add(new Pair<String, String>("2079-06-01", "2022-09-17"));
        datePairs.add(new Pair<String, String>("2079-06-02", "2022-09-18"));
        datePairs.add(new Pair<String, String>("2079-06-03", "2022-09-19"));
        datePairs.add(new Pair<String, String>("2079-06-04", "2022-09-20"));
        datePairs.add(new Pair<String, String>("2079-06-05", "2022-09-21"));
        datePairs.add(new Pair<String, String>("2079-06-06", "2022-09-22"));
        datePairs.add(new Pair<String, String>("2079-06-07", "2022-09-23"));
        datePairs.add(new Pair<String, String>("2079-06-08", "2022-09-24"));
        datePairs.add(new Pair<String, String>("2079-06-09", "2022-09-25"));
        datePairs.add(new Pair<String, String>("2079-06-10", "2022-09-26"));
        datePairs.add(new Pair<String, String>("2079-06-11", "2022-09-27"));
        datePairs.add(new Pair<String, String>("2079-06-12", "2022-09-28"));
        datePairs.add(new Pair<String, String>("2079-06-13", "2022-09-29"));
        datePairs.add(new Pair<String, String>("2079-06-14", "2022-09-30"));
        datePairs.add(new Pair<String, String>("2079-06-15", "2022-10-01"));
        datePairs.add(new Pair<String, String>("2079-06-16", "2022-10-02"));
        datePairs.add(new Pair<String, String>("2079-06-17", "2022-10-03"));
        datePairs.add(new Pair<String, String>("2079-06-18", "2022-10-04"));
        datePairs.add(new Pair<String, String>("2079-06-19", "2022-10-05"));
        datePairs.add(new Pair<String, String>("2079-06-20", "2022-10-06"));
        datePairs.add(new Pair<String, String>("2079-06-21", "2022-10-07"));
        datePairs.add(new Pair<String, String>("2079-06-22", "2022-10-08"));
        datePairs.add(new Pair<String, String>("2079-06-23", "2022-10-09"));
        datePairs.add(new Pair<String, String>("2079-06-24", "2022-10-10"));
        datePairs.add(new Pair<String, String>("2079-06-25", "2022-10-11"));
        datePairs.add(new Pair<String, String>("2079-06-26", "2022-10-12"));
        datePairs.add(new Pair<String, String>("2079-06-27", "2022-10-13"));
        datePairs.add(new Pair<String, String>("2079-06-28", "2022-10-14"));
        datePairs.add(new Pair<String, String>("2079-06-29", "2022-10-15"));
        datePairs.add(new Pair<String, String>("2079-06-30", "2022-10-16"));
        datePairs.add(new Pair<String, String>("2079-06-31", "2022-10-17"));
        datePairs.add(new Pair<String, String>("2079-07-01", "2022-10-18"));
        datePairs.add(new Pair<String, String>("2079-07-02", "2022-10-19"));
        datePairs.add(new Pair<String, String>("2079-07-03", "2022-10-20"));
        datePairs.add(new Pair<String, String>("2079-07-04", "2022-10-21"));
        datePairs.add(new Pair<String, String>("2079-07-05", "2022-10-22"));
        datePairs.add(new Pair<String, String>("2079-07-06", "2022-10-23"));
        datePairs.add(new Pair<String, String>("2079-07-07", "2022-10-24"));
        datePairs.add(new Pair<String, String>("2079-07-08", "2022-10-25"));
        datePairs.add(new Pair<String, String>("2079-07-09", "2022-10-26"));
        datePairs.add(new Pair<String, String>("2079-07-10", "2022-10-27"));
        datePairs.add(new Pair<String, String>("2079-07-11", "2022-10-28"));
        datePairs.add(new Pair<String, String>("2079-07-12", "2022-10-29"));
        datePairs.add(new Pair<String, String>("2079-07-13", "2022-10-30"));
        datePairs.add(new Pair<String, String>("2079-07-14", "2022-10-31"));
        datePairs.add(new Pair<String, String>("2079-07-15", "2022-11-01"));
        datePairs.add(new Pair<String, String>("2079-07-16", "2022-11-02"));
        datePairs.add(new Pair<String, String>("2079-07-17", "2022-11-03"));
        datePairs.add(new Pair<String, String>("2079-07-18", "2022-11-04"));
        datePairs.add(new Pair<String, String>("2079-07-19", "2022-11-05"));
        datePairs.add(new Pair<String, String>("2079-07-20", "2022-11-06"));
        datePairs.add(new Pair<String, String>("2079-07-21", "2022-11-07"));
        datePairs.add(new Pair<String, String>("2079-07-22", "2022-11-08"));
        datePairs.add(new Pair<String, String>("2079-07-23", "2022-11-09"));
        datePairs.add(new Pair<String, String>("2079-07-24", "2022-11-10"));
        datePairs.add(new Pair<String, String>("2079-07-25", "2022-11-11"));
        datePairs.add(new Pair<String, String>("2079-07-26", "2022-11-12"));
        datePairs.add(new Pair<String, String>("2079-07-27", "2022-11-13"));
        datePairs.add(new Pair<String, String>("2079-07-28", "2022-11-14"));
        datePairs.add(new Pair<String, String>("2079-07-29", "2022-11-15"));
        datePairs.add(new Pair<String, String>("2079-07-30", "2022-11-16"));
        datePairs.add(new Pair<String, String>("2079-08-01", "2022-11-17"));
        datePairs.add(new Pair<String, String>("2079-08-02", "2022-11-18"));
        datePairs.add(new Pair<String, String>("2079-08-03", "2022-11-19"));
        datePairs.add(new Pair<String, String>("2079-08-04", "2022-11-20"));
        datePairs.add(new Pair<String, String>("2079-08-05", "2022-11-21"));
        datePairs.add(new Pair<String, String>("2079-08-06", "2022-11-22"));
        datePairs.add(new Pair<String, String>("2079-08-07", "2022-11-23"));
        datePairs.add(new Pair<String, String>("2079-08-08", "2022-11-24"));
        datePairs.add(new Pair<String, String>("2079-08-09", "2022-11-25"));
        datePairs.add(new Pair<String, String>("2079-08-10", "2022-11-26"));
        datePairs.add(new Pair<String, String>("2079-08-11", "2022-11-27"));
        datePairs.add(new Pair<String, String>("2079-08-12", "2022-11-28"));
        datePairs.add(new Pair<String, String>("2079-08-13", "2022-11-29"));
        datePairs.add(new Pair<String, String>("2079-08-14", "2022-11-30"));
        datePairs.add(new Pair<String, String>("2079-08-15", "2022-12-01"));
        datePairs.add(new Pair<String, String>("2079-08-16", "2022-12-02"));
        datePairs.add(new Pair<String, String>("2079-08-17", "2022-12-03"));
        datePairs.add(new Pair<String, String>("2079-08-18", "2022-12-04"));
        datePairs.add(new Pair<String, String>("2079-08-19", "2022-12-05"));
        datePairs.add(new Pair<String, String>("2079-08-20", "2022-12-06"));
        datePairs.add(new Pair<String, String>("2079-08-21", "2022-12-07"));
        datePairs.add(new Pair<String, String>("2079-08-22", "2022-12-08"));
        datePairs.add(new Pair<String, String>("2079-08-23", "2022-12-09"));
        datePairs.add(new Pair<String, String>("2079-08-24", "2022-12-10"));
        datePairs.add(new Pair<String, String>("2079-08-25", "2022-12-11"));
        datePairs.add(new Pair<String, String>("2079-08-26", "2022-12-12"));
        datePairs.add(new Pair<String, String>("2079-08-27", "2022-12-13"));
        datePairs.add(new Pair<String, String>("2079-08-28", "2022-12-14"));
        datePairs.add(new Pair<String, String>("2079-08-29", "2022-12-15"));
        datePairs.add(new Pair<String, String>("2079-09-01", "2022-12-16"));
        datePairs.add(new Pair<String, String>("2079-09-02", "2022-12-17"));
        datePairs.add(new Pair<String, String>("2079-09-03", "2022-12-18"));
        datePairs.add(new Pair<String, String>("2079-09-04", "2022-12-19"));
        datePairs.add(new Pair<String, String>("2079-09-05", "2022-12-20"));
        datePairs.add(new Pair<String, String>("2079-09-06", "2022-12-21"));
        datePairs.add(new Pair<String, String>("2079-09-07", "2022-12-22"));
        datePairs.add(new Pair<String, String>("2079-09-08", "2022-12-23"));
        datePairs.add(new Pair<String, String>("2079-09-09", "2022-12-24"));
        datePairs.add(new Pair<String, String>("2079-09-10", "2022-12-25"));
        datePairs.add(new Pair<String, String>("2079-09-11", "2022-12-26"));
        datePairs.add(new Pair<String, String>("2079-09-12", "2022-12-27"));
        datePairs.add(new Pair<String, String>("2079-09-13", "2022-12-28"));
        datePairs.add(new Pair<String, String>("2079-09-14", "2022-12-29"));
        datePairs.add(new Pair<String, String>("2079-09-15", "2022-12-30"));
        datePairs.add(new Pair<String, String>("2079-09-16", "2022-12-31"));
        datePairs.add(new Pair<String, String>("2079-09-17", "2023-01-01"));
        datePairs.add(new Pair<String, String>("2079-09-18", "2023-01-02"));
        datePairs.add(new Pair<String, String>("2079-09-19", "2023-01-03"));
        datePairs.add(new Pair<String, String>("2079-09-20", "2023-01-04"));
        datePairs.add(new Pair<String, String>("2079-09-21", "2023-01-05"));
        datePairs.add(new Pair<String, String>("2079-09-22", "2023-01-06"));
        datePairs.add(new Pair<String, String>("2079-09-23", "2023-01-07"));
        datePairs.add(new Pair<String, String>("2079-09-24", "2023-01-08"));
        datePairs.add(new Pair<String, String>("2079-09-25", "2023-01-09"));
        datePairs.add(new Pair<String, String>("2079-09-26", "2023-01-10"));
        datePairs.add(new Pair<String, String>("2079-09-27", "2023-01-11"));
        datePairs.add(new Pair<String, String>("2079-09-28", "2023-01-12"));
        datePairs.add(new Pair<String, String>("2079-09-29", "2023-01-13"));
        datePairs.add(new Pair<String, String>("2079-09-30", "2023-01-14"));
        datePairs.add(new Pair<String, String>("2079-10-01", "2023-01-15"));
        datePairs.add(new Pair<String, String>("2079-10-02", "2023-01-16"));
        datePairs.add(new Pair<String, String>("2079-10-03", "2023-01-17"));
        datePairs.add(new Pair<String, String>("2079-10-04", "2023-01-18"));
        datePairs.add(new Pair<String, String>("2079-10-05", "2023-01-19"));
        datePairs.add(new Pair<String, String>("2079-10-06", "2023-01-20"));
        datePairs.add(new Pair<String, String>("2079-10-07", "2023-01-21"));
        datePairs.add(new Pair<String, String>("2079-10-08", "2023-01-22"));
        datePairs.add(new Pair<String, String>("2079-10-09", "2023-01-23"));
        datePairs.add(new Pair<String, String>("2079-10-10", "2023-01-24"));
        datePairs.add(new Pair<String, String>("2079-10-11", "2023-01-25"));
        datePairs.add(new Pair<String, String>("2079-10-12", "2023-01-26"));
        datePairs.add(new Pair<String, String>("2079-10-13", "2023-01-27"));
        datePairs.add(new Pair<String, String>("2079-10-14", "2023-01-28"));
        datePairs.add(new Pair<String, String>("2079-10-15", "2023-01-29"));
        datePairs.add(new Pair<String, String>("2079-10-16", "2023-01-30"));
        datePairs.add(new Pair<String, String>("2079-10-17", "2023-01-31"));
        datePairs.add(new Pair<String, String>("2079-10-18", "2023-02-01"));
        datePairs.add(new Pair<String, String>("2079-10-19", "2023-02-02"));
        datePairs.add(new Pair<String, String>("2079-10-20", "2023-02-03"));
        datePairs.add(new Pair<String, String>("2079-10-21", "2023-02-04"));
        datePairs.add(new Pair<String, String>("2079-10-22", "2023-02-05"));
        datePairs.add(new Pair<String, String>("2079-10-23", "2023-02-06"));
        datePairs.add(new Pair<String, String>("2079-10-24", "2023-02-07"));
        datePairs.add(new Pair<String, String>("2079-10-25", "2023-02-08"));
        datePairs.add(new Pair<String, String>("2079-10-26", "2023-02-09"));
        datePairs.add(new Pair<String, String>("2079-10-27", "2023-02-10"));
        datePairs.add(new Pair<String, String>("2079-10-28", "2023-02-11"));
        datePairs.add(new Pair<String, String>("2079-10-29", "2023-02-12"));
        datePairs.add(new Pair<String, String>("2079-11-01", "2023-02-13"));
        datePairs.add(new Pair<String, String>("2079-11-02", "2023-02-14"));
        datePairs.add(new Pair<String, String>("2079-11-03", "2023-02-15"));
        datePairs.add(new Pair<String, String>("2079-11-04", "2023-02-16"));
        datePairs.add(new Pair<String, String>("2079-11-05", "2023-02-17"));
        datePairs.add(new Pair<String, String>("2079-11-06", "2023-02-18"));
        datePairs.add(new Pair<String, String>("2079-11-07", "2023-02-19"));
        datePairs.add(new Pair<String, String>("2079-11-08", "2023-02-20"));
        datePairs.add(new Pair<String, String>("2079-11-09", "2023-02-21"));
        datePairs.add(new Pair<String, String>("2079-11-10", "2023-02-22"));
        datePairs.add(new Pair<String, String>("2079-11-11", "2023-02-23"));
        datePairs.add(new Pair<String, String>("2079-11-12", "2023-02-24"));
        datePairs.add(new Pair<String, String>("2079-11-13", "2023-02-25"));
        datePairs.add(new Pair<String, String>("2079-11-14", "2023-02-26"));
        datePairs.add(new Pair<String, String>("2079-11-15", "2023-02-27"));
        datePairs.add(new Pair<String, String>("2079-11-16", "2023-02-28"));
        datePairs.add(new Pair<String, String>("2079-11-17", "2023-03-01"));
        datePairs.add(new Pair<String, String>("2079-11-18", "2023-03-02"));
        datePairs.add(new Pair<String, String>("2079-11-19", "2023-03-03"));
        datePairs.add(new Pair<String, String>("2079-11-20", "2023-03-04"));
        datePairs.add(new Pair<String, String>("2079-11-21", "2023-03-05"));
        datePairs.add(new Pair<String, String>("2079-11-22", "2023-03-06"));
        datePairs.add(new Pair<String, String>("2079-11-23", "2023-03-07"));
        datePairs.add(new Pair<String, String>("2079-11-24", "2023-03-08"));
        datePairs.add(new Pair<String, String>("2079-11-25", "2023-03-09"));
        datePairs.add(new Pair<String, String>("2079-11-26", "2023-03-10"));
        datePairs.add(new Pair<String, String>("2079-11-27", "2023-03-11"));
        datePairs.add(new Pair<String, String>("2079-11-28", "2023-03-12"));
        datePairs.add(new Pair<String, String>("2079-11-29", "2023-03-13"));
        datePairs.add(new Pair<String, String>("2079-11-30", "2023-03-14"));
        datePairs.add(new Pair<String, String>("2079-12-01", "2023-03-15"));
        datePairs.add(new Pair<String, String>("2079-12-02", "2023-03-16"));
        datePairs.add(new Pair<String, String>("2079-12-03", "2023-03-17"));
        datePairs.add(new Pair<String, String>("2079-12-04", "2023-03-18"));
        datePairs.add(new Pair<String, String>("2079-12-05", "2023-03-19"));
        datePairs.add(new Pair<String, String>("2079-12-06", "2023-03-20"));
        datePairs.add(new Pair<String, String>("2079-12-07", "2023-03-21"));
        datePairs.add(new Pair<String, String>("2079-12-08", "2023-03-22"));
        datePairs.add(new Pair<String, String>("2079-12-09", "2023-03-23"));
        datePairs.add(new Pair<String, String>("2079-12-10", "2023-03-24"));
        datePairs.add(new Pair<String, String>("2079-12-11", "2023-03-25"));
        datePairs.add(new Pair<String, String>("2079-12-12", "2023-03-26"));
        datePairs.add(new Pair<String, String>("2079-12-13", "2023-03-27"));
        datePairs.add(new Pair<String, String>("2079-12-14", "2023-03-28"));
        datePairs.add(new Pair<String, String>("2079-12-15", "2023-03-29"));
        datePairs.add(new Pair<String, String>("2079-12-16", "2023-03-30"));
        datePairs.add(new Pair<String, String>("2079-12-17", "2023-03-31"));
        datePairs.add(new Pair<String, String>("2079-12-18", "2023-04-01"));
        datePairs.add(new Pair<String, String>("2079-12-19", "2023-04-02"));
        datePairs.add(new Pair<String, String>("2079-12-20", "2023-04-03"));
        datePairs.add(new Pair<String, String>("2079-12-21", "2023-04-04"));
        datePairs.add(new Pair<String, String>("2079-12-22", "2023-04-05"));
        datePairs.add(new Pair<String, String>("2079-12-23", "2023-04-06"));
        datePairs.add(new Pair<String, String>("2079-12-24", "2023-04-07"));
        datePairs.add(new Pair<String, String>("2079-12-25", "2023-04-08"));
        datePairs.add(new Pair<String, String>("2079-12-26", "2023-04-09"));
        datePairs.add(new Pair<String, String>("2079-12-27", "2023-04-10"));
        datePairs.add(new Pair<String, String>("2079-12-28", "2023-04-11"));
        datePairs.add(new Pair<String, String>("2079-12-29", "2023-04-12"));
        datePairs.add(new Pair<String, String>("2079-12-30", "2023-04-13"));
        datePairs.add(new Pair<String, String>("2080-01-01", "2023-04-14"));
        datePairs.add(new Pair<String, String>("2080-01-02", "2023-04-15"));
        datePairs.add(new Pair<String, String>("2080-01-03", "2023-04-16"));
        datePairs.add(new Pair<String, String>("2080-01-04", "2023-04-17"));
        datePairs.add(new Pair<String, String>("2080-01-05", "2023-04-18"));
        datePairs.add(new Pair<String, String>("2080-01-06", "2023-04-19"));
        datePairs.add(new Pair<String, String>("2080-01-07", "2023-04-20"));
        datePairs.add(new Pair<String, String>("2080-01-08", "2023-04-21"));
        datePairs.add(new Pair<String, String>("2080-01-09", "2023-04-22"));
        datePairs.add(new Pair<String, String>("2080-01-10", "2023-04-23"));
        datePairs.add(new Pair<String, String>("2080-01-11", "2023-04-24"));
        datePairs.add(new Pair<String, String>("2080-01-12", "2023-04-25"));
        datePairs.add(new Pair<String, String>("2080-01-13", "2023-04-26"));
        datePairs.add(new Pair<String, String>("2080-01-14", "2023-04-27"));
        datePairs.add(new Pair<String, String>("2080-01-15", "2023-04-28"));
        datePairs.add(new Pair<String, String>("2080-01-16", "2023-04-29"));
        datePairs.add(new Pair<String, String>("2080-01-17", "2023-04-30"));
        datePairs.add(new Pair<String, String>("2080-01-18", "2023-05-01"));
        datePairs.add(new Pair<String, String>("2080-01-19", "2023-05-02"));
        datePairs.add(new Pair<String, String>("2080-01-20", "2023-05-03"));
        datePairs.add(new Pair<String, String>("2080-01-21", "2023-05-04"));
        datePairs.add(new Pair<String, String>("2080-01-22", "2023-05-05"));
        datePairs.add(new Pair<String, String>("2080-01-23", "2023-05-06"));
        datePairs.add(new Pair<String, String>("2080-01-24", "2023-05-07"));
        datePairs.add(new Pair<String, String>("2080-01-25", "2023-05-08"));
        datePairs.add(new Pair<String, String>("2080-01-26", "2023-05-09"));
        datePairs.add(new Pair<String, String>("2080-01-27", "2023-05-10"));
        datePairs.add(new Pair<String, String>("2080-01-28", "2023-05-11"));
        datePairs.add(new Pair<String, String>("2080-01-29", "2023-05-12"));
        datePairs.add(new Pair<String, String>("2080-01-30", "2023-05-13"));
        datePairs.add(new Pair<String, String>("2080-01-31", "2023-05-14"));
        datePairs.add(new Pair<String, String>("2080-02-01", "2023-05-15"));
        datePairs.add(new Pair<String, String>("2080-02-02", "2023-05-16"));
        datePairs.add(new Pair<String, String>("2080-02-03", "2023-05-17"));
        datePairs.add(new Pair<String, String>("2080-02-04", "2023-05-18"));
        datePairs.add(new Pair<String, String>("2080-02-05", "2023-05-19"));
        datePairs.add(new Pair<String, String>("2080-02-06", "2023-05-20"));
        datePairs.add(new Pair<String, String>("2080-02-07", "2023-05-21"));
        datePairs.add(new Pair<String, String>("2080-02-08", "2023-05-22"));
        datePairs.add(new Pair<String, String>("2080-02-09", "2023-05-23"));
        datePairs.add(new Pair<String, String>("2080-02-10", "2023-05-24"));
        datePairs.add(new Pair<String, String>("2080-02-11", "2023-05-25"));
        datePairs.add(new Pair<String, String>("2080-02-12", "2023-05-26"));
        datePairs.add(new Pair<String, String>("2080-02-13", "2023-05-27"));
        datePairs.add(new Pair<String, String>("2080-02-14", "2023-05-28"));
        datePairs.add(new Pair<String, String>("2080-02-15", "2023-05-29"));
        datePairs.add(new Pair<String, String>("2080-02-16", "2023-05-30"));
        datePairs.add(new Pair<String, String>("2080-02-17", "2023-05-31"));
        datePairs.add(new Pair<String, String>("2080-02-18", "2023-06-01"));
        datePairs.add(new Pair<String, String>("2080-02-19", "2023-06-02"));
        datePairs.add(new Pair<String, String>("2080-02-20", "2023-06-03"));
        datePairs.add(new Pair<String, String>("2080-02-21", "2023-06-04"));
        datePairs.add(new Pair<String, String>("2080-02-22", "2023-06-05"));
        datePairs.add(new Pair<String, String>("2080-02-23", "2023-06-06"));
        datePairs.add(new Pair<String, String>("2080-02-24", "2023-06-07"));
        datePairs.add(new Pair<String, String>("2080-02-25", "2023-06-08"));
        datePairs.add(new Pair<String, String>("2080-02-26", "2023-06-09"));
        datePairs.add(new Pair<String, String>("2080-02-27", "2023-06-10"));
        datePairs.add(new Pair<String, String>("2080-02-28", "2023-06-11"));
        datePairs.add(new Pair<String, String>("2080-02-29", "2023-06-12"));
        datePairs.add(new Pair<String, String>("2080-02-30", "2023-06-13"));
        datePairs.add(new Pair<String, String>("2080-02-31", "2023-06-14"));
        datePairs.add(new Pair<String, String>("2080-02-32", "2023-06-15"));
        datePairs.add(new Pair<String, String>("2080-03-01", "2023-06-16"));
        datePairs.add(new Pair<String, String>("2080-03-02", "2023-06-17"));
        datePairs.add(new Pair<String, String>("2080-03-03", "2023-06-18"));
        datePairs.add(new Pair<String, String>("2080-03-04", "2023-06-19"));
        datePairs.add(new Pair<String, String>("2080-03-05", "2023-06-20"));
        datePairs.add(new Pair<String, String>("2080-03-06", "2023-06-21"));
        datePairs.add(new Pair<String, String>("2080-03-07", "2023-06-22"));
        datePairs.add(new Pair<String, String>("2080-03-08", "2023-06-23"));
        datePairs.add(new Pair<String, String>("2080-03-09", "2023-06-24"));
        datePairs.add(new Pair<String, String>("2080-03-10", "2023-06-25"));
        datePairs.add(new Pair<String, String>("2080-03-11", "2023-06-26"));
        datePairs.add(new Pair<String, String>("2080-03-12", "2023-06-27"));
        datePairs.add(new Pair<String, String>("2080-03-13", "2023-06-28"));
        datePairs.add(new Pair<String, String>("2080-03-14", "2023-06-29"));
        datePairs.add(new Pair<String, String>("2080-03-15", "2023-06-30"));
        datePairs.add(new Pair<String, String>("2080-03-16", "2023-07-01"));
        datePairs.add(new Pair<String, String>("2080-03-17", "2023-07-02"));
        datePairs.add(new Pair<String, String>("2080-03-18", "2023-07-03"));
        datePairs.add(new Pair<String, String>("2080-03-19", "2023-07-04"));
        datePairs.add(new Pair<String, String>("2080-03-20", "2023-07-05"));
        datePairs.add(new Pair<String, String>("2080-03-21", "2023-07-06"));
        datePairs.add(new Pair<String, String>("2080-03-22", "2023-07-07"));
        datePairs.add(new Pair<String, String>("2080-03-23", "2023-07-08"));
        datePairs.add(new Pair<String, String>("2080-03-24", "2023-07-09"));
        datePairs.add(new Pair<String, String>("2080-03-25", "2023-07-10"));
        datePairs.add(new Pair<String, String>("2080-03-26", "2023-07-11"));
        datePairs.add(new Pair<String, String>("2080-03-27", "2023-07-12"));
        datePairs.add(new Pair<String, String>("2080-03-28", "2023-07-13"));
        datePairs.add(new Pair<String, String>("2080-03-29", "2023-07-14"));
        datePairs.add(new Pair<String, String>("2080-03-30", "2023-07-15"));
        datePairs.add(new Pair<String, String>("2080-03-31", "2023-07-16"));
        datePairs.add(new Pair<String, String>("2080-04-01", "2023-07-17"));
        datePairs.add(new Pair<String, String>("2080-04-02", "2023-07-18"));
        datePairs.add(new Pair<String, String>("2080-04-03", "2023-07-19"));
        datePairs.add(new Pair<String, String>("2080-04-04", "2023-07-20"));
        datePairs.add(new Pair<String, String>("2080-04-05", "2023-07-21"));
        datePairs.add(new Pair<String, String>("2080-04-06", "2023-07-22"));
        datePairs.add(new Pair<String, String>("2080-04-07", "2023-07-23"));
        datePairs.add(new Pair<String, String>("2080-04-08", "2023-07-24"));
        datePairs.add(new Pair<String, String>("2080-04-09", "2023-07-25"));
        datePairs.add(new Pair<String, String>("2080-04-10", "2023-07-26"));
        datePairs.add(new Pair<String, String>("2080-04-11", "2023-07-27"));
        datePairs.add(new Pair<String, String>("2080-04-12", "2023-07-28"));
        datePairs.add(new Pair<String, String>("2080-04-13", "2023-07-29"));
        datePairs.add(new Pair<String, String>("2080-04-14", "2023-07-30"));
        datePairs.add(new Pair<String, String>("2080-04-15", "2023-07-31"));
        datePairs.add(new Pair<String, String>("2080-04-16", "2023-08-01"));
        datePairs.add(new Pair<String, String>("2080-04-17", "2023-08-02"));
        datePairs.add(new Pair<String, String>("2080-04-18", "2023-08-03"));
        datePairs.add(new Pair<String, String>("2080-04-19", "2023-08-04"));
        datePairs.add(new Pair<String, String>("2080-04-20", "2023-08-05"));
        datePairs.add(new Pair<String, String>("2080-04-21", "2023-08-06"));
        datePairs.add(new Pair<String, String>("2080-04-22", "2023-08-07"));
        datePairs.add(new Pair<String, String>("2080-04-23", "2023-08-08"));
        datePairs.add(new Pair<String, String>("2080-04-24", "2023-08-09"));
        datePairs.add(new Pair<String, String>("2080-04-25", "2023-08-10"));
        datePairs.add(new Pair<String, String>("2080-04-26", "2023-08-11"));
        datePairs.add(new Pair<String, String>("2080-04-27", "2023-08-12"));
        datePairs.add(new Pair<String, String>("2080-04-28", "2023-08-13"));
        datePairs.add(new Pair<String, String>("2080-04-29", "2023-08-14"));
        datePairs.add(new Pair<String, String>("2080-04-30", "2023-08-15"));
        datePairs.add(new Pair<String, String>("2080-04-31", "2023-08-16"));
        datePairs.add(new Pair<String, String>("2080-04-32", "2023-08-17"));
        datePairs.add(new Pair<String, String>("2080-05-01", "2023-08-18"));
        datePairs.add(new Pair<String, String>("2080-05-02", "2023-08-19"));
        datePairs.add(new Pair<String, String>("2080-05-03", "2023-08-20"));
        datePairs.add(new Pair<String, String>("2080-05-04", "2023-08-21"));
        datePairs.add(new Pair<String, String>("2080-05-05", "2023-08-22"));
        datePairs.add(new Pair<String, String>("2080-05-06", "2023-08-23"));
        datePairs.add(new Pair<String, String>("2080-05-07", "2023-08-24"));
        datePairs.add(new Pair<String, String>("2080-05-08", "2023-08-25"));
        datePairs.add(new Pair<String, String>("2080-05-09", "2023-08-26"));
        datePairs.add(new Pair<String, String>("2080-05-10", "2023-08-27"));
        datePairs.add(new Pair<String, String>("2080-05-11", "2023-08-28"));
        datePairs.add(new Pair<String, String>("2080-05-12", "2023-08-29"));
        datePairs.add(new Pair<String, String>("2080-05-13", "2023-08-30"));
        datePairs.add(new Pair<String, String>("2080-05-14", "2023-08-31"));
        datePairs.add(new Pair<String, String>("2080-05-15", "2023-09-01"));
        datePairs.add(new Pair<String, String>("2080-05-16", "2023-09-02"));
        datePairs.add(new Pair<String, String>("2080-05-17", "2023-09-03"));
        datePairs.add(new Pair<String, String>("2080-05-18", "2023-09-04"));
        datePairs.add(new Pair<String, String>("2080-05-19", "2023-09-05"));
        datePairs.add(new Pair<String, String>("2080-05-20", "2023-09-06"));
        datePairs.add(new Pair<String, String>("2080-05-21", "2023-09-07"));
        datePairs.add(new Pair<String, String>("2080-05-22", "2023-09-08"));
        datePairs.add(new Pair<String, String>("2080-05-23", "2023-09-09"));
        datePairs.add(new Pair<String, String>("2080-05-24", "2023-09-10"));
        datePairs.add(new Pair<String, String>("2080-05-25", "2023-09-11"));
        datePairs.add(new Pair<String, String>("2080-05-26", "2023-09-12"));
        datePairs.add(new Pair<String, String>("2080-05-27", "2023-09-13"));
        datePairs.add(new Pair<String, String>("2080-05-28", "2023-09-14"));
        datePairs.add(new Pair<String, String>("2080-05-29", "2023-09-15"));
        datePairs.add(new Pair<String, String>("2080-05-30", "2023-09-16"));
        datePairs.add(new Pair<String, String>("2080-05-31", "2023-09-17"));
        datePairs.add(new Pair<String, String>("2080-06-01", "2023-09-18"));
        datePairs.add(new Pair<String, String>("2080-06-02", "2023-09-19"));
        datePairs.add(new Pair<String, String>("2080-06-03", "2023-09-20"));
        datePairs.add(new Pair<String, String>("2080-06-04", "2023-09-21"));
        datePairs.add(new Pair<String, String>("2080-06-05", "2023-09-22"));
        datePairs.add(new Pair<String, String>("2080-06-06", "2023-09-23"));
        datePairs.add(new Pair<String, String>("2080-06-07", "2023-09-24"));
        datePairs.add(new Pair<String, String>("2080-06-08", "2023-09-25"));
        datePairs.add(new Pair<String, String>("2080-06-09", "2023-09-26"));
        datePairs.add(new Pair<String, String>("2080-06-10", "2023-09-27"));
        datePairs.add(new Pair<String, String>("2080-06-11", "2023-09-28"));
        datePairs.add(new Pair<String, String>("2080-06-12", "2023-09-29"));
        datePairs.add(new Pair<String, String>("2080-06-13", "2023-09-30"));
        datePairs.add(new Pair<String, String>("2080-06-14", "2023-10-01"));
        datePairs.add(new Pair<String, String>("2080-06-15", "2023-10-02"));
        datePairs.add(new Pair<String, String>("2080-06-16", "2023-10-03"));
        datePairs.add(new Pair<String, String>("2080-06-17", "2023-10-04"));
        datePairs.add(new Pair<String, String>("2080-06-18", "2023-10-05"));
        datePairs.add(new Pair<String, String>("2080-06-19", "2023-10-06"));
        datePairs.add(new Pair<String, String>("2080-06-20", "2023-10-07"));
        datePairs.add(new Pair<String, String>("2080-06-21", "2023-10-08"));
        datePairs.add(new Pair<String, String>("2080-06-22", "2023-10-09"));
        datePairs.add(new Pair<String, String>("2080-06-23", "2023-10-10"));
        datePairs.add(new Pair<String, String>("2080-06-24", "2023-10-11"));
        datePairs.add(new Pair<String, String>("2080-06-25", "2023-10-12"));
        datePairs.add(new Pair<String, String>("2080-06-26", "2023-10-13"));
        datePairs.add(new Pair<String, String>("2080-06-27", "2023-10-14"));
        datePairs.add(new Pair<String, String>("2080-06-28", "2023-10-15"));
        datePairs.add(new Pair<String, String>("2080-06-29", "2023-10-16"));
        datePairs.add(new Pair<String, String>("2080-06-30", "2023-10-17"));
        datePairs.add(new Pair<String, String>("2080-07-01", "2023-10-18"));
        datePairs.add(new Pair<String, String>("2080-07-02", "2023-10-19"));
        datePairs.add(new Pair<String, String>("2080-07-03", "2023-10-20"));
        datePairs.add(new Pair<String, String>("2080-07-04", "2023-10-21"));
        datePairs.add(new Pair<String, String>("2080-07-05", "2023-10-22"));
        datePairs.add(new Pair<String, String>("2080-07-06", "2023-10-23"));
        datePairs.add(new Pair<String, String>("2080-07-07", "2023-10-24"));
        datePairs.add(new Pair<String, String>("2080-07-08", "2023-10-25"));
        datePairs.add(new Pair<String, String>("2080-07-09", "2023-10-26"));
        datePairs.add(new Pair<String, String>("2080-07-10", "2023-10-27"));
        datePairs.add(new Pair<String, String>("2080-07-11", "2023-10-28"));
        datePairs.add(new Pair<String, String>("2080-07-12", "2023-10-29"));
        datePairs.add(new Pair<String, String>("2080-07-13", "2023-10-30"));
        datePairs.add(new Pair<String, String>("2080-07-14", "2023-10-31"));
        datePairs.add(new Pair<String, String>("2080-07-15", "2023-11-01"));
        datePairs.add(new Pair<String, String>("2080-07-16", "2023-11-02"));
        datePairs.add(new Pair<String, String>("2080-07-17", "2023-11-03"));
        datePairs.add(new Pair<String, String>("2080-07-18", "2023-11-04"));
        datePairs.add(new Pair<String, String>("2080-07-19", "2023-11-05"));
        datePairs.add(new Pair<String, String>("2080-07-20", "2023-11-06"));
        datePairs.add(new Pair<String, String>("2080-07-21", "2023-11-07"));
        datePairs.add(new Pair<String, String>("2080-07-22", "2023-11-08"));
        datePairs.add(new Pair<String, String>("2080-07-23", "2023-11-09"));
        datePairs.add(new Pair<String, String>("2080-07-24", "2023-11-10"));
        datePairs.add(new Pair<String, String>("2080-07-25", "2023-11-11"));
        datePairs.add(new Pair<String, String>("2080-07-26", "2023-11-12"));
        datePairs.add(new Pair<String, String>("2080-07-27", "2023-11-13"));
        datePairs.add(new Pair<String, String>("2080-07-28", "2023-11-14"));
        datePairs.add(new Pair<String, String>("2080-07-29", "2023-11-15"));
        datePairs.add(new Pair<String, String>("2080-07-30", "2023-11-16"));
        datePairs.add(new Pair<String, String>("2080-08-01", "2023-11-17"));
        datePairs.add(new Pair<String, String>("2080-08-02", "2023-11-18"));
        datePairs.add(new Pair<String, String>("2080-08-03", "2023-11-19"));
        datePairs.add(new Pair<String, String>("2080-08-04", "2023-11-20"));
        datePairs.add(new Pair<String, String>("2080-08-05", "2023-11-21"));
        datePairs.add(new Pair<String, String>("2080-08-06", "2023-11-22"));
        datePairs.add(new Pair<String, String>("2080-08-07", "2023-11-23"));
        datePairs.add(new Pair<String, String>("2080-08-08", "2023-11-24"));
        datePairs.add(new Pair<String, String>("2080-08-09", "2023-11-25"));
        datePairs.add(new Pair<String, String>("2080-08-10", "2023-11-26"));
        datePairs.add(new Pair<String, String>("2080-08-11", "2023-11-27"));
        datePairs.add(new Pair<String, String>("2080-08-12", "2023-11-28"));
        datePairs.add(new Pair<String, String>("2080-08-13", "2023-11-29"));
        datePairs.add(new Pair<String, String>("2080-08-14", "2023-11-30"));
        datePairs.add(new Pair<String, String>("2080-08-15", "2023-12-01"));
        datePairs.add(new Pair<String, String>("2080-08-16", "2023-12-02"));
        datePairs.add(new Pair<String, String>("2080-08-17", "2023-12-03"));
        datePairs.add(new Pair<String, String>("2080-08-18", "2023-12-04"));
        datePairs.add(new Pair<String, String>("2080-08-19", "2023-12-05"));
        datePairs.add(new Pair<String, String>("2080-08-20", "2023-12-06"));
        datePairs.add(new Pair<String, String>("2080-08-21", "2023-12-07"));
        datePairs.add(new Pair<String, String>("2080-08-22", "2023-12-08"));
        datePairs.add(new Pair<String, String>("2080-08-23", "2023-12-09"));
        datePairs.add(new Pair<String, String>("2080-08-24", "2023-12-10"));
        datePairs.add(new Pair<String, String>("2080-08-25", "2023-12-11"));
        datePairs.add(new Pair<String, String>("2080-08-26", "2023-12-12"));
        datePairs.add(new Pair<String, String>("2080-08-27", "2023-12-13"));
        datePairs.add(new Pair<String, String>("2080-08-28", "2023-12-14"));
        datePairs.add(new Pair<String, String>("2080-08-29", "2023-12-15"));
        datePairs.add(new Pair<String, String>("2080-08-30", "2023-12-16"));
        datePairs.add(new Pair<String, String>("2080-09-01", "2023-12-17"));
        datePairs.add(new Pair<String, String>("2080-09-02", "2023-12-18"));
        datePairs.add(new Pair<String, String>("2080-09-03", "2023-12-19"));
        datePairs.add(new Pair<String, String>("2080-09-04", "2023-12-20"));
        datePairs.add(new Pair<String, String>("2080-09-05", "2023-12-21"));
        datePairs.add(new Pair<String, String>("2080-09-06", "2023-12-22"));
        datePairs.add(new Pair<String, String>("2080-09-07", "2023-12-23"));
        datePairs.add(new Pair<String, String>("2080-09-08", "2023-12-24"));
        datePairs.add(new Pair<String, String>("2080-09-09", "2023-12-25"));
        datePairs.add(new Pair<String, String>("2080-09-10", "2023-12-26"));
        datePairs.add(new Pair<String, String>("2080-09-11", "2023-12-27"));
        datePairs.add(new Pair<String, String>("2080-09-12", "2023-12-28"));
        datePairs.add(new Pair<String, String>("2080-09-13", "2023-12-29"));
        datePairs.add(new Pair<String, String>("2080-09-14", "2023-12-30"));
        datePairs.add(new Pair<String, String>("2080-09-15", "2023-12-31"));
        datePairs.add(new Pair<String, String>("2080-09-16", "2024-01-01"));
        datePairs.add(new Pair<String, String>("2080-09-17", "2024-01-02"));
        datePairs.add(new Pair<String, String>("2080-09-18", "2024-01-03"));
        datePairs.add(new Pair<String, String>("2080-09-19", "2024-01-04"));
        datePairs.add(new Pair<String, String>("2080-09-20", "2024-01-05"));
        datePairs.add(new Pair<String, String>("2080-09-21", "2024-01-06"));
        datePairs.add(new Pair<String, String>("2080-09-22", "2024-01-07"));
        datePairs.add(new Pair<String, String>("2080-09-23", "2024-01-08"));
        datePairs.add(new Pair<String, String>("2080-09-24", "2024-01-09"));
        datePairs.add(new Pair<String, String>("2080-09-25", "2024-01-10"));
        datePairs.add(new Pair<String, String>("2080-09-26", "2024-01-11"));
        datePairs.add(new Pair<String, String>("2080-09-27", "2024-01-12"));
        datePairs.add(new Pair<String, String>("2080-09-28", "2024-01-13"));
        datePairs.add(new Pair<String, String>("2080-09-29", "2024-01-14"));
        datePairs.add(new Pair<String, String>("2080-10-01", "2024-01-15"));
        datePairs.add(new Pair<String, String>("2080-10-02", "2024-01-16"));
        datePairs.add(new Pair<String, String>("2080-10-03", "2024-01-17"));
        datePairs.add(new Pair<String, String>("2080-10-04", "2024-01-18"));
        datePairs.add(new Pair<String, String>("2080-10-05", "2024-01-19"));
        datePairs.add(new Pair<String, String>("2080-10-06", "2024-01-20"));
        datePairs.add(new Pair<String, String>("2080-10-07", "2024-01-21"));
        datePairs.add(new Pair<String, String>("2080-10-08", "2024-01-22"));
        datePairs.add(new Pair<String, String>("2080-10-09", "2024-01-23"));
        datePairs.add(new Pair<String, String>("2080-10-10", "2024-01-24"));
        datePairs.add(new Pair<String, String>("2080-10-11", "2024-01-25"));
        datePairs.add(new Pair<String, String>("2080-10-12", "2024-01-26"));
        datePairs.add(new Pair<String, String>("2080-10-13", "2024-01-27"));
        datePairs.add(new Pair<String, String>("2080-10-14", "2024-01-28"));
        datePairs.add(new Pair<String, String>("2080-10-15", "2024-01-29"));
        datePairs.add(new Pair<String, String>("2080-10-16", "2024-01-30"));
        datePairs.add(new Pair<String, String>("2080-10-17", "2024-01-31"));
        datePairs.add(new Pair<String, String>("2080-10-18", "2024-02-01"));
        datePairs.add(new Pair<String, String>("2080-10-19", "2024-02-02"));
        datePairs.add(new Pair<String, String>("2080-10-20", "2024-02-03"));
        datePairs.add(new Pair<String, String>("2080-10-21", "2024-02-04"));
        datePairs.add(new Pair<String, String>("2080-10-22", "2024-02-05"));
        datePairs.add(new Pair<String, String>("2080-10-23", "2024-02-06"));
        datePairs.add(new Pair<String, String>("2080-10-24", "2024-02-07"));
        datePairs.add(new Pair<String, String>("2080-10-25", "2024-02-08"));
        datePairs.add(new Pair<String, String>("2080-10-26", "2024-02-09"));
        datePairs.add(new Pair<String, String>("2080-10-27", "2024-02-10"));
        datePairs.add(new Pair<String, String>("2080-10-28", "2024-02-11"));
        datePairs.add(new Pair<String, String>("2080-10-29", "2024-02-12"));
        datePairs.add(new Pair<String, String>("2080-11-01", "2024-02-13"));
        datePairs.add(new Pair<String, String>("2080-11-02", "2024-02-14"));
        datePairs.add(new Pair<String, String>("2080-11-03", "2024-02-15"));
        datePairs.add(new Pair<String, String>("2080-11-04", "2024-02-16"));
        datePairs.add(new Pair<String, String>("2080-11-05", "2024-02-17"));
        datePairs.add(new Pair<String, String>("2080-11-06", "2024-02-18"));
        datePairs.add(new Pair<String, String>("2080-11-07", "2024-02-19"));
        datePairs.add(new Pair<String, String>("2080-11-08", "2024-02-20"));
        datePairs.add(new Pair<String, String>("2080-11-09", "2024-02-21"));
        datePairs.add(new Pair<String, String>("2080-11-10", "2024-02-22"));
        datePairs.add(new Pair<String, String>("2080-11-11", "2024-02-23"));
        datePairs.add(new Pair<String, String>("2080-11-12", "2024-02-24"));
        datePairs.add(new Pair<String, String>("2080-11-13", "2024-02-25"));
        datePairs.add(new Pair<String, String>("2080-11-14", "2024-02-26"));
        datePairs.add(new Pair<String, String>("2080-11-15", "2024-02-27"));
        datePairs.add(new Pair<String, String>("2080-11-16", "2024-02-28"));
        datePairs.add(new Pair<String, String>("2080-11-17", "2024-02-29"));
        datePairs.add(new Pair<String, String>("2080-11-18", "2024-03-01"));
        datePairs.add(new Pair<String, String>("2080-11-19", "2024-03-02"));
        datePairs.add(new Pair<String, String>("2080-11-20", "2024-03-03"));
        datePairs.add(new Pair<String, String>("2080-11-21", "2024-03-04"));
        datePairs.add(new Pair<String, String>("2080-11-22", "2024-03-05"));
        datePairs.add(new Pair<String, String>("2080-11-23", "2024-03-06"));
        datePairs.add(new Pair<String, String>("2080-11-24", "2024-03-07"));
        datePairs.add(new Pair<String, String>("2080-11-25", "2024-03-08"));
        datePairs.add(new Pair<String, String>("2080-11-26", "2024-03-09"));
        datePairs.add(new Pair<String, String>("2080-11-27", "2024-03-10"));
        datePairs.add(new Pair<String, String>("2080-11-28", "2024-03-11"));
        datePairs.add(new Pair<String, String>("2080-11-29", "2024-03-12"));
        datePairs.add(new Pair<String, String>("2080-11-30", "2024-03-13"));
        datePairs.add(new Pair<String, String>("2080-12-01", "2024-03-14"));
        datePairs.add(new Pair<String, String>("2080-12-02", "2024-03-15"));
        datePairs.add(new Pair<String, String>("2080-12-03", "2024-03-16"));
        datePairs.add(new Pair<String, String>("2080-12-04", "2024-03-17"));
        datePairs.add(new Pair<String, String>("2080-12-05", "2024-03-18"));
        datePairs.add(new Pair<String, String>("2080-12-06", "2024-03-19"));
        datePairs.add(new Pair<String, String>("2080-12-07", "2024-03-20"));
        datePairs.add(new Pair<String, String>("2080-12-08", "2024-03-21"));
        datePairs.add(new Pair<String, String>("2080-12-09", "2024-03-22"));
        datePairs.add(new Pair<String, String>("2080-12-10", "2024-03-23"));
        datePairs.add(new Pair<String, String>("2080-12-11", "2024-03-24"));
        datePairs.add(new Pair<String, String>("2080-12-12", "2024-03-25"));
        datePairs.add(new Pair<String, String>("2080-12-13", "2024-03-26"));
        datePairs.add(new Pair<String, String>("2080-12-14", "2024-03-27"));
        datePairs.add(new Pair<String, String>("2080-12-15", "2024-03-28"));
        datePairs.add(new Pair<String, String>("2080-12-16", "2024-03-29"));
        datePairs.add(new Pair<String, String>("2080-12-17", "2024-03-30"));
        datePairs.add(new Pair<String, String>("2080-12-18", "2024-03-31"));
        datePairs.add(new Pair<String, String>("2080-12-19", "2024-04-01"));
        datePairs.add(new Pair<String, String>("2080-12-20", "2024-04-02"));
        datePairs.add(new Pair<String, String>("2080-12-21", "2024-04-03"));
        datePairs.add(new Pair<String, String>("2080-12-22", "2024-04-04"));
        datePairs.add(new Pair<String, String>("2080-12-23", "2024-04-05"));
        datePairs.add(new Pair<String, String>("2080-12-24", "2024-04-06"));
        datePairs.add(new Pair<String, String>("2080-12-25", "2024-04-07"));
        datePairs.add(new Pair<String, String>("2080-12-26", "2024-04-08"));
        datePairs.add(new Pair<String, String>("2080-12-27", "2024-04-09"));
        datePairs.add(new Pair<String, String>("2080-12-28", "2024-04-10"));
        datePairs.add(new Pair<String, String>("2080-12-29", "2024-04-11"));
        datePairs.add(new Pair<String, String>("2080-12-30", "2024-04-12"));
        datePairs.add(new Pair<String, String>("2081-01-01", "2024-04-13"));
        datePairs.add(new Pair<String, String>("2081-01-02", "2024-04-14"));
        datePairs.add(new Pair<String, String>("2081-01-03", "2024-04-15"));
        datePairs.add(new Pair<String, String>("2081-01-04", "2024-04-16"));
        datePairs.add(new Pair<String, String>("2081-01-05", "2024-04-17"));
        datePairs.add(new Pair<String, String>("2081-01-06", "2024-04-18"));
        datePairs.add(new Pair<String, String>("2081-01-07", "2024-04-19"));
        datePairs.add(new Pair<String, String>("2081-01-08", "2024-04-20"));
        datePairs.add(new Pair<String, String>("2081-01-09", "2024-04-21"));
        datePairs.add(new Pair<String, String>("2081-01-10", "2024-04-22"));
        datePairs.add(new Pair<String, String>("2081-01-11", "2024-04-23"));
        datePairs.add(new Pair<String, String>("2081-01-12", "2024-04-24"));
        datePairs.add(new Pair<String, String>("2081-01-13", "2024-04-25"));
        datePairs.add(new Pair<String, String>("2081-01-14", "2024-04-26"));
        datePairs.add(new Pair<String, String>("2081-01-15", "2024-04-27"));
        datePairs.add(new Pair<String, String>("2081-01-16", "2024-04-28"));
        datePairs.add(new Pair<String, String>("2081-01-17", "2024-04-29"));
        datePairs.add(new Pair<String, String>("2081-01-18", "2024-04-30"));
        datePairs.add(new Pair<String, String>("2081-01-19", "2024-05-01"));
        datePairs.add(new Pair<String, String>("2081-01-20", "2024-05-02"));
        datePairs.add(new Pair<String, String>("2081-01-21", "2024-05-03"));
        datePairs.add(new Pair<String, String>("2081-01-22", "2024-05-04"));
        datePairs.add(new Pair<String, String>("2081-01-23", "2024-05-05"));
        datePairs.add(new Pair<String, String>("2081-01-24", "2024-05-06"));
        datePairs.add(new Pair<String, String>("2081-01-25", "2024-05-07"));
        datePairs.add(new Pair<String, String>("2081-01-26", "2024-05-08"));
        datePairs.add(new Pair<String, String>("2081-01-27", "2024-05-09"));
        datePairs.add(new Pair<String, String>("2081-01-28", "2024-05-10"));
        datePairs.add(new Pair<String, String>("2081-01-29", "2024-05-11"));
        datePairs.add(new Pair<String, String>("2081-01-30", "2024-05-12"));
        datePairs.add(new Pair<String, String>("2081-01-31", "2024-05-13"));
        datePairs.add(new Pair<String, String>("2081-02-01", "2024-05-14"));
        datePairs.add(new Pair<String, String>("2081-02-02", "2024-05-15"));
        datePairs.add(new Pair<String, String>("2081-02-03", "2024-05-16"));
        datePairs.add(new Pair<String, String>("2081-02-04", "2024-05-17"));
        datePairs.add(new Pair<String, String>("2081-02-05", "2024-05-18"));
        datePairs.add(new Pair<String, String>("2081-02-06", "2024-05-19"));
        datePairs.add(new Pair<String, String>("2081-02-07", "2024-05-20"));
        datePairs.add(new Pair<String, String>("2081-02-08", "2024-05-21"));
        datePairs.add(new Pair<String, String>("2081-02-09", "2024-05-22"));
        datePairs.add(new Pair<String, String>("2081-02-10", "2024-05-23"));
        datePairs.add(new Pair<String, String>("2081-02-11", "2024-05-24"));
        datePairs.add(new Pair<String, String>("2081-02-12", "2024-05-25"));
        datePairs.add(new Pair<String, String>("2081-02-13", "2024-05-26"));
        datePairs.add(new Pair<String, String>("2081-02-14", "2024-05-27"));
        datePairs.add(new Pair<String, String>("2081-02-15", "2024-05-28"));
        datePairs.add(new Pair<String, String>("2081-02-16", "2024-05-29"));
        datePairs.add(new Pair<String, String>("2081-02-17", "2024-05-30"));
        datePairs.add(new Pair<String, String>("2081-02-18", "2024-05-31"));
        datePairs.add(new Pair<String, String>("2081-02-19", "2024-06-01"));
        datePairs.add(new Pair<String, String>("2081-02-20", "2024-06-02"));
        datePairs.add(new Pair<String, String>("2081-02-21", "2024-06-03"));
        datePairs.add(new Pair<String, String>("2081-02-22", "2024-06-04"));
        datePairs.add(new Pair<String, String>("2081-02-23", "2024-06-05"));
        datePairs.add(new Pair<String, String>("2081-02-24", "2024-06-06"));
        datePairs.add(new Pair<String, String>("2081-02-25", "2024-06-07"));
        datePairs.add(new Pair<String, String>("2081-02-26", "2024-06-08"));
        datePairs.add(new Pair<String, String>("2081-02-27", "2024-06-09"));
        datePairs.add(new Pair<String, String>("2081-02-28", "2024-06-10"));
        datePairs.add(new Pair<String, String>("2081-02-29", "2024-06-11"));
        datePairs.add(new Pair<String, String>("2081-02-30", "2024-06-12"));
        datePairs.add(new Pair<String, String>("2081-02-31", "2024-06-13"));
        datePairs.add(new Pair<String, String>("2081-03-01", "2024-06-14"));
        datePairs.add(new Pair<String, String>("2081-03-02", "2024-06-15"));
        datePairs.add(new Pair<String, String>("2081-03-03", "2024-06-16"));
        datePairs.add(new Pair<String, String>("2081-03-04", "2024-06-17"));
        datePairs.add(new Pair<String, String>("2081-03-05", "2024-06-18"));
        datePairs.add(new Pair<String, String>("2081-03-06", "2024-06-19"));
        datePairs.add(new Pair<String, String>("2081-03-07", "2024-06-20"));
        datePairs.add(new Pair<String, String>("2081-03-08", "2024-06-21"));
        datePairs.add(new Pair<String, String>("2081-03-09", "2024-06-22"));
        datePairs.add(new Pair<String, String>("2081-03-10", "2024-06-23"));
        datePairs.add(new Pair<String, String>("2081-03-11", "2024-06-24"));
        datePairs.add(new Pair<String, String>("2081-03-12", "2024-06-25"));
        datePairs.add(new Pair<String, String>("2081-03-13", "2024-06-26"));
        datePairs.add(new Pair<String, String>("2081-03-14", "2024-06-27"));
        datePairs.add(new Pair<String, String>("2081-03-15", "2024-06-28"));
        datePairs.add(new Pair<String, String>("2081-03-16", "2024-06-29"));
        datePairs.add(new Pair<String, String>("2081-03-17", "2024-06-30"));
        datePairs.add(new Pair<String, String>("2081-03-18", "2024-07-01"));
        datePairs.add(new Pair<String, String>("2081-03-19", "2024-07-02"));
        datePairs.add(new Pair<String, String>("2081-03-20", "2024-07-03"));
        datePairs.add(new Pair<String, String>("2081-03-21", "2024-07-04"));
        datePairs.add(new Pair<String, String>("2081-03-22", "2024-07-05"));
        datePairs.add(new Pair<String, String>("2081-03-23", "2024-07-06"));
        datePairs.add(new Pair<String, String>("2081-03-24", "2024-07-07"));
        datePairs.add(new Pair<String, String>("2081-03-25", "2024-07-08"));
        datePairs.add(new Pair<String, String>("2081-03-26", "2024-07-09"));
        datePairs.add(new Pair<String, String>("2081-03-27", "2024-07-10"));
        datePairs.add(new Pair<String, String>("2081-03-28", "2024-07-11"));
        datePairs.add(new Pair<String, String>("2081-03-29", "2024-07-12"));
        datePairs.add(new Pair<String, String>("2081-03-30", "2024-07-13"));
        datePairs.add(new Pair<String, String>("2081-03-31", "2024-07-14"));
        datePairs.add(new Pair<String, String>("2081-03-32", "2024-07-15"));
        datePairs.add(new Pair<String, String>("2081-04-01", "2024-07-16"));
        datePairs.add(new Pair<String, String>("2081-04-02", "2024-07-17"));
        datePairs.add(new Pair<String, String>("2081-04-03", "2024-07-18"));
        datePairs.add(new Pair<String, String>("2081-04-04", "2024-07-19"));
        datePairs.add(new Pair<String, String>("2081-04-05", "2024-07-20"));
        datePairs.add(new Pair<String, String>("2081-04-06", "2024-07-21"));
        datePairs.add(new Pair<String, String>("2081-04-07", "2024-07-22"));
        datePairs.add(new Pair<String, String>("2081-04-08", "2024-07-23"));
        datePairs.add(new Pair<String, String>("2081-04-09", "2024-07-24"));
        datePairs.add(new Pair<String, String>("2081-04-10", "2024-07-25"));
        datePairs.add(new Pair<String, String>("2081-04-11", "2024-07-26"));
        datePairs.add(new Pair<String, String>("2081-04-12", "2024-07-27"));
        datePairs.add(new Pair<String, String>("2081-04-13", "2024-07-28"));
        datePairs.add(new Pair<String, String>("2081-04-14", "2024-07-29"));
        datePairs.add(new Pair<String, String>("2081-04-15", "2024-07-30"));
        datePairs.add(new Pair<String, String>("2081-04-16", "2024-07-31"));
        datePairs.add(new Pair<String, String>("2081-04-17", "2024-08-01"));
        datePairs.add(new Pair<String, String>("2081-04-18", "2024-08-02"));
        datePairs.add(new Pair<String, String>("2081-04-19", "2024-08-03"));
        datePairs.add(new Pair<String, String>("2081-04-20", "2024-08-04"));
        datePairs.add(new Pair<String, String>("2081-04-21", "2024-08-05"));
        datePairs.add(new Pair<String, String>("2081-04-22", "2024-08-06"));
        datePairs.add(new Pair<String, String>("2081-04-23", "2024-08-07"));
        datePairs.add(new Pair<String, String>("2081-04-24", "2024-08-08"));
        datePairs.add(new Pair<String, String>("2081-04-25", "2024-08-09"));
        datePairs.add(new Pair<String, String>("2081-04-26", "2024-08-10"));
        datePairs.add(new Pair<String, String>("2081-04-27", "2024-08-11"));
        datePairs.add(new Pair<String, String>("2081-04-28", "2024-08-12"));
        datePairs.add(new Pair<String, String>("2081-04-29", "2024-08-13"));
        datePairs.add(new Pair<String, String>("2081-04-30", "2024-08-14"));
        datePairs.add(new Pair<String, String>("2081-04-31", "2024-08-15"));
        datePairs.add(new Pair<String, String>("2081-04-32", "2024-08-16"));
        datePairs.add(new Pair<String, String>("2081-05-01", "2024-08-17"));
        datePairs.add(new Pair<String, String>("2081-05-02", "2024-08-18"));
        datePairs.add(new Pair<String, String>("2081-05-03", "2024-08-19"));
        datePairs.add(new Pair<String, String>("2081-05-04", "2024-08-20"));
        datePairs.add(new Pair<String, String>("2081-05-05", "2024-08-21"));
        datePairs.add(new Pair<String, String>("2081-05-06", "2024-08-22"));
        datePairs.add(new Pair<String, String>("2081-05-07", "2024-08-23"));
        datePairs.add(new Pair<String, String>("2081-05-08", "2024-08-24"));
        datePairs.add(new Pair<String, String>("2081-05-09", "2024-08-25"));
        datePairs.add(new Pair<String, String>("2081-05-10", "2024-08-26"));
        datePairs.add(new Pair<String, String>("2081-05-11", "2024-08-27"));
        datePairs.add(new Pair<String, String>("2081-05-12", "2024-08-28"));
        datePairs.add(new Pair<String, String>("2081-05-13", "2024-08-29"));
        datePairs.add(new Pair<String, String>("2081-05-14", "2024-08-30"));
        datePairs.add(new Pair<String, String>("2081-05-15", "2024-08-31"));
        datePairs.add(new Pair<String, String>("2081-05-16", "2024-09-01"));
        datePairs.add(new Pair<String, String>("2081-05-17", "2024-09-02"));
        datePairs.add(new Pair<String, String>("2081-05-18", "2024-09-03"));
        datePairs.add(new Pair<String, String>("2081-05-19", "2024-09-04"));
        datePairs.add(new Pair<String, String>("2081-05-20", "2024-09-05"));
        datePairs.add(new Pair<String, String>("2081-05-21", "2024-09-06"));
        datePairs.add(new Pair<String, String>("2081-05-22", "2024-09-07"));
        datePairs.add(new Pair<String, String>("2081-05-23", "2024-09-08"));
        datePairs.add(new Pair<String, String>("2081-05-24", "2024-09-09"));
        datePairs.add(new Pair<String, String>("2081-05-25", "2024-09-10"));
        datePairs.add(new Pair<String, String>("2081-05-26", "2024-09-11"));
        datePairs.add(new Pair<String, String>("2081-05-27", "2024-09-12"));
        datePairs.add(new Pair<String, String>("2081-05-28", "2024-09-13"));
        datePairs.add(new Pair<String, String>("2081-05-29", "2024-09-14"));
        datePairs.add(new Pair<String, String>("2081-05-30", "2024-09-15"));
        datePairs.add(new Pair<String, String>("2081-05-31", "2024-09-16"));
        datePairs.add(new Pair<String, String>("2081-06-01", "2024-09-17"));
        datePairs.add(new Pair<String, String>("2081-06-02", "2024-09-18"));
        datePairs.add(new Pair<String, String>("2081-06-03", "2024-09-19"));
        datePairs.add(new Pair<String, String>("2081-06-04", "2024-09-20"));
        datePairs.add(new Pair<String, String>("2081-06-05", "2024-09-21"));
        datePairs.add(new Pair<String, String>("2081-06-06", "2024-09-22"));
        datePairs.add(new Pair<String, String>("2081-06-07", "2024-09-23"));
        datePairs.add(new Pair<String, String>("2081-06-08", "2024-09-24"));
        datePairs.add(new Pair<String, String>("2081-06-09", "2024-09-25"));
        datePairs.add(new Pair<String, String>("2081-06-10", "2024-09-26"));
        datePairs.add(new Pair<String, String>("2081-06-11", "2024-09-27"));
        datePairs.add(new Pair<String, String>("2081-06-12", "2024-09-28"));
        datePairs.add(new Pair<String, String>("2081-06-13", "2024-09-29"));
        datePairs.add(new Pair<String, String>("2081-06-14", "2024-09-30"));
        datePairs.add(new Pair<String, String>("2081-06-15", "2024-10-01"));
        datePairs.add(new Pair<String, String>("2081-06-16", "2024-10-02"));
        datePairs.add(new Pair<String, String>("2081-06-17", "2024-10-03"));
        datePairs.add(new Pair<String, String>("2081-06-18", "2024-10-04"));
        datePairs.add(new Pair<String, String>("2081-06-19", "2024-10-05"));
        datePairs.add(new Pair<String, String>("2081-06-20", "2024-10-06"));
        datePairs.add(new Pair<String, String>("2081-06-21", "2024-10-07"));
        datePairs.add(new Pair<String, String>("2081-06-22", "2024-10-08"));
        datePairs.add(new Pair<String, String>("2081-06-23", "2024-10-09"));
        datePairs.add(new Pair<String, String>("2081-06-24", "2024-10-10"));
        datePairs.add(new Pair<String, String>("2081-06-25", "2024-10-11"));
        datePairs.add(new Pair<String, String>("2081-06-26", "2024-10-12"));
        datePairs.add(new Pair<String, String>("2081-06-27", "2024-10-13"));
        datePairs.add(new Pair<String, String>("2081-06-28", "2024-10-14"));
        datePairs.add(new Pair<String, String>("2081-06-29", "2024-10-15"));
        datePairs.add(new Pair<String, String>("2081-06-30", "2024-10-16"));
        datePairs.add(new Pair<String, String>("2081-07-01", "2024-10-17"));
        datePairs.add(new Pair<String, String>("2081-07-02", "2024-10-18"));
        datePairs.add(new Pair<String, String>("2081-07-03", "2024-10-19"));
        datePairs.add(new Pair<String, String>("2081-07-04", "2024-10-20"));
        datePairs.add(new Pair<String, String>("2081-07-05", "2024-10-21"));
        datePairs.add(new Pair<String, String>("2081-07-06", "2024-10-22"));
        datePairs.add(new Pair<String, String>("2081-07-07", "2024-10-23"));
        datePairs.add(new Pair<String, String>("2081-07-08", "2024-10-24"));
        datePairs.add(new Pair<String, String>("2081-07-09", "2024-10-25"));
        datePairs.add(new Pair<String, String>("2081-07-10", "2024-10-26"));
        datePairs.add(new Pair<String, String>("2081-07-11", "2024-10-27"));
        datePairs.add(new Pair<String, String>("2081-07-12", "2024-10-28"));
        datePairs.add(new Pair<String, String>("2081-07-13", "2024-10-29"));
        datePairs.add(new Pair<String, String>("2081-07-14", "2024-10-30"));
        datePairs.add(new Pair<String, String>("2081-07-15", "2024-10-31"));
        datePairs.add(new Pair<String, String>("2081-07-16", "2024-11-01"));
        datePairs.add(new Pair<String, String>("2081-07-17", "2024-11-02"));
        datePairs.add(new Pair<String, String>("2081-07-18", "2024-11-03"));
        datePairs.add(new Pair<String, String>("2081-07-19", "2024-11-04"));
        datePairs.add(new Pair<String, String>("2081-07-20", "2024-11-05"));
        datePairs.add(new Pair<String, String>("2081-07-21", "2024-11-06"));
        datePairs.add(new Pair<String, String>("2081-07-22", "2024-11-07"));
        datePairs.add(new Pair<String, String>("2081-07-23", "2024-11-08"));
        datePairs.add(new Pair<String, String>("2081-07-24", "2024-11-09"));
        datePairs.add(new Pair<String, String>("2081-07-25", "2024-11-10"));
        datePairs.add(new Pair<String, String>("2081-07-26", "2024-11-11"));
        datePairs.add(new Pair<String, String>("2081-07-27", "2024-11-12"));
        datePairs.add(new Pair<String, String>("2081-07-28", "2024-11-13"));
        datePairs.add(new Pair<String, String>("2081-07-29", "2024-11-14"));
        datePairs.add(new Pair<String, String>("2081-07-30", "2024-11-15"));
        datePairs.add(new Pair<String, String>("2081-08-01", "2024-11-16"));
        datePairs.add(new Pair<String, String>("2081-08-02", "2024-11-17"));
        datePairs.add(new Pair<String, String>("2081-08-03", "2024-11-18"));
        datePairs.add(new Pair<String, String>("2081-08-04", "2024-11-19"));
        datePairs.add(new Pair<String, String>("2081-08-05", "2024-11-20"));
        datePairs.add(new Pair<String, String>("2081-08-06", "2024-11-21"));
        datePairs.add(new Pair<String, String>("2081-08-07", "2024-11-22"));
        datePairs.add(new Pair<String, String>("2081-08-08", "2024-11-23"));
        datePairs.add(new Pair<String, String>("2081-08-09", "2024-11-24"));
        datePairs.add(new Pair<String, String>("2081-08-10", "2024-11-25"));
        datePairs.add(new Pair<String, String>("2081-08-11", "2024-11-26"));
        datePairs.add(new Pair<String, String>("2081-08-12", "2024-11-27"));
        datePairs.add(new Pair<String, String>("2081-08-13", "2024-11-28"));
        datePairs.add(new Pair<String, String>("2081-08-14", "2024-11-29"));
        datePairs.add(new Pair<String, String>("2081-08-15", "2024-11-30"));
        datePairs.add(new Pair<String, String>("2081-08-16", "2024-12-01"));
        datePairs.add(new Pair<String, String>("2081-08-17", "2024-12-02"));
        datePairs.add(new Pair<String, String>("2081-08-18", "2024-12-03"));
        datePairs.add(new Pair<String, String>("2081-08-19", "2024-12-04"));
        datePairs.add(new Pair<String, String>("2081-08-20", "2024-12-05"));
        datePairs.add(new Pair<String, String>("2081-08-21", "2024-12-06"));
        datePairs.add(new Pair<String, String>("2081-08-22", "2024-12-07"));
        datePairs.add(new Pair<String, String>("2081-08-23", "2024-12-08"));
        datePairs.add(new Pair<String, String>("2081-08-24", "2024-12-09"));
        datePairs.add(new Pair<String, String>("2081-08-25", "2024-12-10"));
        datePairs.add(new Pair<String, String>("2081-08-26", "2024-12-11"));
        datePairs.add(new Pair<String, String>("2081-08-27", "2024-12-12"));
        datePairs.add(new Pair<String, String>("2081-08-28", "2024-12-13"));
        datePairs.add(new Pair<String, String>("2081-08-29", "2024-12-14"));
        datePairs.add(new Pair<String, String>("2081-08-30", "2024-12-15"));
        datePairs.add(new Pair<String, String>("2081-09-01", "2024-12-16"));
        datePairs.add(new Pair<String, String>("2081-09-02", "2024-12-17"));
        datePairs.add(new Pair<String, String>("2081-09-03", "2024-12-18"));
        datePairs.add(new Pair<String, String>("2081-09-04", "2024-12-19"));
        datePairs.add(new Pair<String, String>("2081-09-05", "2024-12-20"));
        datePairs.add(new Pair<String, String>("2081-09-06", "2024-12-21"));
        datePairs.add(new Pair<String, String>("2081-09-07", "2024-12-22"));
        datePairs.add(new Pair<String, String>("2081-09-08", "2024-12-23"));
        datePairs.add(new Pair<String, String>("2081-09-09", "2024-12-24"));
        datePairs.add(new Pair<String, String>("2081-09-10", "2024-12-25"));
        datePairs.add(new Pair<String, String>("2081-09-11", "2024-12-26"));
        datePairs.add(new Pair<String, String>("2081-09-12", "2024-12-27"));
        datePairs.add(new Pair<String, String>("2081-09-13", "2024-12-28"));
        datePairs.add(new Pair<String, String>("2081-09-14", "2024-12-29"));
        datePairs.add(new Pair<String, String>("2081-09-15", "2024-12-30"));
        datePairs.add(new Pair<String, String>("2081-09-16", "2024-12-31"));
        datePairs.add(new Pair<String, String>("2081-09-17", "2025-01-01"));
        datePairs.add(new Pair<String, String>("2081-09-18", "2025-01-02"));
        datePairs.add(new Pair<String, String>("2081-09-19", "2025-01-03"));
        datePairs.add(new Pair<String, String>("2081-09-20", "2025-01-04"));
        datePairs.add(new Pair<String, String>("2081-09-21", "2025-01-05"));
        datePairs.add(new Pair<String, String>("2081-09-22", "2025-01-06"));
        datePairs.add(new Pair<String, String>("2081-09-23", "2025-01-07"));
        datePairs.add(new Pair<String, String>("2081-09-24", "2025-01-08"));
        datePairs.add(new Pair<String, String>("2081-09-25", "2025-01-09"));
        datePairs.add(new Pair<String, String>("2081-09-26", "2025-01-10"));
        datePairs.add(new Pair<String, String>("2081-09-27", "2025-01-11"));
        datePairs.add(new Pair<String, String>("2081-09-28", "2025-01-12"));
        datePairs.add(new Pair<String, String>("2081-09-29", "2025-01-13"));
        datePairs.add(new Pair<String, String>("2081-10-01", "2025-01-14"));
        datePairs.add(new Pair<String, String>("2081-10-02", "2025-01-15"));
        datePairs.add(new Pair<String, String>("2081-10-03", "2025-01-16"));
        datePairs.add(new Pair<String, String>("2081-10-04", "2025-01-17"));
        datePairs.add(new Pair<String, String>("2081-10-05", "2025-01-18"));
        datePairs.add(new Pair<String, String>("2081-10-06", "2025-01-19"));
        datePairs.add(new Pair<String, String>("2081-10-07", "2025-01-20"));
        datePairs.add(new Pair<String, String>("2081-10-08", "2025-01-21"));
        datePairs.add(new Pair<String, String>("2081-10-09", "2025-01-22"));
        datePairs.add(new Pair<String, String>("2081-10-10", "2025-01-23"));
        datePairs.add(new Pair<String, String>("2081-10-11", "2025-01-24"));
        datePairs.add(new Pair<String, String>("2081-10-12", "2025-01-25"));
        datePairs.add(new Pair<String, String>("2081-10-13", "2025-01-26"));
        datePairs.add(new Pair<String, String>("2081-10-14", "2025-01-27"));
        datePairs.add(new Pair<String, String>("2081-10-15", "2025-01-28"));
        datePairs.add(new Pair<String, String>("2081-10-16", "2025-01-29"));
        datePairs.add(new Pair<String, String>("2081-10-17", "2025-01-30"));
        datePairs.add(new Pair<String, String>("2081-10-18", "2025-01-31"));
        datePairs.add(new Pair<String, String>("2081-10-19", "2025-02-01"));
        datePairs.add(new Pair<String, String>("2081-10-20", "2025-02-02"));
        datePairs.add(new Pair<String, String>("2081-10-21", "2025-02-03"));
        datePairs.add(new Pair<String, String>("2081-10-22", "2025-02-04"));
        datePairs.add(new Pair<String, String>("2081-10-23", "2025-02-05"));
        datePairs.add(new Pair<String, String>("2081-10-24", "2025-02-06"));
        datePairs.add(new Pair<String, String>("2081-10-25", "2025-02-07"));
        datePairs.add(new Pair<String, String>("2081-10-26", "2025-02-08"));
        datePairs.add(new Pair<String, String>("2081-10-27", "2025-02-09"));
        datePairs.add(new Pair<String, String>("2081-10-28", "2025-02-10"));
        datePairs.add(new Pair<String, String>("2081-10-29", "2025-02-11"));
        datePairs.add(new Pair<String, String>("2081-10-30", "2025-02-12"));
        datePairs.add(new Pair<String, String>("2081-11-01", "2025-02-13"));
        datePairs.add(new Pair<String, String>("2081-11-02", "2025-02-14"));
        datePairs.add(new Pair<String, String>("2081-11-03", "2025-02-15"));
        datePairs.add(new Pair<String, String>("2081-11-04", "2025-02-16"));
        datePairs.add(new Pair<String, String>("2081-11-05", "2025-02-17"));
        datePairs.add(new Pair<String, String>("2081-11-06", "2025-02-18"));
        datePairs.add(new Pair<String, String>("2081-11-07", "2025-02-19"));
        datePairs.add(new Pair<String, String>("2081-11-08", "2025-02-20"));
        datePairs.add(new Pair<String, String>("2081-11-09", "2025-02-21"));
        datePairs.add(new Pair<String, String>("2081-11-10", "2025-02-22"));
        datePairs.add(new Pair<String, String>("2081-11-11", "2025-02-23"));
        datePairs.add(new Pair<String, String>("2081-11-12", "2025-02-24"));
        datePairs.add(new Pair<String, String>("2081-11-13", "2025-02-25"));
        datePairs.add(new Pair<String, String>("2081-11-14", "2025-02-26"));
        datePairs.add(new Pair<String, String>("2081-11-15", "2025-02-27"));
        datePairs.add(new Pair<String, String>("2081-11-16", "2025-02-28"));
        datePairs.add(new Pair<String, String>("2081-11-17", "2025-03-01"));
        datePairs.add(new Pair<String, String>("2081-11-18", "2025-03-02"));
        datePairs.add(new Pair<String, String>("2081-11-19", "2025-03-03"));
        datePairs.add(new Pair<String, String>("2081-11-20", "2025-03-04"));
        datePairs.add(new Pair<String, String>("2081-11-21", "2025-03-05"));
        datePairs.add(new Pair<String, String>("2081-11-22", "2025-03-06"));
        datePairs.add(new Pair<String, String>("2081-11-23", "2025-03-07"));
        datePairs.add(new Pair<String, String>("2081-11-24", "2025-03-08"));
        datePairs.add(new Pair<String, String>("2081-11-25", "2025-03-09"));
        datePairs.add(new Pair<String, String>("2081-11-26", "2025-03-10"));
        datePairs.add(new Pair<String, String>("2081-11-27", "2025-03-11"));
        datePairs.add(new Pair<String, String>("2081-11-28", "2025-03-12"));
        datePairs.add(new Pair<String, String>("2081-11-29", "2025-03-13"));
        datePairs.add(new Pair<String, String>("2081-11-30", "2025-03-14"));
        datePairs.add(new Pair<String, String>("2081-12-01", "2025-03-15"));
        datePairs.add(new Pair<String, String>("2081-12-02", "2025-03-16"));
        datePairs.add(new Pair<String, String>("2081-12-03", "2025-03-17"));
        datePairs.add(new Pair<String, String>("2081-12-04", "2025-03-18"));
        datePairs.add(new Pair<String, String>("2081-12-05", "2025-03-19"));
        datePairs.add(new Pair<String, String>("2081-12-06", "2025-03-20"));
        datePairs.add(new Pair<String, String>("2081-12-07", "2025-03-21"));
        datePairs.add(new Pair<String, String>("2081-12-08", "2025-03-22"));
        datePairs.add(new Pair<String, String>("2081-12-09", "2025-03-23"));
        datePairs.add(new Pair<String, String>("2081-12-10", "2025-03-24"));
        datePairs.add(new Pair<String, String>("2081-12-11", "2025-03-25"));
        datePairs.add(new Pair<String, String>("2081-12-12", "2025-03-26"));
        datePairs.add(new Pair<String, String>("2081-12-13", "2025-03-27"));
        datePairs.add(new Pair<String, String>("2081-12-14", "2025-03-28"));
        datePairs.add(new Pair<String, String>("2081-12-15", "2025-03-29"));
        datePairs.add(new Pair<String, String>("2081-12-16", "2025-03-30"));
        datePairs.add(new Pair<String, String>("2081-12-17", "2025-03-31"));
        datePairs.add(new Pair<String, String>("2081-12-18", "2025-04-01"));
        datePairs.add(new Pair<String, String>("2081-12-19", "2025-04-02"));
        datePairs.add(new Pair<String, String>("2081-12-20", "2025-04-03"));
        datePairs.add(new Pair<String, String>("2081-12-21", "2025-04-04"));
        datePairs.add(new Pair<String, String>("2081-12-22", "2025-04-05"));
        datePairs.add(new Pair<String, String>("2081-12-23", "2025-04-06"));
        datePairs.add(new Pair<String, String>("2081-12-24", "2025-04-07"));
        datePairs.add(new Pair<String, String>("2081-12-25", "2025-04-08"));
        datePairs.add(new Pair<String, String>("2081-12-26", "2025-04-09"));
        datePairs.add(new Pair<String, String>("2081-12-27", "2025-04-10"));
        datePairs.add(new Pair<String, String>("2081-12-28", "2025-04-11"));
        datePairs.add(new Pair<String, String>("2081-12-29", "2025-04-12"));
        datePairs.add(new Pair<String, String>("2081-12-30", "2025-04-13"));
        datePairs.add(new Pair<String, String>("2082-01-01", "2025-04-14"));
        datePairs.add(new Pair<String, String>("2082-01-02", "2025-04-15"));
        datePairs.add(new Pair<String, String>("2082-01-03", "2025-04-16"));
        datePairs.add(new Pair<String, String>("2082-01-04", "2025-04-17"));
        datePairs.add(new Pair<String, String>("2082-01-05", "2025-04-18"));
        datePairs.add(new Pair<String, String>("2082-01-06", "2025-04-19"));
        datePairs.add(new Pair<String, String>("2082-01-07", "2025-04-20"));
        datePairs.add(new Pair<String, String>("2082-01-08", "2025-04-21"));
        datePairs.add(new Pair<String, String>("2082-01-09", "2025-04-22"));
        datePairs.add(new Pair<String, String>("2082-01-10", "2025-04-23"));
        datePairs.add(new Pair<String, String>("2082-01-11", "2025-04-24"));
        datePairs.add(new Pair<String, String>("2082-01-12", "2025-04-25"));
        datePairs.add(new Pair<String, String>("2082-01-13", "2025-04-26"));
        datePairs.add(new Pair<String, String>("2082-01-14", "2025-04-27"));
        datePairs.add(new Pair<String, String>("2082-01-15", "2025-04-28"));
        datePairs.add(new Pair<String, String>("2082-01-16", "2025-04-29"));
        datePairs.add(new Pair<String, String>("2082-01-17", "2025-04-30"));
        datePairs.add(new Pair<String, String>("2082-01-18", "2025-05-01"));
        datePairs.add(new Pair<String, String>("2082-01-19", "2025-05-02"));
        datePairs.add(new Pair<String, String>("2082-01-20", "2025-05-03"));
        datePairs.add(new Pair<String, String>("2082-01-21", "2025-05-04"));
        datePairs.add(new Pair<String, String>("2082-01-22", "2025-05-05"));
        datePairs.add(new Pair<String, String>("2082-01-23", "2025-05-06"));
        datePairs.add(new Pair<String, String>("2082-01-24", "2025-05-07"));
        datePairs.add(new Pair<String, String>("2082-01-25", "2025-05-08"));
        datePairs.add(new Pair<String, String>("2082-01-26", "2025-05-09"));
        datePairs.add(new Pair<String, String>("2082-01-27", "2025-05-10"));
        datePairs.add(new Pair<String, String>("2082-01-28", "2025-05-11"));
        datePairs.add(new Pair<String, String>("2082-01-29", "2025-05-12"));
        datePairs.add(new Pair<String, String>("2082-01-30", "2025-05-13"));
        datePairs.add(new Pair<String, String>("2082-02-01", "2025-05-14"));
        datePairs.add(new Pair<String, String>("2082-02-02", "2025-05-15"));
        datePairs.add(new Pair<String, String>("2082-02-03", "2025-05-16"));
        datePairs.add(new Pair<String, String>("2082-02-04", "2025-05-17"));
        datePairs.add(new Pair<String, String>("2082-02-05", "2025-05-18"));
        datePairs.add(new Pair<String, String>("2082-02-06", "2025-05-19"));
        datePairs.add(new Pair<String, String>("2082-02-07", "2025-05-20"));
        datePairs.add(new Pair<String, String>("2082-02-08", "2025-05-21"));
        datePairs.add(new Pair<String, String>("2082-02-09", "2025-05-22"));
        datePairs.add(new Pair<String, String>("2082-02-10", "2025-05-23"));
        datePairs.add(new Pair<String, String>("2082-02-11", "2025-05-24"));
        datePairs.add(new Pair<String, String>("2082-02-12", "2025-05-25"));
        datePairs.add(new Pair<String, String>("2082-02-13", "2025-05-26"));
        datePairs.add(new Pair<String, String>("2082-02-14", "2025-05-27"));
        datePairs.add(new Pair<String, String>("2082-02-15", "2025-05-28"));
        datePairs.add(new Pair<String, String>("2082-02-16", "2025-05-29"));
        datePairs.add(new Pair<String, String>("2082-02-17", "2025-05-30"));
        datePairs.add(new Pair<String, String>("2082-02-18", "2025-05-31"));
        datePairs.add(new Pair<String, String>("2082-02-19", "2025-06-01"));
        datePairs.add(new Pair<String, String>("2082-02-20", "2025-06-02"));
        datePairs.add(new Pair<String, String>("2082-02-21", "2025-06-03"));
        datePairs.add(new Pair<String, String>("2082-02-22", "2025-06-04"));
        datePairs.add(new Pair<String, String>("2082-02-23", "2025-06-05"));
        datePairs.add(new Pair<String, String>("2082-02-24", "2025-06-06"));
        datePairs.add(new Pair<String, String>("2082-02-25", "2025-06-07"));
        datePairs.add(new Pair<String, String>("2082-02-26", "2025-06-08"));
        datePairs.add(new Pair<String, String>("2082-02-27", "2025-06-09"));
        datePairs.add(new Pair<String, String>("2082-02-28", "2025-06-10"));
        datePairs.add(new Pair<String, String>("2082-02-29", "2025-06-11"));
        datePairs.add(new Pair<String, String>("2082-02-30", "2025-06-12"));
        datePairs.add(new Pair<String, String>("2082-02-31", "2025-06-13"));
        datePairs.add(new Pair<String, String>("2082-02-32", "2025-06-14"));
        datePairs.add(new Pair<String, String>("2082-03-01", "2025-06-15"));
        datePairs.add(new Pair<String, String>("2082-03-02", "2025-06-16"));
        datePairs.add(new Pair<String, String>("2082-03-03", "2025-06-17"));
        datePairs.add(new Pair<String, String>("2082-03-04", "2025-06-18"));
        datePairs.add(new Pair<String, String>("2082-03-05", "2025-06-19"));
        datePairs.add(new Pair<String, String>("2082-03-06", "2025-06-20"));
        datePairs.add(new Pair<String, String>("2082-03-07", "2025-06-21"));
        datePairs.add(new Pair<String, String>("2082-03-08", "2025-06-22"));
        datePairs.add(new Pair<String, String>("2082-03-09", "2025-06-23"));
        datePairs.add(new Pair<String, String>("2082-03-10", "2025-06-24"));
        datePairs.add(new Pair<String, String>("2082-03-11", "2025-06-25"));
        datePairs.add(new Pair<String, String>("2082-03-12", "2025-06-26"));
        datePairs.add(new Pair<String, String>("2082-03-13", "2025-06-27"));
        datePairs.add(new Pair<String, String>("2082-03-14", "2025-06-28"));
        datePairs.add(new Pair<String, String>("2082-03-15", "2025-06-29"));
        datePairs.add(new Pair<String, String>("2082-03-16", "2025-06-30"));
        datePairs.add(new Pair<String, String>("2082-03-17", "2025-07-01"));
        datePairs.add(new Pair<String, String>("2082-03-18", "2025-07-02"));
        datePairs.add(new Pair<String, String>("2082-03-19", "2025-07-03"));
        datePairs.add(new Pair<String, String>("2082-03-20", "2025-07-04"));
        datePairs.add(new Pair<String, String>("2082-03-21", "2025-07-05"));
        datePairs.add(new Pair<String, String>("2082-03-22", "2025-07-06"));
        datePairs.add(new Pair<String, String>("2082-03-23", "2025-07-07"));
        datePairs.add(new Pair<String, String>("2082-03-24", "2025-07-08"));
        datePairs.add(new Pair<String, String>("2082-03-25", "2025-07-09"));
        datePairs.add(new Pair<String, String>("2082-03-26", "2025-07-10"));
        datePairs.add(new Pair<String, String>("2082-03-27", "2025-07-11"));
        datePairs.add(new Pair<String, String>("2082-03-28", "2025-07-12"));
        datePairs.add(new Pair<String, String>("2082-03-29", "2025-07-13"));
        datePairs.add(new Pair<String, String>("2082-03-30", "2025-07-14"));
        datePairs.add(new Pair<String, String>("2082-03-31", "2025-07-15"));
        datePairs.add(new Pair<String, String>("2082-04-01", "2025-07-16"));
        datePairs.add(new Pair<String, String>("2082-04-02", "2025-07-17"));
        datePairs.add(new Pair<String, String>("2082-04-03", "2025-07-18"));
        datePairs.add(new Pair<String, String>("2082-04-04", "2025-07-19"));
        datePairs.add(new Pair<String, String>("2082-04-05", "2025-07-20"));
        datePairs.add(new Pair<String, String>("2082-04-06", "2025-07-21"));
        datePairs.add(new Pair<String, String>("2082-04-07", "2025-07-22"));
        datePairs.add(new Pair<String, String>("2082-04-08", "2025-07-23"));
        datePairs.add(new Pair<String, String>("2082-04-09", "2025-07-24"));
        datePairs.add(new Pair<String, String>("2082-04-10", "2025-07-25"));
        datePairs.add(new Pair<String, String>("2082-04-11", "2025-07-26"));
        datePairs.add(new Pair<String, String>("2082-04-12", "2025-07-27"));
        datePairs.add(new Pair<String, String>("2082-04-13", "2025-07-28"));
        datePairs.add(new Pair<String, String>("2082-04-14", "2025-07-29"));
        datePairs.add(new Pair<String, String>("2082-04-15", "2025-07-30"));
        datePairs.add(new Pair<String, String>("2082-04-16", "2025-07-31"));
        datePairs.add(new Pair<String, String>("2082-04-17", "2025-08-01"));
        datePairs.add(new Pair<String, String>("2082-04-18", "2025-08-02"));
        datePairs.add(new Pair<String, String>("2082-04-19", "2025-08-03"));
        datePairs.add(new Pair<String, String>("2082-04-20", "2025-08-04"));
        datePairs.add(new Pair<String, String>("2082-04-21", "2025-08-05"));
        datePairs.add(new Pair<String, String>("2082-04-22", "2025-08-06"));
        datePairs.add(new Pair<String, String>("2082-04-23", "2025-08-07"));
        datePairs.add(new Pair<String, String>("2082-04-24", "2025-08-08"));
        datePairs.add(new Pair<String, String>("2082-04-25", "2025-08-09"));
        datePairs.add(new Pair<String, String>("2082-04-26", "2025-08-10"));
        datePairs.add(new Pair<String, String>("2082-04-27", "2025-08-11"));
        datePairs.add(new Pair<String, String>("2082-04-28", "2025-08-12"));
        datePairs.add(new Pair<String, String>("2082-04-29", "2025-08-13"));
        datePairs.add(new Pair<String, String>("2082-04-30", "2025-08-14"));
        datePairs.add(new Pair<String, String>("2082-04-31", "2025-08-15"));
        datePairs.add(new Pair<String, String>("2082-04-32", "2025-08-16"));
        datePairs.add(new Pair<String, String>("2082-05-01", "2025-08-17"));
        datePairs.add(new Pair<String, String>("2082-05-02", "2025-08-18"));
        datePairs.add(new Pair<String, String>("2082-05-03", "2025-08-19"));
        datePairs.add(new Pair<String, String>("2082-05-04", "2025-08-20"));
        datePairs.add(new Pair<String, String>("2082-05-05", "2025-08-21"));
        datePairs.add(new Pair<String, String>("2082-05-06", "2025-08-22"));
        datePairs.add(new Pair<String, String>("2082-05-07", "2025-08-23"));
        datePairs.add(new Pair<String, String>("2082-05-08", "2025-08-24"));
        datePairs.add(new Pair<String, String>("2082-05-09", "2025-08-25"));
        datePairs.add(new Pair<String, String>("2082-05-10", "2025-08-26"));
        datePairs.add(new Pair<String, String>("2082-05-11", "2025-08-27"));
        datePairs.add(new Pair<String, String>("2082-05-12", "2025-08-28"));
        datePairs.add(new Pair<String, String>("2082-05-13", "2025-08-29"));
        datePairs.add(new Pair<String, String>("2082-05-14", "2025-08-30"));
        datePairs.add(new Pair<String, String>("2082-05-15", "2025-08-31"));
        datePairs.add(new Pair<String, String>("2082-05-16", "2025-09-01"));
        datePairs.add(new Pair<String, String>("2082-05-17", "2025-09-02"));
        datePairs.add(new Pair<String, String>("2082-05-18", "2025-09-03"));
        datePairs.add(new Pair<String, String>("2082-05-19", "2025-09-04"));
        datePairs.add(new Pair<String, String>("2082-05-20", "2025-09-05"));
        datePairs.add(new Pair<String, String>("2082-05-21", "2025-09-06"));
        datePairs.add(new Pair<String, String>("2082-05-22", "2025-09-07"));
        datePairs.add(new Pair<String, String>("2082-05-23", "2025-09-08"));
        datePairs.add(new Pair<String, String>("2082-05-24", "2025-09-09"));
        datePairs.add(new Pair<String, String>("2082-05-25", "2025-09-10"));
        datePairs.add(new Pair<String, String>("2082-05-26", "2025-09-11"));
        datePairs.add(new Pair<String, String>("2082-05-27", "2025-09-12"));
        datePairs.add(new Pair<String, String>("2082-05-28", "2025-09-13"));
        datePairs.add(new Pair<String, String>("2082-05-29", "2025-09-14"));
        datePairs.add(new Pair<String, String>("2082-05-30", "2025-09-15"));
        datePairs.add(new Pair<String, String>("2082-05-31", "2025-09-16"));
        datePairs.add(new Pair<String, String>("2082-06-01", "2025-09-17"));
        datePairs.add(new Pair<String, String>("2082-06-02", "2025-09-18"));
        datePairs.add(new Pair<String, String>("2082-06-03", "2025-09-19"));
        datePairs.add(new Pair<String, String>("2082-06-04", "2025-09-20"));
        datePairs.add(new Pair<String, String>("2082-06-05", "2025-09-21"));
        datePairs.add(new Pair<String, String>("2082-06-06", "2025-09-22"));
        datePairs.add(new Pair<String, String>("2082-06-07", "2025-09-23"));
        datePairs.add(new Pair<String, String>("2082-06-08", "2025-09-24"));
        datePairs.add(new Pair<String, String>("2082-06-09", "2025-09-25"));
        datePairs.add(new Pair<String, String>("2082-06-10", "2025-09-26"));
        datePairs.add(new Pair<String, String>("2082-06-11", "2025-09-27"));
        datePairs.add(new Pair<String, String>("2082-06-12", "2025-09-28"));
        datePairs.add(new Pair<String, String>("2082-06-13", "2025-09-29"));
        datePairs.add(new Pair<String, String>("2082-06-14", "2025-09-30"));
        datePairs.add(new Pair<String, String>("2082-06-15", "2025-10-01"));
        datePairs.add(new Pair<String, String>("2082-06-16", "2025-10-02"));
        datePairs.add(new Pair<String, String>("2082-06-17", "2025-10-03"));
        datePairs.add(new Pair<String, String>("2082-06-18", "2025-10-04"));
        datePairs.add(new Pair<String, String>("2082-06-19", "2025-10-05"));
        datePairs.add(new Pair<String, String>("2082-06-20", "2025-10-06"));
        datePairs.add(new Pair<String, String>("2082-06-21", "2025-10-07"));
        datePairs.add(new Pair<String, String>("2082-06-22", "2025-10-08"));
        datePairs.add(new Pair<String, String>("2082-06-23", "2025-10-09"));
        datePairs.add(new Pair<String, String>("2082-06-24", "2025-10-10"));
        datePairs.add(new Pair<String, String>("2082-06-25", "2025-10-11"));
        datePairs.add(new Pair<String, String>("2082-06-26", "2025-10-12"));
        datePairs.add(new Pair<String, String>("2082-06-27", "2025-10-13"));
        datePairs.add(new Pair<String, String>("2082-06-28", "2025-10-14"));
        datePairs.add(new Pair<String, String>("2082-06-29", "2025-10-15"));
        datePairs.add(new Pair<String, String>("2082-06-30", "2025-10-16"));
        datePairs.add(new Pair<String, String>("2082-07-01", "2025-10-17"));
        datePairs.add(new Pair<String, String>("2082-07-02", "2025-10-18"));
        datePairs.add(new Pair<String, String>("2082-07-03", "2025-10-19"));
        datePairs.add(new Pair<String, String>("2082-07-04", "2025-10-20"));
        datePairs.add(new Pair<String, String>("2082-07-05", "2025-10-21"));
        datePairs.add(new Pair<String, String>("2082-07-06", "2025-10-22"));
        datePairs.add(new Pair<String, String>("2082-07-07", "2025-10-23"));
        datePairs.add(new Pair<String, String>("2082-07-08", "2025-10-24"));
        datePairs.add(new Pair<String, String>("2082-07-09", "2025-10-25"));
        datePairs.add(new Pair<String, String>("2082-07-10", "2025-10-26"));
        datePairs.add(new Pair<String, String>("2082-07-11", "2025-10-27"));
        datePairs.add(new Pair<String, String>("2082-07-12", "2025-10-28"));
        datePairs.add(new Pair<String, String>("2082-07-13", "2025-10-29"));
        datePairs.add(new Pair<String, String>("2082-07-14", "2025-10-30"));
        datePairs.add(new Pair<String, String>("2082-07-15", "2025-10-31"));
        datePairs.add(new Pair<String, String>("2082-07-16", "2025-11-01"));
        datePairs.add(new Pair<String, String>("2082-07-17", "2025-11-02"));
        datePairs.add(new Pair<String, String>("2082-07-18", "2025-11-03"));
        datePairs.add(new Pair<String, String>("2082-07-19", "2025-11-04"));
        datePairs.add(new Pair<String, String>("2082-07-20", "2025-11-05"));
        datePairs.add(new Pair<String, String>("2082-07-21", "2025-11-06"));
        datePairs.add(new Pair<String, String>("2082-07-22", "2025-11-07"));
        datePairs.add(new Pair<String, String>("2082-07-23", "2025-11-08"));
        datePairs.add(new Pair<String, String>("2082-07-24", "2025-11-09"));
        datePairs.add(new Pair<String, String>("2082-07-25", "2025-11-10"));
        datePairs.add(new Pair<String, String>("2082-07-26", "2025-11-11"));
        datePairs.add(new Pair<String, String>("2082-07-27", "2025-11-12"));
        datePairs.add(new Pair<String, String>("2082-07-28", "2025-11-13"));
        datePairs.add(new Pair<String, String>("2082-07-29", "2025-11-14"));
        datePairs.add(new Pair<String, String>("2082-07-30", "2025-11-15"));
        datePairs.add(new Pair<String, String>("2082-08-01", "2025-11-16"));
        datePairs.add(new Pair<String, String>("2082-08-02", "2025-11-17"));
        datePairs.add(new Pair<String, String>("2082-08-03", "2025-11-18"));
        datePairs.add(new Pair<String, String>("2082-08-04", "2025-11-19"));
        datePairs.add(new Pair<String, String>("2082-08-05", "2025-11-20"));
        datePairs.add(new Pair<String, String>("2082-08-06", "2025-11-21"));
        datePairs.add(new Pair<String, String>("2082-08-07", "2025-11-22"));
        datePairs.add(new Pair<String, String>("2082-08-08", "2025-11-23"));
        datePairs.add(new Pair<String, String>("2082-08-09", "2025-11-24"));
        datePairs.add(new Pair<String, String>("2082-08-10", "2025-11-25"));
        datePairs.add(new Pair<String, String>("2082-08-11", "2025-11-26"));
        datePairs.add(new Pair<String, String>("2082-08-12", "2025-11-27"));
        datePairs.add(new Pair<String, String>("2082-08-13", "2025-11-28"));
        datePairs.add(new Pair<String, String>("2082-08-14", "2025-11-29"));
        datePairs.add(new Pair<String, String>("2082-08-15", "2025-11-30"));
        datePairs.add(new Pair<String, String>("2082-08-16", "2025-12-01"));
        datePairs.add(new Pair<String, String>("2082-08-17", "2025-12-02"));
        datePairs.add(new Pair<String, String>("2082-08-18", "2025-12-03"));
        datePairs.add(new Pair<String, String>("2082-08-19", "2025-12-04"));
        datePairs.add(new Pair<String, String>("2082-08-20", "2025-12-05"));
        datePairs.add(new Pair<String, String>("2082-08-21", "2025-12-06"));
        datePairs.add(new Pair<String, String>("2082-08-22", "2025-12-07"));
        datePairs.add(new Pair<String, String>("2082-08-23", "2025-12-08"));
        datePairs.add(new Pair<String, String>("2082-08-24", "2025-12-09"));
        datePairs.add(new Pair<String, String>("2082-08-25", "2025-12-10"));
        datePairs.add(new Pair<String, String>("2082-08-26", "2025-12-11"));
        datePairs.add(new Pair<String, String>("2082-08-27", "2025-12-12"));
        datePairs.add(new Pair<String, String>("2082-08-28", "2025-12-13"));
        datePairs.add(new Pair<String, String>("2082-08-29", "2025-12-14"));
        datePairs.add(new Pair<String, String>("2082-08-30", "2025-12-15"));
        datePairs.add(new Pair<String, String>("2082-09-01", "2025-12-16"));
        datePairs.add(new Pair<String, String>("2082-09-02", "2025-12-17"));
        datePairs.add(new Pair<String, String>("2082-09-03", "2025-12-18"));
        datePairs.add(new Pair<String, String>("2082-09-04", "2025-12-19"));
        datePairs.add(new Pair<String, String>("2082-09-05", "2025-12-20"));
        datePairs.add(new Pair<String, String>("2082-09-06", "2025-12-21"));
        datePairs.add(new Pair<String, String>("2082-09-07", "2025-12-22"));
        datePairs.add(new Pair<String, String>("2082-09-08", "2025-12-23"));
        datePairs.add(new Pair<String, String>("2082-09-09", "2025-12-24"));
        datePairs.add(new Pair<String, String>("2082-09-10", "2025-12-25"));
        datePairs.add(new Pair<String, String>("2082-09-11", "2025-12-26"));
        datePairs.add(new Pair<String, String>("2082-09-12", "2025-12-27"));
        datePairs.add(new Pair<String, String>("2082-09-13", "2025-12-28"));
        datePairs.add(new Pair<String, String>("2082-09-14", "2025-12-29"));
        datePairs.add(new Pair<String, String>("2082-09-15", "2025-12-30"));
        datePairs.add(new Pair<String, String>("2082-09-16", "2025-12-31"));
        datePairs.add(new Pair<String, String>("2082-09-17", "2026-01-01"));
        datePairs.add(new Pair<String, String>("2082-09-18", "2026-01-02"));
        datePairs.add(new Pair<String, String>("2082-09-19", "2026-01-03"));
        datePairs.add(new Pair<String, String>("2082-09-20", "2026-01-04"));
        datePairs.add(new Pair<String, String>("2082-09-21", "2026-01-05"));
        datePairs.add(new Pair<String, String>("2082-09-22", "2026-01-06"));
        datePairs.add(new Pair<String, String>("2082-09-23", "2026-01-07"));
        datePairs.add(new Pair<String, String>("2082-09-24", "2026-01-08"));
        datePairs.add(new Pair<String, String>("2082-09-25", "2026-01-09"));
        datePairs.add(new Pair<String, String>("2082-09-26", "2026-01-10"));
        datePairs.add(new Pair<String, String>("2082-09-27", "2026-01-11"));
        datePairs.add(new Pair<String, String>("2082-09-28", "2026-01-12"));
        datePairs.add(new Pair<String, String>("2082-09-29", "2026-01-13"));
        datePairs.add(new Pair<String, String>("2082-10-01", "2026-01-14"));
        datePairs.add(new Pair<String, String>("2082-10-02", "2026-01-15"));
        datePairs.add(new Pair<String, String>("2082-10-03", "2026-01-16"));
        datePairs.add(new Pair<String, String>("2082-10-04", "2026-01-17"));
        datePairs.add(new Pair<String, String>("2082-10-05", "2026-01-18"));
        datePairs.add(new Pair<String, String>("2082-10-06", "2026-01-19"));
        datePairs.add(new Pair<String, String>("2082-10-07", "2026-01-20"));
        datePairs.add(new Pair<String, String>("2082-10-08", "2026-01-21"));
        datePairs.add(new Pair<String, String>("2082-10-09", "2026-01-22"));
        datePairs.add(new Pair<String, String>("2082-10-10", "2026-01-23"));
        datePairs.add(new Pair<String, String>("2082-10-11", "2026-01-24"));
        datePairs.add(new Pair<String, String>("2082-10-12", "2026-01-25"));
        datePairs.add(new Pair<String, String>("2082-10-13", "2026-01-26"));
        datePairs.add(new Pair<String, String>("2082-10-14", "2026-01-27"));
        datePairs.add(new Pair<String, String>("2082-10-15", "2026-01-28"));
        datePairs.add(new Pair<String, String>("2082-10-16", "2026-01-29"));
        datePairs.add(new Pair<String, String>("2082-10-17", "2026-01-30"));
        datePairs.add(new Pair<String, String>("2082-10-18", "2026-01-31"));
        datePairs.add(new Pair<String, String>("2082-10-19", "2026-02-01"));
        datePairs.add(new Pair<String, String>("2082-10-20", "2026-02-02"));
        datePairs.add(new Pair<String, String>("2082-10-21", "2026-02-03"));
        datePairs.add(new Pair<String, String>("2082-10-22", "2026-02-04"));
        datePairs.add(new Pair<String, String>("2082-10-23", "2026-02-05"));
        datePairs.add(new Pair<String, String>("2082-10-24", "2026-02-06"));
        datePairs.add(new Pair<String, String>("2082-10-25", "2026-02-07"));
        datePairs.add(new Pair<String, String>("2082-10-26", "2026-02-08"));
        datePairs.add(new Pair<String, String>("2082-10-27", "2026-02-09"));
        datePairs.add(new Pair<String, String>("2082-10-28", "2026-02-10"));
        datePairs.add(new Pair<String, String>("2082-10-29", "2026-02-11"));
        datePairs.add(new Pair<String, String>("2082-10-30", "2026-02-12"));
        datePairs.add(new Pair<String, String>("2082-11-01", "2026-02-13"));
        datePairs.add(new Pair<String, String>("2082-11-02", "2026-02-14"));
        datePairs.add(new Pair<String, String>("2082-11-03", "2026-02-15"));
        datePairs.add(new Pair<String, String>("2082-11-04", "2026-02-16"));
        datePairs.add(new Pair<String, String>("2082-11-05", "2026-02-17"));
        datePairs.add(new Pair<String, String>("2082-11-06", "2026-02-18"));
        datePairs.add(new Pair<String, String>("2082-11-07", "2026-02-19"));
        datePairs.add(new Pair<String, String>("2082-11-08", "2026-02-20"));
        datePairs.add(new Pair<String, String>("2082-11-09", "2026-02-21"));
        datePairs.add(new Pair<String, String>("2082-11-10", "2026-02-22"));
        datePairs.add(new Pair<String, String>("2082-11-11", "2026-02-23"));
        datePairs.add(new Pair<String, String>("2082-11-12", "2026-02-24"));
        datePairs.add(new Pair<String, String>("2082-11-13", "2026-02-25"));
        datePairs.add(new Pair<String, String>("2082-11-14", "2026-02-26"));
        datePairs.add(new Pair<String, String>("2082-11-15", "2026-02-27"));
        datePairs.add(new Pair<String, String>("2082-11-16", "2026-02-28"));
        datePairs.add(new Pair<String, String>("2082-11-17", "2026-03-01"));
        datePairs.add(new Pair<String, String>("2082-11-18", "2026-03-02"));
        datePairs.add(new Pair<String, String>("2082-11-19", "2026-03-03"));
        datePairs.add(new Pair<String, String>("2082-11-20", "2026-03-04"));
        datePairs.add(new Pair<String, String>("2082-11-21", "2026-03-05"));
        datePairs.add(new Pair<String, String>("2082-11-22", "2026-03-06"));
        datePairs.add(new Pair<String, String>("2082-11-23", "2026-03-07"));
        datePairs.add(new Pair<String, String>("2082-11-24", "2026-03-08"));
        datePairs.add(new Pair<String, String>("2082-11-25", "2026-03-09"));
        datePairs.add(new Pair<String, String>("2082-11-26", "2026-03-10"));
        datePairs.add(new Pair<String, String>("2082-11-27", "2026-03-11"));
        datePairs.add(new Pair<String, String>("2082-11-28", "2026-03-12"));
        datePairs.add(new Pair<String, String>("2082-11-29", "2026-03-13"));
        datePairs.add(new Pair<String, String>("2082-11-30", "2026-03-14"));
        datePairs.add(new Pair<String, String>("2082-12-01", "2026-03-15"));
        datePairs.add(new Pair<String, String>("2082-12-02", "2026-03-16"));
        datePairs.add(new Pair<String, String>("2082-12-03", "2026-03-17"));
        datePairs.add(new Pair<String, String>("2082-12-04", "2026-03-18"));
        datePairs.add(new Pair<String, String>("2082-12-05", "2026-03-19"));
        datePairs.add(new Pair<String, String>("2082-12-06", "2026-03-20"));
        datePairs.add(new Pair<String, String>("2082-12-07", "2026-03-21"));
        datePairs.add(new Pair<String, String>("2082-12-08", "2026-03-22"));
        datePairs.add(new Pair<String, String>("2082-12-09", "2026-03-23"));
        datePairs.add(new Pair<String, String>("2082-12-10", "2026-03-24"));
        datePairs.add(new Pair<String, String>("2082-12-11", "2026-03-25"));
        datePairs.add(new Pair<String, String>("2082-12-12", "2026-03-26"));
        datePairs.add(new Pair<String, String>("2082-12-13", "2026-03-27"));
        datePairs.add(new Pair<String, String>("2082-12-14", "2026-03-28"));
        datePairs.add(new Pair<String, String>("2082-12-15", "2026-03-29"));
        datePairs.add(new Pair<String, String>("2082-12-16", "2026-03-30"));
        datePairs.add(new Pair<String, String>("2082-12-17", "2026-03-31"));
        datePairs.add(new Pair<String, String>("2082-12-18", "2026-04-01"));
        datePairs.add(new Pair<String, String>("2082-12-19", "2026-04-02"));
        datePairs.add(new Pair<String, String>("2082-12-20", "2026-04-03"));
        datePairs.add(new Pair<String, String>("2082-12-21", "2026-04-04"));
        datePairs.add(new Pair<String, String>("2082-12-22", "2026-04-05"));
        datePairs.add(new Pair<String, String>("2082-12-23", "2026-04-06"));
        datePairs.add(new Pair<String, String>("2082-12-24", "2026-04-07"));
        datePairs.add(new Pair<String, String>("2082-12-25", "2026-04-08"));
        datePairs.add(new Pair<String, String>("2082-12-26", "2026-04-09"));
        datePairs.add(new Pair<String, String>("2082-12-27", "2026-04-10"));
        datePairs.add(new Pair<String, String>("2082-12-28", "2026-04-11"));
        datePairs.add(new Pair<String, String>("2082-12-29", "2026-04-12"));
        datePairs.add(new Pair<String, String>("2082-12-30", "2026-04-13"));
        datePairs.add(new Pair<String, String>("2083-01-01", "2026-04-14"));
        datePairs.add(new Pair<String, String>("2083-01-02", "2026-04-15"));
        datePairs.add(new Pair<String, String>("2083-01-03", "2026-04-16"));
        datePairs.add(new Pair<String, String>("2083-01-04", "2026-04-17"));
        datePairs.add(new Pair<String, String>("2083-01-05", "2026-04-18"));
        datePairs.add(new Pair<String, String>("2083-01-06", "2026-04-19"));
        datePairs.add(new Pair<String, String>("2083-01-07", "2026-04-20"));
        datePairs.add(new Pair<String, String>("2083-01-08", "2026-04-21"));
        datePairs.add(new Pair<String, String>("2083-01-09", "2026-04-22"));
        datePairs.add(new Pair<String, String>("2083-01-10", "2026-04-23"));
        datePairs.add(new Pair<String, String>("2083-01-11", "2026-04-24"));
        datePairs.add(new Pair<String, String>("2083-01-12", "2026-04-25"));
        datePairs.add(new Pair<String, String>("2083-01-13", "2026-04-26"));
        datePairs.add(new Pair<String, String>("2083-01-14", "2026-04-27"));
        datePairs.add(new Pair<String, String>("2083-01-15", "2026-04-28"));
        datePairs.add(new Pair<String, String>("2083-01-16", "2026-04-29"));
        datePairs.add(new Pair<String, String>("2083-01-17", "2026-04-30"));
        datePairs.add(new Pair<String, String>("2083-01-18", "2026-05-01"));
        datePairs.add(new Pair<String, String>("2083-01-19", "2026-05-02"));
        datePairs.add(new Pair<String, String>("2083-01-20", "2026-05-03"));
        datePairs.add(new Pair<String, String>("2083-01-21", "2026-05-04"));
        datePairs.add(new Pair<String, String>("2083-01-22", "2026-05-05"));
        datePairs.add(new Pair<String, String>("2083-01-23", "2026-05-06"));
        datePairs.add(new Pair<String, String>("2083-01-24", "2026-05-07"));
        datePairs.add(new Pair<String, String>("2083-01-25", "2026-05-08"));
        datePairs.add(new Pair<String, String>("2083-01-26", "2026-05-09"));
        datePairs.add(new Pair<String, String>("2083-01-27", "2026-05-10"));
        datePairs.add(new Pair<String, String>("2083-01-28", "2026-05-11"));
        datePairs.add(new Pair<String, String>("2083-01-29", "2026-05-12"));
        datePairs.add(new Pair<String, String>("2083-01-30", "2026-05-13"));
        datePairs.add(new Pair<String, String>("2083-01-31", "2026-05-14"));
        datePairs.add(new Pair<String, String>("2083-02-01", "2026-05-15"));
        datePairs.add(new Pair<String, String>("2083-02-02", "2026-05-16"));
        datePairs.add(new Pair<String, String>("2083-02-03", "2026-05-17"));
        datePairs.add(new Pair<String, String>("2083-02-04", "2026-05-18"));
        datePairs.add(new Pair<String, String>("2083-02-05", "2026-05-19"));
        datePairs.add(new Pair<String, String>("2083-02-06", "2026-05-20"));
        datePairs.add(new Pair<String, String>("2083-02-07", "2026-05-21"));
        datePairs.add(new Pair<String, String>("2083-02-08", "2026-05-22"));
        datePairs.add(new Pair<String, String>("2083-02-09", "2026-05-23"));
        datePairs.add(new Pair<String, String>("2083-02-10", "2026-05-24"));
        datePairs.add(new Pair<String, String>("2083-02-11", "2026-05-25"));
        datePairs.add(new Pair<String, String>("2083-02-12", "2026-05-26"));
        datePairs.add(new Pair<String, String>("2083-02-13", "2026-05-27"));
        datePairs.add(new Pair<String, String>("2083-02-14", "2026-05-28"));
        datePairs.add(new Pair<String, String>("2083-02-15", "2026-05-29"));
        datePairs.add(new Pair<String, String>("2083-02-16", "2026-05-30"));
        datePairs.add(new Pair<String, String>("2083-02-17", "2026-05-31"));
        datePairs.add(new Pair<String, String>("2083-02-18", "2026-06-01"));
        datePairs.add(new Pair<String, String>("2083-02-19", "2026-06-02"));
        datePairs.add(new Pair<String, String>("2083-02-20", "2026-06-03"));
        datePairs.add(new Pair<String, String>("2083-02-21", "2026-06-04"));
        datePairs.add(new Pair<String, String>("2083-02-22", "2026-06-05"));
        datePairs.add(new Pair<String, String>("2083-02-23", "2026-06-06"));
        datePairs.add(new Pair<String, String>("2083-02-24", "2026-06-07"));
        datePairs.add(new Pair<String, String>("2083-02-25", "2026-06-08"));
        datePairs.add(new Pair<String, String>("2083-02-26", "2026-06-09"));
        datePairs.add(new Pair<String, String>("2083-02-27", "2026-06-10"));
        datePairs.add(new Pair<String, String>("2083-02-28", "2026-06-11"));
        datePairs.add(new Pair<String, String>("2083-02-29", "2026-06-12"));
        datePairs.add(new Pair<String, String>("2083-02-30", "2026-06-13"));
        datePairs.add(new Pair<String, String>("2083-02-31", "2026-06-14"));
        datePairs.add(new Pair<String, String>("2083-03-01", "2026-06-15"));
        datePairs.add(new Pair<String, String>("2083-03-02", "2026-06-16"));
        datePairs.add(new Pair<String, String>("2083-03-03", "2026-06-17"));
        datePairs.add(new Pair<String, String>("2083-03-04", "2026-06-18"));
        datePairs.add(new Pair<String, String>("2083-03-05", "2026-06-19"));
        datePairs.add(new Pair<String, String>("2083-03-06", "2026-06-20"));
        datePairs.add(new Pair<String, String>("2083-03-07", "2026-06-21"));
        datePairs.add(new Pair<String, String>("2083-03-08", "2026-06-22"));
        datePairs.add(new Pair<String, String>("2083-03-09", "2026-06-23"));
        datePairs.add(new Pair<String, String>("2083-03-10", "2026-06-24"));
        datePairs.add(new Pair<String, String>("2083-03-11", "2026-06-25"));
        datePairs.add(new Pair<String, String>("2083-03-12", "2026-06-26"));
        datePairs.add(new Pair<String, String>("2083-03-13", "2026-06-27"));
        datePairs.add(new Pair<String, String>("2083-03-14", "2026-06-28"));
        datePairs.add(new Pair<String, String>("2083-03-15", "2026-06-29"));
        datePairs.add(new Pair<String, String>("2083-03-16", "2026-06-30"));
        datePairs.add(new Pair<String, String>("2083-03-17", "2026-07-01"));
        datePairs.add(new Pair<String, String>("2083-03-18", "2026-07-02"));
        datePairs.add(new Pair<String, String>("2083-03-19", "2026-07-03"));
        datePairs.add(new Pair<String, String>("2083-03-20", "2026-07-04"));
        datePairs.add(new Pair<String, String>("2083-03-21", "2026-07-05"));
        datePairs.add(new Pair<String, String>("2083-03-22", "2026-07-06"));
        datePairs.add(new Pair<String, String>("2083-03-23", "2026-07-07"));
        datePairs.add(new Pair<String, String>("2083-03-24", "2026-07-08"));
        datePairs.add(new Pair<String, String>("2083-03-25", "2026-07-09"));
        datePairs.add(new Pair<String, String>("2083-03-26", "2026-07-10"));
        datePairs.add(new Pair<String, String>("2083-03-27", "2026-07-11"));
        datePairs.add(new Pair<String, String>("2083-03-28", "2026-07-12"));
        datePairs.add(new Pair<String, String>("2083-03-29", "2026-07-13"));
        datePairs.add(new Pair<String, String>("2083-03-30", "2026-07-14"));
        datePairs.add(new Pair<String, String>("2083-03-31", "2026-07-15"));
        datePairs.add(new Pair<String, String>("2083-03-32", "2026-07-16"));
        datePairs.add(new Pair<String, String>("2083-04-01", "2026-07-17"));
        datePairs.add(new Pair<String, String>("2083-04-02", "2026-07-18"));
        datePairs.add(new Pair<String, String>("2083-04-03", "2026-07-19"));
        datePairs.add(new Pair<String, String>("2083-04-04", "2026-07-20"));
        datePairs.add(new Pair<String, String>("2083-04-05", "2026-07-21"));
        datePairs.add(new Pair<String, String>("2083-04-06", "2026-07-22"));
        datePairs.add(new Pair<String, String>("2083-04-07", "2026-07-23"));
        datePairs.add(new Pair<String, String>("2083-04-08", "2026-07-24"));
        datePairs.add(new Pair<String, String>("2083-04-09", "2026-07-25"));
        datePairs.add(new Pair<String, String>("2083-04-10", "2026-07-26"));
        datePairs.add(new Pair<String, String>("2083-04-11", "2026-07-27"));
        datePairs.add(new Pair<String, String>("2083-04-12", "2026-07-28"));
        datePairs.add(new Pair<String, String>("2083-04-13", "2026-07-29"));
        datePairs.add(new Pair<String, String>("2083-04-14", "2026-07-30"));
        datePairs.add(new Pair<String, String>("2083-04-15", "2026-07-31"));
        datePairs.add(new Pair<String, String>("2083-04-16", "2026-08-01"));
        datePairs.add(new Pair<String, String>("2083-04-17", "2026-08-02"));
        datePairs.add(new Pair<String, String>("2083-04-18", "2026-08-03"));
        datePairs.add(new Pair<String, String>("2083-04-19", "2026-08-04"));
        datePairs.add(new Pair<String, String>("2083-04-20", "2026-08-05"));
        datePairs.add(new Pair<String, String>("2083-04-21", "2026-08-06"));
        datePairs.add(new Pair<String, String>("2083-04-22", "2026-08-07"));
        datePairs.add(new Pair<String, String>("2083-04-23", "2026-08-08"));
        datePairs.add(new Pair<String, String>("2083-04-24", "2026-08-09"));
        datePairs.add(new Pair<String, String>("2083-04-25", "2026-08-10"));
        datePairs.add(new Pair<String, String>("2083-04-26", "2026-08-11"));
        datePairs.add(new Pair<String, String>("2083-04-27", "2026-08-12"));
        datePairs.add(new Pair<String, String>("2083-04-28", "2026-08-13"));
        datePairs.add(new Pair<String, String>("2083-04-29", "2026-08-14"));
        datePairs.add(new Pair<String, String>("2083-04-30", "2026-08-15"));
        datePairs.add(new Pair<String, String>("2083-04-31", "2026-08-16"));
        datePairs.add(new Pair<String, String>("2083-05-01", "2026-08-17"));
        datePairs.add(new Pair<String, String>("2083-05-02", "2026-08-18"));
        datePairs.add(new Pair<String, String>("2083-05-03", "2026-08-19"));
        datePairs.add(new Pair<String, String>("2083-05-04", "2026-08-20"));
        datePairs.add(new Pair<String, String>("2083-05-05", "2026-08-21"));
        datePairs.add(new Pair<String, String>("2083-05-06", "2026-08-22"));
        datePairs.add(new Pair<String, String>("2083-05-07", "2026-08-23"));
        datePairs.add(new Pair<String, String>("2083-05-08", "2026-08-24"));
        datePairs.add(new Pair<String, String>("2083-05-09", "2026-08-25"));
        datePairs.add(new Pair<String, String>("2083-05-10", "2026-08-26"));
        datePairs.add(new Pair<String, String>("2083-05-11", "2026-08-27"));
        datePairs.add(new Pair<String, String>("2083-05-12", "2026-08-28"));
        datePairs.add(new Pair<String, String>("2083-05-13", "2026-08-29"));
        datePairs.add(new Pair<String, String>("2083-05-14", "2026-08-30"));
        datePairs.add(new Pair<String, String>("2083-05-15", "2026-08-31"));
        datePairs.add(new Pair<String, String>("2083-05-16", "2026-09-01"));
        datePairs.add(new Pair<String, String>("2083-05-17", "2026-09-02"));
        datePairs.add(new Pair<String, String>("2083-05-18", "2026-09-03"));
        datePairs.add(new Pair<String, String>("2083-05-19", "2026-09-04"));
        datePairs.add(new Pair<String, String>("2083-05-20", "2026-09-05"));
        datePairs.add(new Pair<String, String>("2083-05-21", "2026-09-06"));
        datePairs.add(new Pair<String, String>("2083-05-22", "2026-09-07"));
        datePairs.add(new Pair<String, String>("2083-05-23", "2026-09-08"));
        datePairs.add(new Pair<String, String>("2083-05-24", "2026-09-09"));
        datePairs.add(new Pair<String, String>("2083-05-25", "2026-09-10"));
        datePairs.add(new Pair<String, String>("2083-05-26", "2026-09-11"));
        datePairs.add(new Pair<String, String>("2083-05-27", "2026-09-12"));
        datePairs.add(new Pair<String, String>("2083-05-28", "2026-09-13"));
        datePairs.add(new Pair<String, String>("2083-05-29", "2026-09-14"));
        datePairs.add(new Pair<String, String>("2083-05-30", "2026-09-15"));
        datePairs.add(new Pair<String, String>("2083-05-31", "2026-09-16"));
        datePairs.add(new Pair<String, String>("2083-06-01", "2026-09-17"));
        datePairs.add(new Pair<String, String>("2083-06-02", "2026-09-18"));
        datePairs.add(new Pair<String, String>("2083-06-03", "2026-09-19"));
        datePairs.add(new Pair<String, String>("2083-06-04", "2026-09-20"));
        datePairs.add(new Pair<String, String>("2083-06-05", "2026-09-21"));
        datePairs.add(new Pair<String, String>("2083-06-06", "2026-09-22"));
        datePairs.add(new Pair<String, String>("2083-06-07", "2026-09-23"));
        datePairs.add(new Pair<String, String>("2083-06-08", "2026-09-24"));
        datePairs.add(new Pair<String, String>("2083-06-09", "2026-09-25"));
        datePairs.add(new Pair<String, String>("2083-06-10", "2026-09-26"));
        datePairs.add(new Pair<String, String>("2083-06-11", "2026-09-27"));
        datePairs.add(new Pair<String, String>("2083-06-12", "2026-09-28"));
        datePairs.add(new Pair<String, String>("2083-06-13", "2026-09-29"));
        datePairs.add(new Pair<String, String>("2083-06-14", "2026-09-30"));
        datePairs.add(new Pair<String, String>("2083-06-15", "2026-10-01"));
        datePairs.add(new Pair<String, String>("2083-06-16", "2026-10-02"));
        datePairs.add(new Pair<String, String>("2083-06-17", "2026-10-03"));
        datePairs.add(new Pair<String, String>("2083-06-18", "2026-10-04"));
        datePairs.add(new Pair<String, String>("2083-06-19", "2026-10-05"));
        datePairs.add(new Pair<String, String>("2083-06-20", "2026-10-06"));
        datePairs.add(new Pair<String, String>("2083-06-21", "2026-10-07"));
        datePairs.add(new Pair<String, String>("2083-06-22", "2026-10-08"));
        datePairs.add(new Pair<String, String>("2083-06-23", "2026-10-09"));
        datePairs.add(new Pair<String, String>("2083-06-24", "2026-10-10"));
        datePairs.add(new Pair<String, String>("2083-06-25", "2026-10-11"));
        datePairs.add(new Pair<String, String>("2083-06-26", "2026-10-12"));
        datePairs.add(new Pair<String, String>("2083-06-27", "2026-10-13"));
        datePairs.add(new Pair<String, String>("2083-06-28", "2026-10-14"));
        datePairs.add(new Pair<String, String>("2083-06-29", "2026-10-15"));
        datePairs.add(new Pair<String, String>("2083-06-30", "2026-10-16"));
        datePairs.add(new Pair<String, String>("2083-07-01", "2026-10-17"));
        datePairs.add(new Pair<String, String>("2083-07-02", "2026-10-18"));
        datePairs.add(new Pair<String, String>("2083-07-03", "2026-10-19"));
        datePairs.add(new Pair<String, String>("2083-07-04", "2026-10-20"));
        datePairs.add(new Pair<String, String>("2083-07-05", "2026-10-21"));
        datePairs.add(new Pair<String, String>("2083-07-06", "2026-10-22"));
        datePairs.add(new Pair<String, String>("2083-07-07", "2026-10-23"));
        datePairs.add(new Pair<String, String>("2083-07-08", "2026-10-24"));
        datePairs.add(new Pair<String, String>("2083-07-09", "2026-10-25"));
        datePairs.add(new Pair<String, String>("2083-07-10", "2026-10-26"));
        datePairs.add(new Pair<String, String>("2083-07-11", "2026-10-27"));
        datePairs.add(new Pair<String, String>("2083-07-12", "2026-10-28"));
        datePairs.add(new Pair<String, String>("2083-07-13", "2026-10-29"));
        datePairs.add(new Pair<String, String>("2083-07-14", "2026-10-30"));
        datePairs.add(new Pair<String, String>("2083-07-15", "2026-10-31"));
        datePairs.add(new Pair<String, String>("2083-07-16", "2026-11-01"));
        datePairs.add(new Pair<String, String>("2083-07-17", "2026-11-02"));
        datePairs.add(new Pair<String, String>("2083-07-18", "2026-11-03"));
        datePairs.add(new Pair<String, String>("2083-07-19", "2026-11-04"));
        datePairs.add(new Pair<String, String>("2083-07-20", "2026-11-05"));
        datePairs.add(new Pair<String, String>("2083-07-21", "2026-11-06"));
        datePairs.add(new Pair<String, String>("2083-07-22", "2026-11-07"));
        datePairs.add(new Pair<String, String>("2083-07-23", "2026-11-08"));
        datePairs.add(new Pair<String, String>("2083-07-24", "2026-11-09"));
        datePairs.add(new Pair<String, String>("2083-07-25", "2026-11-10"));
        datePairs.add(new Pair<String, String>("2083-07-26", "2026-11-11"));
        datePairs.add(new Pair<String, String>("2083-07-27", "2026-11-12"));
        datePairs.add(new Pair<String, String>("2083-07-28", "2026-11-13"));
        datePairs.add(new Pair<String, String>("2083-07-29", "2026-11-14"));
        datePairs.add(new Pair<String, String>("2083-07-30", "2026-11-15"));
        datePairs.add(new Pair<String, String>("2083-08-01", "2026-11-16"));
        datePairs.add(new Pair<String, String>("2083-08-02", "2026-11-17"));
        datePairs.add(new Pair<String, String>("2083-08-03", "2026-11-18"));
        datePairs.add(new Pair<String, String>("2083-08-04", "2026-11-19"));
        datePairs.add(new Pair<String, String>("2083-08-05", "2026-11-20"));
        datePairs.add(new Pair<String, String>("2083-08-06", "2026-11-21"));
        datePairs.add(new Pair<String, String>("2083-08-07", "2026-11-22"));
        datePairs.add(new Pair<String, String>("2083-08-08", "2026-11-23"));
        datePairs.add(new Pair<String, String>("2083-08-09", "2026-11-24"));
        datePairs.add(new Pair<String, String>("2083-08-10", "2026-11-25"));
        datePairs.add(new Pair<String, String>("2083-08-11", "2026-11-26"));
        datePairs.add(new Pair<String, String>("2083-08-12", "2026-11-27"));
        datePairs.add(new Pair<String, String>("2083-08-13", "2026-11-28"));
        datePairs.add(new Pair<String, String>("2083-08-14", "2026-11-29"));
        datePairs.add(new Pair<String, String>("2083-08-15", "2026-11-30"));
        datePairs.add(new Pair<String, String>("2083-08-16", "2026-12-01"));
        datePairs.add(new Pair<String, String>("2083-08-17", "2026-12-02"));
        datePairs.add(new Pair<String, String>("2083-08-18", "2026-12-03"));
        datePairs.add(new Pair<String, String>("2083-08-19", "2026-12-04"));
        datePairs.add(new Pair<String, String>("2083-08-20", "2026-12-05"));
        datePairs.add(new Pair<String, String>("2083-08-21", "2026-12-06"));
        datePairs.add(new Pair<String, String>("2083-08-22", "2026-12-07"));
        datePairs.add(new Pair<String, String>("2083-08-23", "2026-12-08"));
        datePairs.add(new Pair<String, String>("2083-08-24", "2026-12-09"));
        datePairs.add(new Pair<String, String>("2083-08-25", "2026-12-10"));
        datePairs.add(new Pair<String, String>("2083-08-26", "2026-12-11"));
        datePairs.add(new Pair<String, String>("2083-08-27", "2026-12-12"));
        datePairs.add(new Pair<String, String>("2083-08-28", "2026-12-13"));
        datePairs.add(new Pair<String, String>("2083-08-29", "2026-12-14"));
        datePairs.add(new Pair<String, String>("2083-08-30", "2026-12-15"));
        datePairs.add(new Pair<String, String>("2083-09-01", "2026-12-16"));
        datePairs.add(new Pair<String, String>("2083-09-02", "2026-12-17"));
        datePairs.add(new Pair<String, String>("2083-09-03", "2026-12-18"));
        datePairs.add(new Pair<String, String>("2083-09-04", "2026-12-19"));
        datePairs.add(new Pair<String, String>("2083-09-05", "2026-12-20"));
        datePairs.add(new Pair<String, String>("2083-09-06", "2026-12-21"));
        datePairs.add(new Pair<String, String>("2083-09-07", "2026-12-22"));
        datePairs.add(new Pair<String, String>("2083-09-08", "2026-12-23"));
        datePairs.add(new Pair<String, String>("2083-09-09", "2026-12-24"));
        datePairs.add(new Pair<String, String>("2083-09-10", "2026-12-25"));
        datePairs.add(new Pair<String, String>("2083-09-11", "2026-12-26"));
        datePairs.add(new Pair<String, String>("2083-09-12", "2026-12-27"));
        datePairs.add(new Pair<String, String>("2083-09-13", "2026-12-28"));
        datePairs.add(new Pair<String, String>("2083-09-14", "2026-12-29"));
        datePairs.add(new Pair<String, String>("2083-09-15", "2026-12-30"));
        datePairs.add(new Pair<String, String>("2083-09-16", "2026-12-31"));
        datePairs.add(new Pair<String, String>("2083-09-17", "2027-01-01"));
        datePairs.add(new Pair<String, String>("2083-09-18", "2027-01-02"));
        datePairs.add(new Pair<String, String>("2083-09-19", "2027-01-03"));
        datePairs.add(new Pair<String, String>("2083-09-20", "2027-01-04"));
        datePairs.add(new Pair<String, String>("2083-09-21", "2027-01-05"));
        datePairs.add(new Pair<String, String>("2083-09-22", "2027-01-06"));
        datePairs.add(new Pair<String, String>("2083-09-23", "2027-01-07"));
        datePairs.add(new Pair<String, String>("2083-09-24", "2027-01-08"));
        datePairs.add(new Pair<String, String>("2083-09-25", "2027-01-09"));
        datePairs.add(new Pair<String, String>("2083-09-26", "2027-01-10"));
        datePairs.add(new Pair<String, String>("2083-09-27", "2027-01-11"));
        datePairs.add(new Pair<String, String>("2083-09-28", "2027-01-12"));
        datePairs.add(new Pair<String, String>("2083-09-29", "2027-01-13"));
        datePairs.add(new Pair<String, String>("2083-10-01", "2027-01-14"));
        datePairs.add(new Pair<String, String>("2083-10-02", "2027-01-15"));
        datePairs.add(new Pair<String, String>("2083-10-03", "2027-01-16"));
        datePairs.add(new Pair<String, String>("2083-10-04", "2027-01-17"));
        datePairs.add(new Pair<String, String>("2083-10-05", "2027-01-18"));
        datePairs.add(new Pair<String, String>("2083-10-06", "2027-01-19"));
        datePairs.add(new Pair<String, String>("2083-10-07", "2027-01-20"));
        datePairs.add(new Pair<String, String>("2083-10-08", "2027-01-21"));
        datePairs.add(new Pair<String, String>("2083-10-09", "2027-01-22"));
        datePairs.add(new Pair<String, String>("2083-10-10", "2027-01-23"));
        datePairs.add(new Pair<String, String>("2083-10-11", "2027-01-24"));
        datePairs.add(new Pair<String, String>("2083-10-12", "2027-01-25"));
        datePairs.add(new Pair<String, String>("2083-10-13", "2027-01-26"));
        datePairs.add(new Pair<String, String>("2083-10-14", "2027-01-27"));
        datePairs.add(new Pair<String, String>("2083-10-15", "2027-01-28"));
        datePairs.add(new Pair<String, String>("2083-10-16", "2027-01-29"));
        datePairs.add(new Pair<String, String>("2083-10-17", "2027-01-30"));
        datePairs.add(new Pair<String, String>("2083-10-18", "2027-01-31"));
        datePairs.add(new Pair<String, String>("2083-10-19", "2027-02-01"));
        datePairs.add(new Pair<String, String>("2083-10-20", "2027-02-02"));
        datePairs.add(new Pair<String, String>("2083-10-21", "2027-02-03"));
        datePairs.add(new Pair<String, String>("2083-10-22", "2027-02-04"));
        datePairs.add(new Pair<String, String>("2083-10-23", "2027-02-05"));
        datePairs.add(new Pair<String, String>("2083-10-24", "2027-02-06"));
        datePairs.add(new Pair<String, String>("2083-10-25", "2027-02-07"));
        datePairs.add(new Pair<String, String>("2083-10-26", "2027-02-08"));
        datePairs.add(new Pair<String, String>("2083-10-27", "2027-02-09"));
        datePairs.add(new Pair<String, String>("2083-10-28", "2027-02-10"));
        datePairs.add(new Pair<String, String>("2083-10-29", "2027-02-11"));
        datePairs.add(new Pair<String, String>("2083-10-30", "2027-02-12"));
        datePairs.add(new Pair<String, String>("2083-11-01", "2027-02-13"));
        datePairs.add(new Pair<String, String>("2083-11-02", "2027-02-14"));
        datePairs.add(new Pair<String, String>("2083-11-03", "2027-02-15"));
        datePairs.add(new Pair<String, String>("2083-11-04", "2027-02-16"));
        datePairs.add(new Pair<String, String>("2083-11-05", "2027-02-17"));
        datePairs.add(new Pair<String, String>("2083-11-06", "2027-02-18"));
        datePairs.add(new Pair<String, String>("2083-11-07", "2027-02-19"));
        datePairs.add(new Pair<String, String>("2083-11-08", "2027-02-20"));
        datePairs.add(new Pair<String, String>("2083-11-09", "2027-02-21"));
        datePairs.add(new Pair<String, String>("2083-11-10", "2027-02-22"));
        datePairs.add(new Pair<String, String>("2083-11-11", "2027-02-23"));
        datePairs.add(new Pair<String, String>("2083-11-12", "2027-02-24"));
        datePairs.add(new Pair<String, String>("2083-11-13", "2027-02-25"));
        datePairs.add(new Pair<String, String>("2083-11-14", "2027-02-26"));
        datePairs.add(new Pair<String, String>("2083-11-15", "2027-02-27"));
        datePairs.add(new Pair<String, String>("2083-11-16", "2027-02-28"));
        datePairs.add(new Pair<String, String>("2083-11-17", "2027-03-01"));
        datePairs.add(new Pair<String, String>("2083-11-18", "2027-03-02"));
        datePairs.add(new Pair<String, String>("2083-11-19", "2027-03-03"));
        datePairs.add(new Pair<String, String>("2083-11-20", "2027-03-04"));
        datePairs.add(new Pair<String, String>("2083-11-21", "2027-03-05"));
        datePairs.add(new Pair<String, String>("2083-11-22", "2027-03-06"));
        datePairs.add(new Pair<String, String>("2083-11-23", "2027-03-07"));
        datePairs.add(new Pair<String, String>("2083-11-24", "2027-03-08"));
        datePairs.add(new Pair<String, String>("2083-11-25", "2027-03-09"));
        datePairs.add(new Pair<String, String>("2083-11-26", "2027-03-10"));
        datePairs.add(new Pair<String, String>("2083-11-27", "2027-03-11"));
        datePairs.add(new Pair<String, String>("2083-11-28", "2027-03-12"));
        datePairs.add(new Pair<String, String>("2083-11-29", "2027-03-13"));
        datePairs.add(new Pair<String, String>("2083-11-30", "2027-03-14"));
        datePairs.add(new Pair<String, String>("2083-12-01", "2027-03-15"));
        datePairs.add(new Pair<String, String>("2083-12-02", "2027-03-16"));
        datePairs.add(new Pair<String, String>("2083-12-03", "2027-03-17"));
        datePairs.add(new Pair<String, String>("2083-12-04", "2027-03-18"));
        datePairs.add(new Pair<String, String>("2083-12-05", "2027-03-19"));
        datePairs.add(new Pair<String, String>("2083-12-06", "2027-03-20"));
        datePairs.add(new Pair<String, String>("2083-12-07", "2027-03-21"));
        datePairs.add(new Pair<String, String>("2083-12-08", "2027-03-22"));
        datePairs.add(new Pair<String, String>("2083-12-09", "2027-03-23"));
        datePairs.add(new Pair<String, String>("2083-12-10", "2027-03-24"));
    }

    public void setUp() {
        appendConversionValues1();
        appendConversionValues2();
        appendConversionValues3();
        appendConversionValues4();
    }

    public void testConversion() {
       for (Pair<String, String> datePair : datePairs) {
            String nepali = datePair.a;
            String english = datePair.b;
            // Convert nepali to english
            {
                Date<Bs> n = new Date<Bs>(nepali, bs);
                Date<Ad> e = n.convertTo(ad);
                assertEquals(e.toString(), english.toString());
            }
            // Convert english to nepali
            {
                Date<Ad> e = new Date<Ad>(english, ad);
                Date<Bs> n = e.convertTo(bs);
                assertEquals(n.toString(), nepali.toString());
            }
        }
    }
}
